---
datatable: true
---



# OrNetStats

Tor network data as of: **2025-01-24 14:00 UTC**

OrNetStats provides statistics and network health data about the Tor network and it's relay groups (families).

With OrNetStats we aim to answer questions about the Tor network, for example:

* Who are the largest relay groups on the network in each position (exit, guard)?
* How did their fraction of the network evolve over time and when did they join the network?
* What Autonomous System make up the largest fractions of the Tor network?
* What relay groups have potential MyFamily misconfigurations?
* What fraction of the network is running end-of-life tor releases?
* What relay groups potentially pose a risk to Tor users (end-to-end correlation)?

On a relay level OrNetStats
shows the usual information similar to Relay Search, but it has also indicators
like the warning icon when a relay runs a vulnerable tor versions.

**The list of relays can be found [here](w).**

## Authenticated Relay Operator IDs

A Tor relay's ContactInfo is an arbitrary string which can be freely choosen by the relay operator,
unfortunatelly this allows malicious entities to impersonate other relay operators by using their ContactInfo.
This has been exploited in the wild already.

Since Tor relay ContactInfos are unverified strings, OrNetStats aims to display the
**Authenticated Relay Operator ID (AROI)** instead, when possible.
Unlike the torrc ContactInfo, an AROI is authenticated and can not be spoofed
without some control at the DNS or webserver level.

Relay operators can follow this short **[HowTo](aroi-setup)**
if they want to setup their AROI.

### Top 10 largest Exit Operators with an Authenticated Relay Operator ID (AROI)

<div>                        <script type="text/javascript">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>
        <script charset="utf-8" src="https://cdn.plot.ly/plotly-2.20.0.min.js"></script>                <div id="7ca70cdd-6d35-4303-b193-42ce725e4ed7" class="plotly-graph-div" style="height:100%; width:100%;"></div>            <script type="text/javascript">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("7ca70cdd-6d35-4303-b193-42ce725e4ed7")) {                    Plotly.newPlot(                        "7ca70cdd-6d35-4303-b193-42ce725e4ed7",                        [{"alignmentgroup":"True","hovertemplate":"Exit Probability (%)=%{marker.color}<br>Authenticated Relay Operator Identifier=%{y}<extra></extra>","legendgroup":"","marker":{"color":[19.91,12.76,8.09,7.68,4.36,3.43,3.33,3.23,2.74,2.64],"coloraxis":"coloraxis","pattern":{"shape":""}},"name":"","offsetgroup":"","orientation":"h","showlegend":false,"textposition":"auto","x":[19.91,12.76,8.09,7.68,4.36,3.43,3.33,3.23,2.74,2.64],"xaxis":"x","y":["nothingtohide.nl","artikel10.org","quetzalcoatl-relays.org","applied-privacy.net","www.f3netze.de","digitalcourage.social","for-privacy.net","www.cccs.de","tor.r0cket.net","tuxli.org"],"yaxis":"y","type":"bar"}],                        {"template":{"data":{"histogram2dcontour":[{"type":"histogram2dcontour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"choropleth":[{"type":"choropleth","colorbar":{"outlinewidth":0,"ticks":""}}],"histogram2d":[{"type":"histogram2d","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmap":[{"type":"heatmap","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmapgl":[{"type":"heatmapgl","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"contourcarpet":[{"type":"contourcarpet","colorbar":{"outlinewidth":0,"ticks":""}}],"contour":[{"type":"contour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"surface":[{"type":"surface","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"mesh3d":[{"type":"mesh3d","colorbar":{"outlinewidth":0,"ticks":""}}],"scatter":[{"fillpattern":{"fillmode":"overlay","size":10,"solidity":0.2},"type":"scatter"}],"parcoords":[{"type":"parcoords","line":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolargl":[{"type":"scatterpolargl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"bar":[{"error_x":{"color":"#2a3f5f"},"error_y":{"color":"#2a3f5f"},"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"bar"}],"scattergeo":[{"type":"scattergeo","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolar":[{"type":"scatterpolar","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"histogram":[{"marker":{"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"histogram"}],"scattergl":[{"type":"scattergl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatter3d":[{"type":"scatter3d","line":{"colorbar":{"outlinewidth":0,"ticks":""}},"marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattermapbox":[{"type":"scattermapbox","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterternary":[{"type":"scatterternary","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattercarpet":[{"type":"scattercarpet","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"carpet":[{"aaxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"baxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"type":"carpet"}],"table":[{"cells":{"fill":{"color":"#EBF0F8"},"line":{"color":"white"}},"header":{"fill":{"color":"#C8D4E3"},"line":{"color":"white"}},"type":"table"}],"barpolar":[{"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"barpolar"}],"pie":[{"automargin":true,"type":"pie"}]},"layout":{"autotypenumbers":"strict","colorway":["#636efa","#EF553B","#00cc96","#ab63fa","#FFA15A","#19d3f3","#FF6692","#B6E880","#FF97FF","#FECB52"],"font":{"color":"#2a3f5f"},"hovermode":"closest","hoverlabel":{"align":"left"},"paper_bgcolor":"white","plot_bgcolor":"#E5ECF6","polar":{"bgcolor":"#E5ECF6","angularaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"radialaxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"ternary":{"bgcolor":"#E5ECF6","aaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"baxis":{"gridcolor":"white","linecolor":"white","ticks":""},"caxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"coloraxis":{"colorbar":{"outlinewidth":0,"ticks":""}},"colorscale":{"sequential":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"sequentialminus":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"diverging":[[0,"#8e0152"],[0.1,"#c51b7d"],[0.2,"#de77ae"],[0.3,"#f1b6da"],[0.4,"#fde0ef"],[0.5,"#f7f7f7"],[0.6,"#e6f5d0"],[0.7,"#b8e186"],[0.8,"#7fbc41"],[0.9,"#4d9221"],[1,"#276419"]]},"xaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"yaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"scene":{"xaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"yaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"zaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2}},"shapedefaults":{"line":{"color":"#2a3f5f"}},"annotationdefaults":{"arrowcolor":"#2a3f5f","arrowhead":0,"arrowwidth":1},"geo":{"bgcolor":"white","landcolor":"#E5ECF6","subunitcolor":"white","showland":true,"showlakes":true,"lakecolor":"white"},"title":{"x":0.05},"mapbox":{"style":"light"}}},"xaxis":{"anchor":"y","domain":[0.0,1.0],"title":{"text":"Exit Probability (%)"},"ticksuffix":"%"},"yaxis":{"anchor":"x","domain":[0.0,1.0],"title":{"text":"Authenticated Relay Operator Identifier"},"categoryorder":"array","categoryarray":["tuxli.org","tor.r0cket.net","www.cccs.de","for-privacy.net","digitalcourage.social","www.f3netze.de","applied-privacy.net","quetzalcoatl-relays.org","artikel10.org","nothingtohide.nl"]},"coloraxis":{"colorbar":{"title":{"text":"Exit Probability (%)"}},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]},"legend":{"tracegroupgap":0},"margin":{"t":60},"barmode":"relative"},                        {"responsive": true}                    )                };                            </script>        </div>

### Exit Probability by AROI over Time

This graph is limited to operators that had an exit probability greater than 1% today.

<div>                        <script type="text/javascript">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>
        <script charset="utf-8" src="https://cdn.plot.ly/plotly-2.20.0.min.js"></script>                <div id="fdf8030e-a430-4922-a173-163dd05b2444" class="plotly-graph-div" style="height:100%; width:100%;"></div>            <script type="text/javascript">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("fdf8030e-a430-4922-a173-163dd05b2444")) {                    Plotly.newPlot(                        "fdf8030e-a430-4922-a173-163dd05b2444",                        [{"hovertemplate":"AROI=applied-privacy.net<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"applied-privacy.net","line":{"color":"#636efa","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"applied-privacy.net","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[5.27,5.27,5.22,5.21,5.18,5.14,5.23,5.29,5.2,5.37,5.37,5.37,5.35,5.34,5.45,5.48,5.54,5.56,5.55,5.54,5.51,5.65,5.66,5.64,5.67,5.68,5.69,5.76,5.89,5.79,6.03,6.2,6.27,6.18,6.27,6.42,6.56,6.64,6.68,6.76,6.77,6.85,6.96,7.17,7.01,7.14,7.19,7.21,7.24,7.25,7.41,7.37,7.41,7.36,7.35,7.21,7.09,6.9,6.82,6.87,7.14,7.0,7.15,7.14,7.11,7.23,7.26,7.23,7.14,7.23,7.38,7.33,7.55,7.55,7.52,7.45,7.5,7.46,7.43,7.45,7.54,7.61,7.61,7.55,7.52,7.58,7.66,7.61,7.67,7.68],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=artikel10.org<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"artikel10.org","line":{"color":"#EF553B","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"artikel10.org","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[10.12,10.12,10.32,10.48,10.66,10.46,11.47,10.71,10.6,10.82,10.68,10.68,10.8,10.74,10.89,10.95,11.25,11.09,11.01,11.03,11.06,11.21,11.18,11.03,11.03,10.96,10.87,10.88,10.99,11.0,11.13,11.19,11.27,11.38,11.47,11.36,11.63,11.65,11.64,11.69,11.68,11.72,11.8,3.7,11.74,11.79,11.83,11.92,11.93,11.95,12.24,12.37,12.37,12.16,12.16,12.05,11.92,11.89,11.88,11.97,12.37,12.21,12.55,12.5,12.49,12.78,12.87,12.91,12.91,13.12,13.41,13.35,13.02,13.03,12.99,13.0,13.03,12.93,13.0,13.03,12.94,12.83,12.66,12.61,12.59,12.52,12.75,12.7,12.71,12.76],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=dfri.se<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"dfri.se","line":{"color":"#00cc96","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"dfri.se","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[1.1,1.1,1.07,1.05,1.07,1.06,1.11,1.09,1.06,1.09,1.09,1.08,1.04,1.03,1.03,1.03,1.02,1.03,1.02,1.01,0.99,0.99,0.97,0.96,0.99,1.01,1.01,1.0,1.01,1.01,0.99,0.99,1.02,1.05,1.05,1.05,1.06,1.04,1.01,1.02,1.03,1.03,1.04,1.15,1.01,1.02,1.03,1.04,1.03,1.04,1.1,1.05,1.06,1.05,1.05,1.05,1.05,1.04,1.04,1.02,1.09,1.03,1.0,1.03,0.98,1.02,1.01,1.01,1.01,1.01,1.06,1.03,1.02,1.02,1.04,1.05,1.06,1.11,1.1,1.1,1.1,1.12,1.13,1.13,1.16,1.2,1.19,1.18,1.19,1.17],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=digitalcourage.social<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"digitalcourage.social","line":{"color":"#ab63fa","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"digitalcourage.social","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[2.77,2.77,2.77,2.85,2.79,2.85,null,null,2.89,2.88,2.91,2.95,2.95,2.99,3.02,3.04,3.05,3.08,3.1,3.19,3.23,3.34,3.3,3.34,3.36,3.35,3.27,3.26,3.31,3.28,3.27,3.22,3.24,2.99,2.96,3.08,3.11,3.08,3.13,3.09,3.11,3.09,3.13,3.58,3.22,3.31,3.32,3.26,3.23,3.21,3.36,3.17,3.26,3.15,3.14,3.32,3.33,3.16,3.16,3.1,3.33,3.12,0.02,0.02,2.94,2.97,2.96,2.84,2.79,2.81,2.9,2.89,3.14,3.13,3.17,3.22,3.41,3.51,3.62,3.66,3.76,3.16,3.22,3.26,3.3,3.38,3.39,3.43,3.47,3.43],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=for-privacy.net<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"for-privacy.net","line":{"color":"#FFA15A","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"for-privacy.net","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[4.02,4.05,4.06,3.99,4.04,4.02,4.07,4.09,4.03,4.2,4.28,4.29,4.31,4.22,4.19,4.21,4.1,4.23,4.19,4.14,4.11,4.09,4.04,4.01,4.12,4.2,4.22,4.24,4.3,4.32,4.23,4.18,4.16,4.06,4.01,4.04,4.02,4.06,3.99,3.96,3.96,3.93,3.86,4.26,3.77,3.83,3.8,3.8,3.78,3.76,3.99,3.77,3.83,3.78,3.75,3.82,3.84,3.71,3.74,3.71,4.02,3.82,3.69,3.68,3.5,3.6,3.57,3.49,3.36,3.34,3.46,3.29,3.4,3.39,3.38,3.37,3.31,3.33,3.3,3.3,3.28,3.28,3.3,3.34,3.32,3.37,3.36,3.36,3.36,3.33],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=nos-oignons.net<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"nos-oignons.net","line":{"color":"#19d3f3","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"nos-oignons.net","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[1.83,1.83,1.79,1.71,1.78,1.8,1.88,1.87,1.78,1.86,1.87,1.87,1.85,1.82,1.82,1.81,1.79,1.85,1.86,1.83,1.79,1.82,1.82,1.82,1.87,1.88,1.86,1.9,1.88,1.88,1.8,1.8,1.84,1.84,1.88,1.87,1.89,1.9,1.88,1.91,1.93,1.91,1.93,2.14,1.87,1.91,1.91,1.9,1.89,1.9,2.0,1.86,1.88,1.86,1.87,1.89,1.94,2.0,2.0,1.96,2.2,2.13,2.11,2.12,2.0,2.06,2.1,2.03,1.98,1.94,2.0,1.91,1.91,1.91,1.91,1.89,1.86,1.85,1.82,1.8,1.8,1.8,1.81,1.83,1.84,1.88,1.83,1.82,1.83,1.84],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=nothingtohide.nl<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"nothingtohide.nl","line":{"color":"#FF6692","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"nothingtohide.nl","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[17.54,17.59,17.56,18.02,17.8,17.63,17.94,18.12,17.76,18.23,18.42,18.44,18.15,18.18,18.21,18.26,18.21,18.56,18.8,19.31,19.35,19.76,19.69,19.56,19.81,19.72,19.52,19.45,19.38,19.39,19.31,19.33,19.27,18.03,18.0,18.96,18.96,18.8,18.53,18.45,18.34,18.32,18.34,19.46,18.3,18.43,18.55,18.59,18.68,18.87,19.53,19.12,19.52,19.33,19.24,19.12,19.07,17.89,18.01,18.12,19.03,18.51,18.37,18.22,17.69,17.95,17.9,17.74,17.61,17.68,18.04,17.8,18.92,18.88,18.92,18.84,18.96,19.04,19.14,19.24,19.34,19.46,19.54,19.47,19.39,19.62,19.73,19.82,19.92,19.91],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=quetzalcoatl-relays.org<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"quetzalcoatl-relays.org","line":{"color":"#B6E880","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"quetzalcoatl-relays.org","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[9.85,9.69,9.34,8.95,8.86,8.81,8.9,8.95,8.41,8.64,8.48,8.47,8.56,8.79,9.06,9.18,9.13,9.3,9.18,8.97,8.94,9.0,8.94,8.9,9.13,9.19,9.22,9.26,9.38,9.5,9.43,9.51,9.45,9.64,9.43,9.39,9.51,9.56,9.38,9.32,9.26,9.19,9.11,9.93,8.76,8.9,8.87,8.83,8.82,8.8,9.31,8.75,8.82,8.37,8.54,8.5,8.44,8.57,8.61,8.55,9.42,9.0,8.78,8.87,8.22,8.68,8.68,7.9,8.26,8.17,8.38,8.28,8.27,8.28,8.34,8.29,8.06,7.96,7.97,7.98,8.07,8.18,8.34,8.29,8.33,8.44,8.34,8.22,8.22,8.09],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=tor.r0cket.net<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"tor.r0cket.net","line":{"color":"#FF97FF","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"tor.r0cket.net","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[0.57,0.57,0.56,0.54,0.56,0.48,0.48,0.49,0.47,0.48,0.49,0.48,0.47,0.46,0.46,0.46,0.45,0.47,0.63,0.65,0.69,0.71,0.78,0.86,0.94,1.0,1.07,1.08,1.19,1.24,1.28,1.28,1.31,1.37,1.39,1.43,1.44,1.44,1.47,1.49,1.48,1.47,1.49,1.71,1.54,1.57,1.6,1.66,1.63,1.66,1.77,1.61,null,1.78,1.76,1.71,1.65,1.53,1.2,1.07,1.07,1.01,1.0,0.94,0.92,0.91,0.88,0.88,0.85,0.84,0.75,0.81,0.9,1.03,1.13,1.19,1.22,1.24,1.29,1.33,1.37,1.51,1.56,1.6,1.62,1.7,1.78,2.16,2.61,2.74],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=tuxli.org<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"tuxli.org","line":{"color":"#FECB52","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"tuxli.org","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[2.28,2.29,2.27,2.22,2.28,2.26,2.35,2.4,2.29,2.38,2.37,2.34,2.31,2.27,2.28,2.28,2.23,2.3,2.26,2.25,2.22,2.22,2.19,2.18,2.23,2.26,2.29,2.3,2.31,2.29,2.25,2.22,2.24,2.31,2.29,2.19,2.18,2.18,2.13,2.15,2.13,2.15,1.82,2.43,2.18,2.21,2.2,2.29,2.27,2.29,2.43,2.39,2.41,2.41,2.43,2.46,2.48,2.49,2.5,2.49,2.71,2.59,2.49,2.48,2.37,2.47,2.48,2.44,2.39,2.36,2.45,2.36,2.35,2.36,2.39,2.37,2.35,2.36,2.38,2.38,2.41,2.45,2.49,2.72,2.73,2.77,2.74,2.67,2.67,2.64],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=www.cccs.de<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"www.cccs.de","line":{"color":"#636efa","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"www.cccs.de","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[4.46,4.42,4.5,4.38,4.44,4.44,4.63,4.78,4.6,4.87,4.94,4.91,4.83,4.86,4.8,4.78,4.74,4.84,4.77,4.79,5.05,5.12,5.12,5.17,5.39,5.52,5.58,5.56,5.58,5.37,5.28,5.25,5.25,4.99,4.9,4.93,4.88,4.92,4.85,4.83,4.85,4.8,4.85,5.48,4.85,4.9,4.87,4.75,4.72,4.7,4.98,4.62,4.74,4.66,4.66,4.74,4.77,4.53,4.5,4.42,4.87,4.64,4.51,4.54,4.23,4.34,4.27,4.13,3.95,3.88,4.03,3.87,4.1,4.14,4.22,4.15,4.12,4.17,4.2,4.14,4.1,4.14,4.12,4.05,4.09,3.18,3.17,3.21,3.23,3.23],"yaxis":"y","type":"scattergl"},{"hovertemplate":"AROI=www.f3netze.de<br>date=%{x}<br>exit_probability=%{y}<extra></extra>","legendgroup":"www.f3netze.de","line":{"color":"#EF553B","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"www.f3netze.de","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[4.26,4.35,4.4,4.51,4.25,4.24,4.27,4.38,4.23,4.38,4.45,4.5,4.43,4.37,4.26,4.22,4.24,4.46,4.49,4.36,4.49,4.56,4.62,4.62,4.72,4.81,4.92,4.95,4.89,4.82,4.71,4.7,4.7,5.99,5.97,4.85,4.83,4.76,4.62,4.65,4.59,4.48,4.41,4.88,4.43,4.45,4.44,4.31,4.23,4.16,null,4.05,4.13,4.0,3.98,3.92,3.87,5.66,5.64,5.87,null,3.52,7.47,7.38,7.31,4.87,4.86,6.59,7.65,7.69,5.1,7.15,5.65,5.63,5.47,5.41,5.31,5.18,4.93,4.98,4.98,5.11,5.11,5.03,5.02,4.69,4.64,4.58,4.54,4.36],"yaxis":"y","type":"scattergl"}],                        {"template":{"data":{"histogram2dcontour":[{"type":"histogram2dcontour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"choropleth":[{"type":"choropleth","colorbar":{"outlinewidth":0,"ticks":""}}],"histogram2d":[{"type":"histogram2d","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmap":[{"type":"heatmap","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmapgl":[{"type":"heatmapgl","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"contourcarpet":[{"type":"contourcarpet","colorbar":{"outlinewidth":0,"ticks":""}}],"contour":[{"type":"contour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"surface":[{"type":"surface","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"mesh3d":[{"type":"mesh3d","colorbar":{"outlinewidth":0,"ticks":""}}],"scatter":[{"fillpattern":{"fillmode":"overlay","size":10,"solidity":0.2},"type":"scatter"}],"parcoords":[{"type":"parcoords","line":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolargl":[{"type":"scatterpolargl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"bar":[{"error_x":{"color":"#2a3f5f"},"error_y":{"color":"#2a3f5f"},"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"bar"}],"scattergeo":[{"type":"scattergeo","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolar":[{"type":"scatterpolar","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"histogram":[{"marker":{"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"histogram"}],"scattergl":[{"type":"scattergl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatter3d":[{"type":"scatter3d","line":{"colorbar":{"outlinewidth":0,"ticks":""}},"marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattermapbox":[{"type":"scattermapbox","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterternary":[{"type":"scatterternary","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattercarpet":[{"type":"scattercarpet","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"carpet":[{"aaxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"baxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"type":"carpet"}],"table":[{"cells":{"fill":{"color":"#EBF0F8"},"line":{"color":"white"}},"header":{"fill":{"color":"#C8D4E3"},"line":{"color":"white"}},"type":"table"}],"barpolar":[{"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"barpolar"}],"pie":[{"automargin":true,"type":"pie"}]},"layout":{"autotypenumbers":"strict","colorway":["#636efa","#EF553B","#00cc96","#ab63fa","#FFA15A","#19d3f3","#FF6692","#B6E880","#FF97FF","#FECB52"],"font":{"color":"#2a3f5f"},"hovermode":"closest","hoverlabel":{"align":"left"},"paper_bgcolor":"white","plot_bgcolor":"#E5ECF6","polar":{"bgcolor":"#E5ECF6","angularaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"radialaxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"ternary":{"bgcolor":"#E5ECF6","aaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"baxis":{"gridcolor":"white","linecolor":"white","ticks":""},"caxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"coloraxis":{"colorbar":{"outlinewidth":0,"ticks":""}},"colorscale":{"sequential":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"sequentialminus":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"diverging":[[0,"#8e0152"],[0.1,"#c51b7d"],[0.2,"#de77ae"],[0.3,"#f1b6da"],[0.4,"#fde0ef"],[0.5,"#f7f7f7"],[0.6,"#e6f5d0"],[0.7,"#b8e186"],[0.8,"#7fbc41"],[0.9,"#4d9221"],[1,"#276419"]]},"xaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"yaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"scene":{"xaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"yaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"zaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2}},"shapedefaults":{"line":{"color":"#2a3f5f"}},"annotationdefaults":{"arrowcolor":"#2a3f5f","arrowhead":0,"arrowwidth":1},"geo":{"bgcolor":"white","landcolor":"#E5ECF6","subunitcolor":"white","showland":true,"showlakes":true,"lakecolor":"white"},"title":{"x":0.05},"mapbox":{"style":"light"}}},"xaxis":{"anchor":"y","domain":[0.0,1.0],"title":{"text":"date"}},"yaxis":{"anchor":"x","domain":[0.0,1.0],"title":{"text":"exit_probability"},"ticksuffix":"%"},"legend":{"title":{"text":"AROI"},"tracegroupgap":0},"margin":{"t":60}},                        {"responsive": true}                    )                };                            </script>        </div>

### Top 10 largest Guard Operators with an Authenticated Relay Operator ID (AROI)

<div>                        <script type="text/javascript">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>
        <script charset="utf-8" src="https://cdn.plot.ly/plotly-2.20.0.min.js"></script>                <div id="bfd7d19f-3871-46d8-b6c4-c644ea957e19" class="plotly-graph-div" style="height:100%; width:100%;"></div>            <script type="text/javascript">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("bfd7d19f-3871-46d8-b6c4-c644ea957e19")) {                    Plotly.newPlot(                        "bfd7d19f-3871-46d8-b6c4-c644ea957e19",                        [{"alignmentgroup":"True","hovertemplate":"Guard Probability (%)=%{marker.color}<br>Authenticated Relay Operator Identifier=%{y}<extra></extra>","legendgroup":"","marker":{"color":[2.55,1.89,1.35,0.73,0.46,0.43,0.39,0.3,0.27,0.25],"coloraxis":"coloraxis","pattern":{"shape":""}},"name":"","offsetgroup":"","orientation":"h","showlegend":false,"textposition":"auto","x":[2.55,1.89,1.35,0.73,0.46,0.43,0.39,0.3,0.27,0.25],"xaxis":"x","y":["tuxli.org","for-privacy.net","nothingtohide.nl","ftp.halifax.rwth-aachen.de","limoneneis.de","gojira-family.dedyn.io","shadowbrokers.eu","zwiebeltoralf.de","axstet.de","arbitrary.ch"],"yaxis":"y","type":"bar"}],                        {"template":{"data":{"histogram2dcontour":[{"type":"histogram2dcontour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"choropleth":[{"type":"choropleth","colorbar":{"outlinewidth":0,"ticks":""}}],"histogram2d":[{"type":"histogram2d","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmap":[{"type":"heatmap","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmapgl":[{"type":"heatmapgl","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"contourcarpet":[{"type":"contourcarpet","colorbar":{"outlinewidth":0,"ticks":""}}],"contour":[{"type":"contour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"surface":[{"type":"surface","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"mesh3d":[{"type":"mesh3d","colorbar":{"outlinewidth":0,"ticks":""}}],"scatter":[{"fillpattern":{"fillmode":"overlay","size":10,"solidity":0.2},"type":"scatter"}],"parcoords":[{"type":"parcoords","line":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolargl":[{"type":"scatterpolargl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"bar":[{"error_x":{"color":"#2a3f5f"},"error_y":{"color":"#2a3f5f"},"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"bar"}],"scattergeo":[{"type":"scattergeo","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolar":[{"type":"scatterpolar","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"histogram":[{"marker":{"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"histogram"}],"scattergl":[{"type":"scattergl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatter3d":[{"type":"scatter3d","line":{"colorbar":{"outlinewidth":0,"ticks":""}},"marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattermapbox":[{"type":"scattermapbox","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterternary":[{"type":"scatterternary","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattercarpet":[{"type":"scattercarpet","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"carpet":[{"aaxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"baxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"type":"carpet"}],"table":[{"cells":{"fill":{"color":"#EBF0F8"},"line":{"color":"white"}},"header":{"fill":{"color":"#C8D4E3"},"line":{"color":"white"}},"type":"table"}],"barpolar":[{"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"barpolar"}],"pie":[{"automargin":true,"type":"pie"}]},"layout":{"autotypenumbers":"strict","colorway":["#636efa","#EF553B","#00cc96","#ab63fa","#FFA15A","#19d3f3","#FF6692","#B6E880","#FF97FF","#FECB52"],"font":{"color":"#2a3f5f"},"hovermode":"closest","hoverlabel":{"align":"left"},"paper_bgcolor":"white","plot_bgcolor":"#E5ECF6","polar":{"bgcolor":"#E5ECF6","angularaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"radialaxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"ternary":{"bgcolor":"#E5ECF6","aaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"baxis":{"gridcolor":"white","linecolor":"white","ticks":""},"caxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"coloraxis":{"colorbar":{"outlinewidth":0,"ticks":""}},"colorscale":{"sequential":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"sequentialminus":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"diverging":[[0,"#8e0152"],[0.1,"#c51b7d"],[0.2,"#de77ae"],[0.3,"#f1b6da"],[0.4,"#fde0ef"],[0.5,"#f7f7f7"],[0.6,"#e6f5d0"],[0.7,"#b8e186"],[0.8,"#7fbc41"],[0.9,"#4d9221"],[1,"#276419"]]},"xaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"yaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"scene":{"xaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"yaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"zaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2}},"shapedefaults":{"line":{"color":"#2a3f5f"}},"annotationdefaults":{"arrowcolor":"#2a3f5f","arrowhead":0,"arrowwidth":1},"geo":{"bgcolor":"white","landcolor":"#E5ECF6","subunitcolor":"white","showland":true,"showlakes":true,"lakecolor":"white"},"title":{"x":0.05},"mapbox":{"style":"light"}}},"xaxis":{"anchor":"y","domain":[0.0,1.0],"title":{"text":"Guard Probability (%)"},"ticksuffix":"%"},"yaxis":{"anchor":"x","domain":[0.0,1.0],"title":{"text":"Authenticated Relay Operator Identifier"},"categoryorder":"array","categoryarray":["arbitrary.ch","axstet.de","zwiebeltoralf.de","shadowbrokers.eu","gojira-family.dedyn.io","limoneneis.de","ftp.halifax.rwth-aachen.de","nothingtohide.nl","for-privacy.net","tuxli.org"]},"coloraxis":{"colorbar":{"title":{"text":"Guard Probability (%)"}},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]},"legend":{"tracegroupgap":0},"margin":{"t":60},"barmode":"relative"},                        {"responsive": true}                    )                };                            </script>        </div>

### Guard Probability by AROI over Time

This graph is limited to operators that had a guard probability greater than 0.4% today.

<div>                        <script type="text/javascript">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>
        <script charset="utf-8" src="https://cdn.plot.ly/plotly-2.20.0.min.js"></script>                <div id="2e551705-513f-4299-9a91-3787345a0b3a" class="plotly-graph-div" style="height:100%; width:100%;"></div>            <script type="text/javascript">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("2e551705-513f-4299-9a91-3787345a0b3a")) {                    Plotly.newPlot(                        "2e551705-513f-4299-9a91-3787345a0b3a",                        [{"hovertemplate":"AROI=for-privacy.net<br>date=%{x}<br>guard_probability=%{y}<extra></extra>","legendgroup":"for-privacy.net","line":{"color":"#636efa","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"for-privacy.net","orientation":"v","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[2.04,2.03,2.04,1.99,2.08,2.06,2.04,2.01,2.03,2.02,2.0,2.01,2.05,2.07,2.08,2.13,2.18,2.07,2.06,2.04,2.01,2.03,2.0,2.01,1.98,1.95,1.91,1.9,1.88,1.82,2.0,2.09,2.1,2.09,2.08,2.18,2.22,2.2,2.21,2.2,2.14,2.2,2.18,2.03,2.15,2.14,2.23,2.2,2.18,2.15,2.12,2.21,2.17,2.12,2.07,2.0,2.0,1.92,1.91,1.95,1.9,1.94,2.07,2.03,2.09,2.03,2.04,2.06,2.04,2.03,2.03,2.09,2.2,2.23,2.22,2.23,2.24,2.22,2.18,2.18,2.2,2.2,2.16,2.17,2.18,2.16,2.2,2.23,2.2,2.23],"yaxis":"y","type":"scatter"},{"hovertemplate":"AROI=ftp.halifax.rwth-aachen.de<br>date=%{x}<br>guard_probability=%{y}<extra></extra>","legendgroup":"ftp.halifax.rwth-aachen.de","line":{"color":"#EF553B","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"ftp.halifax.rwth-aachen.de","orientation":"v","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[0.01,0.01,0.01,0.0,0.01,0.01,0.01,0.01,0.01,0.01,0.01,0.01,0.0,0.0,0.0,0.0,0.01,0.01,0.01,0.01,0.01,0.01,0.01,0.01,0.0,0.0,0.01,0.01,1.11,1.01,1.03,1.03,0.97,0.99,0.81,0.7,0.65,0.64,0.6,0.6,0.56,0.5,0.5,0.49,0.5,0.52,0.58,0.61,0.6,0.61,0.62,0.6,0.61,0.61,0.62,0.7,0.71,0.75,0.74,0.8,0.8,0.8,0.86,0.88,0.87,0.89,0.91,0.86,0.87,0.82,0.76,0.72,0.73,0.78,0.76,0.75,0.74,0.75,0.71,0.7,0.76,0.76,0.74,0.74,0.72,0.72,0.73,0.73,0.72,0.73],"yaxis":"y","type":"scatter"},{"hovertemplate":"AROI=gojira-family.dedyn.io<br>date=%{x}<br>guard_probability=%{y}<extra></extra>","legendgroup":"gojira-family.dedyn.io","line":{"color":"#00cc96","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"gojira-family.dedyn.io","orientation":"v","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[0.38,0.38,0.38,0.41,0.41,0.41,0.39,0.38,0.36,0.32,0.29,0.29,0.36,0.37,0.4,0.41,0.41,0.44,0.45,0.45,0.44,0.45,0.44,0.45,0.46,0.44,0.43,0.41,0.41,0.4,0.41,0.42,0.4,0.38,0.36,0.36,0.35,0.32,0.32,0.32,0.32,0.34,0.38,0.4,0.41,0.43,0.47,0.47,0.47,0.48,0.5,0.48,0.46,0.46,0.44,0.44,0.44,0.44,0.44,0.43,0.45,0.44,0.45,0.44,0.4,0.37,0.37,0.37,0.35,0.34,0.31,0.31,0.32,0.35,0.38,0.4,0.39,0.4,0.41,0.4,0.41,0.41,0.41,0.41,0.42,0.41,0.43,0.44,0.44,0.43],"yaxis":"y","type":"scatter"},{"hovertemplate":"AROI=limoneneis.de<br>date=%{x}<br>guard_probability=%{y}<extra></extra>","legendgroup":"limoneneis.de","line":{"color":"#ab63fa","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"limoneneis.de","orientation":"v","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[0.43,0.43,0.43,0.51,0.49,0.51,0.52,0.53,0.53,0.53,0.51,0.51,0.51,0.51,0.52,0.55,0.54,0.56,0.55,0.54,0.53,0.53,0.52,0.54,0.55,0.57,0.58,0.6,0.57,0.54,0.53,0.55,0.54,0.55,0.56,0.54,0.56,0.58,0.59,0.6,0.58,0.59,0.58,0.57,0.57,0.58,0.62,0.62,0.59,0.61,0.63,0.6,0.6,0.59,0.59,0.6,0.62,0.62,0.63,0.64,0.62,0.6,0.61,0.61,0.58,0.58,0.52,0.51,0.53,0.49,0.5,0.5,0.5,0.52,0.51,0.52,0.52,0.53,0.51,0.5,0.48,0.46,0.47,0.46,0.49,0.48,0.45,0.45,0.46,0.46],"yaxis":"y","type":"scatter"},{"hovertemplate":"AROI=nothingtohide.nl<br>date=%{x}<br>guard_probability=%{y}<extra></extra>","legendgroup":"nothingtohide.nl","line":{"color":"#FFA15A","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"nothingtohide.nl","orientation":"v","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[1.37,1.38,1.44,1.59,1.62,1.64,1.62,1.66,1.74,1.68,1.68,1.64,1.64,1.68,1.69,1.76,1.81,1.77,1.82,1.87,1.88,1.95,1.95,1.92,1.87,1.82,1.79,1.76,1.7,1.7,1.75,1.83,1.82,1.76,1.87,1.92,1.95,1.96,1.99,2.0,1.94,1.98,1.97,1.72,1.98,1.92,1.81,1.78,1.88,1.93,1.86,2.06,2.02,2.04,2.0,1.91,1.85,1.69,1.68,1.73,1.56,1.65,1.79,1.72,1.86,1.83,1.84,1.92,1.97,2.07,2.05,2.18,2.3,2.3,2.22,2.19,2.17,2.11,2.07,2.03,2.05,2.02,1.94,1.94,1.95,1.91,1.94,1.97,1.96,1.99],"yaxis":"y","type":"scatter"},{"hovertemplate":"AROI=quetzalcoatl-relays.org<br>date=%{x}<br>guard_probability=%{y}<extra></extra>","legendgroup":"quetzalcoatl-relays.org","line":{"color":"#19d3f3","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"quetzalcoatl-relays.org","orientation":"v","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[0.01,0.01,0.08,0.07,0.17,0.11,0.01,0.0,0.1,0.04,0.04,0.05,0.08,0.11,0.15,0.16,0.25,0.12,0.14,0.19,0.2,0.25,0.26,0.21,0.11,0.04,0.0,0.0,0.0,0.0,0.12,0.22,0.19,0.07,0.09,0.22,0.28,0.26,0.31,0.33,0.32,0.41,0.42,0.06,0.51,0.46,0.49,0.48,0.49,0.46,0.31,0.55,0.47,0.46,0.43,0.34,0.28,0.14,0.14,0.23,0.0,0.12,0.29,0.25,0.44,0.34,0.37,0.43,0.53,0.62,0.52,0.66,0.76,0.75,0.71,0.73,0.79,0.79,0.81,0.82,0.86,0.83,0.77,0.76,0.76,0.72,0.81,0.81,0.81,0.84],"yaxis":"y","type":"scatter"},{"hovertemplate":"AROI=tuxli.org<br>date=%{x}<br>guard_probability=%{y}<extra></extra>","legendgroup":"tuxli.org","line":{"color":"#FF6692","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"tuxli.org","orientation":"v","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2024-12-28","2024-12-29","2024-12-30","2024-12-31","2025-01-01","2025-01-02","2025-01-03","2025-01-04","2025-01-05","2025-01-06","2025-01-07","2025-01-08","2025-01-09","2025-01-10","2025-01-11","2025-01-12","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[2.04,2.04,2.05,2.05,2.17,2.17,2.16,2.25,2.35,2.4,2.4,2.4,2.49,2.48,2.46,2.52,2.59,2.58,2.69,2.66,2.7,2.78,2.73,2.74,2.74,2.75,2.72,2.72,2.78,2.79,2.85,2.91,2.94,2.86,2.78,2.89,2.87,2.91,3.03,2.62,2.86,2.88,2.87,2.83,2.79,2.75,2.84,2.82,2.78,2.73,2.74,2.72,2.76,2.8,2.88,2.86,2.82,2.81,2.75,2.72,2.6,2.62,2.7,2.66,2.7,2.64,2.63,2.63,2.59,2.59,2.54,2.6,2.75,2.74,2.76,2.81,2.84,2.81,2.82,2.83,2.9,2.88,2.88,2.75,2.77,2.77,2.83,2.82,2.77,2.82],"yaxis":"y","type":"scatter"},{"hovertemplate":"AROI=www.f3netze.de<br>date=%{x}<br>guard_probability=%{y}<extra></extra>","legendgroup":"www.f3netze.de","line":{"color":"#B6E880","dash":"solid"},"marker":{"symbol":"circle"},"mode":"lines","name":"www.f3netze.de","orientation":"v","showlegend":true,"x":["2024-10-27","2024-10-28","2024-10-29","2024-10-30","2024-10-31","2024-11-01","2024-11-02","2024-11-03","2024-11-04","2024-11-05","2024-11-06","2024-11-07","2024-11-08","2024-11-09","2024-11-10","2024-11-11","2024-11-12","2024-11-13","2024-11-14","2024-11-15","2024-11-16","2024-11-17","2024-11-18","2024-11-19","2024-11-20","2024-11-21","2024-11-22","2024-11-23","2024-11-24","2024-11-25","2024-11-26","2024-11-27","2024-11-28","2024-11-29","2024-11-30","2024-12-01","2024-12-02","2024-12-03","2024-12-04","2024-12-05","2024-12-06","2024-12-07","2024-12-08","2024-12-09","2024-12-10","2024-12-11","2024-12-12","2024-12-13","2024-12-14","2024-12-15","2024-12-16","2024-12-17","2024-12-18","2024-12-19","2024-12-20","2024-12-21","2024-12-22","2024-12-23","2024-12-24","2024-12-25","2024-12-26","2024-12-27","2025-01-05","2025-01-06","2025-01-13","2025-01-14","2025-01-15","2025-01-16","2025-01-17","2025-01-18","2025-01-19","2025-01-20","2025-01-21","2025-01-22","2025-01-23","2025-01-24"],"xaxis":"x","y":[0.0,0.0,0.04,0.03,0.08,0.06,0.0,0.0,0.05,0.02,0.02,0.03,0.04,0.06,0.07,0.08,0.12,0.06,0.07,0.1,0.11,0.13,0.14,0.12,0.06,0.02,0.0,0.0,0.0,0.0,0.06,0.11,0.09,0.04,0.05,0.11,0.14,0.13,0.16,0.17,0.16,0.2,0.2,0.03,0.26,0.23,0.25,0.23,0.23,0.22,null,0.26,0.22,0.22,0.2,0.15,0.12,0.09,0.09,0.16,null,null,null,0.18,0.13,0.14,0.14,0.14,0.13,0.12,0.12,0.25,0.28,0.28,0.35,0.45],"yaxis":"y","type":"scatter"}],                        {"template":{"data":{"histogram2dcontour":[{"type":"histogram2dcontour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"choropleth":[{"type":"choropleth","colorbar":{"outlinewidth":0,"ticks":""}}],"histogram2d":[{"type":"histogram2d","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmap":[{"type":"heatmap","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmapgl":[{"type":"heatmapgl","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"contourcarpet":[{"type":"contourcarpet","colorbar":{"outlinewidth":0,"ticks":""}}],"contour":[{"type":"contour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"surface":[{"type":"surface","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"mesh3d":[{"type":"mesh3d","colorbar":{"outlinewidth":0,"ticks":""}}],"scatter":[{"fillpattern":{"fillmode":"overlay","size":10,"solidity":0.2},"type":"scatter"}],"parcoords":[{"type":"parcoords","line":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolargl":[{"type":"scatterpolargl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"bar":[{"error_x":{"color":"#2a3f5f"},"error_y":{"color":"#2a3f5f"},"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"bar"}],"scattergeo":[{"type":"scattergeo","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolar":[{"type":"scatterpolar","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"histogram":[{"marker":{"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"histogram"}],"scattergl":[{"type":"scattergl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatter3d":[{"type":"scatter3d","line":{"colorbar":{"outlinewidth":0,"ticks":""}},"marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattermapbox":[{"type":"scattermapbox","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterternary":[{"type":"scatterternary","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattercarpet":[{"type":"scattercarpet","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"carpet":[{"aaxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"baxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"type":"carpet"}],"table":[{"cells":{"fill":{"color":"#EBF0F8"},"line":{"color":"white"}},"header":{"fill":{"color":"#C8D4E3"},"line":{"color":"white"}},"type":"table"}],"barpolar":[{"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"barpolar"}],"pie":[{"automargin":true,"type":"pie"}]},"layout":{"autotypenumbers":"strict","colorway":["#636efa","#EF553B","#00cc96","#ab63fa","#FFA15A","#19d3f3","#FF6692","#B6E880","#FF97FF","#FECB52"],"font":{"color":"#2a3f5f"},"hovermode":"closest","hoverlabel":{"align":"left"},"paper_bgcolor":"white","plot_bgcolor":"#E5ECF6","polar":{"bgcolor":"#E5ECF6","angularaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"radialaxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"ternary":{"bgcolor":"#E5ECF6","aaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"baxis":{"gridcolor":"white","linecolor":"white","ticks":""},"caxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"coloraxis":{"colorbar":{"outlinewidth":0,"ticks":""}},"colorscale":{"sequential":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"sequentialminus":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"diverging":[[0,"#8e0152"],[0.1,"#c51b7d"],[0.2,"#de77ae"],[0.3,"#f1b6da"],[0.4,"#fde0ef"],[0.5,"#f7f7f7"],[0.6,"#e6f5d0"],[0.7,"#b8e186"],[0.8,"#7fbc41"],[0.9,"#4d9221"],[1,"#276419"]]},"xaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"yaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"scene":{"xaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"yaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"zaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2}},"shapedefaults":{"line":{"color":"#2a3f5f"}},"annotationdefaults":{"arrowcolor":"#2a3f5f","arrowhead":0,"arrowwidth":1},"geo":{"bgcolor":"white","landcolor":"#E5ECF6","subunitcolor":"white","showland":true,"showlakes":true,"lakecolor":"white"},"title":{"x":0.05},"mapbox":{"style":"light"}}},"xaxis":{"anchor":"y","domain":[0.0,1.0],"title":{"text":"date"}},"yaxis":{"anchor":"x","domain":[0.0,1.0],"title":{"text":"guard_probability"},"ticksuffix":"%"},"legend":{"title":{"text":"AROI"},"tracegroupgap":0},"margin":{"t":60}},                        {"responsive": true}                    )                };                            </script>        </div>

### Exit Fraction by AROI over Time

<iframe title="Exit Probability by Authenticated Tor Relay Operator ID" aria-label="Interactive area chart" id="datawrapper-chart-0k7vX" src="https://datawrapper.dwcdn.net/0k7vX/2/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="800"></iframe>

### Top Relay Contributors by AROI

The graph below shows which AROIs contributed most to the network since 2021-01-01.
Contribution is measured in accumulated [consensus weight](https://metrics.torproject.org/onionoo.html#details_relay_consensus_weight).
To calculate the contribution we take a single consensus weight of every running relay for each AROI every day
and sum it up.
So for example if you run 10 relays with a CW of 2 for 7 days the accumulated CW is 140.

<div>                        <script type="text/javascript">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>
        <script charset="utf-8" src="https://cdn.plot.ly/plotly-2.20.0.min.js"></script>                <div id="fccc9e5d-0da0-4b12-b115-9aa4b3c68a54" class="plotly-graph-div" style="height:550px; width:100%;"></div>            <script type="text/javascript">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("fccc9e5d-0da0-4b12-b115-9aa4b3c68a54")) {                    Plotly.newPlot(                        "fccc9e5d-0da0-4b12-b115-9aa4b3c68a54",                        [{"alignmentgroup":"True","hovertemplate":"Total Accumulated CW since 2021-01-01=%{x}<br>Authenticated Relay Operator Identifier=%{y}<extra></extra>","legendgroup":"","marker":{"color":"#636efa","pattern":{"shape":""}},"name":"","offsetgroup":"","orientation":"h","showlegend":false,"textposition":"auto","x":[5156829703.0,3988186968.0,3603283606.0,3123091335.0,2932930154.0,2869405595.0,2468092517.0,2391527026.0,1810769164.0,1409384928.0],"xaxis":"x","y":["nothingtohide.nl","artikel10.org","quetzalcoatl-relays.org","for-privacy.net","tuxli.org","applied-privacy.net","www.f3netze.de","relayon.org","digitalcourage.social","www.cccs.de"],"yaxis":"y","type":"bar"}],                        {"template":{"data":{"histogram2dcontour":[{"type":"histogram2dcontour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"choropleth":[{"type":"choropleth","colorbar":{"outlinewidth":0,"ticks":""}}],"histogram2d":[{"type":"histogram2d","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmap":[{"type":"heatmap","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"heatmapgl":[{"type":"heatmapgl","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"contourcarpet":[{"type":"contourcarpet","colorbar":{"outlinewidth":0,"ticks":""}}],"contour":[{"type":"contour","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"surface":[{"type":"surface","colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]}],"mesh3d":[{"type":"mesh3d","colorbar":{"outlinewidth":0,"ticks":""}}],"scatter":[{"fillpattern":{"fillmode":"overlay","size":10,"solidity":0.2},"type":"scatter"}],"parcoords":[{"type":"parcoords","line":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolargl":[{"type":"scatterpolargl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"bar":[{"error_x":{"color":"#2a3f5f"},"error_y":{"color":"#2a3f5f"},"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"bar"}],"scattergeo":[{"type":"scattergeo","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterpolar":[{"type":"scatterpolar","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"histogram":[{"marker":{"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"histogram"}],"scattergl":[{"type":"scattergl","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatter3d":[{"type":"scatter3d","line":{"colorbar":{"outlinewidth":0,"ticks":""}},"marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattermapbox":[{"type":"scattermapbox","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scatterternary":[{"type":"scatterternary","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"scattercarpet":[{"type":"scattercarpet","marker":{"colorbar":{"outlinewidth":0,"ticks":""}}}],"carpet":[{"aaxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"baxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"type":"carpet"}],"table":[{"cells":{"fill":{"color":"#EBF0F8"},"line":{"color":"white"}},"header":{"fill":{"color":"#C8D4E3"},"line":{"color":"white"}},"type":"table"}],"barpolar":[{"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"barpolar"}],"pie":[{"automargin":true,"type":"pie"}]},"layout":{"autotypenumbers":"strict","colorway":["#636efa","#EF553B","#00cc96","#ab63fa","#FFA15A","#19d3f3","#FF6692","#B6E880","#FF97FF","#FECB52"],"font":{"color":"#2a3f5f"},"hovermode":"closest","hoverlabel":{"align":"left"},"paper_bgcolor":"white","plot_bgcolor":"#E5ECF6","polar":{"bgcolor":"#E5ECF6","angularaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"radialaxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"ternary":{"bgcolor":"#E5ECF6","aaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"baxis":{"gridcolor":"white","linecolor":"white","ticks":""},"caxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"coloraxis":{"colorbar":{"outlinewidth":0,"ticks":""}},"colorscale":{"sequential":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"sequentialminus":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"diverging":[[0,"#8e0152"],[0.1,"#c51b7d"],[0.2,"#de77ae"],[0.3,"#f1b6da"],[0.4,"#fde0ef"],[0.5,"#f7f7f7"],[0.6,"#e6f5d0"],[0.7,"#b8e186"],[0.8,"#7fbc41"],[0.9,"#4d9221"],[1,"#276419"]]},"xaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"yaxis":{"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","automargin":true,"zerolinewidth":2},"scene":{"xaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"yaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2},"zaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white","gridwidth":2}},"shapedefaults":{"line":{"color":"#2a3f5f"}},"annotationdefaults":{"arrowcolor":"#2a3f5f","arrowhead":0,"arrowwidth":1},"geo":{"bgcolor":"white","landcolor":"#E5ECF6","subunitcolor":"white","showland":true,"showlakes":true,"lakecolor":"white"},"title":{"x":0.05},"mapbox":{"style":"light"}}},"xaxis":{"anchor":"y","domain":[0.0,1.0],"title":{"text":"Total Accumulated CW since 2021-01-01"}},"yaxis":{"anchor":"x","domain":[0.0,1.0],"title":{"text":"Authenticated Relay Operator Identifier"},"categoryorder":"array","categoryarray":["www.cccs.de","digitalcourage.social","relayon.org","www.f3netze.de","applied-privacy.net","tuxli.org","for-privacy.net","quetzalcoatl-relays.org","artikel10.org","nothingtohide.nl"]},"legend":{"tracegroupgap":0},"margin":{"t":60},"barmode":"relative","height":550},                        {"responsive": true}                    )                };                            </script>        </div>

### Current guard and exit probability by AROI

<div class="datatable-begin"></div>

| Authenticated Operator ID                                         | Guard(%)   | Exit(%)   |   #Relays | First Seen   |
|:------------------------------------------------------------------|:-----------|:----------|----------:|:-------------|
| [nothingtohide.nl](nothingtohide.nl.html)                         | 1.99       | 19.91     |       292 | 2020-07-02   |
| [artikel10.org](artikel10.org.html)                               | 0.0        | 12.76     |       160 | 2021-02-27   |
| [quetzalcoatl-relays.org](quetzalcoatl-relays.org.html)           | 0.84       | 8.09      |       376 | 2020-11-08   |
| [applied-privacy.net](applied-privacy.net.html)                   | 0.0        | 7.68      |       104 | 2018-04-15   |
| [www.f3netze.de](www.f3netze.de.html)                             | 0.45       | 4.36      |        24 | 2019-02-18   |
| [digitalcourage.social](digitalcourage.social.html)               | 0.35       | 3.43      |        31 | 2019-02-18   |
| [for-privacy.net](for-privacy.net.html)                           | 2.23       | 3.33      |        86 | 2019-03-05   |
| [www.cccs.de](www.cccs.de.html)                                   | 0.33       | 3.23      |        54 | 2022-01-16   |
| [tor.r0cket.net](tor.r0cket.net.html)                             | 0.19       | 2.74      |        80 | 2024-09-26   |
| [tuxli.org](tuxli.org.html)                                       | 2.82       | 2.64      |       117 | 2020-06-02   |
| [nos-oignons.net](nos-oignons.net.html)                           | 0.19       | 1.84      |        39 | 2019-02-18   |
| [dfri.se](dfri.se.html)                                           | 0.12       | 1.17      |        32 | 2021-11-04   |
| [artikel5ev.de](artikel5ev.de.html)                               | 0.27       | 0.8       |        31 | 2016-10-19   |
| [dotsrc.org](dotsrc.org.html)                                     | 0.23       | 0.58      |        12 | 2020-09-10   |
| [www.digitale-gesellschaft.ch](www.digitale-gesellschaft.ch.html) | 0.05       | 0.53      |         9 | 2015-05-22   |
| [unredacted.org](unredacted.org.html)                             | 0.05       | 0.53      |        30 | 2021-11-07   |
| [hviv.nl](hviv.nl.html)                                           | 0.05       | 0.49      |        14 | 2018-04-27   |
| [sabotage.net](sabotage.net.html)                                 | 0.04       | 0.46      |         6 | 2019-02-18   |
| [middelstaedt.com](middelstaedt.com.html)                         | 0.24       | 0.44      |        19 | 2022-10-20   |
| [a-n-o-n-y-m-e.net](a-n-o-n-y-m-e.net.html)                       | 0.05       | 0.39      |        18 | 2023-03-25   |
| [torix-relays.org](torix-relays.org.html)                         | 0.02       | 0.27      |        14 | 2021-08-26   |
| [lokodlare.com](lokodlare.com.html)                               | 0.26       | 0.23      |        12 | 2021-11-14   |
| [stareintodeathandbestill.com](stareintodeathandbestill.com.html) | 0.01       | 0.18      |         2 | 2024-08-24   |
| [torservers.net](torservers.net.html)                             | 0.01       | 0.17      |         2 | 2023-01-08   |
| [www.privex.io](www.privex.io.html)                               | 0.09       | 0.1       |         3 | 2019-06-28   |
| [worldofmatthew.com](worldofmatthew.com.html)                     | 0.07       | 0.07      |         6 | 2019-07-08   |
| [emeraldonion.org](emeraldonion.org.html)                         | 0.0        | 0.07      |         3 | 2024-07-26   |
| [tor-exit-1.allium.dev](tor-exit-1.allium.dev.html)               | 0.0        | 0.06      |         1 | 2023-06-01   |
| [tor-exit-2.allium.dev](tor-exit-2.allium.dev.html)               | 0.0        | 0.02      |         1 | 2022-08-21   |
| [teitel.net](teitel.net.html)                                     | 0.0        | 0.02      |         2 | 2019-12-25   |
| [katawaredoki.net](katawaredoki.net.html)                         | 0.09       | 0.01      |         4 | 2019-02-18   |
| [ftp.halifax.rwth-aachen.de](ftp.halifax.rwth-aachen.de.html)     | 0.73       | 0.0       |         9 | 2021-07-17   |
| [limoneneis.de](limoneneis.de.html)                               | 0.46       | 0.0       |         8 | 2022-01-26   |
| [gojira-family.dedyn.io](gojira-family.dedyn.io.html)             | 0.43       | 0.0       |        12 | 2022-04-03   |
| [shadowbrokers.eu](shadowbrokers.eu.html)                         | 0.39       | 0.0       |        14 | 2023-02-17   |
| [zwiebeltoralf.de](zwiebeltoralf.de.html)                         | 0.3        | 0.0       |         9 | 2019-02-18   |
| [axstet.de](axstet.de.html)                                       | 0.27       | 0.0       |         9 | 2022-01-13   |
| [arbitrary.ch](arbitrary.ch.html)                                 | 0.25       | 0.0       |        14 | 2019-02-18   |
| [louis.weebl.me](louis.weebl.me.html)                             | 0.22       | 0.0       |         3 | 2019-02-18   |
| [null-f.org](null-f.org.html)                                     | 0.19       | 0.0       |        13 | 2024-11-27   |
| [terjan.net](terjan.net.html)                                     | 0.18       | 0.0       |         6 | 2019-02-18   |
| [enkidu-6.github.io](enkidu-6.github.io.html)                     | 0.18       | 0.0       |         6 | 2022-06-12   |
| [zwiebelrouter.net](zwiebelrouter.net.html)                       | 0.17       | 0.0       |         5 | 2022-03-14   |
| [xonumi.com](xonumi.com.html)                                     | 0.17       | 0.0       |         5 | 2024-01-15   |
| [lucaswerkmeister.de](lucaswerkmeister.de.html)                   | 0.15       | 0.0       |         1 | 2021-01-08   |
| [doedelkiste.de](doedelkiste.de.html)                             | 0.14       | 0.0       |        11 | 2015-10-18   |
| [mkg20001.io](mkg20001.io.html)                                   | 0.13       | 0.0       |         1 | 2021-05-08   |
| [rofl.cat](rofl.cat.html)                                         | 0.09       | 0.0       |         6 | 2019-02-18   |
| [www.schmeling-ol.de](www.schmeling-ol.de.html)                   | 0.08       | 0.0       |         3 | 2019-09-16   |
| [pikachu.systems](pikachu.systems.html)                           | 0.07       | 0.0       |         2 | 2021-12-22   |
| [galtland.network](galtland.network.html)                         | 0.06       | 0.0       |         1 | 2022-06-27   |
| [ezyn.de](ezyn.de.html)                                           | 0.05       | 0.0       |         3 | 2021-10-05   |
| [www.rince.de](www.rince.de.html)                                 | 0.05       | 0.0       |         1 | 2020-08-21   |
| [alxu.ca](alxu.ca.html)                                           | 0.05       | 0.0       |         3 | 2019-02-18   |
| [holonet.sh](holonet.sh.html)                                     | 0.05       | 0.0       |         1 | 2022-04-23   |
| [tor.gabrielg.es](tor.gabrielg.es.html)                           | 0.05       | 0.0       |         1 | 2021-05-18   |
| [colincogle.name](colincogle.name.html)                           | 0.04       | 0.0       |         1 | 2022-03-14   |
| [miraty.niv.re](miraty.niv.re.html)                               | 0.04       | 0.0       |         1 | 2022-05-03   |
| [tor.skankhunt42.pw](tor.skankhunt42.pw.html)                     | 0.04       | 0.0       |         2 | 2023-05-12   |
| [www.triplebit.org](www.triplebit.org.html)                       | 0.03       | 0.0       |        20 | 2024-10-07   |
| [sebastianboegl.de](sebastianboegl.de.html)                       | 0.03       | 0.0       |         1 | 2019-02-18   |
| [nicoleiocana.com](nicoleiocana.com.html)                         | 0.03       | 0.0       |         1 | 2020-09-20   |
| [phillw.net](phillw.net.html)                                     | 0.02       | 0.0       |         2 | 2019-02-18   |
| [kai.sx](kai.sx.html)                                             | 0.02       | 0.0       |         2 | 2019-02-18   |
| [arpsel.ws](arpsel.ws.html)                                       | 0.01       | 0.0       |         1 | 2023-06-21   |
| [plasmatrap.com](plasmatrap.com.html)                             | 0.01       | 0.0       |         1 | 2020-09-10   |
| [arvanode.net](arvanode.net.html)                                 | 0.01       | 0.0       |         1 | 2024-01-30   |
| [nx42.de](nx42.de.html)                                           | 0.01       | 0.0       |         1 | 2019-02-18   |
| [nullvoid.me](nullvoid.me.html)                                   | 0.01       | 0.0       |         2 | 2017-10-29   |
| [athalis.de](athalis.de.html)                                     | 0.01       | 0.0       |         1 | 2020-10-30   |
| [trinity.fr.eu.org](trinity.fr.eu.org.html)                       | 0.01       | 0.0       |         1 | 2020-06-12   |
| [hwsystems.com](hwsystems.com.html)                               | 0.01       | 0.0       |         1 | 2023-01-28   |
| [manasiwibi.com](manasiwibi.com.html)                             | 0.01       | 0.0       |         1 | 2021-10-15   |
| [kszczot.pl](kszczot.pl.html)                                     | 0.01       | 0.0       |         3 | 2024-10-30   |
| [gutter.duckdns.org](gutter.duckdns.org.html)                     | 0.01       | 0.0       |         8 | 2021-12-04   |
| [surveillance.monster](surveillance.monster.html)                 | 0.01       | 0.0       |         2 | 2024-11-05   |
| [www.habedieeh.re](www.habedieeh.re.html)                         | 0.01       | 0.0       |         1 | 2022-12-29   |
| [d00t.de](d00t.de.html)                                           | 0.0        | 0.0       |         1 | 2024-09-29   |
| [pasquino.cyblings.on.ca](pasquino.cyblings.on.ca.html)           | 0.0        | 0.0       |         1 | 2024-02-27   |
| [relays.foo](relays.foo.html)                                     | 0.0        | 0.0       |         1 | 2024-02-01   |
| [www.miskatonic.org](www.miskatonic.org.html)                     | 0.0        | 0.0       |         1 | 2019-02-18   |
| [fart.website](fart.website.html)                                 | 0.0        | 0.0       |         1 | 2020-09-10   |
| [petrarca.codeberg.page](petrarca.codeberg.page.html)             | 0.0        | 0.0       |         1 | 2019-02-18   |
| [tor2.xn--sb-lka.org](tor2.xn--sb-lka.org.html)                   | 0.0        | 0.0       |         1 | 2020-08-21   |
| [saklad5.com](saklad5.com.html)                                   | 0.0        | 0.0       |         2 | 2023-01-08   |
| [elzpiraten.de](elzpiraten.de.html)                               | 0.0        | 0.0       |         1 | 2021-09-15   |
| [cgl.sh](cgl.sh.html)                                             | 0.0        | 0.0       |         1 | 2024-07-24   |
| [tor.rawbit.ninja](tor.rawbit.ninja.html)                         | 0.0        | 0.0       |         1 | 2019-02-18   |
| [mutantmonkey.in](mutantmonkey.in.html)                           | 0.0        | 0.0       |         1 | 2019-08-06   |
| [privacylayer.xyz](privacylayer.xyz.html)                         | 0.0        | 0.0       |         1 | 2024-12-29   |
| [snapserv.net](snapserv.net.html)                                 | 0.0        | 0.0       |         1 | 2022-09-10   |
| [niceware.xyz](niceware.xyz.html)                                 | 0.0        | 0.0       |         1 | 2024-10-07   |
| [tor.yyzz.dev](tor.yyzz.dev.html)                                 | 0.0        | 0.0       |         3 | 2021-01-28   |
| [KurumiKira.github.io](KurumiKira.github.io.html)                 | 0.0        | 0.0       |         1 | 2023-02-07   |
| [tor.saru.moe](tor.saru.moe.html)                                 | 0.0        | 0.0       |         4 | 2019-02-18   |
| [itsg.host](itsg.host.html)                                       | 0.0        | 0.0       |         1 | 2019-02-08   |
| [germancraft.net](germancraft.net.html)                           | 0.0        | 0.0       |         4 | 2019-02-18   |
| [txrworlds.net](txrworlds.net.html)                               | 0.0        | 0.0       |         1 | 2024-07-07   |
| [dontinterceptmebro.com](dontinterceptmebro.com.html)             | 0.0        | 0.0       |         2 | 2019-02-18   |
| [thinkindifferent.net](thinkindifferent.net.html)                 | 0.0        | 0.0       |         1 | 2020-07-02   |
| [b0c4.de](b0c4.de.html)                                           | 0.0        | 0.0       |         1 | 2022-01-03   |
| [www.digidow.eu](www.digidow.eu.html)                             | 0.0        | 0.0       |        50 | 2021-02-26   |
| [graven.dev](graven.dev.html)                                     | 0.0        | 0.0       |         1 | 2019-12-05   |
| [tor.koishi.io](tor.koishi.io.html)                               | 0.0        | 0.0       |         1 | 2025-01-13   |
| [stalkr.net](stalkr.net.html)                                     | 0.0        | 0.0       |         1 | 2019-02-18   |
| [hydra-family.github.io](hydra-family.github.io.html)             | 0.0        | 0.0       |         1 | 2025-01-13   |
| [bundesgebaermutter.ddnss.eu](bundesgebaermutter.ddnss.eu.html)   | 0.0        | 0.0       |         1 | 2016-08-09   |
| [mpan.pl](mpan.pl.html)                                           | 0.0        | 0.0       |         1 | 2019-02-18   |
| [zorc.xyz](zorc.xyz.html)                                         | 0.0        | 0.0       |         1 | 2021-01-28   |
| [dodo.pm](dodo.pm.html)                                           | 0.0        | 0.0       |         3 | 2021-02-27   |
| [melmac.space](melmac.space.html)                                 | 0.0        | 0.0       |         1 | 2022-11-19   |
| [unzane.com](unzane.com.html)                                     | 0.0        | 0.0       |         1 | 2019-02-18   |
| [relayon.org](relayon.org.html)                                   | 0.0        | 0.0       |         4 | 2020-10-19   |
| [itsporkroll.com](itsporkroll.com.html)                           | 0.0        | 0.0       |         4 | 2024-07-30   |
| [c3w.at](c3w.at.html)                                             | 0.0        | 0.0       |         3 | 2019-07-18   |
| [slash.dynu.com](slash.dynu.com.html)                             | 0.0        | 0.0       |         1 | 2019-02-18   |
| [lobi.to](lobi.to.html)                                           | 0.0        | 0.0       |         1 | 2019-02-18   |
| [www.defcon.org](www.defcon.org.html)                             | None       | None      |         1 | 2020-12-29   |
| [nognu.de](nognu.de.html)                                         | None       | None      |         3 | 2021-05-02   |

<div class="datatable-end"></div>

## Biggest Relay Families on the Tor Network

Relays are aggregated based on effective families. Effective families are relays
with a mutually configured MyFamily setting.
Single relays (without family) are also considered but not aggregated.

### Exit Families

<div class="datatable-begin"></div>

|     | Authenticated Relay Operator ID or Contact (unverified)                                                                                                                |   Exit(%) |   #Relays | First Seen   |
|----:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------:|----------:|:-------------|
|   0 | [nothingtohide.nl](w/family/cdd109daf1976d63204efd66d89354222d57f8fbbca75cbaacd8e801fe56a9fa)                                                                          |     19.91 |       260 | 2022-04-22   |
|   1 | [artikel10.org](w/family/d3b1b3c59c4f50b9a9e46ca76abbea6995af6410b3c159a77f9bc8de76254716)                                                                             |     12.76 |       160 | 2021-02-27   |
|   2 | [quetzalcoatl-relays.org](w/family/e53b96a2e713f195c40b23066c02855e52d4b8312ec428806181618b988f9dbc)                                                                   |      7.81 |       350 | 2020-11-08   |
|   3 | [applied-privacy.net](w/family/6ba1ad9b8a5c8d91ade07a067299de03a3ab01adb55dca778dd858fa7bddb798)                                                                       |      7.68 |       104 | 2018-04-15   |
|   4 | [www.f3netze.de](w/family/41de79b6591980723300320038e764274aa76efdba8d97331c8253c630ff707b)                                                                            |      4.36 |        24 | 2019-02-18   |
|   5 | [digitalcourage.social](w/family/402d73786074e99e7d2ea8e637aca732fbe55256f2ed5a122047d18bb537ceac)                                                                     |      3.43 |        30 | 2020-07-12   |
|   6 | [for-privacy.net](w/family/8b0a1698e9701148fe1f4f49cb27c1f579dce411952de942b889d4d08bfd2f68)                                                                           |      3.33 |        43 | 2020-04-03   |
|   7 | [www.cccs.de](w/family/5401b5c6fd3deb946e9864f7b2bfba241f1dabc0ee0b1ddae2be44e6b49687e7)                                                                               |      3.23 |        42 | 2022-01-16   |
|   8 | [tor.r0cket.net](w/family/9393a5f7c52867fae73a02e65231b3fcf7bd473937f68d1409509045b5cdb03a)                                                                            |      2.74 |        80 | 2024-09-26   |
|   9 | [tuxli.org](w/family/688bf759a396dc0c171b2fcdcf8302cbd4dd913f4a1e29f7d0ac763471968014)                                                                                 |      2.64 |        50 | 2022-03-04   |
|  10 | [nos-oignons.net](w/family/d1c45eefa93e9afcc06447683ab4bbeb2a5f00a628053335ae7c868ce7242f25)                                                                           |      1.84 |        39 | 2019-02-18   |
|  11 | [email:torix protonmail.com url:https://torix-relays.org proof:uri-rsa hoster:RD](w/family/d6793cfc497962f8d9fd4d00366a2bebdbeda5b7d72ab1809ef11b7e81b0531d)           |      1.8  |        76 | 2021-08-26   |
|  12 | [email:admin prsv.ch url:https://prsv.ch/ proof:uri-rsa ciissversion:2](w/family/87119f7e2b1b336fdf6429d53ff38a1619451120836f7fa20c35460a511607f5)                     |      1.72 |        56 | 2024-05-24   |
|  13 | [KeFF NOC &lt;noc AT keff dot org&gt;](w/family/7eedfa16e179476528b51ccc4e17a8d0860e3645b279dc421c1c445f6ca78836)                                                      |      1.23 |        26 | 2020-07-28   |
|  14 | [dfri.se](w/family/6fb7a0af3654ec1c23c01edf49ae4770b655cf73b5309f2ebd6a29f844ee7387)                                                                                   |      1.17 |        32 | 2021-11-04   |
|  15 | [artikel5ev.de](w/family/112404eed179f708ec241c1243dc451989f66248bd61fa2a2da6cb9fc5f36039)                                                                             |      0.8  |        22 | 2016-10-19   |
|  16 | [dotsrc.org](w/family/9865b6a9911eeb03241484047e1a87e8cf56ab5dd8b307f9f88c9025629a74a0)                                                                                |      0.58 |        10 | 2020-09-10   |
|  17 | [Brandon Kuschel &lt;tor AT NOSPAM brandonkuschel dot com&gt;](w/family/098593149ac40b486e17384a6a7e36388d541e5ba4fa446bdf75649451945b8b)                              |      0.55 |        21 | 2022-08-21   |
|  18 | [old memes222 AT pm.me](w/family/099f5ac9a4923e0867054c890eb0d29d5eb3ffb130c49d7d0a5860b2a22a1e1b)                                                                     |      0.53 |         6 | 2025-01-07   |
|  19 | [www.digitale-gesellschaft.ch](w/family/2b347e140ca2083820b8065a4c36cd001295daa6ec54149e0ae66528173ab16d)                                                              |      0.53 |         9 | 2015-05-22   |
|  20 | [FlokiNET &lt;noc@flokinet.is&gt;](w/family/771c968d16497365c3b229607b130bbbfe46817a410549a7757b3718698fe175)                                                          |      0.53 |         9 | 2021-11-24   |
|  21 | [unredacted.org](w/family/d483e43e3415af923180ae140e4e9bde334d217288881f842616adde5dec8995)                                                                            |      0.53 |        30 | 2021-11-07   |
|  22 | [hviv.nl](w/family/cd4836da405366bd79a30ced489dd18364b379db15ae344919ff93fd5e09e49a)                                                                                   |      0.49 |        14 | 2018-04-27   |
|  23 | [TNinja &lt;abuse-team at tor dot ninja&gt;](w/family/11ff631d37c696436fd62e0f22a4f9b803022ba62876b5633f1001eff431ab99)                                                |      0.48 |         3 | 2024-06-03   |
|  24 | [middelstaedt.com](w/family/7cdf3fadd53acd400f32861a800244204f1f24ed05a3fc7712adec1122d67daf)                                                                          |      0.44 |        10 | 2022-11-19   |
|  25 | [mentor@palokaj.co](w/family/20f6ae6ad5a6efcb15166c95a223f78065811919028d285edae71497e5b03ffe)                                                                         |      0.42 |         7 | 2023-03-22   |
|  26 | [Neel Chauhan &lt;neel AT neelc DOT org&gt;](w/family/5c65a303311d5601d6ef10465e209b1c8ec964ea0305c45d61d1d273b215adb3)                                                |      0.4  |        12 | 2024-08-26   |
|  27 | [mikael datanerd.se](w/family/104fba39fb82697b595ac32d291f192d3cf0d991b095973c697a037b9f5fc5ae)                                                                        |      0.4  |         9 | 2024-12-07   |
|  28 | [FreeExitProvider at protonmail dot com tor-relay.co](w/family/c134040cc073b7bc5bbf298c91946c2506f827ea59aae767100751b6b99423b2)                                       |      0.38 |         8 | 2021-08-26   |
|  29 | [mikael datanerd.se](w/family/4a1c6a86b8dd087bd3a926c4a3669d12cf0e5e99b0223ad7acef96d39234dd4e)                                                                        |      0.33 |         7 | 2024-10-19   |
|  30 | [Nicholas Merrill &lt;nick AT calyx dot com&gt; BTC - 14wntQ8cBdnhUVfYmDjXz6PbpSSX8nCtk](w/family/e4f17008b5301250340182d45bb2d6379545bb51db0d2550ab36a3cb274ba134)    |      0.31 |        19 | 2013-11-12   |
|  31 | [PRQ Hosting &lt;info AT prq dot se&gt;](w/family/56e60f347003e42be7ebee6d2b15d5bca94e726d9874ab74307c1b3f0b9cf255)                                                    |      0.3  |         9 | 2024-10-20   |
|  32 | [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/family/e836a284406d5859af570808ef5382ebda7a31f4ff44f871cea5691f79b0c08d)           |      0.25 |         8 | 2024-12-18   |
|  33 | [lokodlare.com](w/family/319484775b244a3b771e32435accb18b4ab42a702608f6e74eee8b9d644dbd5b)                                                                             |      0.23 |         4 | 2022-01-03   |
|  34 | [Abuse Poseidon2 &lt;poseidon2.mule134 AT silomails DOT com&gt;](w/family/997d0bb430f4ecddb64ccbc1fd4fe52958ef7aedc0c8a262b1f675a54dac08d7)                            |      0.23 |         2 | 2024-05-08   |
|  35 | [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/family/91fced5df52f16ecc2bd9ce7cd7ac8d00dd1a94bf15b7f1b0881f840e8f1e8e0)           |      0.21 |         7 | 2024-12-17   |
|  36 | [Henrik Kramselund &lt;hlk AT zencurity dot com&gt;](w/family/e365b0ef10ae8a1fbd5b7a1fe501fbaab5f3b0b8fc9b9880245f320c534a390c)                                        |      0.2  |         2 | 2021-03-29   |
|  37 | [Osservatorio Nessuno ODV &lt;exit@osservatorionessuno.org&gt;](w/family/957db25302ea561574b0567ad88159af102f30564915eb44f7800f6af1da5bec)                             |      0.2  |         7 | 2018-12-21   |
|  38 | [peTelRobi aT gmaIl DOT cOm&gt;](w/family/4ecac114ecff9dbcb8ecfeb076373c9e0660bf7b79d9f45b273f664033105a0f)                                                            |      0.2  |         7 | 2024-02-14   |
|  39 | [uncertain krait AT proton . me](w/family/9adb3e4903c3354048574fbe0a3e7501e58bb502494a38f60eb9d73fdce1edc1)                                                            |      0.19 |         3 | 2024-09-04   |
|  40 | [mikael datanerd.se](w/family/770e1e36e901bb94518034f18671e4730b27bfff944f85ad4a58bffe3c8631bd)                                                                        |      0.19 |         4 | 2024-10-19   |
|  41 | [tor-exit@vrij-heid.nl](w/family/918760c893166353347a022bae10472e11c44b7d6d1ba844f7556c68df90f45b)                                                                     |      0.18 |         4 | 2024-01-22   |
|  42 | [stareintodeathandbestill.com](w/family/e010ca788a7e48576c391ae17299259e4e14c728e9512cd44f2e9c6a4c18c530)                                                              |      0.18 |         2 | 2024-08-24   |
|  43 | [le1025656haha102vvs210000bnmuiooop11x@protonmail.ch](w/family/ec97f757736ae3627860dc7568043dc6521ac750cec0baeaecaf36658fc4676e)                                       |      0.16 |         2 | 2024-12-05   |
|  44 | [noc@as204750.net](w/relay/A0B4BD14D86B8D1D77AED742BF8381764B624295)                                                                                                   |      0.16 |         1 | 2024-09-22   |
|  45 | [quetzalcoatl-relays.org](w/family/a5fff0523301e058a091331f564d2eed0abad225902f0a96fa9ef6f6a11d66c8)                                                                   |      0.15 |         8 | 2021-06-17   |
|  46 | [tor-exit@mxmla.de](w/family/abc7318e423a5c1ef731e383b14e9886c3e56ac456e653cb232e4e8a8c338e6e)                                                                         |      0.15 |         2 | 2024-11-06   |
|  47 | [csheats@tutanota.com](w/family/d56ed6d53a15c2911dfe3eaa6dfb847557db8462c55ad246217568fbea806673)                                                                      |      0.14 |         3 | 2022-10-25   |
|  48 | [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/family/704fcecb4e2a2073adb8c1a35dd152ddbc6b83f29351f65fbcabff44cfb4fe08)           |      0.13 |         8 | 2024-08-29   |
|  49 | [Matthias Schmidt &lt;tor@vegms.de&gt;](w/relay/8DB706C9B7ABA89F08FCE919DE18DAC63266EC8D)                                                                              |      0.13 |         1 | 2024-01-21   |
|  50 | [email:privacyboys@tutanota.com hoster:atomicnetworks cost:64USD donationurl:http](w/family/c1a4e0d4144899fdb5be10d58c15215a01ba0f1692aa5e5b5ab00a937afe42bd)          |      0.12 |         4 | 2023-07-08   |
|  51 | [Stan &lt;favorite0ne@proton.me&gt;](w/family/1cde88e9b09e46b048a9790a8173153428eccf12b0bb70f5e6179e6f68fde6ff)                                                        |      0.12 |         3 | 2024-08-02   |
|  52 | [Sven Reissmann &lt;abuse at rz.hs-fulda.de&gt;](w/relay/E70906B974DF23A6858B06FED589DC3696781F00)                                                                     |      0.12 |         1 | 2024-01-21   |
|  53 | [John Doe johndoe@anon.local](w/relay/51646B520852370793AAA332CEFD5F4BFAA8C46B)                                                                                        |      0.11 |         1 | 2024-01-21   |
|  54 | [Hurdy-Gurdy &lt;admin AT my-mail dot rocks&gt;](w/family/1e225bfaffcc58003d2ae588f3a8216c92d6fa8c70c3de756b6a0d6b99706293)                                            |      0.11 |         2 | 2023-05-10   |
|  55 | [Behemoth Project Anonimity &lt;make-tor-great-again@encrypt.co.il&gt;](w/family/42cc31523fd2cfbcf7d66c2ae311466f7267670b888c61679341d52b71e86ed4)                     |      0.11 |         3 | 2024-07-21   |
|  56 | [sabotage.net](w/relay/74C0C2705DB1192C03F19F7CD1BB234843B1A81F)                                                                                                       |      0.11 |         1 | 2019-02-18   |
|  57 | [portaler-typ.0c@icloud.com](w/relay/A47C8E0D64E733EDC8CB4409BDE07DB3C0ED28A8)                                                                                         |      0.11 |         1 | 2022-08-31   |
|  58 | [your@e-mail](w/relay/B4F1193BECADD10F7EC08DB02C7672FB717987A4)                                                                                                        |      0.11 |         1 | 2024-10-11   |
|  59 | [tor-operator@xor.sc](w/relay/CBCC85F335E20705F791CFC8685951C90E24134D)                                                                                                |      0.11 |         1 | 2022-08-21   |
|  60 | [tornode2022@protonmail.com](w/family/0ba85393b2eb642b4690663a6876dfd2c83e8bb26d7060b339a3441c76ca60ae)                                                                |      0.1  |         6 | 2023-02-17   |
|  61 | [z9kx21zk855s@protonmail.com](w/family/d302854ffd3517cc7576ce0f2d3fc9bb9d36f4d7815bbce142b3ad36d2cf00c8)                                                               |      0.1  |         2 | 2023-06-13   |
|  62 | [xor.st &lt;tor@xor.st&gt;](w/relay/2ACF25EDCB5CAECF2F2AB2A5F9EB1E7600CD8B0D)                                                                                          |      0.1  |         1 | 2024-07-04   |
|  63 | [jets843@privatemail.com](w/family/7024a68bf944969260c25e761b44112e643f0bb81e873761c6c72d32f1296616)                                                                   |      0.1  |         6 | 2022-08-11   |
|  64 | [maxzrbn AT protonmail DOT com](w/family/b02865586c455fecc750dc75ac9cdfd02795ec56f5d92f5c107cd849a8532c26)                                                             |      0.1  |         5 | 2024-04-14   |
|  65 | [www.privex.io](w/family/bd6a90ee09451b7622b29ba5321dbefc2c140e806e1b798d4f3475b5706a0bbb)                                                                             |      0.1  |         2 | 2019-06-28   |
|  66 | [cvjoint73@protonmail.com](w/family/f9095e0709c28c7c351f9099082ccc3e47cc3141375a0587026d1ee6941edb2c)                                                                  |      0.1  |         2 | 2022-04-03   |
|  67 | [your@e-mail](w/relay/72409582B43695A8A75EE323D0402086292688A6)                                                                                                        |      0.1  |         1 | 2024-09-02   |
|  68 | [tor-relay-admin@carlos1001.com](w/family/cbce76aa7036390374a9cb68eab4137b14a29d71e4348275ff8e1befe34e149d)                                                            |      0.09 |         2 | 2022-11-09   |
|  69 | [0AFD832F](w/relay/0AFD832F09B6C2C9E0FE99E78B29E2ED325B0E54)                                                                                                           |      0.09 |         1 | 2024-03-13   |
|  70 | [Alexander abuse@spynode.cc 8E28C7AAD6360D19802D6D5734FB3F3EDCB8B222](w/relay/1C15BB5B81EF103108EE7EAB6A88A39E3658990C)                                                |      0.09 |         1 | 2024-12-01   |
|  71 | [sabotage.net](w/relay/678B3A694071537AD62723BDA96C6CF1358AE67A)                                                                                                       |      0.09 |         1 | 2024-01-22   |
|  72 | [info@syndicateguys.com](w/family/146ce69c201710c56e7ada04fca862df4953fe8e52ed49d99c60e30688b398d0)                                                                    |      0.09 |         4 | 2024-01-20   |
|  73 | [sabotage.net](w/relay/82E2708957A41EDA0819EE1C5FFC3E2DC38B9FE9)                                                                                                       |      0.09 |         1 | 2024-01-22   |
|  74 | [D0BEAF48](w/relay/D0BEAF489E339783A0146DA7575241A2E7F52C45)                                                                                                           |      0.09 |         1 | 2025-01-08   |
|  75 | [remote VIA uq dot ci](w/relay/43AB3206F0FB241E75AEE9DD1E6FCB0D33EDEC0D)                                                                                               |      0.09 |         1 | 2025-01-12   |
|  76 | [relayA6Bkjm@gmail.com](w/relay/A398E05824C1CF432FE1DD241FF4F3462625F712)                                                                                              |      0.09 |         1 | 2025-01-17   |
|  77 | [tor@birdeck.com](w/relay/B5D257D4D7536C40A50043CDEC223E621E483DDB)                                                                                                    |      0.09 |         1 | 2024-07-27   |
|  78 | [relay@hackster.anonaddy.com](w/relay/F635A9CD6163BD4B7B3BDC32CE0FE7B3340BC5DD)                                                                                        |      0.09 |         1 | 2023-02-21   |
|  79 | [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/family/825a40e0353edc3a905ac274e0016604e6dc65e86e6b5f33c460c2bd0f4d7e3e)           |      0.08 |         7 | 2024-12-16   |
|  80 | [mentor@palokaj.co](w/relay/23899620429B1B0E726AC927EF86BEBDE10F1D0C)                                                                                                  |      0.08 |         1 | 2023-07-27   |
|  81 | [tor-exit-1.allium.dev](w/family/273870e0e7e5969842469e42d16711e0711f142a033b9573ef7a58a99d2755c5)                                                                     |      0.08 |         2 | 2022-08-21   |
|  82 | [586D9093](w/relay/586D90935DF5C0F11DE8475B5A8D294F812A33C2)                                                                                                           |      0.08 |         1 | 2025-01-05   |
|  83 | [torservers.net](w/relay/59267EC3DC757CF850DA0F5AF03AB5E69C75FEB7)                                                                                                     |      0.08 |         1 | 2023-01-08   |
|  84 | [EMAIL IS /kiddailey GMX com/](w/relay/94A1C04DB810A7E9B7BB62A8643CB4D9BDC9E7F2)                                                                                       |      0.08 |         1 | 2024-01-30   |
|  85 | [sabotage.net](w/relay/9928E342EF92F2411D8D68ADC18F6D2B5367171D)                                                                                                       |      0.08 |         1 | 2024-01-18   |
|  86 | [someonesneighbor1@protonmail.com](w/relay/D698261BC1B4A80E24BD050909552C7FE9464CD2)                                                                                   |      0.08 |         1 | 2022-05-03   |
|  87 | [ramin dot schreur at mail dot com](w/relay/7265075D62051D8125661309062B92AE136BB216)                                                                                  |      0.08 |         1 | 2022-04-03   |
|  88 | [torservers.net](w/relay/A1A78BE5F0A6698301913D08DDB76535D5E6D2AA)                                                                                                     |      0.08 |         1 | 2023-01-08   |
|  89 | [a-n-o-n-y-m-e.net](w/relay/E1D7AEBD5218953FB8558056E13B25125CBE2B48)                                                                                                  |      0.08 |         1 | 2023-06-09   |
|  90 | [hermesrelay at protonmail dot com](w/family/39928412a46ad9d32002631d68f470cf79f1a5feaec059082975cd19d1a61453)                                                         |      0.07 |         2 | 2019-07-18   |
|  91 | [worldofmatthew.com](w/relay/259078C74CB230969A6AFCD8535C0B35AECFF868)                                                                                                 |      0.07 |         1 | 2020-08-31   |
|  92 | [belldaddy@tuta.io](w/family/059aec8a300d47973d585ac1d5401692cfbf77c43fc209269d31a1ab366e9068)                                                                         |      0.07 |         2 | 2024-03-10   |
|  93 | [admin@caspervk.net](w/family/a3ef1f9ae6d38e7651876a19438279f1ae36e6e689cb9b1c75a87edf855c4b87)                                                                        |      0.07 |         4 | 2023-08-06   |
|  94 | [46F9FB94](w/relay/46F9FB943917858F618F2648595DEACD931D4400)                                                                                                           |      0.07 |         1 | 2024-02-07   |
|  95 | [AB8C1662](w/relay/AB8C1662485B50947725A0221E09638B46304FD8)                                                                                                           |      0.07 |         1 | 2025-01-07   |
|  96 | [tor-NLfreedom@protonmail.com](w/relay/AF8DB275960279B87F098B16CC9C78092E118DB3)                                                                                       |      0.07 |         1 | 2022-03-04   |
|  97 | [babysharkdootdoot@proton.me](w/relay/B8F50C7C673B72845001FD8D2EE6FD179F56D162)                                                                                        |      0.07 |         1 | 2024-01-22   |
|  98 | [zcarba@gmx.com](w/relay/CBB6074B15FF8BF9DF77FD4D083D6C585373E647)                                                                                                     |      0.07 |         1 | 2024-12-22   |
|  99 | [sabotage.net](w/relay/F9D235DA3EE3C5568A063DDDBC2A89890F71E708)                                                                                                       |      0.07 |         1 | 2022-12-09   |
| 100 | [relaytor at yahoo dot com](w/family/a162faf1b3ad9f3b38d1d1f4802e20504267c9a2e5f38ac7ea70ea237dcb6505)                                                                 |      0.06 |        12 | 2021-11-04   |
| 101 | [Nomad, Digital &lt;digitalnomad34@protonmail.com&gt;](w/relay/03216E9498B9688056F68E6F590FC206E9F40771)                                                               |      0.06 |         1 | 2025-01-02   |
| 102 | [billy819@mail.com](w/relay/0F938542D1C783D3DC0CB78CA53877290D9FB211)                                                                                                  |      0.06 |         1 | 2022-10-21   |
| 103 | [f46edmin@linuxmail.org](w/family/3ea7a11a6bdf49ba121a7992d8da6fb1f0d4361f007b91c38d1c06e4d5ec066a)                                                                    |      0.06 |         3 | 2022-04-13   |
| 104 | [Dev Null &lt;root@dev.null&gt;](w/relay/1F9F37C4EBD9E450AD61E745D49CEC05030D52BC)                                                                                     |      0.06 |         1 | 2024-09-30   |
| 105 | [darreng@posteo.net](w/relay/2483EFC5532F81C08CA48B15FA7F9AFAB3D2B041)                                                                                                 |      0.06 |         1 | 2024-09-01   |
| 106 | [Tor-Admins &lt;toooor AT all DOT de&gt;](w/relay/4B170476D09459328438F3E68ED19516C9F75A80)                                                                            |      0.06 |         1 | 2019-02-28   |
| 107 | [greorod1206@gmail.com](w/relay/83394E5B57988EFAD5102F1AF0E19E6FFCF8842A)                                                                                              |      0.06 |         1 | 2023-06-03   |
| 108 | [WSSH - &lt;wssh at gmx dot com&gt;](w/relay/98CDDAF76419C5DBCBCF512D87E3F99BA5F22770)                                                                                 |      0.06 |         1 | 2021-12-04   |
| 109 | [staaf@protonmaildotch](w/relay/CE9ED7FB244F80F6310A6DC399F904C202FD8068)                                                                                              |      0.06 |         1 | 2023-08-14   |
| 110 | [hole1@gmx.com](w/relay/D47EE2158B8410670208016497C0BB27AA704630)                                                                                                      |      0.06 |         1 | 2024-01-22   |
| 111 | [torcornholio at gmail.com](w/relay/45F4FE80352C1B30AAFA8FF8F5E5715F1A98F3AC)                                                                                          |      0.06 |         1 | 2023-07-07   |
| 112 | [mewtwowho at proton.me](w/family/21c6a68720f51e00c522b330de6f697546773762d02a3a2ce8adf65e15985dde)                                                                    |      0.06 |         2 | 2024-12-30   |
| 113 | [hot.taco.relay@protonmail.com](w/relay/B8E18CA62C1B7F6D077BAF2F92548ECA9E2DA0CA)                                                                                      |      0.06 |         1 | 2024-04-03   |
| 114 | [Effi.org &lt;tor AT effi dot org&gt;](w/family/725a367c290d2590645ff637b94e3eed17544f6a2c8631abdd98e71f7ecb385e)                                                      |      0.05 |         2 | 2018-11-13   |
| 115 | [dhnet.torcontact@gmail.com](w/relay/0A11C7546A1332412D1EBD13BD4C3D6A6644D7E0)                                                                                         |      0.05 |         1 | 2022-09-09   |
| 116 | [David Kabo &lt;mytorrealy@proton.me&gt;](w/relay/26F5D0F28B756CDB8FEF0081C8F0A26FCEB5F943)                                                                            |      0.05 |         1 | 2025-01-16   |
| 117 | [name is Blaze --- blazeready@Mail.com](w/family/947a6df30c23c6b66753dae9d0af9deb7359ad72e98709fb339ad9e5447fb6ba)                                                     |      0.05 |         2 | 2024-01-21   |
| 118 | [Bartosz Waszak &lt;waszi@httpx.pl&gt;](w/relay/132395E199674BC4E65EA90DA0150D51D12B8221)                                                                              |      0.05 |         1 | 2022-03-04   |
| 119 | [peoplesliberation@proton.me](w/relay/14AE2154A26F1D42C3C3BEDC10D05FDD9F8545BB)                                                                                        |      0.05 |         1 | 2023-07-06   |
| 120 | [mikael datanerd.se](w/relay/7AFFC971486FEADE7583170A616EA97DECA11190)                                                                                                 |      0.05 |         1 | 2024-10-19   |
| 121 | [&lt;tor AT busybear DOT se&gt;](w/relay/7BE9E2EF2BB41BB662D9A3CD68289B9E3DBF8A08)                                                                                     |      0.05 |         1 | 2019-02-18   |
| 122 | [&lt;statusquo@mailbox.org&gt;](w/relay/7D4389DC3BA69BECAB418D11E5E6B999014A70F7)                                                                                      |      0.05 |         1 | 2024-05-03   |
| 123 | [noc@as210630.net](w/family/ae873d10502be5fc88dbe7f89e590ff9a8f66b8263fbb6c5d71c3e0ad9cab8be)                                                                          |      0.05 |         3 | 2025-01-10   |
| 124 | [scofflaw@mailfence.com](w/relay/77D85A7CE40DA25AEDB73AA2D8762C547BE287F2)                                                                                             |      0.05 |         1 | 2024-11-05   |
| 125 | [Digineo GmbH &lt;tor AT digineo dot de&gt;](w/relay/B49649340BAABF74E9CA5D5014E45155382E0A13)                                                                         |      0.05 |         1 | 2024-05-23   |
| 126 | [a-n-o-n-y-m-e.net](w/relay/C54BBA45D25E64037CAA107C3699F327D9934A67)                                                                                                  |      0.05 |         1 | 2024-05-07   |
| 127 | [contact@cypher.re](w/relay/010D853EA9DC7BEAA3BF9B1910D0AF6439C43CAC)                                                                                                  |      0.04 |         1 | 2024-11-17   |
| 128 | [quetzalcoatl-relays.org](w/family/93395e779985d1f01b989ce655dd6ff615ceadf02bb0bb81006aaa9a167ed0d0)                                                                   |      0.04 |         8 | 2023-07-03   |
| 129 | [Resistance Change Freedom](w/family/1ce19397b939014bc9e4e622565f1f42b1e45413f84f143ddb4199ecd9ff2e75)                                                                 |      0.04 |         2 | 2024-03-01   |
| 130 | [Svea Hosting &lt;info@svea.net&gt;](w/relay/10B689D11CDCB8EB74BF394880508C975058C608)                                                                                 |      0.04 |         1 | 2020-07-28   |
| 131 | [quetzalcoatl-relays.org](w/family/27acefdf1fbded4b9aa8ba7f51dc2cb58c7f087f8e4224690664149886e9f0fb)                                                                   |      0.04 |         8 | 2023-06-03   |
| 132 | [a-n-o-n-y-m-e.net](w/relay/3B5B6351330FA96EF3527A1BBB3F389C2310E8E6)                                                                                                  |      0.04 |         1 | 2024-05-05   |
| 133 | [fulloffaith -SPAM-CUTTOFF- @gmx.com](w/relay/3E26373D9F491C3C11FAE484E2A705611D019C02)                                                                                |      0.04 |         1 | 2024-01-22   |
| 134 | [gk@torproject.org](w/relay/50485E03CA39D393BD54D315CEBA65E6DD0FDDB9)                                                                                                  |      0.04 |         1 | 2021-11-24   |
| 135 | [50E23506](w/relay/50E23506E5DC8576EB4E8F60751644364A3E13CE)                                                                                                           |      0.04 |         1 | 2021-09-25   |
| 136 | [favorite0ne @proton.me](w/relay/56E9E80B813A69AA6B72E4B464A7154142EC45F6)                                                                                             |      0.04 |         1 | 2024-01-21   |
| 137 | [judas priest doamin here](w/relay/7F0541B21603F5D4A17A75C5326CEBC37E8E9D74)                                                                                           |      0.04 |         1 | 2024-09-01   |
| 138 | [a-n-o-n-y-m-e.net](w/relay/90705D63956EDD5904D173F1998F421C5FC5B6FC)                                                                                                  |      0.04 |         1 | 2024-05-30   |
| 139 | [nashepro at proton dot me](w/relay/936AAC50D69C9A3E3B37BA258156547F000C8D9D)                                                                                          |      0.04 |         1 | 2024-06-28   |
| 140 | [Privacy Is @ Human Right Two](w/relay/D53C431C0C194310553C2C780B5733BF223B1078)                                                                                       |      0.04 |         1 | 2025-01-06   |
| 141 | [4096R/34650013 La Quadrature du Net &lt;tor@laquadrature.net&gt;](w/relay/D71B1CA1C9DC7E8CA64158E106AD770A21160FEE)                                                   |      0.04 |         1 | 2019-02-18   |
| 142 | [th3wanderlust proton me](w/relay/431C23492DE6169E6A5ACEB9B24033D58428C116)                                                                                            |      0.04 |         1 | 2023-05-28   |
| 143 | [relayfwy0Oo@gmail.com](w/relay/681EE8E76A96980BAC18EFE622E965FF709C30C0)                                                                                              |      0.04 |         1 | 2024-12-13   |
| 144 | [none](w/family/16faf099921a0d55d301748d269f9dc1c9068108023f9d99e3e8e02924f1753e)                                                                                      |      0.04 |         2 | 2024-02-01   |
| 145 | [-nighrydr88-privatemail-com-](w/relay/6F278A2CFF7C5C90E7BCDC8A8B148E914C79C284)                                                                                       |      0.04 |         1 | 2024-02-19   |
| 146 | [evansaike consultant com](w/relay/B4260AEC56DCECC301C89B117D754C605B0FA231)                                                                                           |      0.04 |         1 | 2022-07-22   |
| 147 | [mikael datanerd.se](w/relay/B5410AF840A3DA3DCDA1EEC093167311CEB432EF)                                                                                                 |      0.04 |         1 | 2024-12-07   |
| 148 | [B8CE7258](w/relay/B8CE72588C2314C6513BF4B3817856A4EB314F6D)                                                                                                           |      0.04 |         1 | 2024-08-28   |
| 149 | [the dude ------------------@---------------------- gmx.com](w/relay/E1C5E4857CD8E918FA03B1E15F1076D0A235B075)                                                         |      0.04 |         1 | 2024-02-16   |
| 150 | [frei.raum Technikkollektiv &lt;roland.k AT disroot DOT org&gt; &lt;https://frei-raum.epiz](w/family/6eb4e863c875c944fd902a6d0e3e9b8fc4d5e36f89de53804bf428182d574dbf) |      0.04 |         2 | 2019-09-16   |
| 151 | [Vulnix &lt;tor-contact AT vulnix dot net&gt;](w/relay/F319E2C484E2DE9001E6485F25064562D7EA8C6A)                                                                       |      0.04 |         1 | 2025-01-05   |
| 152 | [email:abuse-zuluu at protonmail dot com url:http://tor-exit.zuluu.net](w/relay/C09DFF947C9ED5C479B371C3BCAE7FF7D573F98C)                                              |      0.04 |         1 | 2023-08-20   |
| 153 | [YoyoYankee &lt;american AT protonmail dot com&gt;](w/relay/F745D5A34A289EF0C88544D0DC400B21120F5E81)                                                                  |      0.04 |         1 | 2024-07-21   |
| 154 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/003A08F1ADC002D24979C68AA5A33369C04D9C7F)                                               |      0.03 |         1 | 2023-11-09   |
| 155 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/05EA20BE14D0AC4F3D69DECF20F15A2E28353C0A)                                               |      0.03 |         1 | 2023-09-06   |
| 156 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/0B041A1650BD8989F9187AE553C9DB41783F114B)                                               |      0.03 |         1 | 2023-11-09   |
| 157 | [noc@0x7c0.com](w/family/568289c40df335fe3b7195e1c0e950a5626b982b2ad0672880a5844a0bfc61ed)                                                                             |      0.03 |         4 | 2024-07-26   |
| 158 | [gleebear@proton.me](w/family/cdd3fc6a9b3c2f0bb0182ed668f0d2fdb28bbd59477e1924785393fd58ce066e)                                                                        |      0.03 |         2 | 2022-12-09   |
| 159 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/22CDC8DE6BE8A6E6ED4A9FADF66740B8F1A29DE0)                                               |      0.03 |         1 | 2024-01-22   |
| 160 | [abuse at miner dot dk see https://www.miner.dk](w/relay/248A96B2A88A3EAB14699B9096CE6ABF77D0606A)                                                                     |      0.03 |         1 | 2020-07-02   |
| 161 | [7be58bbb-2028-4549-923c-93325619a0f1@anonaddy.me](w/family/588ab26502807550c11d60951958a6fcf1070439c5c436a6fb9fe873d4690b35)                                          |      0.03 |         2 | 2024-11-10   |
| 162 | [&lt; onion-exit @ /stagingdomain- dot -name&gt;](w/relay/5AA6370205AA611CED967BDB4D8EBCB9D5DB57A9)                                                                    |      0.03 |         1 | 2021-06-27   |
| 163 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/5AB3131D0B48E66C6770FB8E7BBA991D4A4F7D59)                                               |      0.03 |         1 | 2024-01-22   |
| 164 | [fuentescielo@cock.li](w/relay/5AC002A3FE3FFCF0FCC66A75FCFFC1F4B3786BDD)                                                                                               |      0.03 |         1 | 2024-04-16   |
| 165 | [yumpy&lt;at&gt;fastmail&lt;.&gt;net](w/family/0816458e9ae0c4d79b32e3a0ec888b66a854d6d2c78a9f3cdaa1c12794949bed)                                                       |      0.03 |         2 | 2024-01-22   |
| 166 | [your friendly tor relay operator/ Ulie Dein / CommanderDein @ proton.me](w/relay/5EF4629DB729712EF7FECBA74533BBF06704E00D)                                            |      0.03 |         1 | 2024-02-24   |
| 167 | [cl1ps.geamy at protonmail dot com](w/relay/6465578393CD74400E68E8A9F09B5375C1BB5C24)                                                                                  |      0.03 |         1 | 2025-01-16   |
| 168 | [Admin &lt;tor.uncharted624@passmail.net&gt;](w/relay/6796C85E7E1D547CAEC9D5CED6DE9068187288C6)                                                                        |      0.03 |         1 | 2024-01-21   |
| 169 | [quetzalcoatl-relays.org](w/relay/31AB04A3080091FECCAFD6B02B3D46BE9DB82FE5)                                                                                            |      0.03 |         1 | 2020-12-29   |
| 170 | [a-n-o-n-y-m-e.net](w/relay/36E4BEA3E092D05DC25F4CD29A9A5C7D9D0C7571)                                                                                                  |      0.03 |         1 | 2024-06-11   |
| 171 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/3D1D69A2A1254BD52A938D68C1AD4FBD31F1852A)                                               |      0.03 |         1 | 2024-01-14   |
| 172 | [&lt;nobody AT example dot com&gt;](w/relay/1137AB1F84EC2D52DFB1915717F14FF1A10EB392)                                                                                  |      0.03 |         1 | 2018-11-22   |
| 173 | [email:schroedingers cat riseup.net pgp:4A74E1B84035C1C989D0EA8C4209E0AFB4D47D88](w/relay/114F6F2A3A6E8AB9AC2BD54B8C5A204C1CA5942B)                                    |      0.03 |         1 | 2019-04-13   |
| 174 | [&lt;developing ATT keemail dott me&gt;](w/relay/127F6358F68FFB7E437DBA51D6D4DAC47B9F78A7)                                                                             |      0.03 |         1 | 2021-05-26   |
| 175 | [fritohlays@fastmail.com](w/relay/7FE7D3A5B11CCA6D2BC37F83B5674CF28F4B2FAD)                                                                                            |      0.03 |         1 | 2024-01-22   |
| 176 | [8F16229D](w/relay/8F16229D5425774DCA566D7737596178153DB838)                                                                                                           |      0.03 |         1 | 2020-04-03   |
| 177 | [987CFC56](w/relay/987CFC56FD7BE2B940B91D087C88F82386453663)                                                                                                           |      0.03 |         1 | 2022-05-23   |
| 178 | [CC3113E6](w/relay/CC3113E6D50D2CC7A1CAC94624DD2D6C0021F56F)                                                                                                           |      0.03 |         1 | 2021-03-29   |
| 179 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/CD92DB6464DDE96E1FDB2381B7DB92D2D31CC8B9)                                               |      0.03 |         1 | 2024-01-22   |
| 180 | [411361FD](w/relay/411361FDBEE704CEE86BF599257E117BC1F7063B)                                                                                                           |      0.03 |         1 | 2024-08-15   |
| 181 | [no-spam@example.com](w/relay/6C8FAF1A64CF7D4B956FC20FB94F8D1F94D18FFE)                                                                                                |      0.03 |         1 | 2025-01-15   |
| 182 | [turtlecute @ horsefucker . org](w/relay/9A5F67C5BA8DBD2C5E9FA00EBE5A81D7CCD79C81)                                                                                     |      0.03 |         1 | 2022-12-09   |
| 183 | [laladee@posteo.net](w/relay/9DBD92C848EEC352D542FBAC89DE2439271F699B)                                                                                                 |      0.03 |         1 | 2024-12-04   |
| 184 | [h0tch0c @caramail.fr](w/relay/A6CD7CA239580522C4B6ED93AFB9A058B275AD9E)                                                                                               |      0.03 |         1 | 2023-07-29   |
| 185 | [BAF223E9](w/relay/BAF223E9DF62D3261F1675C6CFC4E5D50F15FA57)                                                                                                           |      0.03 |         1 | 2020-02-13   |
| 186 | [supermp3man@protonmail.com](w/relay/EE72F8544BC46F6FFCDB47CCDB954E5AC642756C)                                                                                         |      0.03 |         1 | 2022-04-23   |
| 187 | [Tor &lt;tor@plutex.de&gt;](w/relay/EF9C4611FAA7C21155A8BA2A721DDC3D27816035)                                                                                          |      0.03 |         1 | 2019-02-18   |
| 188 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/F5A1575131F8EE7F41D72532592FA6A784821C4F)                                               |      0.03 |         1 | 2024-01-22   |
| 189 | [NO SOLICITING ////// jimbo263 ///// @fastmail.com ------](w/relay/BFF8AE91EA09B2207432CA4C60E449F3516E7C3D)                                                           |      0.03 |         1 | 2024-03-15   |
| 190 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C028378B070FC72B2AB9E5C93F6E292D841B9EAC)                                               |      0.03 |         1 | 2024-01-21   |
| 191 | [C4ECFD56](w/relay/C4ECFD56A447F7F32907683873A28287EA3A1E06)                                                                                                           |      0.03 |         1 | 2024-02-19   |
| 192 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/0138DDE95A04DF80DAF96111C93051BBBB6BF0A2)                                               |      0.02 |         1 | 2023-09-06   |
| 193 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/05EA56935F2740BDEDC6C67DF1D839A410E547A3)                                               |      0.02 |         1 | 2023-09-06   |
| 194 | [tor at localhost dot lu](w/relay/05FFA39D71DA116F7669EA4EE53A0BAEA315BA7F)                                                                                            |      0.02 |         1 | 2015-06-12   |
| 195 | [hnlexit@bsideshawaii.org](w/family/2e38d9c0bc47fc019d86071bf72fcb809a5df81a1165dc48981ea9fd6770170c)                                                                  |      0.02 |         8 | 2024-05-13   |
| 196 | [&lt;DONTPANIC&gt; &lt;gmx.co.uk&gt;](w/relay/0932F9009DCF32EC60FD52F975318D3F6E8E59F9)                                                                                |      0.02 |         1 | 2023-12-02   |
| 197 | [0xD5792C4C8C6F8DE8377949D1F48380B2EC8F9449 Tor Operator &lt;tor@teaparty.net&gt;](w/relay/2A36005A811C8B420F380D67C4A9D630655F0900)                                   |      0.02 |         1 | 2019-02-18   |
| 198 | [cris.sanders22@protonmail.com](w/relay/2B31FB827D4CEA734B9F78C16137CFD6F8AEBB7B)                                                                                      |      0.02 |         1 | 2019-02-18   |
| 199 | [0xA178459DC4EC1DA3 Ryan Omasta &lt;abuse dash tor AT ryand dot ca&gt;](w/relay/2BC257D07F517E58D2A9EF229708B539D5F7D96F)                                              |      0.02 |         1 | 2025-01-07   |
| 200 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/2CD63CEC51AD829787BCF22D6AD6DB46A6227CDD)                                               |      0.02 |         1 | 2024-01-31   |
| 201 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/2E446653FB9132BFEA79E07FA2ABF44D0138D7E3)                                               |      0.02 |         1 | 2024-01-22   |
| 202 | [kleku &lt;kleku AT protonmail dot com&gt;](w/relay/1C377BC2516F7F966BA0D9F965EC182477A35BCE)                                                                          |      0.02 |         1 | 2025-01-17   |
| 203 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/25477058A522069A16C1BCCB61DCB8C5B708756E)                                               |      0.02 |         1 | 2024-01-22   |
| 204 | [a-n-o-n-y-m-e.net](w/relay/25FC41154DCB2CAE3ABD74A8DFCD5B90D2CFFD57)                                                                                                  |      0.02 |         1 | 2024-01-30   |
| 205 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/5D4A69F36303D603AD7BA6B2A5A0CB8BA9A6F133)                                               |      0.02 |         1 | 2024-01-21   |
| 206 | [620562B7](w/relay/620562B7EA252030D579134EDC5045BA83C5F10D)                                                                                                           |      0.02 |         1 | 2024-01-25   |
| 207 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/650740A5AEE1C38B681039B5A6218166B9891C5B)                                               |      0.02 |         1 | 2024-01-21   |
| 208 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/33846FC102CD10D39F69517C501FFAABB07D82EC)                                               |      0.02 |         1 | 2024-01-22   |
| 209 | [345ADFD8](w/relay/345ADFD8F0DED72D6D2690A248D1E03AC90F0CCB)                                                                                                           |      0.02 |         1 | 2025-01-21   |
| 210 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/3A8919588E3AB85CAFD70C019A60251C597C092B)                                               |      0.02 |         1 | 2024-01-22   |
| 211 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/3CACB856C546B8195970DED8987D7E8C47006BB4)                                               |      0.02 |         1 | 2024-01-22   |
| 212 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/1787FF83F7828EDCA54D684D7B4DA99B4063BAC4)                                               |      0.02 |         1 | 2024-01-22   |
| 213 | [email me if you gotta u89b47 AT proton mail](w/family/6118f07fcd042e78056e8f5afb1f117e0066c3d2360cdb6f1de3e0e903c2a9f6)                                               |      0.02 |         3 | 2022-02-02   |
| 214 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/1851149F9CFB05971CF592FA00B9F29D8D71FDC4)                                               |      0.02 |         1 | 2024-01-22   |
| 215 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/187528ECDA723BFBEB80AA2906CA479F8D33E88B)                                               |      0.02 |         1 | 2024-01-22   |
| 216 | [slavy991 at protonmail.ch](w/relay/1AAC8733A118351B56FCBBD532E1D6F47A95022B)                                                                                          |      0.02 |         1 | 2023-07-19   |
| 217 | [postmaster@km30701-02.keymachine.de](w/relay/4A3B874F0187F2CF0DA3C8F76063B070F9F7A14F)                                                                                |      0.02 |         1 | 2024-10-07   |
| 218 | [pazcthy@mail.com](w/relay/4B61EC04E1797D8688475BD24EDA450914497D84)                                                                                                   |      0.02 |         1 | 2023-07-31   |
| 219 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/4D858FB8C79FDBBEF38D4B2561580DE50636CC12)                                               |      0.02 |         1 | 2024-01-21   |
| 220 | [privacy@tor-for-privacy.com](w/relay/4F4341441DDB5410FE6F9346A760DB8DBC90A8A1)                                                                                        |      0.02 |         1 | 2024-01-22   |
| 221 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/559D41FC8551439CD563657D69E203FF656962A5)                                               |      0.02 |         1 | 2024-01-22   |
| 222 | [bf two zero nine @mailbox.org](w/relay/58B81035FC28AACA8F0E85E46C8EBAD7FCFA8404)                                                                                      |      0.02 |         1 | 2024-01-22   |
| 223 | [art4096 proton mail](w/relay/825365C44650897970F158574AF29D42A33DE541)                                                                                                |      0.02 |         1 | 2022-09-30   |
| 224 | [emeraldonion.org](w/relay/887CB7C9DD87ADD7B0A2771280AC17ED913136A5)                                                                                                   |      0.02 |         1 | 2024-07-26   |
| 225 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/8F41B425EDAACEB88AB17E3F8751B53AE35DC725)                                               |      0.02 |         1 | 2024-01-22   |
| 226 | [&lt;c4t2816 at protonmail . ch&gt;](w/relay/90668E0C9E0E46E017D7D8FB842A2D23E9004E84)                                                                                 |      0.02 |         1 | 2023-06-29   |
| 227 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/91A5D6A1DE5D8248A8EE99D0099792BAEB80E03D)                                               |      0.02 |         1 | 2024-01-31   |
| 228 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/97E7C6EC9F18B3503EAA0960E009402A26BC7C3A)                                               |      0.02 |         1 | 2024-01-22   |
| 229 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/CCB4EF6BE592DFCF4CAED248085CC0F81A6201E6)                                               |      0.02 |         1 | 2024-01-22   |
| 230 | [D1E009FB](w/relay/D1E009FB5FBF7A494737EEFE17CD90B031BED281)                                                                                                           |      0.02 |         1 | 2025-01-17   |
| 231 | [subtype@protonmail.com](w/family/f77dc921d86415554392d8770fdf80dfd618b63798ba5e28a02cc69ff992925c)                                                                    |      0.02 |         2 | 2019-10-16   |
| 232 | [francois &lt; tor AT zof.sh&gt;](w/relay/D9C55AC5549BF4940BE0ABBBE0E34CCC8D6D06E5)                                                                                    |      0.02 |         1 | 2021-05-18   |
| 233 | [flowerstotheworld at proton dot me](w/relay/DAB938592E18820E54E50FE136171613125F4885)                                                                                 |      0.02 |         1 | 2025-01-14   |
| 234 | [&lt;thebunny.zone&gt; &lt;wintieria proton me&gt; &lt;B9F2F77BA5DC0FC325CB2D9CEDCC0454E6BC832A&gt;](w/relay/DE65BDE74816E940036FCC5F43926C65DE08C1C7)                 |      0.02 |         1 | 2024-09-03   |
| 235 | [potlatch protonmail com](w/family/f4abf23e26d49a1628b4523d07c8ba70cafeb0afd21c0213d9d5d60213ed4de2)                                                                   |      0.02 |         3 | 2019-02-18   |
| 236 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/40BEAF498BB2390D309A1C79A878BCBA78801CC4)                                               |      0.02 |         1 | 2024-01-22   |
| 237 | [&lt;sunshinecowboy56 AT protonmail dot com&gt;](w/family/d4520d9f440bda18174735694989f30764f2f9bd44350b7c908ea1e2ee8a3412)                                            |      0.02 |         4 | 2024-01-22   |
| 238 | [tor at d-ku dot de - 0x86d7bbcc54cbb356](w/relay/467D7417FFA611BC20227FE347494CE5F61218FB)                                                                            |      0.02 |         1 | 2019-10-26   |
| 239 | [copia297@proton.me](w/relay/4746E2B86718D5391CCF18C258460C321945DBD8)                                                                                                 |      0.02 |         1 | 2022-10-30   |
| 240 | [emeraldonion.org](w/relay/481313B7E49931D893B9DD4898AE6218C3172D99)                                                                                                   |      0.02 |         1 | 2024-07-26   |
| 241 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/49607163F41CF0E6A14D25F6E053BBB61FCDEE99)                                               |      0.02 |         1 | 2024-01-22   |
| 242 | [emeraldonion.org](w/relay/686486E748AA8C360A57E81E4ED915479740AF61)                                                                                                   |      0.02 |         1 | 2024-07-26   |
| 243 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/69513BAF07ABF547C8BCD4626D338D3CE959A513)                                               |      0.02 |         1 | 2024-01-22   |
| 244 | [6CFC47B4](w/relay/6CFC47B46E42A9D76D47B911FB719E65308014EE)                                                                                                           |      0.02 |         1 | 2024-01-29   |
| 245 | [a-n-o-n-y-m-e.net](w/relay/6F6CE59AC456500E505D82AF09ADFC583022DB87)                                                                                                  |      0.02 |         1 | 2024-01-22   |
| 246 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/72FFF034C9575CE5959DD616C77CC05D6D7B1203)                                               |      0.02 |         1 | 2024-01-21   |
| 247 | [teitel.net](w/family/0c8dbd3e2711faa5e704ffd38cb72f4fe72f22cb7f5795170f35d60178eac38f)                                                                                |      0.02 |         2 | 2019-12-25   |
| 248 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/76C9FBB8BFFF346326339FEFA2AC6DF96EB47D13)                                               |      0.02 |         1 | 2024-01-31   |
| 249 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/76E7A4833C0EEDCE1F9C959E00F7532F83BB3853)                                               |      0.02 |         1 | 2024-01-22   |
| 250 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/776F55CC446FCDF1AAC59496B4E2627829BAB939)                                               |      0.02 |         1 | 2024-01-21   |
| 251 | [&lt; loik93 @ mail 2 &gt; dot co](w/relay/99317933558461828D54706B64752830448EA124)                                                                                   |      0.02 |         1 | 2024-12-30   |
| 252 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/9B2A6CEDA8CAE94A78E49E8EEAD29F92F5C73D86)                                               |      0.02 |         1 | 2024-01-22   |
| 253 | [9C9B2A36](w/relay/9C9B2A363EA04E554D73CC8FBAC157EC81F41AEE)                                                                                                           |      0.02 |         1 | 2023-06-09   |
| 254 | [Jeff Burrows Jeff@privacywarrior.org](w/family/deece834e8962a4984acd0cbc1815341e00efcadf7116f24ba7ec9a5091c9202)                                                      |      0.02 |         2 | 2024-01-13   |
| 255 | [MIYOP @tutanota.de](w/relay/9EE1970E1AD558CF0F297537E32A449EB740CB9D)                                                                                                 |      0.02 |         1 | 2024-01-16   |
| 256 | [carbo1958@protonmail.com](w/relay/9F81E65D41BFCE0BCB47BE79108E30635E7A7A66)                                                                                           |      0.02 |         1 | 2024-03-08   |
| 257 | [recipe-acl@mit.edu](w/relay/A0B5B5906EB13F213D7CA9AFEC91934BE3A5930F)                                                                                                 |      0.02 |         1 | 2023-03-01   |
| 258 | [halanamili at pm dot me](w/relay/A5AEBB58BD8E17F74DEC3F6F8B8ACF410A8B1A9A)                                                                                            |      0.02 |         1 | 2023-07-31   |
| 259 | [A7F8FBDC](w/relay/A7F8FBDCB5D91093E6AFCD6480D48A97A24A5B71)                                                                                                           |      0.02 |         1 | 2024-03-16   |
| 260 | [DONT SPAM DONT SPY legalizeprivacy protonmail com](w/relay/A92D83E8F98941335076FFA47660BB87EB0AF2E2)                                                                  |      0.02 |         1 | 2023-05-24   |
| 261 | [matrixrevolution@mail2tor.com](w/relay/AAA9D692D1B3BE6788C7E86EA6ABEE3AB17C8289)                                                                                      |      0.02 |         1 | 2024-11-10   |
| 262 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/B1282DB8BB81873030D9E1FA95581A845BC65AB4)                                               |      0.02 |         1 | 2024-01-22   |
| 263 | [x12413@proton.me](w/relay/B196603D5593B557D2FB8735A44C1D947AF793EE)                                                                                                   |      0.02 |         1 | 2024-10-13   |
| 264 | [B1B687C3](w/relay/B1B687C3C4EF46249D638DCE77DDC7AAA39F2996)                                                                                                           |      0.02 |         1 | 2022-02-02   |
| 265 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/B4E8EAB5FEA39F9A2F0BFF46D3BB455B899F1D3D)                                               |      0.02 |         1 | 2024-01-22   |
| 266 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/EBE441C222E132263E4FC5FDC5051C149FB67E29)                                               |      0.02 |         1 | 2024-01-22   |
| 267 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/ECD85A84ED8EF173889F44B1CF750D6A0A2A6998)                                               |      0.02 |         1 | 2024-01-22   |
| 268 | [torzpi222 AT gmail dot com](w/relay/ED43B78B647367E8601F094B3B7238C5E9C45930)                                                                                         |      0.02 |         1 | 2022-10-20   |
| 269 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/F0C802BA1D2379EBE4F86037A752015627C87E08)                                               |      0.02 |         1 | 2024-01-22   |
| 270 | [F1B7D9D7](w/relay/F1B7D9D7533B4AEE2B56AE9F14213A8C271D2001)                                                                                                           |      0.02 |         1 | 2025-01-19   |
| 271 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/BCFE78B4FE68FA812F807AE7FDABA59C37EA6C86)                                               |      0.02 |         1 | 2024-01-22   |
| 272 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C27D17E70B6C5FAF8022FC4ECE2E6008355B2450)                                               |      0.02 |         1 | 2024-01-22   |
| 273 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C28E72CF478CF687A156BF979AB5F2DD35628A37)                                               |      0.02 |         1 | 2024-01-21   |
| 274 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C7E68324F2676CDA23DE7EB43802928D417AA3F5)                                               |      0.02 |         1 | 2024-01-22   |
| 275 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C9368A555C2C31B9B610CF48DE3C4647C84C51EF)                                               |      0.02 |         1 | 2024-01-21   |
| 276 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/F6A4872F38E2851BDE2871B7FADD64A992A7661D)                                               |      0.02 |         1 | 2024-01-22   |
| 277 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/F88691C71CF4F81B1BB40B05DC05812FC835395F)                                               |      0.02 |         1 | 2024-01-22   |
| 278 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/FB8213663E2EFAAB8B58D2DC24F5E4ACF0DD0144)                                               |      0.02 |         1 | 2024-01-22   |
| 279 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/FC90E28556DED669D3582AAD52311C6B04F57436)                                               |      0.02 |         1 | 2024-01-22   |
| 280 | [Kamala for president 2026 Leave Yo Bih get a Dog HELP the Tor Network MOST run](w/family/f3d9f2a8f6f926d5ba2be2ea3f0355d8d86c02ef98d0cc31bfde1e56d75a558d)            |      0.01 |         5 | 2025-01-20   |
| 281 | [fakeblackhatter @ proton.me](w/family/afdb5f928914db20defcd7e9e921b4d434b053a45a37e951ea4c37b51ed4a21c)                                                               |      0.01 |         2 | 2024-01-12   |
| 282 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/05DD02B8B23881A4B627F6E9AF32735EE7C09181)                                               |      0.01 |         1 | 2023-09-06   |
| 283 | [Random Person &lt;nobody AT example dot com&gt;](w/relay/04264780E59E843138D1661653377C80B04D8A54)                                                                    |      0.01 |         1 | 2024-08-10   |
| 284 | [Bit Vint; BitVint2024@protonmail.com; PGPKey: xjMEZuSyFRYJKwYBBAHaRw8BAQdAiClMTl](w/relay/0B07E5B82401DB8857F46B1C5DA915F7D85111F8)                                   |      0.01 |         1 | 2024-12-29   |
| 285 | [flowerstotheworld at proton dot me](w/relay/0D11B4CA3B66C696CFEC5769BD64B8067C664F95)                                                                                 |      0.01 |         1 | 2025-01-14   |
| 286 | [rufo &lt;tor at rufoa dotcom&gt;](w/relay/0E92BF02B3C11B0DD18301A0DE1B164A0546E36F)                                                                                   |      0.01 |         1 | 2015-05-27   |
| 287 | [torjockel@mailbox.org](w/relay/0F64A062EEB86CCFD243848263CD69B708BCE805)                                                                                              |      0.01 |         1 | 2023-03-26   |
| 288 | [2B34099E](w/family/28c4e9c7fe351acd9a417cc3f199e2bc15b373bf71b5cca5d7743aad17929621)                                                                                  |      0.01 |         3 | 2019-04-29   |
| 289 | [Random Person &lt;thud erasure020@simplelogin.com&gt;](w/relay/2B4D5AA9997D4DDFF02BC52E173CF0C8FFFD1B9C)                                                              |      0.01 |         1 | 2024-01-21   |
| 290 | [2BD1936E](w/relay/2BD1936E0B4D5BB615CF99B0CFF74EAF19426888)                                                                                                           |      0.01 |         1 | 2019-08-17   |
| 291 | [30DC46C6](w/relay/30DC46C6BD4CB4E2ADC5D87CD616939BDF0FF12B)                                                                                                           |      0.01 |         1 | 2024-01-21   |
| 292 | [Random Person blobster@tuta.io](w/relay/1E073339919F3AD1E82755A909CF458CCC6252D1)                                                                                     |      0.01 |         1 | 2022-10-20   |
| 293 | [blublufkfk AT inbox dot lv](w/relay/24733C4F64D092586A533F1BE852199D9983C3C2)                                                                                         |      0.01 |         1 | 2025-01-13   |
| 294 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/5B41F18219BC9C3097491CC02A9AE8C9B2D955A4)                                               |      0.01 |         1 | 2024-01-22   |
| 295 | [root@bred.rocks](w/relay/5CD6007FB6EE485474409680B90F034E6B925A3B)                                                                                                    |      0.01 |         1 | 2022-05-13   |
| 296 | [1024D/CF154167 Eirik Oeverby &lt;ltning dash tor AT anduin dot net&gt;](w/relay/5D263037FC175596B3A344132B0B755EB8FB1D1C)                                             |      0.01 |         1 | 2019-02-18   |
| 297 | [Aqua Ray Tor Operators &lt;tor-operators-fr at aquaray dot com&gt; 19rUv8F1y1xc2fL](w/relay/616081EC829593AF4232550DE6FFAA1D75B37A90)                                 |      0.01 |         1 | 2019-02-18   |
| 298 | [creepychris @ protone.me](w/relay/6319F26F9707CC74495C271C47DBE07A94775621)                                                                                           |      0.01 |         1 | 2024-02-21   |
| 299 | [VictorCrypto at the University of Michigan &lt;victorcrypto AT umich dot edu&gt;](w/relay/3514268910D8D6F69A060518DCD239362F9D361E)                                   |      0.01 |         1 | 2024-01-22   |
| 300 | [torzpi222 AT gmail dot com](w/relay/37DA4E982D98F675CD6A818F82EBA3473C7E1882)                                                                                         |      0.01 |         1 | 2023-05-08   |
| 301 | [0x18FFB9259E11C3BC69ABC8857E65272B32D3C971 f19.4jbg3@gmail.com](w/family/74683fef530f0a3be5f4e282087a726edf769b9665252a8f8f114dfd10283fd8)                            |      0.01 |         3 | 2022-07-22   |
| 302 | [&lt;TorRelayRep&gt; no bs plz at mailfence.com](w/relay/1363EB2417A5A3A64DD0D3A735594A2D019E1A86)                                                                     |      0.01 |         1 | 2024-09-01   |
| 303 | [Kim Peters &lt;petersko@mailbox.org&gt;](w/relay/16E60396757D934BBFCC8DD87F9C05B3D1F620DB)                                                                            |      0.01 |         1 | 2024-03-16   |
| 304 | [ricrubar @ tutanota dotde](w/relay/175D823779FBA9B6CCF1A1001FD19456073D60AF)                                                                                          |      0.01 |         1 | 2024-02-20   |
| 305 | [1A847774](w/relay/1A847774329EA9D3891D4B42246665DDE7E89850)                                                                                                           |      0.01 |         1 | 2025-01-02   |
| 306 | [amerdude &lt;amerdude AT protonmail dot com&gt;](w/relay/4B5F487F893D6B77646CF8185B0B66A302AC2A65)                                                                    |      0.01 |         1 | 2022-07-12   |
| 307 | [tornode2022@protonmail.com](w/relay/5076AB57B1D85197011DF5B28D8933737E281FC2)                                                                                         |      0.01 |         1 | 2022-10-10   |
| 308 | [gelios@onionmail.org](w/relay/51E3A292864BD46473858BA9D22A06604EE1731B)                                                                                               |      0.01 |         1 | 2024-10-08   |
| 309 | [55125574](w/relay/5512557491F87D888FC485FF6484265A754ABF53)                                                                                                           |      0.01 |         1 | 2019-02-28   |
| 310 | [torrelayoperator@tutanota.com](w/relay/58698C5E518D428DCA4D9780AD8379BB63B57B42)                                                                                      |      0.01 |         1 | 2022-04-13   |
| 311 | [quetzalcoatl-relays.org](w/relay/59A5BACFE32B6CA0F8F67B6621B3E8B89312CB7A)                                                                                            |      0.01 |         1 | 2020-12-29   |
| 312 | [thatgaydragon@protonmail.com](w/family/7dd61baf6a9c03e4d83ff52a0d20783265e90c180dffa3791fc9b8d8c7b83493)                                                              |      0.01 |         2 | 2024-08-24   |
| 313 | [815AE924](w/relay/815AE924755F1E63986E434A92A88EA1F75A60A3)                                                                                                           |      0.01 |         1 | 2021-01-08   |
| 314 | [rgzxwythod at p dot monash dot edu](w/relay/82431709D1C0284A93FF09B090FE00E627A2F8BB)                                                                                 |      0.01 |         1 | 2024-06-01   |
| 315 | [shallotrelay at fedora dot email](w/relay/831DD5C974E0152DFDF731A694DEDBF4D0D5F5E5)                                                                                   |      0.01 |         1 | 2024-01-21   |
| 316 | [Tor volunteer david.e.trujillo &lt;trujillosexit.proton.me&gt;](w/relay/83BF46C486384BEBB1642925910930012B1C6A91)                                                     |      0.01 |         1 | 2024-01-21   |
| 317 | [donatello@cocaine.ninja](w/relay/88EF3F81A4936A3D5C619F852C70A2A673FA754A)                                                                                            |      0.01 |         1 | 2024-03-26   |
| 318 | [katawaredoki.net](w/relay/892A827BF67DB270E303677A33FE577069DDE558)                                                                                                   |      0.01 |         1 | 2019-02-18   |
| 319 | [8B4BDD0C](w/relay/8B4BDD0C0D6176F0408B6B70CB896D4BAC9C9364)                                                                                                           |      0.01 |         1 | 2025-01-19   |
| 320 | [8D1085E8](w/relay/8D1085E818D0473EC693E3B0911FF18741F1F2DF)                                                                                                           |      0.01 |         1 | 2024-01-29   |
| 321 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/9011E251718D4D3352DF1A4660F78FECCD98AFDC)                                               |      0.01 |         1 | 2024-01-31   |
| 322 | [a-n-o-n-y-m-e.net](w/relay/969F1D67A2115F571D31EFF9F3832829ED7C9C05)                                                                                                  |      0.01 |         1 | 2023-08-12   |
| 323 | [panthera000 AT xmail DOT net](w/relay/97828A82F4A1ACBA2C1F6B860E5436286BC2D623)                                                                                       |      0.01 |         1 | 2025-01-05   |
| 324 | [Osservatorio Nessuno &lt;exit AT osservatorionessuno dot org&gt;](w/relay/CBFD3B3032BFB9C2F8B21A0CD0D4E7D098A6317B)                                                   |      0.01 |         1 | 2024-12-20   |
| 325 | [N/A](w/relay/CD94752BFBC94EC82F081B86E95241BB71D7CF99)                                                                                                                |      0.01 |         1 | 2024-01-29   |
| 326 | [relaySquxXU@gmail.com](w/relay/D15251B36771DEF654801C7786759D5AB448F08D)                                                                                              |      0.01 |         1 | 2025-01-17   |
| 327 | [D5228FA5](w/relay/D5228FA5AA9FDB3825E6F199AFA9F9E6F9526A17)                                                                                                           |      0.01 |         1 | 2019-02-28   |
| 328 | [weeniehutgeneraltorATproootooonmaaaiiilDOOOTCOOOM](w/relay/DAACECD0C2A5BB05FEAA0F25CD6BA39A3E8C6D46)                                                                  |      0.01 |         1 | 2024-12-28   |
| 329 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/DAF646F319498E9FA0C72A8E1C05160D67C614E1)                                               |      0.01 |         1 | 2024-01-22   |
| 330 | [Tor Manager &lt;tor@ibiblio.org&gt;](w/family/76fa0fa73af5210648a27e4df2ed67af7fbcd2092a641086a26b9f3797dc3262)                                                       |      0.01 |         3 | 2019-02-18   |
| 331 | [Bob &lt;exit000bob@gmail.com&gt;](w/relay/4637E79752D5086DD832564924DD455FC7D74683)                                                                                   |      0.01 |         1 | 2024-01-22   |
| 332 | [79D1CBF5](w/relay/79D1CBF51A1FDD140E1733672EDF94C4C1E9C57D)                                                                                                           |      0.01 |         1 | 2024-12-26   |
| 333 | [orangemaster674@proton.me](w/relay/9965E826830CC05485DC22EC8E210AC9859C4D26)                                                                                          |      0.01 |         1 | 2024-12-25   |
| 334 | [ineatery-calator openmail D cc](w/relay/9BAAA9CBA3109C2C807F2E84D5C9C0C8C147DCE6)                                                                                     |      0.01 |         1 | 2020-03-24   |
| 335 | [Random Person &lt;nobody AT ostehaps dot dk&gt;](w/relay/A1526DD0BACC4499101AE59586298DFD55D2534A)                                                                    |      0.01 |         1 | 2022-07-22   |
| 336 | [A1617C69](w/relay/A1617C69B4356D8DDBCEC630CE61AD22DEB71DCB)                                                                                                           |      0.01 |         1 | 2023-08-12   |
| 337 | [a-n-o-n-y-m-e.net](w/relay/A5CF1EAF3C0C3D998A99C8127046FCA0F8B69723)                                                                                                  |      0.01 |         1 | 2024-10-26   |
| 338 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/A8167AE8DA6B463050091A9E5C5B764360E81159)                                               |      0.01 |         1 | 2024-01-22   |
| 339 | [ashlygrp@mail.com](w/relay/A9C1886D47A57EB11D85D8635089B71EE7102DE7)                                                                                                  |      0.01 |         1 | 2023-02-21   |
| 340 | [tor bruzzzla.de](w/relay/AA837AA03D57BD723D0EC31D179429E5B409F79C)                                                                                                    |      0.01 |         1 | 2024-11-12   |
| 341 | [blipp46@fastmail.com](w/relay/AAA2822835CE85D0C623134AFF01093947D73176)                                                                                               |      0.01 |         1 | 2022-12-09   |
| 342 | [idom@cock.li](w/relay/B1AA9E3D8D07DB5873E2036BDBEE079BFA263EB4)                                                                                                       |      0.01 |         1 | 2024-12-25   |
| 343 | [Wyliefowler at g mail dot com](w/relay/B7327B559CA1531D182386E21B4868FCB7F0F456)                                                                                      |      0.01 |         1 | 2021-12-04   |
| 344 | [Vytas &lt;vytas687@protonmail.com&gt;](w/relay/B882ECD090C8128746E9012756424CED20759F76)                                                                              |      0.01 |         1 | 2022-12-09   |
| 345 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/BCBC26684E41BEE0651A1C763ADD91517BD9594B)                                               |      0.01 |         1 | 2024-01-22   |
| 346 | [mailto:iangtornode@cs.uwaterloo.ca - 12UfuXzi5m3PmW5ask1Pc6BnBNe3cgKQan](w/relay/BCEDF6C193AA687AE471B8A22EBF6BC57C2D285E)                                            |      0.01 |         1 | 2019-02-18   |
| 347 | [c4sey.dadot at protonmail dot com](w/relay/E029FF0A9723031FC1139D557357C07A211BFE4E)                                                                                  |      0.01 |         1 | 2025-01-16   |
| 348 | [E0688984](w/relay/E068898472A6FAC41D424FB5E124136C4BA69507)                                                                                                           |      0.01 |         1 | 2023-07-01   |
| 349 | [email:comotion hackeriet.no uri:cereal.hackeriet.no proof:uri-rsa ciissversion:](w/relay/E379A6CACEFAFE1B8EA68503BFCFF1215BF1EE7F)                                    |      0.01 |         1 | 2019-02-18   |
| 350 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/EC50BC7361203B7E3DB644E883BBF44814255C99)                                               |      0.01 |         1 | 2024-01-22   |
| 351 | [MatrixOperator &lt;matrixoperator AT protonmail dot ch&gt;](w/relay/ED56784CA6686229534003F01F869D30720B14DB)                                                         |      0.01 |         1 | 2024-07-02   |
| 352 | [Amer Dude &lt;amerdude AT protonmail dot com&gt;](w/relay/C03BAA3238792C65EEECCB9791C543164F23AB91)                                                                   |      0.01 |         1 | 2024-03-29   |
| 353 | [a-n-o-n-y-m-e.net](w/relay/C36595014939C7B211BCD87502CA37431AF9C15E)                                                                                                  |      0.01 |         1 | 2024-05-29   |
| 354 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C6F67C12A06995DA9290857A23CC636F1FEEBB33)                                               |      0.01 |         1 | 2024-01-22   |
| 355 | [----CHIMPEMPEROR-AT--skiff--DOT--com](w/relay/C8E441DBFECA4EB09A71988405838EE344B59CFE)                                                                               |      0.01 |         1 | 2023-05-06   |
| 356 | [5h098y32 at duck . com](w/relay/C930451331FE2A3BE423C62E45F5C43EA7D06207)                                                                                             |      0.01 |         1 | 2024-08-28   |
| 357 | [0x3FBCCE84D378F232223CCF6637E31222F67A9925 TorOnCampus &lt;toroncampus at uni-goett](w/relay/C9D9FA7EC056D62CC9671F4804F22A0926A11873)                                |      0.01 |         1 | 2021-07-27   |
| 358 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/CBC24A50338BF8D79D3872BCD5383156097A519A)                                               |      0.01 |         1 | 2024-01-21   |
| 359 | [teap0t admin &lt;admin AT teap0t d0t com&gt;](w/relay/F97CC0ED99EF53EB88FB2FB828CD04E4F7E270C4)                                                                       |      0.01 |         1 | 2023-02-21   |
| 360 | [01181B31](w/relay/01181B31BE5860C7D66DA88F88AD522C06470FD9)                                                                                                           |      0    |         1 | 2018-03-19   |
| 361 | [18143105024@163.com](w/relay/01E0F6FB1C36050C4AAC0AFC6FFA6D2D3E9D6880)                                                                                                |      0    |         1 | 2024-08-17   |
| 362 | [timetoreload@protonmail.com xmr:849QhLyrsd9ZVEin7WQMveij5adgcGreo3eSth1Zzq1V5sAu](w/relay/02A8CCB1FB70984226231283596DA734A80E3F6F)                                   |      0    |         1 | 2022-04-27   |
| 363 | [Frans Veldman &lt;tor AT fransveldman DOT world&gt;](w/relay/0321C0C3E51DA94199706CA42F5794B607E395B9)                                                                |      0    |         1 | 2023-06-22   |
| 364 | [tor@centerfortlc.com tor-relay.co 14kmchJcCVVEor1MVSXzfYUL8VQ5JqR9VM](w/relay/03A33C3454FC0F9AC6966F12FA486999F5A22896)                                               |      0    |         1 | 2018-01-05   |
| 365 | [Email: linuxenby at protonmail dot com Website: linuxenby dot is XMR: 83XuMrHLbr](w/family/ce26790a222d2be6737c2b529d19df13e5d833478bb7a66e9b6b8f0622ac692e)          |      0    |         2 | 2024-12-01   |
| 366 | [a-n-o-n-y-m-e.net](w/relay/0D9C0A3DCBF188F3CC364937EE2C16BAEFAA83AE)                                                                                                  |      0    |         1 | 2024-08-13   |
| 367 | [TorExit1 contact@blockbreaker.org](w/relay/0DA306A1AFD2C4A57283341108DEDFBFCA017C39)                                                                                  |      0    |         1 | 2022-01-13   |
| 368 | [k7mvF@proton.me](w/relay/0FEECA6B6F5A701313C476FD3078C4BB12DA2AF0)                                                                                                    |      0    |         1 | 2025-01-22   |
| 369 | [2753A4DE](w/relay/2753A4DED2584CBE86E16EAC4C37355BF07D9666)                                                                                                           |      0    |         1 | 2023-05-14   |
| 370 | [0x8652413B The Lebanon Public Libraries &lt;exit at leblibrary dot com&gt;](w/relay/27A5FD22519F0AF83927CEF1304EE19484247582)                                         |      0    |         1 | 2019-02-18   |
| 371 | [tor@privatebrowing.org](w/relay/2858C4BF05D57D7FEBEE28DEA82BAC374222F858)                                                                                             |      0    |         1 | 2024-03-27   |
| 372 | [Tyler Cipriani &lt;tyler AT tylercipriani dot com&gt;](w/relay/2892073608985977DED33F98A9FA27A9C47C8B61)                                                              |      0    |         1 | 2019-07-08   |
| 373 | [0x8acbab2d00b6adef81416beaf815d5cd87d25b75 Likogan admin at likogan dot dev](w/relay/292FCACE773DC259B799914A23BE65A6A6178E8F)                                        |      0    |         1 | 2024-01-22   |
| 374 | [GigaTux &lt;info@gigatux.com&gt;](w/relay/2AB0B91CCF12664D5D95083A6A7B871918C8CF9C)                                                                                   |      0    |         1 | 2019-02-18   |
| 375 | [a-n-o-n-y-m-e.net](w/relay/2ACD6E9FF8726CC04375D5871498D07B36748158)                                                                                                  |      0    |         1 | 2024-04-16   |
| 376 | [torextop AT pm.me](w/family/fb5e3cc1855a01ef74fc0843f63e3daac5d96672e8f6462f126b744c90e8536b)                                                                         |      0    |         2 | 2019-10-26   |
| 377 | [lopnet &lt;tor-exit at i8t dot com&gt;](w/relay/2C3071872DA75C4BA366762336F31ABADCD9A6A8)                                                                             |      0    |         1 | 2022-12-19   |
| 378 | [unzane.com](w/relay/2C4E15CD40EE3D2D6F062F04ADFE9B85C8C3C52B)                                                                                                         |      0    |         1 | 2019-02-18   |
| 379 | [a-n-o-n-y-m-e.net](w/relay/2FF8FFB28EAA635E291D623E03F231AC265F28F9)                                                                                                  |      0    |         1 | 2024-05-14   |
| 380 | [4E71835210698C55B7D0D7AC634211669EAF7176 admin &lt;allentown - tor - admin AT linux](w/relay/30EE4ED975A19F9CEFD6C9D516B49C688FBDA3A7)                                |      0    |         1 | 2024-01-21   |
| 381 | [k7mvF@proton.me](w/relay/312C9800E6F60EB3257422444B1CC01D0F1EFA0E)                                                                                                    |      0    |         1 | 2025-01-22   |
| 382 | [0x535E2411692D32C3B6407FA18F86F9DF371A5F64 &lt;initramfs AT initramfs DOT io&gt; - bc1](w/relay/1EEA2511471808FD26322F64D6969ACB18936448)                             |      0    |         1 | 2019-02-18   |
| 383 | [tor-jjlayton@proton.me](w/relay/1FBDC948CFEC4F0B5372A683F9BE1CD2EDB7774B)                                                                                             |      0    |         1 | 2024-12-30   |
| 384 | [0xA90AFCF81406CC27 &lt;sjk@dredel.com&gt;](w/relay/2037A6568C5771A5D8FF5C64FC1819247E6FEE7B)                                                                          |      0    |         1 | 2019-02-18   |
| 385 | [MakeSecure Tor Exit Abuse &lt;tor-abuse -AT- makesecure -DOT- nl&gt;](w/relay/22F74E176F803499D4F80D9CE7D325883A8C0E45)                                               |      0    |         1 | 2019-02-18   |
| 386 | [trumpinnagur12@gmail.com](w/relay/230AD43ECA2AFA421A1B7F8B7CBEEEC4A5D4AB01)                                                                                           |      0    |         1 | 2025-01-08   |
| 387 | [kibbleandbits@protonmail.com](w/relay/23B98C9982AE0B79A402A74664B6756F2F424679)                                                                                       |      0    |         1 | 2024-09-30   |
| 388 | [Callme361@proton.me](w/relay/23E1ECA2727D24A05B3407C0A686D0BA9D3D1A26)                                                                                                |      0    |         1 | 2022-09-20   |
| 389 | [4096R/0125D5C0 Philip Hands &lt;phil@hands.com&gt;](w/relay/261FC1359C92D19875CED3BC9CDFB83006CBFB87)                                                                 |      0    |         1 | 2023-07-05   |
| 390 | [Luca Saiu &lt;positron AT gnu dot org&gt;](w/relay/26AD3C1C18F1CD2B357A33FA7652A906DB13A8CC)                                                                          |      0    |         1 | 2016-09-11   |
| 391 | [jimmy2tone6@mailbox.org](w/relay/26B466A5152B058DB26878731AE453D22A8F4B21)                                                                                            |      0    |         1 | 2022-10-20   |
| 392 | [Assange004auX @ Finlay.wattle.id.au](w/relay/5412D862C7625F145E16D3D831F6D33A9FAF5EE9)                                                                                |      0    |         1 | 2020-02-03   |
| 393 | [tartedge2 @ gmx.com](w/relay/5A3319CD08B9334B21A3A2D0A51435BB88E46672)                                                                                                |      0    |         1 | 2022-09-30   |
| 394 | [poppy434@proton.me](w/relay/5B3B3E09BA5F1EB6F72A04FEAD81D9ACB88F8934)                                                                                                 |      0    |         1 | 2024-01-29   |
| 395 | [SPEEVES gmx.com](w/relay/5B5ADDC0911F5B5184DE6601308A655DDBA724B1)                                                                                                    |      0    |         1 | 2024-01-21   |
| 396 | [RandomPerson &lt;skynet@academyforinternetresearch.org&gt;](w/relay/5BDDDD3461CECAB3BBEF562334D014F0EE00DDD0)                                                         |      0    |         1 | 2024-05-15   |
| 397 | [andronikos sys@mail.ru](w/relay/5F6FBB9B007F7E5F6E73BCD2012437815E23139F)                                                                                             |      0    |         1 | 2024-02-05   |
| 398 | [5F875CFB](w/relay/5F875CFB7E2ED0D24E85A5A8B8904A3650AB1ED8)                                                                                                           |      0    |         1 | 2021-10-05   |
| 399 | [dhwon@fastmail.org](w/relay/6231257E90B8D00186E68FFF0C34AA6F1E0B6E55)                                                                                                 |      0    |         1 | 2024-03-24   |
| 400 | [&lt;me@nasrag.com&gt;](w/relay/66C7803C5F95CEC0D78004E15A0E4399CD0E4787)                                                                                              |      0    |         1 | 2024-04-12   |
| 401 | [RandomPerson &lt;skynet@academyforinternetresearch.org&gt;](w/relay/314A240F37F4A70B3A7EA941EFD02EE6D32C04D9)                                                         |      0    |         1 | 2024-05-15   |
| 402 | [bb@yy.hh](w/relay/31B8841E39F03E5E16A9211212E2C809089577D4)                                                                                                           |      0    |         1 | 2024-11-06   |
| 403 | [Random Person &lt;collard tethers0r AT icloud dot com&gt;](w/relay/34DCBA4990C6A597F1FE200715EEE648C7F1CCF8)                                                          |      0    |         1 | 2024-10-18   |
| 404 | [gut morgen@: chumli26 at mail , 0//](w/relay/3816B2B2F6E23AEAF8EF7070476F6AB6B96AAF8B)                                                                                |      0    |         1 | 2022-09-20   |
| 405 | [relaymijn a t gmail d o t com](w/relay/3921612C8455C340FE439B8C9B541C6E4A68E951)                                                                                      |      0    |         1 | 2024-12-12   |
| 406 | [tylersantos12 AT gmail](w/relay/3B4578D0C695D10C85851677AFB3FBA3109ABBE3)                                                                                             |      0    |         1 | 2025-01-23   |
| 407 | [a-n-o-n-y-m-e.net](w/relay/3B85067588C3F017D5CCF7D8F65B5881B7D4C97C)                                                                                                  |      0    |         1 | 2023-03-25   |
| 408 | [&lt;sunshinecowboy56 AT protonmail dot com&gt;](w/relay/3CEEAF497D470A560E4FC9A4523242F35A1594D0)                                                                     |      0    |         1 | 2024-05-12   |
| 409 | [3CEFC722](w/relay/3CEFC72244A56FA0BA7718AA6253FE6BF7E73CF4)                                                                                                           |      0    |         1 | 2025-01-23   |
| 410 | [Ralph Copeland &lt;copelandhosting AT pissmail dot com&gt;](w/relay/3D01CE600B2DC5C719684800E8C6990FE4CB8F9A)                                                         |      0    |         1 | 2024-03-12   |
| 411 | [Miska &lt;abuse@0xmiska.com&gt; or &lt;0xmiska@tutamail.com&gt;](w/relay/118EC6DCE6B26BFD358DA94E8C15DC14C9D21C4E)                                                    |      0    |         1 | 2024-11-24   |
| 412 | [Operator &lt;bubbabot03 gmail com&gt;](w/relay/12F3369E046656A3266B834DA7C7CDBE0B59F8E0)                                                                              |      0    |         1 | 2023-10-25   |
| 413 | [Babel Bard 3d0ozm3b42k7@opayq.com](w/relay/132A636386F5FC61A46C70065B03505281340C9C)                                                                                  |      0    |         1 | 2024-05-23   |
| 414 | [mg321@mailbox.org](w/relay/147321EDE839D266601E65A7FAAD306749B1EEC5)                                                                                                  |      0    |         1 | 2022-08-10   |
| 415 | [4096R/7176DC71 Jon Gjengset &lt;jon@tsp.io&gt; - 1KMjEjoQerKAMJ1ca95pXzCRzZsEhSpjAt](w/relay/1532A36172C70012B1057FBBFAFE2734EDBF4A3B)                                |      0    |         1 | 2013-03-10   |
| 416 | [167DCDA8](w/relay/167DCDA849A47EAEC227B584180CB3E220773151)                                                                                                           |      0    |         1 | 2020-04-23   |
| 417 | [c0wb0y @ aol . com](w/relay/19C64AF24E40C2CE5E3CA5231509213230B46F70)                                                                                                 |      0    |         1 | 2023-06-21   |
| 418 | [&lt;null at privacyrequired.com&gt;](w/relay/4E9A0F74D530EB9DD3C9075D4370738C24333E83)                                                                                |      0    |         1 | 2024-01-21   |
| 419 | [chirkrity6@privatemail.com](w/relay/4ED3097F3BACEE6DDCF761D6DEB132B63E50499D)                                                                                         |      0    |         1 | 2024-12-20   |
| 420 | [http://exitnodev8.v6.rocks](w/relay/4F19B88218263778258D3316511AB88DAFC25F2C)                                                                                         |      0    |         1 | 2024-03-29   |
| 421 | [JimmyG2 &lt;jg261 AT protonmail x.x CH&gt;](w/relay/4FF6F04CE3C4068DBA66283EA6497ED93281566D)                                                                         |      0    |         1 | 2023-04-28   |
| 422 | [tor-exit25896@protonmail.com](w/relay/4FF87F022EDDFD7BA551B63D4EE9CD8304EEBC26)                                                                                       |      0    |         1 | 2024-09-15   |
| 423 | [a-n-o-n-y-m-e.net](w/relay/54FAC042C6F2FDEB449DD5B9EDE6833D155C538B)                                                                                                  |      0    |         1 | 2024-02-02   |
| 424 | [galbrae @ proton.me](w/relay/55973F79052F02012C529F486D015FD61694E913)                                                                                                |      0    |         1 | 2024-01-21   |
| 425 | [7AC935CC](w/relay/7AC935CC22F82902204AC04C647D4CD901EF468E)                                                                                                           |      0    |         1 | 2025-01-23   |
| 426 | [7C27A9DC](w/relay/7C27A9DCFB4130295A33DB9CF2E082E515A88DC0)                                                                                                           |      0    |         1 | 2025-01-24   |
| 427 | [7D33FC2D](w/relay/7D33FC2D047493C6A514F5A4C1D70FCA54EA55DD)                                                                                                           |      0    |         1 | 2020-09-30   |
| 428 | [Brazilian](w/relay/7D4D6A197536F8F79E14B71C2446E0618D7CE6DD)                                                                                                          |      0    |         1 | 2025-01-23   |
| 429 | [bas.mountain@gmail.com](w/relay/7EFD46C8D872902D0AE4B1C648FE318737305761)                                                                                             |      0    |         1 | 2022-04-03   |
| 430 | [a-n-o-n-y-m-e.net](w/relay/7F59D722055FEE84ED7095E33FD2A42D967A5E34)                                                                                                  |      0    |         1 | 2024-07-03   |
| 431 | [8056080E](w/relay/8056080EE822B5CA1A8FFF52B7242A82C5E42FBB)                                                                                                           |      0    |         1 | 2020-01-04   |
| 432 | [unixeno@cubicchaos.net](w/relay/80914004BD527CE984A1576CA63AAA77944D9D2B)                                                                                             |      0    |         1 | 2024-01-22   |
| 433 | [amuse &lt;tor-amuse AT foofus dot com&gt;](w/relay/80E23F24D5BE0195D2827557D260D1676DEA5451)                                                                          |      0    |         1 | 2022-01-03   |
| 434 | [linuxvps@mailfence.com](w/relay/8225215EBC7FF94504D1AFE06E722977A6D36F3F)                                                                                             |      0    |         1 | 2024-03-13   |
| 435 | [n0p33king at tuta d o t io](w/relay/82F51CF025521F9827642B856BC0CCB72AFBAE64)                                                                                         |      0    |         1 | 2023-05-28   |
| 436 | [kr597ot2@anonaddy.me](w/relay/83C72101D7716EE515838CECF7AEF0A5B51D3ED6)                                                                                               |      0    |         1 | 2024-02-01   |
| 437 | [8428C02C](w/relay/8428C02CCD1CF01715C91F1819BA507C1A79A931)                                                                                                           |      0    |         1 | 2021-11-04   |
| 438 | [84640625](w/relay/84640625221A4E96309AFE0810B38646BC60F458)                                                                                                           |      0    |         1 | 2024-01-30   |
| 439 | [8561C0FB](w/relay/8561C0FB6552608735BA27225FF24A40E7FDACC5)                                                                                                           |      0    |         1 | 2022-03-24   |
| 440 | [0x18A24864 mailbox.org support team &lt;support AT mailbox.org&gt;](w/relay/85D4088148B1A6954C9BFFFCA010E85E0AA88FF0)                                                 |      0    |         1 | 2019-02-18   |
| 441 | [pczer@hushmail.com](w/family/a936d1fca2ce5843ff8ed55ffb26088676dc7dc196ffa606a16b859aa93c437c)                                                                        |      0    |         2 | 2022-04-13   |
| 442 | [8AA3E8CD](w/relay/8AA3E8CD23AA9AC8103BAF0ACFF4D12443C5A1F8)                                                                                                           |      0    |         1 | 2021-08-16   |
| 443 | [B34ch B0y &lt;kal4f0rni4@protonmail.com&gt;](w/relay/8BCC134CA1EA40BD8236B8493CF8D9C20E03CF2D)                                                                        |      0    |         1 | 2023-06-23   |
| 444 | [8DB2A65B](w/relay/8DB2A65B5B9691CD9722D2D497784BC3528F9413)                                                                                                           |      0    |         1 | 2025-01-08   |
| 445 | [m781@tutanota.com](w/relay/8E6581B1261B28F0AA95E0A8E19CE959925E5ADA)                                                                                                  |      0    |         1 | 2022-10-10   |
| 446 | [honey3031@rambler.ru](w/relay/8FB4F3DB65CBB602116BA34A3296FDD0847D67F1)                                                                                               |      0    |         1 | 2024-07-24   |
| 447 | [9366185B](w/relay/9366185B4ECB1CC3634F475D20FDDFE7A302BAF2)                                                                                                           |      0    |         1 | 2021-07-27   |
| 448 | [Donny &lt;laws.ofcomputers@gmail.com&gt;](w/relay/9489864F831668000BFEEAEE440DB25581275F4E)                                                                           |      0    |         1 | 2024-02-25   |
| 449 | [Tor Admin &lt;tor -at- cs -dot- bu -dot- edu&gt;](w/relay/94C4B7B8C50C86A92B6A20107539EE2678CF9A28)                                                                   |      0    |         1 | 2019-02-18   |
| 450 | [judgegao06@gmail.com](w/relay/95D2EC4CC7E936E460C7F3085FDC557171022907)                                                                                               |      0    |         1 | 2024-08-17   |
| 451 | [Tor Exit Volunteer &lt; NO robgr6 SPAM @proton.me&gt;](w/family/8955a12c6a7ead3e732bf0b36c1db568ee179048221ab12a177d69de82148f1b)                                     |      0    |         2 | 2023-05-10   |
| 452 | [&lt;sunshinecowboy56 AT protonmail dot com&gt;](w/relay/CF32AA6FAD3A4C01A446CEF8E1382BED88CA56F3)                                                                     |      0    |         1 | 2024-05-11   |
| 453 | [TorAdmin &lt;tor@toor.sh&gt;](w/relay/D254F3BE31EF901DE5C45D291F45F727B3B86B7A)                                                                                       |      0    |         1 | 2024-01-22   |
| 454 | [first@oniontb.anonaddy.com](w/relay/D2E5A276F9477D0E7787C46DFAE6438607D92171)                                                                                         |      0    |         1 | 2024-08-31   |
| 455 | [admin @ project-privacy.com.au](w/relay/D50B00B8199F76FA6D1FB448AAC1BA9EEB4CD400)                                                                                     |      0    |         1 | 2024-01-22   |
| 456 | [kalebmii2 at proton dot me](w/relay/D76D33B4866F2B61166E007C1DEFFEA82C5F1CDF)                                                                                         |      0    |         1 | 2024-10-22   |
| 457 | [ramo at goodvikings dot com](w/relay/D7A80E95892AAF51FF24CF7C2CE49311931B55F7)                                                                                        |      0    |         1 | 2019-12-05   |
| 458 | [anon1mous54@hotmail.com](w/relay/D7F156D1A77B9E5CB59EFEB9CBBB6EC93734DBA1)                                                                                            |      0    |         1 | 2022-11-19   |
| 459 | [DAFCB9F2](w/relay/DAFCB9F268B5F706AD4C17B557EB3C85C769A6FB)                                                                                                           |      0    |         1 | 2024-08-10   |
| 460 | [13018241850@163.com](w/relay/DBDEC96448E0B93709D83FDBA0CF2BBACAB9C2DC)                                                                                                |      0    |         1 | 2024-08-17   |
| 461 | [relayY1lenb@gmail.com](w/relay/DCCE7E81AFFD56A0AA5E4A8DEE31A74E5E4E3BC7)                                                                                              |      0    |         1 | 2025-01-17   |
| 462 | [email:rascal washboard539 AT aleeas DOT com pgp:DF0FF776D2D70719405BBAB5827A](w/relay/4050E7CA7EA55A70CBB43A3A936BCC123CDE203F)                                       |      0    |         1 | 2024-03-04   |
| 463 | [torproject.disjoin051@8shield.net](w/relay/408FB77704942B1DDB836335B42C25BEA47BE59A)                                                                                  |      0    |         1 | 2024-12-04   |
| 464 | [t at q dot com](w/relay/41E319407E67C001D82E55237E66E60044227391)                                                                                                     |      0    |         1 | 2020-10-20   |
| 465 | [gaditonecytor@gmail.com](w/relay/41F355D0D581B6DE853C0B8F7F6BF0EF7D334F44)                                                                                            |      0    |         1 | 2024-05-11   |
| 466 | [ger1atric@gmail.com](w/relay/43B834850DB78E4F9BE35A6FCEA0D95B9598F144)                                                                                                |      0    |         1 | 2024-03-08   |
| 467 | [Proletarian84 84thproletariat @ tuta.io](w/relay/441CCAA27C2CB5858E20121B1F4C3564129E0233)                                                                            |      0    |         1 | 2024-02-05   |
| 468 | [Harpy hp407b@tutanota dot com](w/relay/44B463F8DC2D257C651876B88D76B88B2B338799)                                                                                      |      0    |         1 | 2023-04-22   |
| 469 | [hello@relaymagic.org relaymagic.org/contact](w/family/1327af8bfa855b48212cfb20420c9bc849a19ad649f9b393a06bee441ffe7d31)                                               |      0    |         3 | 2021-03-09   |
| 470 | [Abuse at Texas4Tor dot com tor-relay.co](w/relay/4625F385CA5364CDD63C791893973B0CAD49C4E0)                                                                            |      0    |         1 | 2021-02-07   |
| 471 | [0x51B9E10210661F4C fidelity704 &lt;fidelity704@disroot.org&gt;](w/relay/4639E50D4C1A6F26D8ABD08DCB6A5801ABF64828)                                                     |      0    |         1 | 2024-02-12   |
| 472 | [mingles.97@hotmail.com](w/relay/473BAAC3D406686615B64AFCDC56C316CAFCDFBA)                                                                                             |      0    |         1 | 2024-05-06   |
| 473 | [eldernorn@gmail.com](w/relay/4780749994B23557F74586BA128B4DC01A546676)                                                                                                |      0    |         1 | 2019-02-18   |
| 474 | [yummycusard@proton.me](w/relay/48AFAF561D48B14579C909939550166838405CD2)                                                                                              |      0    |         1 | 2022-09-30   |
| 475 | [Relay Operator &lt;admin AT golosa dot info&gt;](w/relay/48B1FB945E08E3FC0F880110D6A76C87FAD993F0)                                                                    |      0    |         1 | 2020-09-20   |
| 476 | [andr788k at airmail dot cc tor-relay.co](w/relay/4954B51AF0CBADA08E4BC389DF1E3E419535165A)                                                                            |      0    |         1 | 2021-02-17   |
| 477 | [Gavruska777@gmx.de](w/relay/4A0E6789BB622D1F5909F4C58EF3C12D0508BC73)                                                                                                 |      0    |         1 | 2025-01-09   |
| 478 | [servicetor@nixy.moe](w/relay/683A42EFD4D650B8398840A3A19CA39CD961C7E2)                                                                                                |      0    |         1 | 2024-02-01   |
| 479 | [d98313227@gmail.com](w/relay/6BDDB87BD4F79460B1484795C12D5D54B0A1C820)                                                                                                |      0    |         1 | 2023-06-29   |
| 480 | [segfault123@protonmail.com](w/relay/6CB09DD5F42B741F416BDB6BE0E0CD3792CF3947)                                                                                         |      0    |         1 | 2024-08-08   |
| 481 | [qrczak at mailbox dot org](w/relay/6D480FF699AEE0EFF7FF2C92E26907E501E0B996)                                                                                          |      0    |         1 | 2023-08-18   |
| 482 | [tor.yyzz.dev](w/relay/6FF69B7CBB0EB8B905F343AC6B1A3215471E4E42)                                                                                                       |      0    |         1 | 2023-04-22   |
| 483 | [jacob.arick@pm.me](w/relay/7250852CEDDBA7E065EF3202882F4717318465D4)                                                                                                  |      0    |         1 | 2022-04-23   |
| 484 | [0x25B4C293 Matthias Urlichs &lt;matthias@urlichs.de&gt;](w/relay/7574975BA76DE0726231FC916DD70B09B3824CE5)                                                            |      0    |         1 | 2019-02-18   |
| 485 | [godeep@mailfence.comnickname g0deep](w/relay/77B87D2A3A55163170733483967910862236E6D2)                                                                                |      0    |         1 | 2022-09-10   |
| 486 | [Nicolas Christin https://cylab.cmu.edu/directory/bios/christin-nicolas.html](w/relay/78C7C299DB4C4BD119A22B87B57D5AF5F3741A79)                                        |      0    |         1 | 2019-02-18   |
| 487 | [&lt;cocolinofan@protonmail.com&gt;PGP: D8E7 0DAC 2CB9 F4DE 2728 00D5 8CCA F633 B685 9E](w/relay/78CFF6C66B9AF5CB6ED30472ED3BC39C423F0000)                             |      0    |         1 | 2025-01-11   |
| 488 | [0xFFFFFFFF Random Person &lt;tor AT kornnatter.dedyn.io&gt;](w/relay/9990BD426A0142F0A963E25AB8B7F40A9E81786E)                                                        |      0    |         1 | 2022-11-29   |
| 489 | [Trahn Ngyuen &lt;Trahnwins@proton.me&gt;](w/relay/99F41F2CE480F9D761B32A96327DF7454C207B9B)                                                                           |      0    |         1 | 2024-02-17   |
| 490 | [intern &lt;me@theintern.pw&gt;](w/relay/9BA8092290FC85C7E530646AA6BE63FBF80BFDF4)                                                                                     |      0    |         1 | 2024-01-22   |
| 491 | [clan.gardner at protonmail dot com](w/relay/9C24A441000E6636D4041FFFD669C8DD16672CBC)                                                                                 |      0    |         1 | 2022-08-11   |
| 492 | [t at randomperson dot com](w/relay/9C75417BC1177778632C97DAE76B08A3FC3C9AE5)                                                                                          |      0    |         1 | 2025-01-17   |
| 493 | [toradmin@colagioia.net](w/relay/9E88C7C50DA0639424A641E143A600010898A114)                                                                                             |      0    |         1 | 2019-02-18   |
| 494 | [a-n-o-n-y-m-e.net](w/relay/A0E1C5DBA20040BE6E291EE32B7949925159DEF4)                                                                                                  |      0    |         1 | 2024-07-20   |
| 495 | [TOR EXIT &lt;SUCK.IT&gt;](w/relay/A30C7006422806CBF18196C51024AF70F2F43BD1)                                                                                           |      0    |         1 | 2024-10-14   |
| 496 | [0x37C6224D225BCD7D Jon Proulx &lt;jon AT jonproulx dot com&gt;](w/relay/A53C46F5B157DD83366D45A8E99A244934A14C46)                                                     |      0    |         1 | 2019-02-18   |
| 497 | [A5B15D59](w/relay/A5B15D590C207446BFB6F739FCA67DE8C176F431)                                                                                                           |      0    |         1 | 2019-05-19   |
| 498 | [Random Person &lt;ee AT vajn dot icu&gt;](w/relay/A7055154DF2F7D61C6E951C009C15E8AF648D42B)                                                                           |      0    |         1 | 2025-01-14   |
| 499 | [brickbat at fastmail dot org](w/relay/A8BE7C1F596C5DAD1762F40E745C532EE7C51F06)                                                                                       |      0    |         1 | 2024-02-15   |
| 500 | [i.am.baidu](w/relay/AC9C91B182299EBD8F9A866FC9244CD9577799A7)                                                                                                         |      0    |         1 | 2023-02-27   |
| 501 | [viooop11x@protonmail.ch](w/relay/AD0A49F0476AAE4A7454345DFE2513D544C1558B)                                                                                            |      0    |         1 | 2025-01-22   |
| 502 | [DuckSounds31@aol.com](w/relay/AF4997738E0CFC014CD04FB09A670D2C5F1E79A4)                                                                                               |      0    |         1 | 2019-02-18   |
| 503 | [4mdeh8uy7pidm16 &lt;tor abuse@MalShare.com &gt;](w/relay/B0E93B10BD817250A818ABF7F5C2444AF364DD67)                                                                    |      0    |         1 | 2021-12-24   |
| 504 | [B3CF08E9](w/relay/B3CF08E9DF70D46BBEB5165A42D087DB352275DD)                                                                                                           |      0    |         1 | 2024-01-31   |
| 505 | [E5D3A99B2AC5B90EA5DB735767A71BE36A62FF0F tor at cyberjake dot xyz](w/relay/BA2AB4075B2D1F431DE74B2C22D23D430E1B2688)                                                  |      0    |         1 | 2022-01-23   |
| 506 | [t at randomperson dot com](w/relay/DF83376F3D87B4468F84768BC60ABF9CADF638B5)                                                                                          |      0    |         1 | 2025-01-20   |
| 507 | [carter@sullynode.com](w/relay/E0999C5F42D12204AA8038653DBACDCE1F40E7FF)                                                                                               |      0    |         1 | 2024-01-29   |
| 508 | [NIEN SPAM rgrwilco @ mailc.net](w/relay/E1B79753AAD5227001AA1CC697590B7A7CB82BB2)                                                                                     |      0    |         1 | 2023-07-31   |
| 509 | [Random Person &lt;collard tethers0r AT icloud dot com&gt;](w/relay/E2B723BFE7CA5524DA64B56E3FE122E87E62F220)                                                          |      0    |         1 | 2024-01-22   |
| 510 | [tor.admin at samic host domain](w/relay/E33CFFD6F03D53784993802B33DFAE2B178C60C9)                                                                                     |      0    |         1 | 2020-08-31   |
| 511 | [support@xmission.com](w/relay/E41B16F7DDF52EBB1DB4268AB2FE340B37AD8904)                                                                                               |      0    |         1 | 2019-02-18   |
| 512 | [Yuri Stuken &lt;stukenyuritor AT gmail dot com&gt;](w/relay/E801BFE9048106FB3E39A1B076CB03648CE93D8F)                                                                 |      0    |         1 | 2019-02-18   |
| 513 | [EB12A4C4](w/relay/EB12A4C4C3EE1B4301631532DD5D7FC65F10680A)                                                                                                           |      0    |         1 | 2024-08-22   |
| 514 | [px2@funetia.pl](w/relay/EB5DF0124A5EC281E82F0038B2F45FA7EC7C7C75)                                                                                                     |      0    |         1 | 2019-02-18   |
| 515 | [Jon@9072997.com](w/relay/EBC5F191AEC895A3AD3509FD063EC7F446228FE8)                                                                                                    |      0    |         1 | 2024-10-07   |
| 516 | [operator@ambient8.xyz](w/relay/ECE831534426279E32E530CDC9279D36E2A6AC60)                                                                                              |      0    |         1 | 2022-05-03   |
| 517 | [Tor Admin &lt;toradmin A@T esponde D0T net&gt;](w/relay/F0A1E8A5DFE14C18DAFBE99736F28AA3693C3117)                                                                     |      0    |         1 | 2023-07-11   |
| 518 | [F39D6295](w/relay/F39D6295CAF25E3959E53AD786D7A22CBD2D9823)                                                                                                           |      0    |         1 | 2024-01-22   |
| 519 | [ContactInfo email:miked riseup.net pgp:651CC8177A44A276 keybase:miked uplinkbw:](w/relay/F3A4250F63F253B656F78DAE71C75DD600638E95)                                    |      0    |         1 | 2022-03-04   |
| 520 | [lelis -at- zoho.com](w/relay/F485E06EE00880E89C21D10086AABF07776591CD)                                                                                                |      0    |         1 | 2023-08-08   |
| 521 | [t.yeerum@yahoo.com](w/relay/BD610AAEAE179EC259B022A178A75C70042407FB)                                                                                                 |      0    |         1 | 2024-04-10   |
| 522 | [hydra-family.github.io](w/relay/C0BF57D5EAFE114B12BC4156EF5B7B673ABC691E)                                                                                             |      0    |         1 | 2025-01-13   |
| 523 | [C0D3A1CD](w/relay/C0D3A1CD60BD92E899F3AA02E3DDFFC19811CE29)                                                                                                           |      0    |         1 | 2024-02-01   |
| 524 | [email:DicedOnions airmail.cc pgp:44518269EE80A8CD8519F4206CAF73918253E26B os:de](w/relay/C3233B1747A970F7043F090409F5893A9064EDE1)                                    |      0    |         1 | 2021-09-25   |
| 525 | [C5A6FEE5](w/relay/C5A6FEE5BC3BE19F5B9EB086CA95DAD393D8A4F6)                                                                                                           |      0    |         1 | 2019-02-18   |
| 526 | [RandomPerson &lt;skynet@academyforinternetresearch.org&gt;](w/relay/C5B6F0B1C59AAA8B8B9D46E74DBAF25EA6107789)                                                         |      0    |         1 | 2024-05-15   |
| 527 | [b9a3174g @ proton.me](w/relay/C5C7BC6C2CE769A1055AE3FC6A06878260CF314B)                                                                                               |      0    |         1 | 2023-08-20   |
| 528 | [dns@opennameserver.org](w/relay/C6763FBA664E0A4CE434850FAAFA59A6B9C63478)                                                                                             |      0    |         1 | 2022-10-20   |
| 529 | [chromacy@pm.me](w/relay/C6FFE2AB0CFFA86FB161DCB5BC72DA6A764E545E)                                                                                                     |      0    |         1 | 2024-07-18   |
| 530 | [throwawaycontact@protonmail.com](w/relay/C72A20FD33FB2A1E688495681488C3715A66CBA3)                                                                                    |      0    |         1 | 2022-03-14   |
| 531 | [jetplume36 t u t a n o t a c0m](w/relay/CA0AF0AB03DD75E83FC9344566989642E3D5E433)                                                                                     |      0    |         1 | 2022-09-20   |
| 532 | [0xFFFFFFFF &lt;boogly91mailfencecom&gt;](w/relay/CAAF196BBD92CA8BE0F64868D16B7DCD4A629A0F)                                                                            |      0    |         1 | 2022-09-20   |
| 533 | [Relay Admin &lt;tor AT crashme dot org&gt;](w/relay/CB3B9D9932A51F2A2E120EAE0B5F9409EE371E80)                                                                         |      0    |         1 | 2022-06-02   |
| 534 | [endressbgtor@gmail.com](w/relay/F6046200195C334EC3AE9847D118D981D0A7BD5C)                                                                                             |      0    |         1 | 2024-04-21   |
| 535 | [FAD8E4D5](w/relay/FAD8E4D5AFA95B0263FA9B1DEE94135D32C325F3)                                                                                                           |      0    |         1 | 2023-04-12   |
| 536 | [stayt.xenia241@hotmail.com](w/relay/FCBDA69EE953734B5E4A7305DD61D7BF3D3D2C20)                                                                                         |      0    |         1 | 2024-04-03   |
| 537 | [qfhlrud0@mailite dot com](w/relay/FDAFA1BD6B45D8FE09D62F6D282748F7919C8B0C)                                                                                           |      0    |         1 | 2023-08-12   |
| 538 | [ShadowExit@proton.me](w/relay/FE277F2B34C90904C1A2D704ED2A46FC0802400C)                                                                                               |      0    |         1 | 2024-08-30   |

<div class="datatable-end"></div>

### Guard Families

<div class="datatable-begin"></div>

|      | Authenticated Relay Operator ID or Contact (unverified)                                                                                                                         |   Guard(%) |   #Relays | First Seen   |
|-----:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------:|----------:|:-------------|
|    0 | [email:admin prsv.ch url:https://prsv.ch/ proof:uri-rsa ciissversion:2](w/family/87119f7e2b1b336fdf6429d53ff38a1619451120836f7fa20c35460a511607f5)                              |       5.47 |       231 | 2024-03-03   |
|    1 | [tuxli.org](w/family/688bf759a396dc0c171b2fcdcf8302cbd4dd913f4a1e29f7d0ac763471968014)                                                                                          |       2.82 |       101 | 2020-06-02   |
|    2 | [email:support rdp.sh url:https://rdp.sh proof:uri-rsa abuse:abuse as210558.net](w/family/ce5bc1f05a9359fb0051f7df9fe7364ff70709c0d46255f596c2354651a6a99a)                     |       2.29 |        92 | 2024-07-04   |
|    3 | [for-privacy.net](w/family/8b0a1698e9701148fe1f4f49cb27c1f579dce411952de942b889d4d08bfd2f68)                                                                                    |       2.23 |        86 | 2019-03-05   |
|    4 | [nothingtohide.nl](w/family/cdd109daf1976d63204efd66d89354222d57f8fbbca75cbaacd8e801fe56a9fa)                                                                                   |       1.99 |       108 | 2020-07-02   |
|    5 | [09AEBB99](w/family/15125c2a65904ef495f636be6faf122f3a426b074fbf3a45ec2b61e711fe0c1a)                                                                                           |       1.31 |        24 | 2020-07-22   |
|    6 | [quetzalcoatl-relays.org](w/family/e53b96a2e713f195c40b23066c02855e52d4b8312ec428806181618b988f9dbc)                                                                            |       0.81 |       350 | 2020-11-08   |
|    7 | [biogeobizz@nikora.biz.st](w/family/abf08ab4dc3090081c36891260774be8236a7bc709f39cc7d7dca10dfe7d1407)                                                                           |       0.74 |        29 | 2024-12-13   |
|    8 | [tor vidister de](w/family/360c14adcf6b21bdcf9a425811d44d2f948b6158a1052a685e658ff222b709a3)                                                                                    |       0.74 |         8 | 2023-11-11   |
|    9 | [ftp.halifax.rwth-aachen.de](w/family/886498b8b4381f76b4ad48f4d45079c31755564d5cbddb8282e3697168c106ec)                                                                         |       0.73 |         9 | 2021-07-17   |
|   10 | [shadowbrokers.eu](w/family/ef1a383fb7611508270f5449270081df029d1c254dc1e03b5dbfe98f6cd5fde4)                                                                                   |       0.68 |        27 | 2023-02-17   |
|   11 | [relay // at // pommespanzer // dot // cc](w/family/5724f24f4e9f0c64d26ed28486f85199f1d7b2b7d3e55d2b62ee73d194891fc7)                                                           |       0.68 |        26 | 2024-06-03   |
|   12 | [tor-operator@theu.li](w/family/5773405908235e49290e70f81c4bd220e1256242b3c8a5749fac3ad03331f769)                                                                               |       0.67 |        17 | 2022-12-31   |
|   13 | [gus@riseup.net](w/family/449ce42d7162a845a95e9ae91858ec62218e44be1f8bfa24597bbc9bc7099d63)                                                                                     |       0.66 |        16 | 2022-08-31   |
|   14 | [Hurdy-Gurdy &lt;admin AT my-mail dot rocks&gt;](w/family/1e225bfaffcc58003d2ae588f3a8216c92d6fa8c70c3de756b6a0d6b99706293)                                                     |       0.56 |         7 | 2023-05-10   |
|   15 | [email:torrelay limoneneis.de url:limoneneis.de proof:uri-rsa pgp:7BF6A4C298CC27](w/family/9006e8d0ca3c103507258cea792a44e106afa540748f48d53c6b82eca4441fd0)                    |       0.53 |         9 | 2024-04-21   |
|   16 | [Brandon Kuschel &lt;tor AT NOSPAM brandonkuschel dot com&gt;](w/family/098593149ac40b486e17384a6a7e36388d541e5ba4fa446bdf75649451945b8b)                                       |       0.47 |        45 | 2022-08-19   |
|   17 | [735B3810](w/family/08e05139158c2c30db407a4e94c7657be9ff5c55ead3933438c7daaa01f4189d)                                                                                           |       0.46 |         5 | 2024-08-18   |
|   18 | [www.f3netze.de](w/family/41de79b6591980723300320038e764274aa76efdba8d97331c8253c630ff707b)                                                                                     |       0.45 |        24 | 2019-02-18   |
|   19 | [cp tor mailfence dot com](w/family/6828d6cf95ae89f65a2472965a2bbd708862390633ad4d08703c7fc4a9d9a382)                                                                           |       0.44 |        18 | 2022-04-03   |
|   20 | [gojira-family.dedyn.io](w/family/e385ad57ec3f8c820899564eacef183c6ac9f2af63c66d51e4134fe1ab084a13)                                                                             |       0.43 |        12 | 2022-04-03   |
|   21 | [BMTY90VKYRQPUJZOTH @ Safe-mail.net](w/family/600c46e2ea3f5e74058bde039f03520e077048d7a8265452c5fc8ee1af76bcd7)                                                                 |       0.42 |        31 | 2019-02-28   |
|   22 | [Viktor &lt;vnikolov AT vnikolov dot cz&gt;](w/family/3e64411d4e8695d1aa1d6a86b95025db4d7a711e6529489e0db667ce2588f0fd)                                                         |       0.39 |         6 | 2022-09-20   |
|   23 | [kopfschusskorl@gmail.com](w/family/7c4aea12435a2ac1794c5e70f9999b4f7ae3498fc44132d47b9902c489479c18)                                                                           |       0.39 |         5 | 2024-04-09   |
|   24 | [j.abrahim99 at proton dot me](w/family/a2efd0e5df084c324d6a06e9aff0ad80ee19f14210460bb93fb982ead49cf2c4)                                                                       |       0.38 |         9 | 2022-07-12   |
|   25 | [digitalcourage.social](w/family/402d73786074e99e7d2ea8e637aca732fbe55256f2ed5a122047d18bb537ceac)                                                                              |       0.35 |        30 | 2020-07-12   |
|   26 | [email:fuwafuwapankeki@proton.me](w/family/3e6f6a3a768bb5af85fe44c66d20619c0cafc166e3e4a3fa77652b3276482c8b)                                                                    |       0.35 |        12 | 2023-07-21   |
|   27 | [www.cccs.de](w/family/5401b5c6fd3deb946e9864f7b2bfba241f1dabc0ee0b1ddae2be44e6b49687e7)                                                                                        |       0.33 |        42 | 2022-01-16   |
|   28 | [tor@dedi.zone](w/family/356f987ad26ef01a7843d3ca7d2811de63790be5ef299f5f35f18d7018fe7116)                                                                                      |       0.33 |         3 | 2024-08-17   |
|   29 | [flowjob at protonmail dot ch](w/family/5aaf65f12d37f8ebf3f0336bda3c3caf317478ff89ab180d48eed7b70358fde5)                                                                       |       0.32 |         9 | 2019-05-29   |
|   30 | [Contact at SilSte on Twitter tor-relay.co](w/family/9a28c6ad85dcf18af077cd6ed1e289f70449f36f80aa7ac708fd145d1eb1e1b7)                                                          |       0.31 |         8 | 2019-12-15   |
|   31 | [zwiebeltoralf.de](w/family/4f3fa866afc831a87abb270958d0f9b6d8123de8430184c5e1de712b30c4af02)                                                                                   |       0.3  |         9 | 2019-02-18   |
|   32 | [torarbert@delroth.net](w/family/1f7ea8be879a8b3668d3096408eaed6b89e3515dd981b5f1d402031859490bac)                                                                              |       0.28 |         3 | 2019-02-18   |
|   33 | [axstet.de](w/family/271f84a2bd6b1aa06652c0c7e47cf275b9a33ff33a13cde69200674dd0d0a948)                                                                                          |       0.27 |         9 | 2022-01-13   |
|   34 | [artikel5ev.de](w/family/112404eed179f708ec241c1243dc451989f66248bd61fa2a2da6cb9fc5f36039)                                                                                      |       0.27 |        27 | 2016-10-19   |
|   35 | [lokodlare.com](w/family/319484775b244a3b771e32435accb18b4ab42a702608f6e74eee8b9d644dbd5b)                                                                                      |       0.26 |        12 | 2021-11-14   |
|   36 | [2BCA0A8B](w/family/37aebda412cf7e37e30391b69c0e329324eec0d6ec2ba419f80be7234d5d19f0)                                                                                           |       0.25 |         2 | 2022-04-03   |
|   37 | [arbitrary.ch](w/family/aba671450d3f201e72fa3c7554efa89884374c584cdb0a599e076465fa838350)                                                                                       |       0.25 |         8 | 2019-02-28   |
|   38 | [Dave Null &lt;dave@null.net&gt;](w/family/5b3c94da5157c4a6e5c864f3e7c9f8588b9eb15c01c0d933df7b55d1125b8ff3)                                                                    |       0.25 |         8 | 2024-01-16   |
|   39 | [AA1474F6](w/family/cf77495b914cedf0b3851ac0ff2979b1988d4edf7ebf7d6d93e1fd89a7bd6c67)                                                                                           |       0.25 |         3 | 2024-12-10   |
|   40 | [middelstaedt.com](w/family/7cdf3fadd53acd400f32861a800244204f1f24ed05a3fc7712adec1122d67daf)                                                                                   |       0.24 |        19 | 2022-10-20   |
|   41 | [urquanrelays proton me](w/family/025cdd425a26b8f2209018b6a9ddccf4777e52d216fee19be0ec009d3bc17353)                                                                             |       0.24 |         2 | 2017-10-06   |
|   42 | [5h098y32 at duck.com](w/family/2d4cac92bd559e3c7e23ffb47b46247a3fb29be6d00c5dc2d8e4ed825c2b14f5)                                                                               |       0.24 |         2 | 2024-11-02   |
|   43 | [dotsrc.org](w/family/9865b6a9911eeb03241484047e1a87e8cf56ab5dd8b307f9f88c9025629a74a0)                                                                                         |       0.23 |        12 | 2020-09-10   |
|   44 | [GeoDB Tor Service &lt;tor DOT svc AT geodb DOT org&gt;](w/family/55610d1e88d35a4a178844863378be3da858de352a56523ae5ae1a3d018d13b5)                                             |       0.23 |         4 | 2022-04-03   |
|   45 | [6ACAECCF](w/family/0e407d7640030a3047dbdf015b1d1fa06f51d530cb97bec61693d958cf3543a1)                                                                                           |       0.23 |         2 | 2022-07-02   |
|   46 | [louis.weebl.me](w/family/b8631a298db619584598f1434693b073c563026efad0ad63ac1481395be3e6a3)                                                                                     |       0.22 |         3 | 2019-02-18   |
|   47 | [StayStrongServer &lt;staystrongserver AT yandex dot com&gt;](w/relay/ED9A731373456FA071C12A3E63E2C8BEF0A6E721)                                                                 |       0.22 |         1 | 2020-06-12   |
|   48 | [freiraum TK AT protonmail DOT ch](w/family/bc06f13b559c75195a3db6da53d6f7d3312da7d80be6b1f1ff89c979345c4cd4)                                                                   |       0.21 |        16 | 2019-06-18   |
|   49 | [dike &lt;at&gt; tor.rndsh &lt;dot&gt; it](w/family/9f8ee33eaba6a51518bb4e049e9de77c1dd2de45df8034feab5674d8bf0f1cf0)                                                           |       0.2  |         9 | 2018-11-25   |
|   50 | [Sh4d0wC1ph3r@proton.me](w/family/6c9a0f9665c0613aae7e30f1a87347badceac2e8a063c9dc5104d18e7a01f2d7)                                                                             |       0.2  |         2 | 2024-01-21   |
|   51 | [nos-oignons.net](w/family/d1c45eefa93e9afcc06447683ab4bbeb2a5f00a628053335ae7c868ce7242f25)                                                                                    |       0.19 |        39 | 2019-02-18   |
|   52 | [tor.r0cket.net](w/family/9393a5f7c52867fae73a02e65231b3fcf7bd473937f68d1409509045b5cdb03a)                                                                                     |       0.19 |        32 | 2024-09-26   |
|   53 | [alps at AT protonmail dot com](w/family/a3f29a1c0b0a9e30fadecd8dfff57bcc5840fe9d6a2a0b1d0d007d9708f0c951)                                                                      |       0.19 |         2 | 2023-12-29   |
|   54 | [null-f.org](w/family/2b28b41d99847a068c31f55a77b3786bb5a3fc915689e4e5eb31e14b02c4446d)                                                                                         |       0.19 |        11 | 2024-11-27   |
|   55 | [0xFFFFFFFF &lt;tormaster AT kkb-clan dot de&gt;](w/family/5348cbd1a28ed72a9635c5cb3d04f778a0dd3b1bce7c091a4978de94e88169ac)                                                    |       0.19 |         9 | 2019-02-18   |
|   56 | [Strelnikov@bahnhof.se](w/family/9d509066d8cb44632d062db6a87132d3b13b6859abf46d287f20e398d593db22)                                                                              |       0.19 |         2 | 2020-07-12   |
|   57 | [0xFFFFFFFF Random Person &lt;nobody AT example dot com&gt;](w/relay/BD2BC415D5D8AE3C34430E70EC82CF3B0C61BDDF)                                                                  |       0.19 |         1 | 2024-12-01   |
|   58 | [email:torix protonmail.com url:https://torix-relays.org proof:uri-rsa hoster:RD](w/family/d6793cfc497962f8d9fd4d00366a2bebdbeda5b7d72ab1809ef11b7e81b0531d)                    |       0.18 |        76 | 2021-08-26   |
|   59 | [Jonas Hess &lt;tor@jonashess.net&gt;](w/family/f6cc8651b3993a77c0accc4efe55f739df0691f1e066f3c80de5ee9d24ee3dfc)                                                               |       0.18 |         6 | 2023-01-28   |
|   60 | [enkidu-6.github.io](w/family/d8a71212edf7eb8706ca181cf241a9d709de5954d0b32b2ca2b8be7951630124)                                                                                 |       0.18 |         6 | 2022-06-12   |
|   61 | [Sponsored by https://tor.foundation](w/family/12cc8fc8f08c15c96c23569f758262b6d2b4d4bc6ec0e97c46e477d9e7192e9e)                                                                |       0.18 |         4 | 2024-07-19   |
|   62 | [terjan.net](w/family/a465262fd9e3cf34ce3351bd3e38c24eee2710c8b93562f8c8924fbd20035707)                                                                                         |       0.18 |         5 | 2019-02-18   |
|   63 | [zwiebelrouter.net](w/family/8351dcb820f7a11072837aa3bff2c6426561820438ab84b7b88b45928fe79b33)                                                                                  |       0.17 |         5 | 2022-03-14   |
|   64 | [Sponsored by https://tor.foundation](w/family/1ec1fd5607f5e48a6e99f5ade53ebaa84b26ee5a4b96d0c1763a72853a59417b)                                                                |       0.17 |         4 | 2024-07-22   |
|   65 | [9DC0D644](w/family/38264420453f84b58a927217fea72d23a820583cfcc355f80ab8fe4ee9bd4362)                                                                                           |       0.17 |         2 | 2023-07-01   |
|   66 | [0xFFFFFFFF Random Person &lt;niels AT nldo dot nl&gt;](w/relay/A7C2DF525D373D6A0C4F2540C3927ADF511124CC)                                                                       |       0.17 |         1 | 2024-05-07   |
|   67 | [Ariazonaa &lt;torproject@ariazonaa.net&gt;](w/relay/C9DE3C0F2BA06E8BB5F24152584E725E4AC79C6F)                                                                                  |       0.17 |         1 | 2024-08-25   |
|   68 | [torserver at xs4all](w/family/e8fac2642c4149b5b7b436ad074122e81f86ef8f0dc3b0ec2ebffd58b7ac103d)                                                                                |       0.17 |         2 | 2024-02-05   |
|   69 | [DFA46FE6](w/relay/DFA46FE65F01E255D544EF3E7DA9217D51096142)                                                                                                                    |       0.17 |         1 | 2024-02-15   |
|   70 | [max at freifunk-dresden dot de tor-relay.co](w/family/eb935c8a6aeb44cbf90f0c45b19f2d5a1edbeae48887a38a2b65d6780ffa1fce)                                                        |       0.16 |         2 | 2021-02-14   |
|   71 | [Behemoth Project Anonimity &lt;make-tor-great-again@encrypt.co.il&gt;](w/family/42cc31523fd2cfbcf7d66c2ae311466f7267670b888c61679341d52b71e86ed4)                              |       0.16 |         7 | 2024-07-21   |
|   72 | [19662E68](w/family/fd57ee037c627319820143168252077736a816d229f7692fb86ed2226cd36e3e)                                                                                           |       0.16 |         7 | 2024-09-24   |
|   73 | [wagner1.johannes@web.de](w/family/83124115cc9ff66aaca676c3baa34620f68b2dab922a6787102a8123972fb7af)                                                                            |       0.16 |         4 | 2024-08-16   |
|   74 | [Alexander Faeroey &lt;ahf@0x90.dk&gt; 0x61A208E16E7CB435](w/family/f0e3b270e7948a8f377d211520d341dc91824e47b1cb69e1a1045d1fc897a831)                                           |       0.16 |         2 | 2019-02-18   |
|   75 | [0xa1&lt;:at:&gt;mailbox&lt;:dot:&gt;org](w/family/f637ae76c6bdde6ea13c37362757745dd44622b611714e17caf4792932d21eb2)                                                            |       0.15 |         5 | 2020-03-01   |
|   76 | [James Taylor &lt;contact AT tor-servers dot fornoreason dot au&gt;](w/family/fb7df9fe244c138f712046cc3ca0dcb3c8b7383c82eed15b4c9827baa23eb6fa)                                 |       0.15 |         4 | 2019-02-18   |
|   77 | [darmstadt@fridaysforfuture.de](w/family/c9929371a06f2e5e4e6db8a98ec49f86d28368be45a7bd0db96ac1a1f91aeeb4)                                                                      |       0.15 |         3 | 2024-11-07   |
|   78 | [6520532F](w/family/e411dab74dc7c4c16528a631abc4e03228660a5765922e1123d92a5eebcc1c09)                                                                                           |       0.15 |         2 | 2023-08-04   |
|   79 | [lucaswerkmeister.de](w/relay/91892720F9262CB37B91A7176D3D2280F7AF14BE)                                                                                                         |       0.15 |         1 | 2021-01-08   |
|   80 | [99027C42](w/family/9e32965c7d0beb2cfdafb160a615ed55a195b389162f89c61a4955ec5b48fb49)                                                                                           |       0.15 |         2 | 2024-01-22   |
|   81 | [dplus26@fastmail.com](w/family/75d73ca37ce20dc74688b57cc5e1226c273300505622a284436a1bcdc3ee1808)                                                                               |       0.14 |         3 | 2023-01-05   |
|   82 | [doedelkiste.de](w/family/f00c457b1d2c994980771dba0aceb02010833b4695fb3370f2508e9489348d32)                                                                                     |       0.14 |         9 | 2015-10-18   |
|   83 | [4D0F2ADB](w/family/3864fe35065724fee1c5367a331a10f9d71f6b6e7b4eab2066b325eb5908262a)                                                                                           |       0.14 |         2 | 2024-01-21   |
|   84 | [email:relaycontact l33tn0de.cc hoster:hetzner xmr:43oxe3n61tLDTmRViE9Cm74ufQL2v](w/relay/67A54EDB7DADDBBC1E8A07F1EF82364BDAA896B7)                                             |       0.14 |         1 | 2021-11-14   |
|   85 | [email: ammirelay at boatmail.cc confmgmt:ansible ciisversion:2](w/relay/9BD0EE79BB9878DD6D8D8EA2A288D5E301E5C136)                                                              |       0.14 |         1 | 2022-08-01   |
|   86 | [B587EEC1](w/family/4beaa1074121e922bb346e4c00539d1a2a73be2c48b7382db1e4d094b5410d8a)                                                                                           |       0.14 |         2 | 2024-01-21   |
|   87 | [email:antifaang@freenode.cc](w/relay/BFC4044119080D8BEE70218978EE83C3FC16AE7A)                                                                                                 |       0.14 |         1 | 2021-11-24   |
|   88 | [email:peeps@arktis.cc btc:1bR2BRgZ3GgwL1iCW5rGr9Hv3xPNLfRms](w/relay/C45FE5C41ACC37E4EA4687FFC54A74F124739DAF)                                                                 |       0.14 |         1 | 2021-11-24   |
|   89 | [&lt;tor AT sutsuj dot com&gt;](w/relay/CC701FCE86D6AF95FC3D5B71645D3430794910C1)                                                                                               |       0.14 |         1 | 2020-09-10   |
|   90 | [StarApps GmbH, Switzerland](w/family/ce91cf12e4533f61a113535cab243eef081e9c077f77898c8f0c3533aed3fc36)                                                                         |       0.13 |         3 | 2021-10-01   |
|   91 | [haku19-@-mail.com](w/family/eb6d1efa4fc8d3bef3069eecc5d89f5cbbff3a464ee58fb3baa30f833fa85571)                                                                                  |       0.13 |         4 | 2022-03-14   |
|   92 | [Taj Rumbinji contact: taj@tajjina.cc](w/relay/0AE076CD2A4201BF2D90C325211A10D2C8DD6CE9)                                                                                        |       0.13 |         1 | 2024-05-27   |
|   93 | [tor@setsun.org](w/relay/2AA5F598F9A1812F01CD99E3B59BB87362ED7438)                                                                                                              |       0.13 |         1 | 2019-12-25   |
|   94 | [3544DD8F](w/relay/3544DD8F61D3BDEC8E812B80B61177FBD958ECCC)                                                                                                                    |       0.13 |         1 | 2024-10-29   |
|   95 | [3A04AC89](w/relay/3A04AC8969E55DF51C8D11C49ABF18A0CC847FC0)                                                                                                                    |       0.13 |         1 | 2022-05-13   |
|   96 | [queso/loco/at/tutanota/dot/io](w/relay/453D690B2108B814E237418FFF694D978BB63119)                                                                                               |       0.13 |         1 | 2024-07-17   |
|   97 | [Hi Mom im on TV bigmanstu at hidemymail dot xyz](w/relay/494E5000BA79F0078DFA05E610911C2AC525572F)                                                                             |       0.13 |         1 | 2022-12-09   |
|   98 | [ELON TUSK &lt;frosty at ovinet dot org&gt;](w/relay/50B7C4F6C18A3E5FC1D4E2ECE6B7B316B29FB26C)                                                                                  |       0.13 |         1 | 2022-11-29   |
|   99 | [Sponsored by https://tor.foundation](w/family/6b81a191fa91658d339a3eca8a33e7d179ffd8dfe330497281a813beee1743c6)                                                                |       0.13 |         3 | 2024-07-22   |
|  100 | [Sebastian Hahn &lt;tor@sebastianhahn.net&gt;](w/family/37d7f3cda2f6ae5b10f56e84e56b77b358bc4d641149ae2918b536f37fd26be4)                                                       |       0.13 |         2 | 2019-02-18   |
|  101 | [chocolatebyte.mvb0y@slmails.com](w/relay/67BE9A0658EF0106FCCB98FF1C68D6AAFFFC3CA9)                                                                                             |       0.13 |         1 | 2024-01-21   |
|  102 | [0320c8867fccd45d6a6f7a577ed09773f8929a6e CSGuard &lt;admin AT csguard DOT eu&gt;](w/family/b89a9ab59f5dc9c3b1d04f6ddfcc501b2a66cce875c052a9affb7008554cdea6)                   |       0.13 |         2 | 2019-02-18   |
|  103 | [Patrice Mail: patricerice@protonmail.com](w/relay/727EDD6ED7E462532417034475C16E552F14E7E3)                                                                                    |       0.13 |         1 | 2024-12-22   |
|  104 | [mkg20001.io](w/relay/9EEE861CD8A5FE26A1F276879323172F5B91082C)                                                                                                                 |       0.13 |         1 | 2021-05-08   |
|  105 | [email:gh0sthalo@moltencore.org btc:146KFigj4Lc6JjSp18EBTKB3vkLGb5m882 ciisversio](w/relay/B3D398B386FAF2CB78B447FBA46BF2648C3F48CD)                                            |       0.13 |         1 | 2021-11-14   |
|  106 | [email:chuckyhorror sublimestorm dot xyz Donate at xmr:439Ke5Rmd8bbpuQfXsdv4KdyD](w/relay/AF0E2DF4861795CD4CECE2A25686D2BC70C96D03)                                             |       0.13 |         1 | 2022-11-29   |
|  107 | [contact me at : darkknight &lt;AT&gt; binaryvault &lt;DOT&gt; net](w/relay/CA1684516B7FECF3DB76D43FD02F56D8B95E8A69)                                                           |       0.13 |         1 | 2022-08-01   |
|  108 | [Contact: peabodysrv AT odinbox DOT xyz 1GLB7QLpc4NFD6gHa3jt5oTNFnP2eYXC8S](w/relay/D8F4634366466972842F5102FE44738326E43DF0)                                                   |       0.13 |         1 | 2022-11-29   |
|  109 | [EE2A6210](w/relay/EE2A621042994B29452C12FF3B6F62D9E957758C)                                                                                                                    |       0.13 |         1 | 2022-05-13   |
|  110 | [gk@torproject.org](w/relay/FAF0A8829E39063669FA609B904E0FB8D5E1F23F)                                                                                                           |       0.13 |         1 | 2022-03-04   |
|  111 | [mcgraw feathers@wensleydale.cheese](w/relay/00030309EF47C06C3F0FDDA11067CD206092798D)                                                                                          |       0.12 |         1 | 2024-12-31   |
|  112 | [8or8ty8 8or8ty8email@mir4ge.cc](w/relay/049091E0582A6439D7AC7E157D32AB9319B8B78C)                                                                                              |       0.12 |         1 | 2024-05-26   |
|  113 | [dfri.se](w/family/6fb7a0af3654ec1c23c01edf49ae4770b655cf73b5309f2ebd6a29f844ee7387)                                                                                            |       0.12 |        32 | 2021-11-04   |
|  114 | [email:m1dn1ght foxxynodes.com ciisversion:2 btc:14FCyemK4nXThSH9HW3qn5xse1FN73E](w/relay/03D1EF3EF2BE5145150C58ACC72519DD860E61BA)                                             |       0.12 |         1 | 2021-11-13   |
|  115 | [disabled](w/family/75012dc64d71c0eee344a03f6be06d3c4a929f75a033ca38b69de5e4fcb73611)                                                                                           |       0.12 |         2 | 2024-12-02   |
|  116 | [KeFF NOC &lt;noc AT keff dot org&gt;](w/family/7eedfa16e179476528b51ccc4e17a8d0860e3645b279dc421c1c445f6ca78836)                                                               |       0.12 |        26 | 2020-07-28   |
|  117 | [playboicarti at chunguswire.me B.T.C: 1Nvp7LbJ8JsNRu4qPedZbimWR6q2MFAUwf](w/relay/427526EBD012CFE50FCFFCBFE221EFFE199AFA8C)                                                    |       0.12 |         1 | 2022-12-09   |
|  118 | [Alexander abuse@spynode.cc 8E28C7AAD6360D19802D6D5734FB3F3EDCB8B222](w/family/e91fd03ca577044f7808ab20a046fe5f0cba38ea55ad1f7d62c51346106172b7)                                |       0.12 |         2 | 2024-11-13   |
|  119 | [Markus &lt;markus AT mdfnet dot se&gt;](w/family/205be7ee0ce698b34926b0968def3a494ec5fe7234f98190a7824e3835bc7f91)                                                             |       0.12 |         3 | 2014-06-16   |
|  120 | [sloetor@gmail.com](w/family/f0d1e3a89d81d3206f08835582ec93f65c4e7951ceb3caf0707747b49f3dd3da)                                                                                  |       0.12 |         3 | 2022-01-13   |
|  121 | [vaino-relays at ywzmb dot top cii:2](w/family/9c727a5b5bf03fd4a689a35b3206ef350aad039db1e479edc3bfc5f1b50d9b2c)                                                                |       0.12 |         8 | 2025-01-05   |
|  122 | [tor at milkywan dot fr](w/family/e2110c1ef8b31a0bdb16029b9ffc360f1db69ae7fb6c212f6fa76e7040800a9f)                                                                             |       0.12 |         2 | 2019-02-18   |
|  123 | [tzancauraganul@proton.me](w/family/4e6589a6c8c007e2a36be6c558990010f0cf53fdcf1a58490bb542833bfb5bed)                                                                           |       0.12 |         8 | 2024-01-21   |
|  124 | [Mi Gibtsdonet &lt;nobody AT example dot com&gt;](w/family/ee02907dd96de44d6c0c4b7c7a42db6e699c6ae1e278b4f0784fb3094d96e5b2)                                                    |       0.12 |         4 | 2022-05-23   |
|  125 | [Random Person &lt;tor-server@mikitsu.me&gt;](w/family/b8cd068b2dde4e7baf2c280f64a3daafd2888bf2e26911411ceba5ee0522e8de)                                                        |       0.12 |         2 | 2022-07-22   |
|  126 | [b0at dot build3r at proton dot me](w/family/a14831ea64fd44e82b1c81b2c234e9ed470d7f361b95e4304066e4a576ff9db0)                                                                  |       0.12 |         2 | 2022-07-22   |
|  127 | [siroxcw@proton.me](w/relay/5A598836FE112DC9BAA7C5D6FCCFC419581B91C1)                                                                                                           |       0.12 |         1 | 2024-11-25   |
|  128 | [2048R/B640BF1A Tor Relay &lt;tor AT sec dot nl&gt;](w/relay/844AE9CAD04325E955E2BE1521563B79FE7094B7)                                                                          |       0.12 |         1 | 2019-02-18   |
|  129 | [Gaara Patrick M naruto AT wafflehaus DOT org](w/relay/A7A6BAAE17FB162164327C34229E7D0D81D4DC82)                                                                                |       0.12 |         1 | 2022-11-29   |
|  130 | [email:churrodawgsworld](w/relay/AC7C88D67339B90F2C10FF7B702DCB1EF3B8D663)                                                                                                      |       0.12 |         1 | 2022-08-01   |
|  131 | [2048R/B640BF1A Tor Relay &lt;tor AT sec dot nl&gt;](w/relay/ED2338CAC2711B3E331392E1ED2831219B794024)                                                                          |       0.12 |         1 | 2019-02-18   |
|  132 | [Support &lt;support at lunoxia dot de&gt;](w/relay/FE1AB3C4F9F90E13F85D9E4C7F915DD7DBC28CDE)                                                                                   |       0.12 |         1 | 2024-05-20   |
|  133 | [WELCOME TO THE CHUMBUCKET pl4nkton @ froggydispatch . com](w/relay/00DA4A3852EA5EF6841B8B4372DB0EFD3AB0BE92)                                                                   |       0.11 |         1 | 2022-12-04   |
|  134 | [not-real dot gmail.com](w/relay/0155DD3B3E26673F7EB1AA22E0A904BA434D1F00)                                                                                                      |       0.11 |         1 | 2024-11-06   |
|  135 | [enigma aet s0ny d0t net](w/relay/42B4F52C5B11E4D39855F654955425B0D5A0598B)                                                                                                     |       0.11 |         1 | 2019-02-18   |
|  136 | [anders.io](w/family/8e6ea473c6e046a85c5763d1e3214f7e42848ddf488353cad13c124878c8e3d7)                                                                                          |       0.11 |         4 | 2023-06-17   |
|  137 | [2269C990](w/relay/2269C9905B04530E251186FAD6F56033654E5C99)                                                                                                                    |       0.11 |         1 | 2024-11-11   |
|  138 | [Relay run by GhostBros ghostbros at sublimestorm . xyz](w/relay/2955D8C86F5848FD3469E3F38A027D3E169359D8)                                                                      |       0.11 |         1 | 2022-11-29   |
|  139 | [Snorlax &lt;pokemon365 at arktis dot cc&gt;](w/relay/5C386C4F91FD616F0F60F4E6D674D9E3F192C931)                                                                                 |       0.11 |         1 | 2022-11-29   |
|  140 | [Maria &lt;maria.mariposa1&lt;@&gt;protonmail&lt;.&gt;com&gt;](w/relay/5E52B6E15B81AB6428245080D007F4507C88E15D)                                                                |       0.11 |         1 | 2024-12-25   |
|  141 | [Totoro4219 &lt;totoro4219 AT mailbox dot org&gt;](w/family/35e7ab3681cad2b3603a12db4c92dd523f4bb21b6263df91e51fa8d92c5e4d3f)                                                   |       0.11 |         2 | 2024-02-02   |
|  142 | [iwpjx9ay2@mozmail.com](w/relay/8639EC2D472AEC280B11288ADADBCC9A6711EC1B)                                                                                                       |       0.11 |         1 | 2024-11-04   |
|  143 | [pl8 tektonix at proton.me](w/family/0874140e316d60806199560536ab8db83c146e53c03c0622dd925ab0b247271b)                                                                          |       0.11 |         2 | 2024-07-25   |
|  144 | [chappie7 AT riseup.net Donate here: https://paste.debian.net/plainh/8e305550](w/relay/669E9D3CF2C1BF3A9E7A0B7FD89F8B4B5E1EF516)                                                |       0.11 |         1 | 2024-01-21   |
|  145 | [broekemabent@protonmail.com](w/relay/62AFE393020CC3AA3AA30CA78902F5D40E760926)                                                                                                 |       0.11 |         1 | 2022-04-03   |
|  146 | [Abuse and contact address: turik at odinbox dot xyz](w/relay/8284C8A45D22F2981C4B6287C7FB4367116E7CCE)                                                                         |       0.11 |         1 | 2022-03-04   |
|  147 | [Dieter - deeburger@zohomail.com](w/relay/6A84C1DB4C50934A57E13FC7F93EA5217BA0DAB6)                                                                                             |       0.11 |         1 | 2022-05-23   |
|  148 | [freeiranandtheworld@outlook.de](w/relay/9308F49A225022FA39011033E1C31EFF5B7B5000)                                                                                              |       0.11 |         1 | 2024-01-22   |
|  149 | [Eliana Routhampia &lt;eli@novacloudapp.net&gt;](w/relay/8D0E575C7C5E6B8075891121368244C283CBC65A)                                                                              |       0.11 |         1 | 2024-05-25   |
|  150 | [psYchotic](w/relay/8D41994D1D18E94403C3F67D0699E4C9D2248D4A)                                                                                                                   |       0.11 |         1 | 2019-02-18   |
|  151 | [email:pabs@dropbears.cc abuse:pabs@dropbears.cc ciissversion:2 confmgmt:puppet](w/relay/DAE65AD32A074CECB30AD3FBB7504F0CDC616CD1)                                              |       0.11 |         1 | 2022-03-04   |
|  152 | [Lou Tschaier e98c29f1-04e6-46f6-9fc2-fab537bbc120@mailer.me](w/family/ca8b85bdf2466b611c9c25cdf27ccf42113dbb07c866d0178fa984ba9a48cf7d)                                        |       0.11 |         2 | 2024-01-22   |
|  153 | [mail: atl4st1me@protonmail.ch](w/relay/CFBE80FBC371BBCAEE9F6B70C5A0333AB54376D8)                                                                                               |       0.11 |         1 | 2024-12-26   |
|  154 | [07F0E652](w/relay/07F0E652E4CCB0A0F1E88D0046ECB322E6318C86)                                                                                                                    |       0.1  |         1 | 2022-04-15   |
|  155 | [email:contact c0der3d.xyz abuse:contact AT c0der3d.xyz](w/relay/05C32C5EE14454E0C4CD81DAE0F3DC32F729DA4B)                                                                      |       0.1  |         1 | 2021-11-19   |
|  156 | [relay@lotusmassage123.com](w/relay/16E5E5C19F1C0F3FF3326E4D281F647D58730A8B)                                                                                                   |       0.1  |         1 | 2024-05-29   |
|  157 | [email:citadel5 ciphermail.xyz zec:zs1nkw34ffgwxt94ta58pec9teefktvthk65le34xl3cg](w/relay/1F2EB70268CE9E18CE864D44D793E2091F3CE72C)                                             |       0.1  |         1 | 2021-11-24   |
|  158 | [email:bill-torrelays boughton.eu ciissversion:2](w/family/59d1019e3e5b2bd3ccf03549b6a0631d6d8d622a933ad15e808ea59d5dac9869)                                                    |       0.1  |         2 | 2019-02-18   |
|  159 | [tor bruzzzla.de](w/family/0bd21ee35ee0c19775a0012e1b129db75b998a54c3b5096bbdeac4a61817ecb0)                                                                                    |       0.1  |         4 | 2024-10-10   |
|  160 | [email:mickymousecontact sektorblue.com ciissversion:2 abuse:mickymousecontact@s](w/relay/46DB04323499DD535956531DF2BF7B03EB2AB15D)                                             |       0.1  |         1 | 2021-12-04   |
|  161 | [/fabi/hererra/ gmx . com fabiana](w/relay/26BC5109EE3495F4655D133BBE0A77FE1608D9A7)                                                                                            |       0.1  |         1 | 2024-01-21   |
|  162 | [Linus Nordberg 4096R/23291265 &lt;linustor@nordberg.se&gt;](w/family/9f3c73eff64ae5153a545dd123315efceed2f6c4b5e59f5774091ab47ecf6f00)                                         |       0.1  |         2 | 2019-02-18   |
|  163 | [Relay Admin Contact - mail@discretematch.cc](w/relay/340704679F46C155094816B34FF6BE491C0AA16E)                                                                                 |       0.1  |         1 | 2024-01-22   |
|  164 | [flashl1ght77 at pm dot me](w/family/35f85cdf0dd53b361b6ddaf823828a64db676b30a4ef6096588783e1f9fa65c2)                                                                          |       0.1  |         5 | 2022-10-10   |
|  165 | [email:minionrelay@protonmail.com ciissversion:2](w/relay/38F732DD349A2E59078434651162A2F4201934A5)                                                                             |       0.1  |         1 | 2021-11-14   |
|  166 | [email:jlvtrim at dropbears dot cc ciissversion:2](w/relay/408F374F131B45D7D63DBCB00E62F76B647943D9)                                                                            |       0.1  |         1 | 2022-02-12   |
|  167 | [5BE7317D](w/relay/5BE7317D29F26E5A3D96F0E7F8653B870E657C6C)                                                                                                                    |       0.1  |         1 | 2024-11-01   |
|  168 | [bogioa90 dot gmail.com](w/family/cad2b77fcf8a9b9a6a00b2fa8c6a00e646d3ab508db8d170dd8ef3b511ce35e7)                                                                             |       0.1  |         2 | 2024-08-12   |
|  169 | [Martin; &lt;martinlt wafflehaus org&gt;](w/relay/4B7F4885DC18018C0B870DD7D8415E265099C187)                                                                                     |       0.1  |         1 | 2022-11-29   |
|  170 | [you&x27;re assumin&x27; imma human](w/relay/4E98AA295B7171996D18DD1F6A19F64AB4036B4A)                                                                                          |       0.1  |         1 | 2024-11-03   |
|  171 | [goodserver@why.com](w/relay/57B5A1DD96B06F8813A6F269F75A2057DB7E71D0)                                                                                                          |       0.1  |         1 | 2024-11-06   |
|  172 | [nuketheworld email:boom tntrelays.xyz ciissversion:2](w/relay/5FAE28CF4D1C520341EE104BF72516F4308B9485)                                                                        |       0.1  |         1 | 2021-11-14   |
|  173 | [pupokin at gmx de](w/relay/68D2ABD936233A569E2B46D6228816149A16B4FA)                                                                                                           |       0.1  |         1 | 2019-02-18   |
|  174 | [bensraspirelayde@gmail.com](w/family/d417c72939b7b45bc7de9bb2482fbee49d7e1effcda72f31925b589394c3405a)                                                                         |       0.1  |         3 | 2024-01-22   |
|  175 | [:- spicyavo @ binaryvault . net](w/relay/6CBA90E31188A65E2B6AC1EE8412E8DE571ECAD6)                                                                                             |       0.1  |         1 | 2022-08-01   |
|  176 | [xplato1 &lt;at proton.me&gt;](w/relay/740148698671E67BA62AC941BBB74E874E0F579E)                                                                                                |       0.1  |         1 | 2024-10-22   |
|  177 | [vader@ciphermail.xyz](w/relay/77A3ADC5D455778B53C2803761916DFB7DA0A790)                                                                                                        |       0.1  |         1 | 2021-11-24   |
|  178 | [7B8E2AC6](w/relay/7B8E2AC6B8CF87D8F2930725CF8122B657D84357)                                                                                                                    |       0.1  |         1 | 2024-01-21   |
|  179 | [email:nuremberg2tor protonmail.com ciissversion:2](w/relay/7EEDD54E5457DA009E46C91BBF1F443DCEE01968)                                                                           |       0.1  |         1 | 2021-11-14   |
|  180 | [email:d3fc0n c0der3d.xyz ciisversion:2 xmr:49bZRY4V1fVVkFuw64BAwkKX7UMNXUeXc5b7](w/relay/916DC3199F639168CD20AEC4D45969268E807699)                                             |       0.1  |         1 | 2021-11-14   |
|  181 | [GaliNightsbridge &lt;admin@GaliNightsbridge.net&gt;](w/relay/9211C28F875BD179EA4F865A2444C441DFF75840)                                                                         |       0.1  |         1 | 2024-01-21   |
|  182 | [Kuro email:shinobi tntrelays.xyz xmr:47aUBkGxpr2jfc4ftvTumZ5xEpALXzPxHFVC6pbqfr](w/relay/94F5629AE5F2DC409CD44668176597FF48296BA1)                                             |       0.1  |         1 | 2021-11-24   |
|  183 | [email:masterchief@sektorblue.com](w/relay/99EC64FE9EF0E0ECEC3E125A2327C2779C1E7947)                                                                                            |       0.1  |         1 | 2021-11-24   |
|  184 | [A85182BA](w/family/b45f1285ea0d34decadaa7899891bf2e04df6df2f3e9f0875e030124d2a3498e)                                                                                           |       0.1  |         2 | 2023-01-18   |
|  185 | [email: itsvanbobaby AT torbewachen DOT xyz](w/relay/B9F69F144DF5BE2FD92DDBF9E67C659ECC5E539B)                                                                                  |       0.1  |         1 | 2022-08-01   |
|  186 | [email:freeassange foxxynodes.com ciisversion:2 btc:14FCyemK4nXThSH9HW3qn5xse1FN](w/relay/BA13324719485DC3B5FF258C21603287F1AFFD06)                                             |       0.1  |         1 | 2021-11-14   |
|  187 | [FUCK THE NSA Donate: 4AyALFfn3DQ6VSNaTzZMCgAicZyFCNh2a7mU6mePcgSeRCXeyoA91isVf](w/relay/ADEA3D5609FCEC1EF2F4426C49313EB82DFE3E6B)                                              |       0.1  |         1 | 2022-03-04   |
|  188 | [Best cheap vapes vape@citrinio.net](w/relay/C80B8274FCE2FF2F7E2079D1C397F685DEFA0793)                                                                                          |       0.1  |         1 | 2024-01-21   |
|  189 | [email: vivaukrainecontact AT proton DOT me ciisversiom:2](w/relay/ECA08EAF2D28CA54BD487EE464182F5895DE1688)                                                                    |       0.1  |         1 | 2025-01-02   |
|  190 | [Sophie &lt;tor AT 999eagle DOT moe&gt;](w/relay/FC1E441E097BA36930AA2F615EFB325AF76D2595)                                                                                      |       0.1  |         1 | 2020-06-22   |
|  191 | [Nurtic-Vibe &lt;nurtic-vibe AT grmml DOT eu&gt;](w/family/04fa141793cdc93016b08a3ac6f13a2b20a9dab35a7f1b16081109b8e85d7848)                                                    |       0.09 |         2 | 2018-10-03   |
|  192 | [s dot aint667 at proton dot me](w/family/94277fb3eb03ada00f8c15c6b656ac66407a2840dfe12859b65eabe19ba02ba5)                                                                     |       0.09 |         3 | 2022-06-22   |
|  193 | [Yuki Ibuki &lt;yukiibuki090 at proton dot me&gt;](w/relay/2E289A14B649F500C194BD56DEE28F0A0D75533C)                                                                            |       0.09 |         1 | 2024-09-07   |
|  194 | [rofl.cat](w/family/2d51a6fc83984e03f6d2f50a9e7c939245fef2749377ad459f7fb922811abfb3)                                                                                           |       0.09 |         6 | 2019-02-18   |
|  195 | [toradmin at night-site dot org](w/relay/1C0736CF3744A3B87C2D2269B8BD3388C7E60552)                                                                                              |       0.09 |         1 | 2019-02-18   |
|  196 | [tor @ public-files dot de - BTC: 3JVUpva3XdTzNyTVHVXA7g1hVYVLQxHPNq](w/family/eb405561e787b4ac8ab1978accaf1c35c208012d99eb580a3a6fe90e3e0cf6e7)                                |       0.09 |         2 | 2019-02-18   |
|  197 | [ceebee &lt;@&gt; chunguswire &lt;dot&gt; me](w/relay/1EFBACCD28A07FD6AD7AA6F1293177D71397E918)                                                                                 |       0.09 |         1 | 2022-08-01   |
|  198 | [3258B4E7](w/relay/3258B4E7215304549B41F3541DF45D5EE106534D)                                                                                                                    |       0.09 |         1 | 2024-11-24   |
|  199 | [B58D 2CC8 1269 1D74 EDA8 44E2 C2F1 43CF E49F 7671 Daniel Hammer &lt;hammer AT hs-of](w/relay/362FA049325802519090C86BC43FC3C6ACBF5613)                                         |       0.09 |         1 | 2024-11-25   |
|  200 | [tor-relay@t13pr.net](w/family/83d48613f45d2400f50ffa44b8e05ee37bf7fb357f8f7d263defcb3d6069b35b)                                                                                |       0.09 |         2 | 2024-01-26   |
|  201 | [58A2A0E8](w/relay/58A2A0E849E9E3692F7B136223507E93CB099150)                                                                                                                    |       0.09 |         1 | 2022-07-12   |
|  202 | [katawaredoki.net](w/family/84e02e2bba32c27c5bbd692aa3a7ba0a0b3f6c3cebbd47c7ee25e5463d3e67b4)                                                                                   |       0.09 |         4 | 2019-02-18   |
|  203 | [549FA4E3](w/relay/549FA4E30CD098742052B13CEECCF621ECE0E9D3)                                                                                                                    |       0.09 |         1 | 2022-04-03   |
|  204 | [65562EE2](w/relay/65562EE28CB698A451D29452F282A8F6EABD1865)                                                                                                                    |       0.09 |         1 | 2024-01-21   |
|  205 | [66DCBBB9](w/relay/66DCBBB971CA555F86BB2B1D17C00C1828368736)                                                                                                                    |       0.09 |         1 | 2024-01-21   |
|  206 | [email:fatdave moltencore.org ciissversion:2](w/relay/6E1CEDC61F3707C549B88FB9380E4A750621FCB8)                                                                                 |       0.09 |         1 | 2021-11-14   |
|  207 | [email: cs4nders AT proton DOT me](w/relay/71016548832DD26E1BA0D3216D75F3A77679062A)                                                                                            |       0.09 |         1 | 2025-01-06   |
|  208 | [darkened@proton.me](w/relay/7A8DF16033A55D4A7CD6D33A0963416A3E3065B1)                                                                                                          |       0.09 |         1 | 2025-01-03   |
|  209 | [fiad@schloop.win](w/relay/7B842FB48CFF19898C8336A11CAA3F425C90F9B5)                                                                                                            |       0.09 |         1 | 2024-01-22   |
|  210 | [mail: contactmail at s1rocco.org](w/relay/7C781344302E21A6A954D7D794255CFD294D50EE)                                                                                            |       0.09 |         1 | 2024-05-24   |
|  211 | [&lt;thebunny.zone&gt; &lt;wintieria proton me&gt; &lt;B9F2F77BA5DC0FC325CB2D9CEDCC0454E6BC832A&gt;](w/family/9872f3b08842256c74da76d5b55d78f2cd4dbc8522f2910b694634d99e397655) |       0.09 |         7 | 2024-08-17   |
|  212 | [Logforme &lt;m7527 AT abc dot se&gt;](w/relay/8F6A78B1EA917F2BF221E87D14361C050A70CCC3)                                                                                        |       0.09 |         1 | 2021-03-19   |
|  213 | [Yorrick &lt;yorrickh AT mail.ee&gt;](w/relay/90333CD7DF2601BE73557753DEE9B4C8444B5E4A)                                                                                         |       0.09 |         1 | 2022-05-03   |
|  214 | [e: &lt;r3lay&gt;&lt;@torrelaymail.net&gt;](w/relay/8AB172C11996EC969EF5B42B7CB8ADDD07455AA4)                                                                                   |       0.09 |         1 | 2024-05-28   |
|  215 | [AA763073](w/family/3e697b6c77bf8ae63d4a2b160fbd8e9e53d92511e104293d382f8d4cbab4404a)                                                                                           |       0.09 |         3 | 2019-02-18   |
|  216 | [AE68ACD0](w/relay/AE68ACD0266C414CDED4338D10BCDF17081563BC)                                                                                                                    |       0.09 |         1 | 2024-10-28   |
|  217 | [email:spacetex tutanota.com ciissversion:2 btc:14BGN8qDMSuND5iZVTA9CNHkJw4Pq5RU](w/relay/AF2B014CBE98D2E66B288323B47F2E8DDDD9904E)                                             |       0.09 |         1 | 2021-11-14   |
|  218 | [BEC5DA93](w/relay/BEC5DA93729F8ACA043228F057058A90C327AAA3)                                                                                                                    |       0.09 |         1 | 2023-03-05   |
|  219 | [Fields of Nephilim Save my Soul newagenephilim@pm.me](w/relay/C09B0B689E4CF3997C45BAC02543C8433AFFB4A6)                                                                        |       0.09 |         1 | 2024-12-29   |
|  220 | [C3DFB7BD](w/relay/C3DFB7BD40B072EB6D46578F1BE021FDD9D60713)                                                                                                                    |       0.09 |         1 | 2024-12-30   |
|  221 | [bofh@domain.tldr](w/relay/C56E98E934EDB5EEFA9322D5D4818E09325F7A80)                                                                                                            |       0.09 |         1 | 2022-09-20   |
|  222 | [www.privex.io](w/family/bd6a90ee09451b7622b29ba5321dbefc2c140e806e1b798d4f3475b5706a0bbb)                                                                                      |       0.09 |         3 | 2019-06-28   |
|  223 | [pikz at tuta dot io](w/relay/E130296683B896A117CE5DA531A5645644178734)                                                                                                         |       0.09 |         1 | 2019-08-17   |
|  224 | [Contact me at: blazedwizard@rapidmail&lt;.&gt;cc](w/relay/FF353F5D011E69ECDA10A57B46D06BC7B3FEB196)                                                                            |       0.09 |         1 | 2021-12-04   |
|  225 | [miwtor@web.de](w/relay/00F1F247B391B84CB6C221720BCBFC0DFDB91117)                                                                                                               |       0.08 |         1 | 2020-09-29   |
|  226 | [xonumi.com](w/family/39af9e8d5a5a86273742feeaa5b21df80f5d384d35cc08032ea22169d736affa)                                                                                         |       0.08 |         2 | 2024-01-15   |
|  227 | [Sponsored by https://tor.foundation](w/family/ebbcb59ceb9c642bec7b5e7b48c77c048c2a6303deb4633aafaba557beaf0260)                                                                |       0.08 |         2 | 2024-07-22   |
|  228 | [infokoopa@hacktivism.ch](w/family/4aa45f8f00087386e592795d221e10391c34c7166fff774c62ee9fcec1c52e47)                                                                            |       0.08 |         2 | 2024-11-14   |
|  229 | [Stanislaw Halik &lt;sthalik@misaki.pl&gt;](w/relay/0B7BC0BF2C1186C1C6C23742141373B173DA0DA6)                                                                                   |       0.08 |         1 | 2023-11-23   |
|  230 | [0CDCFB0B](w/family/61b41755504eb95bee127f23e38f430ea8ceced0a155f1ec184db801d786521b)                                                                                           |       0.08 |         2 | 2015-04-12   |
|  231 | [1D24826A](w/family/cd22c3b6de05fbb921b1c7663cc9702e34736168259e232d70dc7a535736c197)                                                                                           |       0.08 |         2 | 2024-03-15   |
|  232 | [xonumi.com](w/family/d80b813986a1394c58cdf4001c4f33a00a164951a1088fc353f9b6b76343ce13)                                                                                         |       0.08 |         3 | 2024-01-22   |
|  233 | [1E03D81C](w/relay/1E03D81C9744DE0E3C9DE6E6FBDF1DF9DAEA5AFC)                                                                                                                    |       0.08 |         1 | 2024-09-29   |
|  234 | [opsfi-mail protonmail com](w/family/3540e7dd418c1b6a6600bcc3b872134bdbd325dfdaf9e155314c081ab1f93ee7)                                                                          |       0.08 |         2 | 2024-01-21   |
|  235 | [tor at kyrasec.nl](w/relay/28E1F5E0A2DB270868A879DF749809CAB56296D5)                                                                                                           |       0.08 |         1 | 2024-06-03   |
|  236 | [www.schmeling-ol.de](w/family/b6afa470211e3d6c2b68393447456fd8731f6b38c4561d0408e8ac4a06cf503e)                                                                                |       0.08 |         2 | 2019-09-16   |
|  237 | [348944DB](w/relay/348944DB6A0194FCE0161E400CE778CE0DBE47EA)                                                                                                                    |       0.08 |         1 | 2024-01-21   |
|  238 | [Gaius Sorjonen &lt;sorjonen AT tuta dot io&gt;](w/relay/36BF4C04D566C50BDFBF891C15D1DF0341C93685)                                                                              |       0.08 |         1 | 2024-07-21   |
|  239 | [friend of tor @privatemail.com&gt;](w/relay/36F7F3BCC3847FEE902F460E6011A5627437F138)                                                                                          |       0.08 |         1 | 2024-01-21   |
|  240 | [911](w/relay/38F848796D85A1705E4922DF8726E3FB3464807B)                                                                                                                         |       0.08 |         1 | 2024-03-04   |
|  241 | [44DC2366](w/relay/44DC23661E05DEFD94398936D9334987ABCB6E5E)                                                                                                                    |       0.08 |         1 | 2019-02-18   |
|  242 | [5C426791](w/relay/5C426791CB47BDDDD97A71EB2EFC4CCC84DEB299)                                                                                                                    |       0.08 |         1 | 2023-01-28   |
|  243 | [Jim Bite Me thisssuckss at proton mail dot com](w/relay/5C8CC5659757F690C9B5B9BB4A4302E8397818BF)                                                                              |       0.08 |         1 | 2024-12-23   |
|  244 | [tor@wurzelmann.at](w/family/60dba7e1cd8ac26c7383d1f18a97a4bfe14198b905265405ba40d70ed1304030)                                                                                  |       0.08 |         3 | 2024-08-21   |
|  245 | [Gold Diggers &lt;digginggoldtorrelay@proton.me&gt;](w/relay/4CF204F66452C89712B9CF513A213C1F03D8F706)                                                                          |       0.08 |         1 | 2024-12-24   |
|  246 | [@zandermeer](w/relay/502B0D0D85D056ED7503796F6C28A9731AD5D000)                                                                                                                 |       0.08 |         1 | 2024-04-01   |
|  247 | [Animate@proton.me](w/relay/58907DFC4C11B798A5A7C1149C96F4352F82F662)                                                                                                           |       0.08 |         1 | 2025-01-06   |
|  248 | [553652FB](w/relay/553652FBACFDB28098FDFB020F8F4998FF47DE8E)                                                                                                                    |       0.08 |         1 | 2024-01-22   |
|  249 | [606ECD67](w/relay/606ECD67567ED6C84CA379BD4E7B6EB70C47FA47)                                                                                                                    |       0.08 |         1 | 2023-06-29   |
|  250 | [TorInAS200462&lt;AmyCrossed AT tutanota dot com&gt;](w/relay/60AEEA23A85B83A407312B560A60482A501A6B89)                                                                         |       0.08 |         1 | 2021-06-27   |
|  251 | [7997C3FC](w/relay/7997C3FC88B02A2C6FEF96C5F5B5C50DD7DA2E2C)                                                                                                                    |       0.08 |         1 | 2020-08-01   |
|  252 | [7F302F0A](w/relay/7F302F0AACC76835768AF068849CA07D1CC38C5E)                                                                                                                    |       0.08 |         1 | 2020-09-10   |
|  253 | [torbert then an at and dignonet here a dot org](w/relay/91A147D0792B437BA5DF386B8D84F74D58A0ACC5)                                                                              |       0.08 |         1 | 2023-04-02   |
|  254 | [89EEEFA5](w/relay/89EEEFA5880FA551586091524654BDE14792A812)                                                                                                                    |       0.08 |         1 | 2023-07-21   |
|  255 | [knight AT RELAYNAMEWITHOUTNUMBER DOOOT nett](w/relay/A03E52ED1DE8FDD4FF00C142012D907E3E5568C4)                                                                                 |       0.08 |         1 | 2024-06-11   |
|  256 | [Beanbag &lt;bbag-bbag at pm . me&gt;](w/relay/A208C66E3BAF32B70920EB6AF8081F7CFA5DB1D1)                                                                                        |       0.08 |         1 | 2025-01-04   |
|  257 | [email:tor memcpy.io url:http://memcpy.io proof:uri-rsa abuse:tor memcpy.io pgp](w/family/2d54489f1aa175b8f8a68e9a98538bb7353f388cf3fbaf1a620efc966d3aa71b)                     |       0.08 |         2 | 2021-12-24   |
|  258 | [9A1C9EDB](w/relay/9A1C9EDB9397233138032449B0415E7941DDFC2F)                                                                                                                    |       0.08 |         1 | 2024-01-21   |
|  259 | [9A39B0B7](w/relay/9A39B0B75709DD747F5D94A7F24C6BFD80BC587B)                                                                                                                    |       0.08 |         1 | 2022-04-23   |
|  260 | [9CD25E71](w/family/1fe88672ba09a424ee0db9d3c55b8d3eed1e6849807b679d4064faf6133170db)                                                                                           |       0.08 |         2 | 2024-01-22   |
|  261 | [Tuxifan &lt;tuxifan @ posteo . de&gt;](w/relay/A67891856C914E998E82D97A4CCC17381AC4E4FE)                                                                                       |       0.08 |         1 | 2024-02-05   |
|  262 | [yout@e-mail](w/relay/A9D3E8EB8AD3DE09519AF5C3652E1545E560D5CB)                                                                                                                 |       0.08 |         1 | 2024-06-28   |
|  263 | [B369F97F](w/relay/B369F97F3A75CCDCC219B3B7823370010614E956)                                                                                                                    |       0.08 |         1 | 2024-11-14   |
|  264 | [&lt;private&gt;](w/relay/AEA5C9C1791B36DA7E751723FEB66B0F511E4FC8)                                                                                                             |       0.08 |         1 | 2024-03-11   |
|  265 | [AF37B951](w/relay/AF37B951F76D2BB577366FA059D1B1913DD74D41)                                                                                                                    |       0.08 |         1 | 2024-11-05   |
|  266 | [3490583454676@gmail.com](w/relay/F0D8DC4427780A97A996888E8C4F2819142BEDBB)                                                                                                     |       0.08 |         1 | 2025-01-14   |
|  267 | [email:blueeyeswhitedragon kluismail com ciissversion:2](w/relay/DF6F7908E7FDEEE5DE6DD9C92F7C9DFB20B0CE2A)                                                                      |       0.08 |         1 | 2024-01-29   |
|  268 | [none@none](w/relay/F1CC14C298442FAFF00762BA4339ECBED1AC0F92)                                                                                                                   |       0.08 |         1 | 2023-03-09   |
|  269 | [email: tor at b0rken dot de](w/relay/013ABAED8F4CDB677BE0B5212E4B2583B86035EE)                                                                                                 |       0.07 |         1 | 2021-08-30   |
|  270 | [Attest@proton.me](w/relay/015AB136B11A949009A160747296B21B9FA21D69)                                                                                                            |       0.07 |         1 | 2025-01-06   |
|  271 | [pikachu.systems](w/family/01e79b07890dc183449856bc9202b48de5d81a1360699555534af1ccb41e91fa)                                                                                    |       0.07 |         2 | 2021-12-22   |
|  272 | [This is a university project contact me at jt09816&lt;@&gt;protonmail&lt;.&gt;com](w/relay/07D8ECD7305722EE37FA0A408BC0D2034B9BE07A)                                           |       0.07 |         1 | 2025-01-05   |
|  273 | [abuse at sign zwiebelmett dot xyz](w/relay/046F2D59A85FAE693676A87533717C57436261C2)                                                                                           |       0.07 |         1 | 2019-09-29   |
|  274 | [114555F8](w/relay/114555F8664D317BB9616C02810A8A078049EAE3)                                                                                                                    |       0.07 |         1 | 2023-01-23   |
|  275 | [1079E628](w/relay/1079E628FC6B0025656AC024F2D9975C441498CD)                                                                                                                    |       0.07 |         1 | 2019-03-05   |
|  276 | [Neel Chauhan &lt;neel AT neelc DOT org&gt;](w/family/5c65a303311d5601d6ef10465e209b1c8ec964ea0305c45d61d1d273b215adb3)                                                         |       0.07 |        20 | 2024-01-22   |
|  277 | [09F9CD95](w/relay/09F9CD95B472256DFDFF666A0CFD82A3F3CE3514)                                                                                                                    |       0.07 |         1 | 2023-02-10   |
|  278 | [4134DA29](w/relay/4134DA299E17ED8F6F5AC6642EF1054BC3C133D3)                                                                                                                    |       0.07 |         1 | 2024-11-08   |
|  279 | [giannoug AT-gmail DOt- com](w/family/077fece1fb36eb666ed2c1d82135c9024641c52742e132389166751cbe9cb2cc)                                                                         |       0.07 |         3 | 2019-02-18   |
|  280 | [50shadesofblue85@gmail.com](w/family/a4d071c2de3637704814571897e0be9f9f37bcc4c693302d970c16c95f704144)                                                                         |       0.07 |         8 | 2024-08-30   |
|  281 | [raltullou@posteo.org](w/family/77543e1d6a6c99610f4aa2069634122ccd6bffebb38c725890a64c74f013a256)                                                                               |       0.07 |         2 | 2017-02-13   |
|  282 | [17C2FBA1](w/relay/17C2FBA1F1AAB637E92247D060A734FD6786433B)                                                                                                                    |       0.07 |         1 | 2024-01-22   |
|  283 | [1D6528AA](w/relay/1D6528AA190F17B2C055CBD042D672778A265661)                                                                                                                    |       0.07 |         1 | 2023-06-09   |
|  284 | [1D851C4B](w/family/c8540c25eb333c4f35e0d30d7146995729fb26a8265be498a73a7f036f917f4e)                                                                                           |       0.07 |         2 | 2023-04-04   |
|  285 | [vidarekinci@protonmail.com](w/relay/1F2FC2214D63A90926D0A6837896F84A16F4DB60)                                                                                                  |       0.07 |         1 | 2022-10-10   |
|  286 | [EB68C39C35BC73E97C267CF4087D607D91E0B52C admin &lt;moldova dash tor dash admin AT l](w/family/4b140412d8235a5cc856ceef554c2b0c21d96cc9713ce22e504a4e30fe67143b)                |       0.07 |         4 | 2023-08-22   |
|  287 | [27AD21AE](w/relay/27AD21AE45CC2DA5CE701925F23E30B5F2CE88C7)                                                                                                                    |       0.07 |         1 | 2023-06-23   |
|  288 | [27B7D6C0](w/relay/27B7D6C06F30BD7A3B3BF8334A414513952BF738)                                                                                                                    |       0.07 |         1 | 2023-07-21   |
|  289 | [0xAAF5E25904F58A0F52BE1DA5BECFF25F495915B7 Absturztaube &lt;me AT absturztau dot be](w/relay/2A82DD0F42F479F2F55006D3C7AA052A84071ECB)                                         |       0.07 |         1 | 2024-01-21   |
|  290 | [hostmaster@lauchyt.de](w/family/ec53d9d66a18566fb6da200627a5d6e3eaaae64322d0e11667e1d237b74a9e9e)                                                                              |       0.07 |         2 | 2023-03-27   |
|  291 | [hiwi &lt;hiwi AT nurfuerspam dot de&gt;](w/family/d2a2ed1e1d4b15d5d24bad7f2ca21fd2807f76cc743ccc2da261129283533acd)                                                            |       0.07 |         2 | 2024-11-27   |
|  292 | [0x4471de61 Senf &lt;tor AT senf dot space&gt;](w/family/7be60b207a5080771d922285e1c050dbfceed84b24f89993b19f29eb6a81bc89)                                                      |       0.07 |         2 | 2022-12-29   |
|  293 | [tor-relay@littleroot.de](w/relay/3797C9C124615A03EB45DB7945859F97ADFAC10F)                                                                                                     |       0.07 |         1 | 2024-06-02   |
|  294 | [379AD084](w/relay/379AD084786C17EC2D53C2B0420A330A3838E174)                                                                                                                    |       0.07 |         1 | 2024-11-01   |
|  295 | [Fabian Keil &lt;fk@fabiankeil.de&gt; 8BA2371C](w/family/1e6ae302dff3e61cf137fb954a580428d2918e6618cc66582cd407bcf88578bf)                                                      |       0.07 |         2 | 2019-02-18   |
|  296 | [51407211](w/relay/51407211A947E4D5B670848340EB6C17BD1F600D)                                                                                                                    |       0.07 |         1 | 2024-01-31   |
|  297 | [WilliDieEnte &lt;tor AT ente dot dev&gt;](w/relay/575B47977496E830DF5334F1A2266F16E028CB4B)                                                                                    |       0.07 |         1 | 2024-12-04   |
|  298 | [Tor Admin &lt;toradmin AT veilsoftheonion DOT eu&gt;](w/family/5a85a0b18e18d13799109bbfb7325bdce3b17ea732564c4891cd2ebd3e05fa3d)                                               |       0.07 |         2 | 2019-02-18   |
|  299 | [email:hotpwkr jltn xyz Donate here:17zPicHTVE7GPPMXTJuE6sJQ66M43E29KD](w/relay/5F3B05B9A5575E614337AFA84DF04F526CD14C1B)                                                       |       0.07 |         1 | 2022-11-29   |
|  300 | [IP-Eend &lt;tor AT ip-eend dot nl&gt;](w/relay/5FA794BF301AF35E4AED185E939CBA9D2CFC2360)                                                                                       |       0.07 |         1 | 2024-05-23   |
|  301 | [Kutas Pierdolony &lt; tor.mooned586 A7 silomails , c0m &gt;](w/family/e3cf93aaf41d79c37acee7cc37c789e68fcae134867523d00d2de2e23d8153f4)                                        |       0.07 |         3 | 2024-01-22   |
|  302 | [693F0A23](w/relay/693F0A23AB32726570F79857D92997A5125EC2D2)                                                                                                                    |       0.07 |         1 | 2024-11-01   |
|  303 | [easybird &lt;easybird.relay@proton.me&gt;](w/relay/6FE30A2A59E9A2E84723CF05E3C5051BB42175D3)                                                                                   |       0.07 |         1 | 2024-06-08   |
|  304 | [levitate@proton.me](w/relay/899E99BF99101B3C183BE9AF9CB5A7BE92F9FC4E)                                                                                                          |       0.07 |         1 | 2024-12-05   |
|  305 | [rng29a@wintermute.info](w/relay/8E7ACAD878BBD61097C0E0D557160F5D59BCE5CA)                                                                                                      |       0.07 |         1 | 2020-08-21   |
|  306 | [Ali &lt;AlleyAllator@protonmail.com&gt;](w/relay/8B62F79629C8D4754651801BCF3EC0E255F1E0EE)                                                                                     |       0.07 |         1 | 2024-12-20   |
|  307 | [Vasil Kolev &lt;tor@ludost.net&gt;](w/relay/9E4CC64C4F94C359D43C5BA09094323FDBEFD975)                                                                                          |       0.07 |         1 | 2019-02-18   |
|  308 | [flev @ kpnmail . nl](w/relay/94F16DA2BDDBA092954FF8EC29F9234A69949403)                                                                                                         |       0.07 |         1 | 2019-02-18   |
|  309 | [info@niklasl.com](w/relay/97E4BAB582717350E6FF6160899FA9B665C834E3)                                                                                                            |       0.07 |         1 | 2022-09-30   |
|  310 | [9B81565C](w/relay/9B81565CE9970C205D1CFF2656171608D8603CDE)                                                                                                                    |       0.07 |         1 | 2023-04-04   |
|  311 | [Pump my rump rumpypumpee at nospam protonmail.com](w/relay/A5B23CF462DA919BDD9717331A27206791689B87)                                                                           |       0.07 |         1 | 2024-12-30   |
|  312 | [A5CAF012](w/relay/A5CAF012A4A940914DC441746B9342A6EC116417)                                                                                                                    |       0.07 |         1 | 2023-03-01   |
|  313 | [&lt;olafuringvason@posteo.is&gt;](w/relay/A9FAB6E0396C7B07ECEB39EE71288A08F7443AB7)                                                                                            |       0.07 |         1 | 2024-02-25   |
|  314 | [AA0D90C8](w/relay/AA0D90C85200A0A64CBC58AB4D6AA0058530BCE4)                                                                                                                    |       0.07 |         1 | 2024-04-05   |
|  315 | [maffaypeter847@gmail.com](w/relay/D9ADC85ABCD68A903908FE42FF7CA2D9F56AA32F)                                                                                                    |       0.07 |         1 | 2024-11-27   |
|  316 | [DAB09C9C](w/relay/DAB09C9C6118A8FD61F91C1186B2CF84A1467B3B)                                                                                                                    |       0.07 |         1 | 2024-04-04   |
|  317 | [DAF25DF4](w/relay/DAF25DF4AD0452B958923AA9D77C54F1A5473ACD)                                                                                                                    |       0.07 |         1 | 2024-01-22   |
|  318 | [DB603D15](w/relay/DB603D15336F59DBF6421B3BCBE786D54CE3FED3)                                                                                                                    |       0.07 |         1 | 2023-04-18   |
|  319 | [celtiq.sec A.T. proton D.O.T. me](w/relay/B6F6A56C5DB1CFB18692695923B3E429758C9A3A)                                                                                            |       0.07 |         1 | 2023-02-07   |
|  320 | [Patrice Mail: patricericebluejay@protonmail.com](w/relay/B8F0736B96819C88A1AED46D5965FA18610694B5)                                                                             |       0.07 |         1 | 2025-01-10   |
|  321 | [B16BFE5C](w/relay/B16BFE5C5DD2F76EAB72E3FD41A062706912B0F2)                                                                                                                    |       0.07 |         1 | 2022-08-21   |
|  322 | [florentin.rochet@unamur.be](w/relay/BDD1649638E5BCA3303F89BAA27C06DE13ACFB24)                                                                                                  |       0.07 |         1 | 2024-07-09   |
|  323 | [&lt;x6c656e696e sektorblue.com&gt;](w/relay/C4BDBFD1049EE1D4F6977C42485F94CD5F97BA92)                                                                                          |       0.07 |         1 | 2021-11-24   |
|  324 | [Calypso Strausive mail: calypsos96@protonmail.com](w/relay/C9A13ECA8B56D4641B0339FE62A8482640BDDE26)                                                                           |       0.07 |         1 | 2024-12-28   |
|  325 | [CA0BA8FE](w/relay/CA0BA8FE9207FCF31701D7D3EE3BFBEFA7BB14C5)                                                                                                                    |       0.07 |         1 | 2023-05-06   |
|  326 | [&lt;private&gt;](w/relay/D7C218579374ED6525E12362A0B2A3DAEB0B5CEC)                                                                                                             |       0.07 |         1 | 2024-03-21   |
|  327 | [D870744F](w/relay/D870744F618F20F3A63592B4F9B0BB919FC1BED0)                                                                                                                    |       0.07 |         1 | 2024-10-28   |
|  328 | [E00DFD54](w/relay/E00DFD54DC165D5452FBD3530D30186DAD016A0C)                                                                                                                    |       0.07 |         1 | 2019-02-18   |
|  329 | [FC87BA11](w/relay/FC87BA11F0364DBF5E5B9846F4C82132792F758C)                                                                                                                    |       0.07 |         1 | 2024-01-22   |
|  330 | [c0der@freenode.cc](w/relay/02351FC88D0BF06F6CDE5452656641E6119DBD7E)                                                                                                           |       0.06 |         1 | 2021-11-12   |
|  331 | [mk17hg@brocku.ca](w/family/7342317f7d56b2bfbf442396f4fe069f5879e4adb1a5b47b8661ca2ef5fed96c)                                                                                   |       0.06 |         8 | 2023-05-27   |
|  332 | [Randy Random &lt;postmaster@zocer.net&gt;](w/relay/062F73860BAAE602B63299373B97F085A6417A78)                                                                                   |       0.06 |         1 | 2024-09-22   |
|  333 | [email:contactrelay freenode.cc ciissversion:2 xmr:48QZTS1wSSeYzGNm5y4AKob3AGUQW](w/relay/0439AB73BB2B8730FCB15B18252928FC0C2EDF91)                                             |       0.06 |         1 | 2021-11-14   |
|  334 | [tor@ioexplo.it](w/family/ef0ee00843beb195beea96be95fbd5bfb109291c5cb4809a6f463267b6498cd1)                                                                                     |       0.06 |         5 | 2024-12-23   |
|  335 | [0E83A834](w/relay/0E83A8347254C0572CF2A93D1D34674AC19798A8)                                                                                                                    |       0.06 |         1 | 2024-12-01   |
|  336 | [Eridanus &lt;tor AT 5ir dot de&gt;](w/relay/10A5EFCCD2FB9C1A4AC20FB779A5DB11B58957A7)                                                                                          |       0.06 |         1 | 2020-04-14   |
|  337 | [Critical Cat &lt;tor@critical.cat&gt;](w/relay/2DCF5236122F31C9271FDDE79DB49397ABC05984)                                                                                       |       0.06 |         1 | 2024-01-22   |
|  338 | [Rotate-13 gbeznfgre@ubehf-vg.qr](w/relay/0C3D5E19E3C75B505C8ACD26F89DCA2DF970553E)                                                                                             |       0.06 |         1 | 2016-08-04   |
|  339 | [0CAA2E90](w/relay/0CAA2E9044A86B11915C413B5A0911DF29E9A1AC)                                                                                                                    |       0.06 |         1 | 2023-03-17   |
|  340 | [0D6CD875](w/relay/0D6CD875B60B762F4F65F8685BD0E39F9886340F)                                                                                                                    |       0.06 |         1 | 2023-03-13   |
|  341 | [1261042B](w/relay/1261042B1775BBACE38DC6C4BCAE87A78B1CDF06)                                                                                                                    |       0.06 |         1 | 2024-06-03   |
|  342 | [galtland.network](w/relay/133D3D8F3B7220A314BAF02A42A566E230234638)                                                                                                            |       0.06 |         1 | 2022-06-27   |
|  343 | [&lt;torrelayrunner AT protonmail DOT com&gt;](w/relay/246490C9408834587E96A68A05BEF039F284185A)                                                                                |       0.06 |         1 | 2024-03-12   |
|  344 | [1FE6D59B](w/relay/1FE6D59BC44493017A8CDE25DF300D08BA80CCDD)                                                                                                                    |       0.06 |         1 | 2023-03-23   |
|  345 | [tor a web7seas dot com](w/family/0b525e02eebe28c6333d7c86466b939eff3bebdb366f07bb37d78a0c029964ca)                                                                             |       0.06 |         2 | 2019-09-26   |
|  346 | [admin@tor-relay.utilizer.de](w/family/a96e66fb24d413e3c7604fdac7bef94cdead3ba8ebb239bccd41681cd0646d30)                                                                        |       0.06 |         2 | 2024-07-14   |
|  347 | [474EA76A](w/relay/474EA76AC6B5BA6656560A2C1465C2A299751AD2)                                                                                                                    |       0.06 |         1 | 2023-07-11   |
|  348 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/47F62C33607CD953ED026A63C67542ED424811A4)                                                        |       0.06 |         1 | 2024-01-22   |
|  349 | [2A5F2AD5](w/relay/2A5F2AD5AC3A7A79BA24E26F837D35A56B334002)                                                                                                                    |       0.06 |         1 | 2024-04-08   |
|  350 | [371C00BF](w/relay/371C00BF5F71AC45FBD5FE74504A6D2408BAD5E0)                                                                                                                    |       0.06 |         1 | 2023-05-10   |
|  351 | [37A5E87E](w/relay/37A5E87EBD0B99B09650B32C8F3E085CF83A6EA7)                                                                                                                    |       0.06 |         1 | 2024-05-01   |
|  352 | [37C1D665](w/family/b8a32185e809dc16ad286bdad519cc3527682d7aa524181485752e34682b3c95)                                                                                           |       0.06 |         2 | 2019-02-18   |
|  353 | [38316AF9](w/relay/38316AF9D28F99A451C8789BE21C363ADD0F6846)                                                                                                                    |       0.06 |         1 | 2023-05-12   |
|  354 | [tor at ensayon dot com](w/relay/3ADA8CCC38AF196639ECF7FC7BF2215434F0C64D)                                                                                                      |       0.06 |         1 | 2024-10-09   |
|  355 | [tor-relay@simofamily.org](w/relay/53AD3B560F118E2D0B2433DD4F41775D13A7C7BD)                                                                                                    |       0.06 |         1 | 2024-01-22   |
|  356 | [tor at pingless dot com](w/relay/4F35B3EC9077B58D08129423CB9B1825EDB6FDCB)                                                                                                     |       0.06 |         1 | 2022-01-03   |
|  357 | [samam &lt; at &gt; protonmail.com](w/relay/54DE63F4587058B79152A75A0238D7F7A0279215)                                                                                           |       0.06 |         1 | 2019-02-18   |
|  358 | [60C24AFF](w/relay/60C24AFF465D2E7FB6E9375E243F894E2939DF27)                                                                                                                    |       0.06 |         1 | 2023-06-23   |
|  359 | [6154EEEE](w/relay/6154EEEE65A71AAF6B6CA33059D5E351C3B57D9B)                                                                                                                    |       0.06 |         1 | 2023-06-09   |
|  360 | [mail: admin tjdev.de](w/family/ad0821c91771a0ff34723be3b502a74a3477944dc1c5e9515d62446d809c9d16)                                                                               |       0.06 |         2 | 2022-09-10   |
|  361 | [8329D57A](w/family/952fe25504b11b921a02a502662fbb13e1bd29afdb9abf77c3346a02282c6b12)                                                                                           |       0.06 |         2 | 2024-05-23   |
|  362 | [81EBAD67](w/relay/81EBAD67553A9039B75B96625F305BCA53910159)                                                                                                                    |       0.06 |         1 | 2024-10-06   |
|  363 | [mib at mib dot dev](w/relay/67AF1BD7BF90CC4EF1BDA1E9EA87F29E4C03EDFA)                                                                                                          |       0.06 |         1 | 2024-01-26   |
|  364 | [pinkpurpleorange@proton.me](w/relay/6E3EDE76585F0B9BC2EFF89591D3073471BFD857)                                                                                                  |       0.06 |         1 | 2024-11-24   |
|  365 | [6E5F1BE3](w/relay/6E5F1BE327BFA07D4A6E9D930315E906A4C641DB)                                                                                                                    |       0.06 |         1 | 2023-02-17   |
|  366 | [71986901](w/relay/71986901178D81CBFD56484308B301D873E0760C)                                                                                                                    |       0.06 |         1 | 2024-01-22   |
|  367 | [739AE4DE](w/relay/739AE4DE6FF2FB2500585E12FCE78FA593FA4AC6)                                                                                                                    |       0.06 |         1 | 2023-07-19   |
|  368 | [76D58DE9](w/relay/76D58DE9BF46B35984FC45BB0BAE361A66968ABF)                                                                                                                    |       0.06 |         1 | 2023-05-04   |
|  369 | [secutor secure-bits.org](w/family/91eae0b270158b0c37b7b465db1c3cd17420eb7ef5d146699d0fea240743871d)                                                                            |       0.06 |         2 | 2024-01-22   |
|  370 | [7B78F4D8](w/relay/7B78F4D80FDF06B2CAF510377577BBB04CB11695)                                                                                                                    |       0.06 |         1 | 2024-11-12   |
|  371 | [none](w/relay/7BD1E46FD753FBA0BEA36E569575FBDF4C5B877E)                                                                                                                        |       0.06 |         1 | 2024-01-22   |
|  372 | [tortor AT mailbox dot org](w/relay/7C7862D39221B9C6785AA20A31430944D4BD54DE)                                                                                                   |       0.06 |         1 | 2024-05-10   |
|  373 | [email:validbutanonymaddress protonmail.com abuse:validbutanonymaddress protonm](w/family/7cb59ae64a2b5272263e415e08097ee1ee1e421df69a49bd4aa8cb31451bf5a1)                     |       0.06 |         2 | 2023-07-15   |
|  374 | [7DC499EA](w/relay/7DC499EA72BF553D3CBD1B149167EAA04FD37AA0)                                                                                                                    |       0.06 |         1 | 2023-02-17   |
|  375 | [8921CB0E](w/relay/8921CB0ECEA669EEF8A2FD20537D58A676F47228)                                                                                                                    |       0.06 |         1 | 2023-04-24   |
|  376 | [4096R/701269C611CA9526 OpenNetworX Tor Operator &lt;tor at onwx.org&gt;](w/family/36ddbb7c51c33710fec21cbc6fddd2d7483d1f71adac97567bf4015a9bcc1e98)                            |       0.06 |         3 | 2019-02-18   |
|  377 | [tor at bgp dot rodeo](w/relay/923F05FE883DBC89BF111F391A882168010D165A)                                                                                                        |       0.06 |         1 | 2023-02-07   |
|  378 | [$ CONTACT GPG FINGERPRINT $ CONTACT NAME $ CONTACT EMAIL](w/relay/92630E3353B8E5D1D124FF36B95651CACD17C6F8)                                                                    |       0.06 |         1 | 2025-01-09   |
|  379 | [tor at cyberbunker dot biz](w/relay/8DC39E4999796372A449229C8BFDFBDD87605101)                                                                                                  |       0.06 |         1 | 2023-07-03   |
|  380 | [8E3700E5](w/relay/8E3700E561E8E080564648601093AC9570080D8D)                                                                                                                    |       0.06 |         1 | 2023-05-10   |
|  381 | [8A5EFB7B](w/relay/8A5EFB7BF172104441B5C5F5A047D92D9C70BA37)                                                                                                                    |       0.06 |         1 | 2024-01-21   |
|  382 | [rocking@proton.me](w/relay/8B48D839E679221267F1C33E22688C34501C56B1)                                                                                                           |       0.06 |         1 | 2024-12-13   |
|  383 | [8D1272C0](w/relay/8D1272C0D099500E3AD69774D699BB857AFDF397)                                                                                                                    |       0.06 |         1 | 2024-08-29   |
|  384 | [TorAdmin &lt;toradmin AT tanascius dot com&gt;](w/family/bf0b8be7cc1a07c9e6ae836a74a18b9afc7953a1ff88f31e839fc863962c0c5f)                                                     |       0.06 |         2 | 2019-12-05   |
|  385 | [torrelay fokaia AT manchester DOT gr](w/family/ef72b9be9bf9f745ff54fb9333a2f0d953c0696d6889471b9f93d5cd0a2d0974)                                                               |       0.06 |         2 | 2022-03-14   |
|  386 | [landshrimp at kluismail dot com](w/relay/9BD6765086E8F4B15D17F166F41911494ED78BDE)                                                                                             |       0.06 |         1 | 2022-03-04   |
|  387 | [zsXDYnpE6P at protonmail dot com](w/relay/9D2A5BC019A14D6F4BE1E61CC5E02EB381C810D9)                                                                                            |       0.06 |         1 | 2024-01-22   |
|  388 | [A9F8CA97](w/relay/A9F8CA97F0DD5F05F368B150CB10ECAB77581FAC)                                                                                                                    |       0.06 |         1 | 2023-06-27   |
|  389 | [DC073284](w/relay/DC073284BAA719D8ECC6ED22E7CCDE9919A06547)                                                                                                                    |       0.06 |         1 | 2024-10-29   |
|  390 | [Tor admin &lt;tor AT schellingstrasse dot de&gt;](w/relay/DC7E7D9AB7AD52F03B856E6DC278E9D92BF19B33)                                                                            |       0.06 |         1 | 2020-08-21   |
|  391 | [E42DEAC2](w/relay/E42DEAC28AB38BD89312FB92DA1B5D0CDC09386C)                                                                                                                    |       0.06 |         1 | 2024-05-11   |
|  392 | [BA46824B](w/relay/BA46824BA757FCCC0FB4FDC0A52DC348BD84FBA6)                                                                                                                    |       0.06 |         1 | 2023-08-16   |
|  393 | [0x59205995C95D108C Sylvain Rager &lt;sylvain at regar42 dot fr&gt;](w/relay/BD4C647508162F59CB44E4DFC1C2B2B8A9387CCA)                                                          |       0.06 |         1 | 2019-02-18   |
|  394 | [BE062843](w/relay/BE06284371FD903154A683D6C501FF1978C1FA1E)                                                                                                                    |       0.06 |         1 | 2023-07-25   |
|  395 | [1024D/0x49360B3B1DFBA164 Bernhard M. Wiedemann &lt;torbmw3 lsmod.de&gt;](w/relay/BEEE1C835E2954E74A407CDFFA124F00C2F2505B)                                                     |       0.06 |         1 | 2021-03-09   |
|  396 | [liiberated1@proton.me](w/family/5915014f96cd465111e3414b92a710e907094225013de22dd5f13215b14e9e2e)                                                                              |       0.06 |         2 | 2022-08-11   |
|  397 | [bl4ckpr1sm@proton.me](w/relay/C1DDD8DB3C8AE88548E6ECE16C043E24D40D6FD8)                                                                                                        |       0.06 |         1 | 2024-10-14   |
|  398 | [Paco Caliente &lt;p4co.c4liente AT protonmail dot com&gt;](w/relay/C237392DC121DF50C64C707C3FB95055E68B00CA)                                                                   |       0.06 |         1 | 2021-08-26   |
|  399 | [CDD66C79](w/relay/CDD66C79A1BBE7DA53C6A40E7B604FEE07E9BAD8)                                                                                                                    |       0.06 |         1 | 2023-03-15   |
|  400 | [email johnsmith4675884798@proton.me](w/relay/D15D9A1BD6297C55E73A8AB2E63260EB62C95C4E)                                                                                         |       0.06 |         1 | 2024-12-31   |
|  401 | [t.starlit144@passfwd.com](w/relay/D2A2E8F9CF83FBFF86C29612902F644AE9CB62DC)                                                                                                    |       0.06 |         1 | 2024-05-23   |
|  402 | [D643B486](w/relay/D643B4869F56026CC92B529727B3BF11F2ADB940)                                                                                                                    |       0.06 |         1 | 2024-09-21   |
|  403 | [Vasil Kolev &lt;tor@ludost.net&gt;](w/relay/D8EA105E79803FB0040A8C2A676D93DAEA2CFFF0)                                                                                          |       0.06 |         1 | 2019-06-08   |
|  404 | [EDDD1EE1](w/relay/EDDD1EE1E5EF2C35C70C8FED5A52EF46E08597AF)                                                                                                                    |       0.06 |         1 | 2024-08-28   |
|  405 | [no@thank.you](w/relay/EE9FFFB8FC1B120275BDDAFBC0BCBD98C8E7D532)                                                                                                                |       0.06 |         1 | 2023-04-30   |
|  406 | [bund &lt;at-&gt; posteo dot&gt;de &lt;&gt; tor-relay.co](w/relay/F12C6E3002C96064A4C0B14CA277690E195D7074)                                                                     |       0.06 |         1 | 2023-08-18   |
|  407 | [DE915B27](w/relay/DE915B27AF0453595540924D28B8BA74D1276D31)                                                                                                                    |       0.06 |         1 | 2024-01-22   |
|  408 | [contact this relay operator at one2345ive &x27;@&x27; proton &x27;.&x27; me](w/relay/DF47C5938C23DE8F54DBF3DCE18DAE170AE40EF7)                                                 |       0.06 |         1 | 2025-01-07   |
|  409 | [email:wwallace@tntrelays.xyz zec:zs1tlt8aqleaxy46rvywcywpycw2c2d4p36yg9py9pamlrg](w/relay/E04861C32098EF38D6BB2AEFEC81095953FEF0ED)                                            |       0.06 |         1 | 2022-11-29   |
|  410 | [Random Person &lt;mangolover at tutamail-com&gt;](w/relay/E36DDC844F5E441733CC0133A6A347BF89D8588A)                                                                            |       0.06 |         1 | 2024-05-05   |
|  411 | [tor@schr.at](w/relay/ED134C125AA560DDE5BADEBC228495BFDC226CF8)                                                                                                                 |       0.06 |         1 | 2024-05-24   |
|  412 | [IT &lt;tor AT informatik dot uni-bremen dot de&gt;](w/relay/F1CD870D7A8FA364E459ABA70B1737D40B0B4BB3)                                                                          |       0.06 |         1 | 2022-04-03   |
|  413 | [Relay by H and the team. Contact us at: buzzteam AT boatmail DOT cc](w/relay/F50755D5018C23F6CD115F23C95CCB2DC8B608B1)                                                         |       0.06 |         1 | 2022-08-01   |
|  414 | [theprivacyhaven@proton.me](w/relay/F57C29781F6AEEF2718ED37DF792218BDFC996B3)                                                                                                   |       0.06 |         1 | 2024-12-31   |
|  415 | [Witam kontakt:jan AT hidemymail.xyz](w/relay/F72AF9F63CD443B2CC7FEB8552EC588EF1992F0A)                                                                                         |       0.06 |         1 | 2022-11-29   |
|  416 | [old memes222 AT pm.me](w/family/099f5ac9a4923e0867054c890eb0d29d5eb3ffb130c49d7d0a5860b2a22a1e1b)                                                                              |       0.05 |         6 | 2025-01-07   |
|  417 | [www.digitale-gesellschaft.ch](w/family/2b347e140ca2083820b8065a4c36cd001295daa6ec54149e0ae66528173ab16d)                                                                       |       0.05 |         9 | 2015-05-22   |
|  418 | [ezyn.de](w/family/8459182e128af26901ec8d0cb70ebd17081c9c9ebed31958290d42575e9d31e6)                                                                                            |       0.05 |         3 | 2021-10-05   |
|  419 | [FlokiNET &lt;noc@flokinet.is&gt;](w/family/771c968d16497365c3b229607b130bbbfe46817a410549a7757b3718698fe175)                                                                   |       0.05 |         8 | 2022-08-11   |
|  420 | [torrelay@hayzy.com](w/relay/07895E6DE9B3CBCB74B6CCF1ABB14BF112FF36F7)                                                                                                          |       0.05 |         1 | 2024-07-13   |
|  421 | [obfuscation.oxofrmbl@mein.gmx](w/family/7a6ff48eec6035ca1e7b3468fbaa7067b1a3148ee516b9ffac457959a39aad8d)                                                                      |       0.05 |         2 | 2021-04-18   |
|  422 | [tor dot relay dot edc /at/ danwin1210 dot de](w/family/2552c7ec89fe1bf2c763dfd1ae441fbe5708dbcea6a4b6999d431364e60e2e43)                                                       |       0.05 |         5 | 2021-03-19   |
|  423 | [02C7A07B](w/relay/02C7A07B1214AA338A705EFCCA409D700F757201)                                                                                                                    |       0.05 |         1 | 2023-03-01   |
|  424 | [TNinja &lt;abuse-team at tor dot ninja&gt;](w/family/11ff631d37c696436fd62e0f22a4f9b803022ba62876b5633f1001eff431ab99)                                                         |       0.05 |         3 | 2024-06-03   |
|  425 | [hviv.nl](w/family/cd4836da405366bd79a30ced489dd18364b379db15ae344919ff93fd5e09e49a)                                                                                            |       0.05 |        14 | 2018-04-27   |
|  426 | [unredacted.org](w/family/d483e43e3415af923180ae140e4e9bde334d217288881f842616adde5dec8995)                                                                                     |       0.05 |        22 | 2021-11-07   |
|  427 | [&lt;code9n at pm dot me&gt;](w/relay/41D4F82AB54AE5C5FB8D3CD24B4FC84350EFEF03)                                                                                                 |       0.05 |         1 | 2022-12-19   |
|  428 | [limited0ne@gmx.com](w/family/047b8fb47601f6ad3bf0856f2c9f2eff07bedc8f42967f3160e2f1e88e5f838b)                                                                                 |       0.05 |         2 | 2022-08-21   |
|  429 | [2CD23D10](w/relay/2CD23D10948D1C6039977852274F700278B39EE8)                                                                                                                    |       0.05 |         1 | 2023-05-06   |
|  430 | [2CE9BE1F](w/relay/2CE9BE1FC88B9D0FA03F387C9E4F000B5D4B2AE9)                                                                                                                    |       0.05 |         1 | 2019-05-09   |
|  431 | [NotMyMomsAdmin &lt;NotMyMomsTorRelay AT schaefer minus home dot europes domain&gt;](w/relay/2D8768E3EA8B974ADB69F7FA8140DBEAFC14C8F0)                                          |       0.05 |         1 | 2021-12-14   |
|  432 | [0A8FB5E2](w/family/b647f4616cf340a8a3d6eb196cff59e9fd02ab6b8a7b3642f09c7cebcaa43c0b)                                                                                           |       0.05 |         2 | 2022-10-27   |
|  433 | [community.torproject.8pqny@passmail.net](w/relay/0B4190C676FAAD34EB2DCB9A288939476CEBCF32)                                                                                     |       0.05 |         1 | 2024-05-10   |
|  434 | [12CE2632](w/relay/12CE2632ADF8FA59656836DFBFE0FFBDEE071F79)                                                                                                                    |       0.05 |         1 | 2023-02-09   |
|  435 | [tor@netsecops.blog](w/relay/1355DA12ADB2C0B2C18006FE1E65F3253D35FF61)                                                                                                          |       0.05 |         1 | 2024-12-11   |
|  436 | [1FB9CCBE](w/relay/1FB9CCBE02CF10978EAB16943973AC5C548FA243)                                                                                                                    |       0.05 |         1 | 2022-08-11   |
|  437 | [252957C9](w/relay/252957C95C1E0B9C0A72F7ED4716BA1FFF24BF2F)                                                                                                                    |       0.05 |         1 | 2024-08-28   |
|  438 | [24893333](w/relay/24893333D304C74CCDD11D99090C0471DCFED589)                                                                                                                    |       0.05 |         1 | 2022-11-29   |
|  439 | [sakiratijja@proton.me](w/relay/20C97B1A358B8CFFD65F4FFF141E626218AB8CD4)                                                                                                       |       0.05 |         1 | 2025-01-11   |
|  440 | [darmstadt@fridaysforfuture.de](w/relay/2FDB1719E6A5E6110F93CE3AC5E841F9B3A2B726)                                                                                               |       0.05 |         1 | 2024-12-29   |
|  441 | [Lilly Schramm &lt;lilly tor@trans.ceo&gt;](w/relay/469FB12BF25E0EA9ED889D0FE8BDC0E5AB2CD74C)                                                                                   |       0.05 |         1 | 2024-02-05   |
|  442 | [Rhys RE &lt;me at sign rhysre dot net&gt;](w/relay/484F666C491BCDE22B45E0E19D1CEA5ACC5A9611)                                                                                   |       0.05 |         1 | 2019-02-18   |
|  443 | [Burgwallbronn.xyz@proton.me](w/relay/29A793A4762382FC78F283E6664EF9C42E74B1D2)                                                                                                 |       0.05 |         1 | 2024-09-21   |
|  444 | [tesseract.dk](w/family/231fd42ddce3272c50ca33d8262032cd4397aa597abd086fe5bd6a1e037ff777)                                                                                       |       0.05 |         2 | 2020-05-13   |
|  445 | [2B172EBC](w/relay/2B172EBC296D605A1AE72387139A0D5E5A717A76)                                                                                                                    |       0.05 |         1 | 2024-10-22   |
|  446 | [31588E6B](w/relay/31588E6B91E26E54C32CA0F44A2016A92E1CC479)                                                                                                                    |       0.05 |         1 | 2024-08-28   |
|  447 | [Sponsored by https://tor.foundation](w/relay/32BBFBD2CA50E34E145425090C56CF5C01852E78)                                                                                         |       0.05 |         1 | 2024-07-27   |
|  448 | [froschw403@gmail.com](w/relay/393DB610A19F0C0BF32D603B20D732407C45019D)                                                                                                        |       0.05 |         1 | 2024-11-27   |
|  449 | [tor-relay-contact &lt;at&gt; digitalsquid &lt;dot&gt; co &lt;dot&gt; uk](w/family/e10d665eff7b1de34fa8efb08d7e8884690164ee48f6373ff15cd6572b54a1c3)                            |       0.05 |         3 | 2020-04-03   |
|  450 | [phoenitydawn tor admin &lt;tor@phoenitydawn.de&gt; - 1KWnz9ooQnixjCQZARyUhwgSeYV4XMcLq](w/relay/3E53D3979DB07EFD736661C934A1DED14127B684)                                      |       0.05 |         1 | 2019-02-18   |
|  451 | [kzjaaqwfnabb protonmail com](w/relay/403D9E1DDD8E66FA8081DEAE17C94B2D1D1F6164)                                                                                                 |       0.05 |         1 | 2021-04-28   |
|  452 | [Kavin &lt;kavin-tor AT protonmail dot com&gt;](w/family/a87df169b6b7344121d6079c493700e072767d1b9bf7af0f6582790524bbda44)                                                      |       0.05 |         2 | 2024-01-21   |
|  453 | [0xFFFFFFFF observatory123 &lt;observatory123 AT proton dot me&gt;](w/relay/45431BF8AB66C673942C1E344BB520625CE5F817)                                                           |       0.05 |         1 | 2024-08-14   |
|  454 | [theres-no-email-for@bots.com](w/relay/45959A38ACAF2ECFB488A3C69D0C04F42438AB9D)                                                                                                |       0.05 |         1 | 2024-04-14   |
|  455 | [45EDDBE3](w/relay/45EDDBE30450D5E7D83D8AD2B8FFF0755E773500)                                                                                                                    |       0.05 |         1 | 2024-10-23   |
|  456 | [email:ynp4bj airmail.cc ciissversion:2](w/relay/5B7A7720F84441F7BABE6C6CE8347C56DC4D6569)                                                                                      |       0.05 |         1 | 2024-08-14   |
|  457 | [&lt;tor-contactREMOVEME AT t4cc0.re&gt; GPG: 0x3AFF3AB493B3420D9E5D39529A6A0E3A064C6C3](w/relay/5C8B811887778DCF705F3D39F19E40A21889451F)                                      |       0.05 |         1 | 2019-02-18   |
|  458 | [torspam at timanttikuutio . eu](w/relay/5E0D5B2B4C1AACE479607E84EC1BCE988910AB46)                                                                                              |       0.05 |         1 | 2021-05-08   |
|  459 | [51221964](w/relay/512219649B647564779A016C054ADCF1D08D48EF)                                                                                                                    |       0.05 |         1 | 2024-08-07   |
|  460 | [eandy@gmx.de](w/relay/4FA68EF9F7C1096C87B172D152E5B39513BFD45C)                                                                                                                |       0.05 |         1 | 2024-12-23   |
|  461 | [alxu.ca](w/family/4875ffbca3f8bc4a4e8ee5585f555fb7ec8e810ccdb69548aae13ec80072813a)                                                                                            |       0.05 |         3 | 2019-02-18   |
|  462 | [58AA3EE7](w/relay/58AA3EE7E0830B92DBBB6C62A299A0A644BA31D5)                                                                                                                    |       0.05 |         1 | 2024-04-05   |
|  463 | [Heartfire &lt;heartfire AT heartfire DOT me&gt;](w/family/946af3ad8b968b994f543c22bb519cada2de5d16479b71e6a21e89db3c9bf54e)                                                    |       0.05 |         3 | 2024-12-31   |
|  464 | [&lt;domi.0815@gmail.com&gt;](w/relay/6B0D4904A57D5A5B0F2EDFB6D3B04153F17D189E)                                                                                                 |       0.05 |         1 | 2022-11-29   |
|  465 | [tor-relay@steinmann.help](w/relay/6BD3A16B0A0CFE6493F9C7B4228CFB192468F38A)                                                                                                    |       0.05 |         1 | 2024-04-13   |
|  466 | [6C333B5B](w/relay/6C333B5BDBA3DFE7A782E40CB970C271ABFED119)                                                                                                                    |       0.05 |         1 | 2019-02-18   |
|  467 | [contact at ng1x dot xyz](w/family/357cbb50496f703d9cfc2508cbf5eefb53c07d176a47181222cff7aef42cb292)                                                                            |       0.05 |         2 | 2022-06-02   |
|  468 | [Mike Hertzog /Huthog@poortorrelayer.info](w/relay/7179F808E6817142EB2FD67B5AA21DFBC7876907)                                                                                    |       0.05 |         1 | 2024-01-22   |
|  469 | [71A1DA0D](w/relay/71A1DA0D554EC4107DD6ED7303D38DC9A9F8B241)                                                                                                                    |       0.05 |         1 | 2024-06-05   |
|  470 | [0x1E7523CA911AC822 Markus Witt &lt;markus.witt@rwth-aachen.de&gt;](w/relay/76D2EBA82BBCCA3DF9F254A9A8372A10A26F3D14)                                                           |       0.05 |         1 | 2019-04-29   |
|  471 | [keiferdodderblyyatgmaildodder dot com](w/relay/79E3B585803DE805CCBC00C1EF36B1E74372861D)                                                                                       |       0.05 |         1 | 2024-02-03   |
|  472 | [kontakt@hopfen.space](w/relay/7C80E6E91AF12DA27C15F6EA099E73499D613C18)                                                                                                        |       0.05 |         1 | 2022-05-13   |
|  473 | [Gunnis Va &lt;gv.anonym AT gmail dot com&gt;](w/relay/911B1FE9A2462D1739C1CC5E8FCA12900E72FAED)                                                                                |       0.05 |         1 | 2024-11-28   |
|  474 | [tor at 0x3d dot lu - 1x3dG3utS7FDrTtJutnR3zuCo4Z8fUUAL](w/family/56774e0c7b15fe839d53b6e8f5e3d120ffa810abf918b16765a6e51aa9eeffb5)                                             |       0.05 |         2 | 2019-02-18   |
|  475 | [8F9CD937](w/relay/8F9CD937D0177BE8AC9E27D18604F93216DFA6A9)                                                                                                                    |       0.05 |         1 | 2022-05-03   |
|  476 | [email:snowball at rapidmail.cc](w/relay/90BCBF737079BB5047CB2AEAE49FBC1BA91B5EDB)                                                                                              |       0.05 |         1 | 2021-12-04   |
|  477 | [8B4ECB75](w/relay/8B4ECB759D13BF6778ACAA52D666EB2A3E7D2EED)                                                                                                                    |       0.05 |         1 | 2020-11-09   |
|  478 | [94629572](w/relay/94629572C5FE987B006677296276F8AFD804E7D9)                                                                                                                    |       0.05 |         1 | 2024-04-15   |
|  479 | [atomcats dot tor dot relay at gmail dot com tor-relay.co](w/relay/9AB93B5422149E5DFF4BE6A3814E2F6D9648DB6A)                                                                    |       0.05 |         1 | 2019-02-18   |
|  480 | [torrocks at- mailbox&lt;dot=&gt;org](w/relay/A4F11D693FAB6E949B2B7C18153C3F7989896007)                                                                                         |       0.05 |         1 | 2024-05-20   |
|  481 | [dir act at systemli.org](w/family/32914de500078d3949e64e9114fcbb1160af95a82c313d8fd97c1a68e44f51e7)                                                                            |       0.05 |         2 | 2023-04-18   |
|  482 | [holonet.sh](w/relay/A8FB73D917B7C2B851A358729359E13EBA5978FA)                                                                                                                  |       0.05 |         1 | 2022-04-23   |
|  483 | [DC4EB02B](w/relay/DC4EB02B37F1F7D499303F41986EE4F7ACE2A090)                                                                                                                    |       0.05 |         1 | 2024-12-31   |
|  484 | [tor.gabrielg.es](w/relay/E47C30CE2E397CCDAF0EDE93739789367907DA1A)                                                                                                             |       0.05 |         1 | 2021-05-18   |
|  485 | [Mike Wille &lt;tor@mw.gd&gt; pgp: 1D53B2FF846754E7ABC7B900E8DC24C0F0D96E21](w/relay/E90A98854A970505AEB27934FA4D005BC92A54D9)                                                  |       0.05 |         1 | 2022-11-29   |
|  486 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/B66BDA3E822EEC458DA530A97062362DFE771491)                                                        |       0.05 |         1 | 2023-08-02   |
|  487 | [tor@home.arpa](w/relay/BA197EE81F7461776ED5F57270611FC02072E0D2)                                                                                                               |       0.05 |         1 | 2024-10-14   |
|  488 | [CryptoCactus Tor AT proton dot me](w/family/4de2e3f648a4de3af16e3315dbaec8d24ca44caa9853d46f7a52bd449593a434)                                                                  |       0.05 |         2 | 2024-01-28   |
|  489 | [Lennart Oldenburg &lt;lennart.oldenburg@esat.kuleuven.be&gt;](w/relay/ACC874AD6D4D3AC308CB6C044620A159A1123196)                                                                |       0.05 |         1 | 2019-02-18   |
|  490 | [B1FE4BE9](w/relay/B1FE4BE9DD33376DADC22D271803097E1AE8B35E)                                                                                                                    |       0.05 |         1 | 2023-02-21   |
|  491 | [werger.ufer@tutanota.com](w/relay/BC7BBFBBF4AE5469405591D28BF3EF8071B0F32E)                                                                                                    |       0.05 |         1 | 2024-01-21   |
|  492 | [xyz.1328.tech](w/relay/BE2803357A0DCA205C24A3D318E45053C401EA4D)                                                                                                               |       0.05 |         1 | 2024-11-29   |
|  493 | [relaymijn a t gmail d o t com](w/relay/C310AE2232089F5B13C515FC2DC3E47960C85255)                                                                                               |       0.05 |         1 | 2024-11-21   |
|  494 | [Sponsored by https://tor.foundation](w/relay/C5D1649E5FE05F3B75F2C2AE901783BEF41E6856)                                                                                         |       0.05 |         1 | 2024-08-30   |
|  495 | [C6C2F339](w/relay/C6C2F339836E2A1EFF64B9DAFCB00C1A0D48D5C7)                                                                                                                    |       0.05 |         1 | 2022-07-02   |
|  496 | [C789BEC2](w/relay/C789BEC2E9D1562020A7E089742D8B379029523B)                                                                                                                    |       0.05 |         1 | 2024-05-23   |
|  497 | [CB19C930](w/relay/CB19C930356F4F321CC87E063EBDE473674F2F97)                                                                                                                    |       0.05 |         1 | 2023-03-29   |
|  498 | [@jbrps 0x588F6C31 &lt;jonas@rz-k.de&gt;](w/relay/CDAEBA458F6129776643751934076A51D851C348)                                                                                     |       0.05 |         1 | 2019-02-18   |
|  499 | [Mr.Weasel ferretfet@proton.me](w/relay/CDCCB6E228E9BC0898713BD026CBA47E3C57B87D)                                                                                               |       0.05 |         1 | 2024-04-03   |
|  500 | [&lt;TGSwissNET abcATabc gmail abc abc com&gt;](w/relay/CFE52F8C180D13D0D730C818774EA502FF2073B4)                                                                               |       0.05 |         1 | 2023-06-23   |
|  501 | [www.rince.de](w/relay/D16A75E422664448F8A7E7D536D359D512B91256)                                                                                                                |       0.05 |         1 | 2020-08-21   |
|  502 | [dsasgfds-posteo net](w/relay/D2F05648A73CB0CBA7D254D8D12BB3181408FBAE)                                                                                                         |       0.05 |         1 | 2025-01-11   |
|  503 | [fuckedop@proton.me](w/relay/D6D677014A583E6F783A03F523A6C5DC2F6347D1)                                                                                                          |       0.05 |         1 | 2022-05-03   |
|  504 | [Encode:UTF-8 &lt;&lt; gorrionne87 @ proton . me &gt;&gt;](w/relay/D74914027D56E2B7D431056F0C8B880FF2D8B07A)                                                                    |       0.05 |         1 | 2025-01-12   |
|  505 | [platypus-tor-node/at/proton/dot/me](w/relay/D7B3558020235C1F374EEC8BDE1468E195411E3A)                                                                                          |       0.05 |         1 | 2021-05-08   |
|  506 | [Zufaellige Person vorname nachname@mail2tor.com](w/relay/D97D3472E23D8CA4DC0BD2ECAE6E82AE5DDF3341)                                                                             |       0.05 |         1 | 2024-01-22   |
|  507 | [Gloria Mundi &lt;tor AT gloria-mundi DOT eu&gt;](w/relay/EFCFDBD8B78FE3D6336DBCBA1330E37B5A353709)                                                                             |       0.05 |         1 | 2023-07-21   |
|  508 | [tor@righttoprivacy.net](w/relay/F10F6F548FE8C18C88CC99F752DF64076DCC3759)                                                                                                      |       0.05 |         1 | 2024-01-22   |
|  509 | [0x88888888 Ole Tange &lt;ole@tange.dk&gt;](w/relay/E20F4ADCA4C9F011C8F17073F1119367A4560856)                                                                                   |       0.05 |         1 | 2024-06-16   |
|  510 | [E3D851EB](w/relay/E3D851EB58CD692D626D408390C451BB2CF30AD8)                                                                                                                    |       0.05 |         1 | 2024-08-26   |
|  511 | [email:micrasoft at jltn . xyz ciisversion:2 confmgmt:puppet](w/relay/EA670AB58CD5E1D5DCAB571D100EA1D36D72CA28)                                                                 |       0.05 |         1 | 2024-03-15   |
|  512 | [kolektiv@nolog.cz](w/relay/F4FBFB2773FAB87E3708BEFA0B1BEE64FD52E579)                                                                                                           |       0.05 |         1 | 2024-12-28   |
|  513 | [torrelay at kieran dot de](w/family/6be1737d25dca6e8e42377c9a683ed600935abf8517b0c147972272e071577e4)                                                                          |       0.04 |         3 | 2019-01-31   |
|  514 | [tor@gweifinder.mozmail.com](w/family/a2c4823df2c76f86f9cb79d053061e98adbbd8eb5d637478a9f6ee3fdf72e5ad)                                                                         |       0.04 |         6 | 2023-12-22   |
|  515 | [contact@radical-privacy.com](w/relay/0939A7FBB544A75FAF3887254BCBC6E3B4CEB4C4)                                                                                                 |       0.04 |         1 | 2024-11-14   |
|  516 | [030B59F0](w/relay/030B59F0D25752E6C2332E3F7B14746EE6B16D16)                                                                                                                    |       0.04 |         1 | 2023-09-17   |
|  517 | [katerinazamurieva1996964j3cy@mail.ua](w/relay/069DE6996E15B35B99BFAB40DA170C662140AECA)                                                                                        |       0.04 |         1 | 2025-01-09   |
|  518 | [miraty.niv.re](w/relay/40FA09C151C3893B7018DEF55A9854BC9768B82C)                                                                                                               |       0.04 |         1 | 2022-05-03   |
|  519 | [jens@reinemuth.pt](w/relay/410DA7387625D410089DEF6FFD1B88AE86671AA6)                                                                                                           |       0.04 |         1 | 2024-12-25   |
|  520 | [postmaster@lepenet.link](w/family/d0c975b341c0bd219ecf00a4e6e7b767651c945931fd98919b403952999c126b)                                                                            |       0.04 |         6 | 2024-02-23   |
|  521 | [42C56C1B](w/relay/42C56C1BE2E5EE9EF1E10522A6AFC113F1D0E458)                                                                                                                    |       0.04 |         1 | 2024-01-22   |
|  522 | [4311DB6F](w/family/6ad08318c9efeff5bb920155bd92670025a24b01d67ca56404acea63160ab3c3)                                                                                           |       0.04 |         2 | 2022-02-02   |
|  523 | [43219E6F](w/relay/43219E6FC5B68A2E96317BE36A86193FBEAA063F)                                                                                                                    |       0.04 |         1 | 2024-10-23   |
|  524 | [2EB3C230](w/relay/2EB3C230180694A1E848001E20F36F76A2287039)                                                                                                                    |       0.04 |         1 | 2019-02-18   |
|  525 | [2EC83D2B](w/family/b004551c57b9227d2a3543e51ce0801a440a26c59d3a2e2f9bc88ac135c0c979)                                                                                           |       0.04 |         4 | 2021-11-14   |
|  526 | [email:bigcastle8127@airmail.cc ciissversion:2](w/relay/0C36AE99B744E32088C9ED23D7A31F8D23AE1A58)                                                                               |       0.04 |         1 | 2022-12-06   |
|  527 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/0C741818F254073AF5A3D9F6F31D2A69CEC610EF)                                                        |       0.04 |         1 | 2023-08-07   |
|  528 | [mentor@palokaj.co](w/family/20f6ae6ad5a6efcb15166c95a223f78065811919028d285edae71497e5b03ffe)                                                                                  |       0.04 |         7 | 2023-03-22   |
|  529 | [none](w/relay/14BE32AAACB9E7F0BCAFADC15986D787B1325BB6)                                                                                                                        |       0.04 |         1 | 2022-11-03   |
|  530 | [dev.null@kryptonit.org](w/relay/14E722D088B68CCA306AE7834D564BD6F294BF23)                                                                                                      |       0.04 |         1 | 2024-09-29   |
|  531 | [1884B98A](w/relay/1884B98A6817CEA48AD28311E7E9AC220B05533B)                                                                                                                    |       0.04 |         1 | 2024-11-07   |
|  532 | [email:tor jonas-budde.de ciissversion:2](w/relay/1F65C60F1AFE81BDA6C2AE4D8B6CE2F12A983766)                                                                                     |       0.04 |         1 | 2025-01-05   |
|  533 | [Ka0a &lt;kAl3id0sc0p3@proton.me&gt;](w/family/620dffedbdb0ac4bf8b039508e634d99defd6da39f197eb3787a6a9e6865d18c)                                                                |       0.04 |         2 | 2022-11-09   |
|  534 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/24D6B6B9591A07CCF43B35D559468B19F44DED6A)                                                        |       0.04 |         1 | 2023-08-02   |
|  535 | [25502A58](w/relay/25502A58CE78E0D11427540D0FAE3ADD079276EA)                                                                                                                    |       0.04 |         1 | 2025-01-06   |
|  536 | [mikael datanerd.se](w/family/104fba39fb82697b595ac32d291f192d3cf0d991b095973c697a037b9f5fc5ae)                                                                                 |       0.04 |         9 | 2024-12-07   |
|  537 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/25D7CC3FA3599230CB985F2B6DEAE4D72526CE15)                                                        |       0.04 |         1 | 2023-08-02   |
|  538 | [pitivierglisse@gmail.com](w/relay/24494F0C553D13D1F46BE783DDE1572D7F0850BA)                                                                                                    |       0.04 |         1 | 2023-08-22   |
|  539 | [48215EE6](w/relay/48215EE661083D8BA38E39B455AB93BE5228E274)                                                                                                                    |       0.04 |         1 | 2024-10-16   |
|  540 | [tor-contact@kher.nl](w/family/e0d49ec251ccfe2fdd0fe1a62f9f3b8b3c4255f89fae22563996ef4286f0bbbf)                                                                                |       0.04 |         2 | 2019-06-08   |
|  541 | [4938A9B5](w/relay/4938A9B50436B901B355F5FD1D9D16805A4E41F8)                                                                                                                    |       0.04 |         1 | 2023-08-02   |
|  542 | [2702323C](w/relay/2702323CEB6DE132008AF69618645C01130CD69E)                                                                                                                    |       0.04 |         1 | 2024-10-16   |
|  543 | [2AD82F39](w/relay/2AD82F3964D325B3FE2FF74E980FB006374EF190)                                                                                                                    |       0.04 |         1 | 2024-03-20   |
|  544 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/3158BE2413AC6A8F0BC3EC343BB056F6D24F2E53)                                                        |       0.04 |         1 | 2023-08-02   |
|  545 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/3B175AF473519C959975F39D8127845405F71CCF)                                                        |       0.04 |         1 | 2023-08-02   |
|  546 | [O n i on Ra s pb e rry Sou p@prot o n mail.co m](w/relay/3CEA56B817455E13C4B063E7D3E7726C286F7C9B)                                                                             |       0.04 |         1 | 2019-02-18   |
|  547 | [&lt;BrightEi AT proton dot me&gt;](w/relay/3F0A3B1BB8C73BA9CE79D06F5F76BBB24BF5289A)                                                                                           |       0.04 |         1 | 2024-08-05   |
|  548 | [40508842](w/relay/405088427ADA54F81B245FB6E6AF237521F5D3E7)                                                                                                                    |       0.04 |         1 | 2023-03-29   |
|  549 | [438F3EA4](w/relay/438F3EA4C9FB0DB63F5377A3271AB5435FAD7E04)                                                                                                                    |       0.04 |         1 | 2019-02-18   |
|  550 | [remote VIA uq dot ci](w/family/225f5fbfcad81f559275bdc7460fd4690651f62bb3a6ff931c2db1ca5787a72a)                                                                               |       0.04 |         2 | 2024-12-19   |
|  551 | [PUFF PUFF puuffdaaddy &lt;@&gt;protonmail.ch&lt;.&gt;me](w/relay/5C4FE03A9A6053319D70C5B6D8939D5F5419CE4A)                                                                     |       0.04 |         1 | 2025-01-08   |
|  552 | [colincogle.name](w/relay/498CDD3BF9DE59A5678E8488FEA450E1876242A5)                                                                                                             |       0.04 |         1 | 2022-03-14   |
|  553 | [4ADB08AF](w/relay/4ADB08AFCF04657E0A0288AA230EEB74A96B1CEE)                                                                                                                    |       0.04 |         1 | 2024-01-21   |
|  554 | [4EE694A4](w/relay/4EE694A4556BFA6CDF220CD4C820B6C60E806160)                                                                                                                    |       0.04 |         1 | 2024-11-20   |
|  555 | [tor.skankhunt42.pw](w/family/e65e843467a5f8d4cfea5b152891285a383293d9f8e9aa4866d22d46936067d7)                                                                                 |       0.04 |         2 | 2023-05-12   |
|  556 | [5790B62A](w/relay/5790B62AD6C79A1092B30993A8F0F7F23A969FD6)                                                                                                                    |       0.04 |         1 | 2020-04-23   |
|  557 | [54476788](w/relay/54476788A1AA7C348F20390DFC52ACA1352F4C57)                                                                                                                    |       0.04 |         1 | 2022-11-19   |
|  558 | [friedhaintor posteo.de](w/relay/55B885EFEA16C1EE9C6D65E2BAEBDD68AA968533)                                                                                                      |       0.04 |         1 | 2024-09-01   |
|  559 | [nice try](w/relay/6007EF215FA156F200B634CC83BD76BB2D563DAA)                                                                                                                    |       0.04 |         1 | 2022-10-20   |
|  560 | [PostGuard@gentlemansclub.de](w/relay/615D541946672D02F31995A48A89A526C7EC3524)                                                                                                 |       0.04 |         1 | 2021-05-08   |
|  561 | [Sponsored by https://tor.foundation](w/relay/58F3A320CD73CFE23398B4FAA213E8BA3779C5E7)                                                                                         |       0.04 |         1 | 2024-07-28   |
|  562 | [&lt;trly1 AT proton dot me&gt;](w/family/231bdc505004c0d52fc9ff4c74ef5e5b5ad8bb052aecf8e5403a3a17a158e948)                                                                     |       0.04 |         3 | 2019-02-18   |
|  563 | [tor@mail.flo-the.dev](w/relay/5B11EA82ED4DFAD156AFB6ACF306CE0E710AEDF8)                                                                                                        |       0.04 |         1 | 2024-01-21   |
|  564 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/5B4BA9941C7045C5CAF8D6E748764BB6FEB93360)                                                        |       0.04 |         1 | 2024-03-04   |
|  565 | [zwiebelchentor@gmx.de](w/relay/85378A302B63676FA600E00BD4B3491053381BD7)                                                                                                       |       0.04 |         1 | 2024-01-22   |
|  566 | [moehre-hostingtor@riseup.net](w/relay/61C52DFC090FD1B1AA0C1F431DC535249C311EB9)                                                                                                |       0.04 |         1 | 2024-01-22   |
|  567 | [tor@birdeck.com](w/family/e3f8304b35df82b45c2a08ba5bc5879b50261949c886cc852ee0470a70aa3d9f)                                                                                    |       0.04 |         2 | 2024-07-27   |
|  568 | [edita@danwin1210.de](w/relay/64948AE6A45666B48445A83F4C6C19D3D22B3B3B)                                                                                                         |       0.04 |         1 | 2022-11-19   |
|  569 | [80D36C43](w/relay/80D36C43CC9226D106B99011DE4AD154447E15E6)                                                                                                                    |       0.04 |         1 | 2025-01-12   |
|  570 | [adm AT&gt;&gt;tmrx.cc](w/relay/6A8D2C69C94A3DF3A80CC4153041DA81DC30A52C)                                                                                                       |       0.04 |         1 | 2024-01-22   |
|  571 | [tor@opensource-it.org](w/relay/6F1A5F8E0A53CEF9632B2DC52DB1D5FF00D15409)                                                                                                       |       0.04 |         1 | 2024-08-22   |
|  572 | [tor@worldofmail.com](w/relay/737BF8424F0F4457FCAB53F9282088992C7E104E)                                                                                                         |       0.04 |         1 | 2024-10-13   |
|  573 | [ipunchsharks@protonmail.com](w/relay/75FE5236E67FFA4A44C1152C35EAB36360E4D7DF)                                                                                                 |       0.04 |         1 | 2019-06-08   |
|  574 | [76A4FAD9](w/relay/76A4FAD913B837CBAC6C5A4AC9E0A29A8805D860)                                                                                                                    |       0.04 |         1 | 2024-11-29   |
|  575 | [tor AT ravidwivedi dot in](w/relay/772D509772071D3082BAAF1C781C8F917013F3CB)                                                                                                   |       0.04 |         1 | 2022-01-03   |
|  576 | [7737A403](w/relay/7737A40305131AD8B5E60CFB9126E4BBE1ED7F76)                                                                                                                    |       0.04 |         1 | 2019-02-18   |
|  577 | [Naville Admin &lt;tor-admin naville.com&gt;](w/relay/7E1DBB55DE5CF3E6BD44B9526C9020022A5674A1)                                                                                 |       0.04 |         1 | 2024-12-19   |
|  578 | [88CFB26F](w/relay/88CFB26F0CB7A5506A171DA32C4E19152F464964)                                                                                                                    |       0.04 |         1 | 2025-01-04   |
|  579 | [. . .](w/relay/923DE89BAD9206721D2B1D60AC7E987097EDF070)                                                                                                                       |       0.04 |         1 | 2024-11-23   |
|  580 | [email: admin@xoa.se](w/relay/92A01038972F368200B03DC0D194B217BA441D55)                                                                                                         |       0.04 |         1 | 2022-05-13   |
|  581 | [littlehoster.denote399@passinbox.com](w/relay/933D284804EED001280FE6BBF49C4D592171DF4B)                                                                                        |       0.04 |         1 | 2024-04-23   |
|  582 | [8EF390A0](w/relay/8EF390A0CAA31F6AD7A5E2BE7976F33476A245EC)                                                                                                                    |       0.04 |         1 | 2023-07-21   |
|  583 | [PMG the world@is.yours](w/relay/8F0858DFED67D8850D960FBB5A994A32679D2908)                                                                                                      |       0.04 |         1 | 2022-10-30   |
|  584 | [contact@itsebyte.org](w/relay/89F0A5E334622D2D30DA5F3DDEBB7F07AD555157)                                                                                                        |       0.04 |         1 | 2025-01-05   |
|  585 | [8C5E2A69](w/relay/8C5E2A6935A8BE1E76CE12E777C157BEACE06F07)                                                                                                                    |       0.04 |         1 | 2024-12-03   |
|  586 | [bach.laminar-6e@icloud.com](w/relay/A40253888E9F6FE27EDFE5E8540EAFAF9E6A6B40)                                                                                                  |       0.04 |         1 | 2024-12-30   |
|  587 | [Leon &lt;Leon AT platinumhost dot io&gt;](w/relay/9808D762C79C15C59C68F08693F1650D377E8735)                                                                                    |       0.04 |         1 | 2023-04-12   |
|  588 | [banshee@proton.me](w/relay/98DFFD0922024C86C8AD3CF7C2B4B489550F7DAA)                                                                                                           |       0.04 |         1 | 2025-01-04   |
|  589 | [janiTORX5 &lt;at&gt; protonmail &lt;dot&gt; ch](w/relay/99C7F100EEBA27677715D0318A71D36366B804B1)                                                                              |       0.04 |         1 | 2025-01-06   |
|  590 | [9B5B3B5B](w/relay/9B5B3B5BC953E8BE5058072310FDD0F631FD868E)                                                                                                                    |       0.04 |         1 | 2020-09-10   |
|  591 | [ContactInfo email:knight AT germancraft dot net url:germancraft.net proof:dns-rs](w/relay/9D9F9FCDE5B200695353E0A29BC1872A1F43D648)                                            |       0.04 |         1 | 2024-04-11   |
|  592 | [I dont have an email to contact me on yet :](w/relay/A8E0BBA351D0A1159BED88CCD405D5AA4DF4EAF7)                                                                                 |       0.04 |         1 | 2024-01-21   |
|  593 | [DC0B2CF7](w/relay/DC0B2CF7EFBE640DF3D1615EB8FE50E82FB53B45)                                                                                                                    |       0.04 |         1 | 2024-11-01   |
|  594 | [arpagic1@mail.com](w/family/abd7a80286ee040a5619a2f1d33a8d54df31ada7f6b9ac29e3406236a7ef854e)                                                                                  |       0.04 |         2 | 2024-11-15   |
|  595 | [chaotorum&lt;ASCII64&gt;onionmail&lt;ASCII46&gt;org](w/relay/DCB0BB5DF6D7CE6467DD82193EB4A8581A0F0645)                                                                         |       0.04 |         1 | 2021-08-06   |
|  596 | [wakako &lt;at&gt; rod &lt;dot&gt; ac](w/relay/E6161DD961CBB382B59EFA78252BC2827C469265)                                                                                        |       0.04 |         1 | 2021-02-17   |
|  597 | [E84FB379](w/relay/E84FB379C8D394660A2A34886049C948D3024189)                                                                                                                    |       0.04 |         1 | 2024-01-21   |
|  598 | [B4C39AD4](w/relay/B4C39AD461B21AA48DB4FB371B001D91A3043C0C)                                                                                                                    |       0.04 |         1 | 2022-01-13   |
|  599 | [B50A9826](w/relay/B50A98267A63713F37319D895EA1151C4B27BE4D)                                                                                                                    |       0.04 |         1 | 2019-02-18   |
|  600 | [relay@stateofduality.de](w/relay/AC633C90E126E0BCA96F14ECE5D222B586FA0D56)                                                                                                     |       0.04 |         1 | 2019-10-06   |
|  601 | [zd316@cam.ac.uk](w/relay/B06552737CDA0E1EF84CF56ACB7491FDB81554FC)                                                                                                             |       0.04 |         1 | 2024-12-24   |
|  602 | [r3y7dvprknzsjnwgaufs@tutanota.de](w/relay/BAEE9F1327B726939E6C05550D23850018344390)                                                                                            |       0.04 |         1 | 2024-01-22   |
|  603 | [admin &lt;tor DASH 3xg0k33m AT dzp DOT nz&gt;](w/relay/BF50E09EED25B82861CF95E1AAA42DCFEF53E5D1)                                                                               |       0.04 |         1 | 2019-02-18   |
|  604 | [0xF40E25B8FB8FC3F2204ABFBBA9DE100CAF6305D0 Kilobug &lt;kilobug@kilobug.org&gt;](w/relay/C308657FD420D95E5FD89C140D3C79B76C4C3D2C)                                              |       0.04 |         1 | 2024-11-17   |
|  605 | [Sponsored by https://tor.foundation](w/relay/C57132A0E436DDA078980A6C2FE0BB9147FD0A40)                                                                                         |       0.04 |         1 | 2024-07-28   |
|  606 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C746FE39C3592C470ADD8965A0FCBF5DC7EFF091)                                                        |       0.04 |         1 | 2023-08-02   |
|  607 | [CBD42010](w/relay/CBD420106E46C1EECDB5A02B4CE12CFF1A38B9EB)                                                                                                                    |       0.04 |         1 | 2023-08-08   |
|  608 | [CE602C5F](w/relay/CE602C5FDC13C4745EBE8A9D18BC166DEE5E5743)                                                                                                                    |       0.04 |         1 | 2024-06-06   |
|  609 | [CF70F884](w/relay/CF70F8845167E65067B4279DA684AEF308585553)                                                                                                                    |       0.04 |         1 | 2024-11-18   |
|  610 | [None](w/relay/CFE72C8AFD1838F93D9F0E4A2D58FD87787C816F)                                                                                                                        |       0.04 |         1 | 2024-10-16   |
|  611 | [luis.carilla1@gmail.com](w/relay/D41AFC78224578E5C5B3C26C2E55778037A52C5B)                                                                                                     |       0.04 |         1 | 2024-10-23   |
|  612 | [darmstadt@fridaysforfuture.de](w/relay/DD068520C3C34EA4223DBD82A111E5AADC419EB7)                                                                                               |       0.04 |         1 | 2024-12-31   |
|  613 | [admin at hivemind dot biz](w/family/39be2a64ae2774331260849ca62b9b1cd41c215476be7b680a845ad1f3ae7290)                                                                          |       0.04 |         2 | 2022-07-22   |
|  614 | [DFE3C36A](w/relay/DFE3C36A8D3DE61BFA0AF0E8DEC056458D46E2F3)                                                                                                                    |       0.04 |         1 | 2024-11-02   |
|  615 | [F1542050](w/relay/F154205075BF55E86558C99305F09386D7C4AA0C)                                                                                                                    |       0.04 |         1 | 2024-10-06   |
|  616 | [tor@eti-net.de](w/relay/F32467BB64F3B5A954B9008202C4768BB02CB9E8)                                                                                                              |       0.04 |         1 | 2024-12-25   |
|  617 | [F3FD38F2](w/relay/F3FD38F2D9646A3D72484D15585D9A0E9836AC1E)                                                                                                                    |       0.04 |         1 | 2024-02-08   |
|  618 | [&lt;1ea7deadbeef AT posteo dot net&gt;](w/relay/F475E5987E44A2B7B143A2BEE3F8128EEFD7E5A3)                                                                                      |       0.04 |         1 | 2019-02-18   |
|  619 | [0x88888888 Ole Tange &lt;ole@tange.dk&gt;](w/relay/F5582460A049E13A1E91AE5E0A4531FAAA1831E6)                                                                                   |       0.04 |         1 | 2024-07-29   |
|  620 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/F69E79681EE8C7E56904926AE870C89C04560A4F)                                                        |       0.04 |         1 | 2023-08-02   |
|  621 | [support@vpsfree.org](w/relay/F7B024DB02C601185C202E26DFFD2AD525C16A36)                                                                                                         |       0.04 |         1 | 2019-02-18   |
|  622 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/FA979DCF3A132D3AC796BDFA0C3B64EF76269CCB)                                                        |       0.04 |         1 | 2023-08-08   |
|  623 | [FAB3FE2A](w/relay/FAB3FE2A1A13FFEE20B68FF879FFA0301B67AAFA)                                                                                                                    |       0.04 |         1 | 2024-08-09   |
|  624 | [Our Tor relay: Because sometimes the longest detour is the most direct route -](w/relay/FB4236B1D2C3C7FEA15C86583E808CC294EA8831)                                              |       0.04 |         1 | 2024-10-12   |
|  625 | [GnuPG: 0x6DCEBB9F](w/relay/FD79B7F9230858B48E75F389661840C702511078)                                                                                                           |       0.04 |         1 | 2019-02-18   |
|  626 | [Random Person &lt;ettore dot bertani AT gmail dot com&gt;](w/relay/FF9475B400CF84900C3074BCE5ADFCCFE1CB9943)                                                                   |       0.04 |         1 | 2024-12-19   |
|  627 | [&lt;greenonion AT mailfreude dot de&gt;](w/relay/FFB4BF2AE896CA8E7B3C419855346415D743E889)                                                                                     |       0.04 |         1 | 2024-12-30   |
|  628 | [Nicholas Merrill &lt;nick AT calyx dot com&gt; BTC - 14wntQ8cBdnhUVfYmDjXz6PbpSSX8nCtk](w/family/e4f17008b5301250340182d45bb2d6379545bb51db0d2550ab36a3cb274ba134)             |       0.03 |        18 | 2013-11-12   |
|  629 | [relay@bgrshell.eu](w/relay/01E388EF92B569074D8FA86CC9D442E829F6E885)                                                                                                           |       0.03 |         1 | 2024-11-23   |
|  630 | [1806.one &lt;1806 AT firemail dot cc&gt;](w/relay/090975875D1BBE53F6FF2ADCA8BA41C97DBB3E59)                                                                                    |       0.03 |         1 | 2022-06-15   |
|  631 | [04DFE047](w/relay/04DFE047ACDF7A6620ACA782FAFC5EF1AE7F4754)                                                                                                                    |       0.03 |         1 | 2019-04-17   |
|  632 | [0x31384448 Ole Rydahl Had a cat named Dobbo &lt;ole rydahl at qp12 dot dk&gt;](w/relay/06353ACB9E2AC4D61F53DF152B6C0B5E946CA8AB)                                               |       0.03 |         1 | 2024-03-27   |
|  633 | [0xFFFFFFFF Random Person &lt;nobody AT example dot com&gt;](w/relay/06E72526BBE040C51C5ADFBAA07ADD9AEB5E1FA1)                                                                  |       0.03 |         1 | 2016-02-03   |
|  634 | [www.triplebit.org](w/family/c7f53433d59fcc2d8c960c7250e9d2ec605d088d76675165cba2029f69e410dc)                                                                                  |       0.03 |        11 | 2024-10-07   |
|  635 | [FreeExitProvider at protonmail dot com tor-relay.co](w/family/c134040cc073b7bc5bbf298c91946c2506f827ea59aae767100751b6b99423b2)                                                |       0.03 |         8 | 2021-08-26   |
|  636 | [AntsySeptum@proton.me](w/relay/09505AFA25D17A3EC5D909CB66E8F1F786498422)                                                                                                       |       0.03 |         1 | 2024-11-05   |
|  637 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/2EB3EC47737C98ABC24D274AFD5C9AD39DB75D7E)                                                        |       0.03 |         1 | 2023-08-02   |
|  638 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/0ABA99986CC96F80A273E3F08856137A72DEF31F)                                                        |       0.03 |         1 | 2023-08-07   |
|  639 | [0BB33B60](w/relay/0BB33B60FAED4D8094E73243849BCAF2F2313177)                                                                                                                    |       0.03 |         1 | 2025-01-06   |
|  640 | [mikael datanerd.se](w/family/4a1c6a86b8dd087bd3a926c4a3669d12cf0e5e99b0223ad7acef96d39234dd4e)                                                                                 |       0.03 |         7 | 2024-10-19   |
|  641 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/0CE59DBA1A9A747A428C711892AC093BBA34C38E)                                                        |       0.03 |         1 | 2023-08-07   |
|  642 | [Scott Maxwell tor-contact-2024-netcup-medium-arm at scottmaxwell dot org](w/relay/1BB90EC57A20D2CC36ACFA8E2E729A7772F39DEF)                                                    |       0.03 |         1 | 2024-04-05   |
|  643 | [torrelay.IllidanStormrage@proton.me](w/relay/124B3FF6C0E0C619FFEDDE8ECF226FE9A9BA3B1E)                                                                                         |       0.03 |         1 | 2025-01-11   |
|  644 | [12D5CABC](w/relay/12D5CABC9A021D94D5869A2692B3CD173DB97263)                                                                                                                    |       0.03 |         1 | 2023-01-26   |
|  645 | [vmo7nzzu at anonaddy dot me](w/family/0e2f77a32377b2f0067679e908caacf5629eafa641ced11548db47cd71ee4f72)                                                                        |       0.03 |         7 | 2022-11-09   |
|  646 | [liara.rviin@slmail.me](w/relay/24F465980178B37DC2D5F908713B7FA4B4E43BAA)                                                                                                       |       0.03 |         1 | 2024-11-16   |
|  647 | [2659ACAA](w/relay/2659ACAA140B6845E38F189B4080817B9819EB9A)                                                                                                                    |       0.03 |         1 | 2019-02-18   |
|  648 | [tor@dst.ca](w/family/2c887eb8eb33ad3b044075689e3e767b1b26a28665ae7de7d20e4e0ee7602894)                                                                                         |       0.03 |         4 | 2019-02-18   |
|  649 | [235A96D6](w/relay/235A96D6C1489B504E4DCB35C21C9DCCA01E4758)                                                                                                                    |       0.03 |         1 | 2021-07-07   |
|  650 | [PRQ Hosting &lt;info AT prq dot se&gt;](w/family/56e60f347003e42be7ebee6d2b15d5bca94e726d9874ab74307c1b3f0b9cf255)                                                             |       0.03 |         9 | 2024-10-20   |
|  651 | [2144EC31](w/relay/2144EC311E714F30648F2B62546E2CA28FDBD36B)                                                                                                                    |       0.03 |         1 | 2024-01-21   |
|  652 | [random zandoli &lt;zandoli@riseup.net&gt;](w/relay/219671E56FE6D40F8E355E272FCD05EE23C00AC8)                                                                                   |       0.03 |         1 | 2024-01-21   |
|  653 | [nicoleiocana.com](w/relay/21C9D9F1633246269DEB84A79495E85C07E8466D)                                                                                                            |       0.03 |         1 | 2020-09-20   |
|  654 | [kol3v14@protonmail.com](w/relay/228931BDF59854D7EDD98C58B38D27A1678BE75E)                                                                                                      |       0.03 |         1 | 2024-02-10   |
|  655 | [ralph.ratz@recons.de](w/relay/2F051BD0124C65C8E617DC8B7EE508D0AF11AFC9)                                                                                                        |       0.03 |         1 | 2024-05-03   |
|  656 | [307DF18E](w/relay/307DF18E52874C08881D2A5238DA0CC02BF761CA)                                                                                                                    |       0.03 |         1 | 2024-08-19   |
|  657 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/46B716F602EB0AF7BD5BC1CED5A9737FD8D46BF9)                                                        |       0.03 |         1 | 2023-08-02   |
|  658 | [47D55C9B](w/relay/47D55C9BD170C948961EF1B6C5D1AEB4CF8F7D06)                                                                                                                    |       0.03 |         1 | 2024-12-08   |
|  659 | [relay@enitg.no](w/relay/2800AA717730344F5D6BA282B27CCE64E90F1D13)                                                                                                              |       0.03 |         1 | 2024-09-18   |
|  660 | [28655D30](w/relay/28655D3058B0BAE840B0DB48DC078C1F773D1291)                                                                                                                    |       0.03 |         1 | 2024-01-22   |
|  661 | [298EC333](w/relay/298EC3331E104E9E84313B10B2DF0746594EED47)                                                                                                                    |       0.03 |         1 | 2024-01-22   |
|  662 | [evansaike consultant com](w/family/ed6ad1b40b96aac74a4f6d8d9013b61ab4a93211c7bdb74d3e4bf6ddd08a016e)                                                                           |       0.03 |         2 | 2022-07-22   |
|  663 | [LS &lt;rarity discard300 at simplelogin dot com&gt;](w/family/c373bd870ce7d2b6c3f76c1c4d54ea705d08147c288a04c2e79e08a3b5238b40)                                                |       0.03 |         2 | 2024-10-13   |
|  664 | [327EEC1C](w/relay/327EEC1C3496BED6056DE756A3FD5AC4A69F84D9)                                                                                                                    |       0.03 |         1 | 2024-11-18   |
|  665 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/33382F0CDA84B56BCB2D337B3781450FED849FED)                                                        |       0.03 |         1 | 2023-08-02   |
|  666 | [7E1A01BA167E8023A6B68BE8A05D811694AE4D8E Felix Auringer &lt;felix.auringer@protonma](w/relay/35F5A0B2F017FD09F7EBF33A565A53D8EB2C9272)                                         |       0.03 |         1 | 2022-01-03   |
|  667 | [tor.yhkki@slmail.me](w/family/d5cbd1cf546a8e0766b599e0c85eab9e734f7d659b039fa13a85efbd78765f50)                                                                                |       0.03 |         2 | 2022-03-04   |
|  668 | [pKD9jZ19N1LiTvsjOF3 at ttutanota com](w/relay/37DDF1906EE3DB96130A717EA54667C64DAC78DF)                                                                                        |       0.03 |         1 | 2019-03-30   |
|  669 | [NoxDaFox nox32 at hotmail dot com](w/relay/3BA2A8C1BE4FD6CCEBBCE4689B66372A0519E0C8)                                                                                           |       0.03 |         1 | 2021-02-17   |
|  670 | [Xavier Bettel](w/relay/3BBF9D98C7D058D7C2E60F6BA5BD574CB4F3FE26)                                                                                                               |       0.03 |         1 | 2019-02-18   |
|  671 | [mail: torrelay &lt;at&gt; maciej.cloud](w/relay/3DA05FF92861FB0A0901C65E1C041C72C0D1CAE3)                                                                                      |       0.03 |         1 | 2023-04-06   |
|  672 | [Tor-Admins &lt;toooor AT all DOT de&gt;](w/relay/3E90247F6488DEA0554D2084F15897830FFE668F)                                                                                     |       0.03 |         1 | 2024-02-22   |
|  673 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/403A004838B6477887B8CE7E51393CF0DC34EC2E)                                                        |       0.03 |         1 | 2023-08-02   |
|  674 | [5D15E37B](w/relay/5D15E37B9CE27E3A7A15B93AA1670FCB27D4C0AB)                                                                                                                    |       0.03 |         1 | 2022-06-12   |
|  675 | [Andsec Team &lt;security AT andsec dot ch&gt;](w/relay/5282981DFCF46D5A1CBE40FDF3DDF9968E29A320)                                                                               |       0.03 |         1 | 2024-10-27   |
|  676 | [&lt;tor-relay@ceskar.xyz&gt; s7xwcb5vpszox5a -----BEGIN PGP PUBLIC KEY BLOCK-----mQGNB](w/relay/53136799CC1E2DFE0F5D279D79DDE4F51EE9AF0C)                                      |       0.03 |         1 | 2023-03-11   |
|  677 | [5746FE4B](w/relay/5746FE4B8D868FE07816DB846DFFBCCEF235AD16)                                                                                                                    |       0.03 |         1 | 2024-01-22   |
|  678 | [MarkN.Hebb@gmail.com](w/family/9510119674064ecf6c8e6cf0d8889e7fcb12382b99e2fcbac381ae3c1cc95921)                                                                               |       0.03 |         2 | 2019-02-18   |
|  679 | [53D47235](w/relay/53D4723566DE710BAB029840404466F3EDB24D49)                                                                                                                    |       0.03 |         1 | 2025-01-06   |
|  680 | [54F5431B](w/relay/54F5431B6FB0AE5DF5BDF62C2F823915EBC1DAB9)                                                                                                                    |       0.03 |         1 | 2024-11-19   |
|  681 | [61050750](w/relay/61050750B002143D23CA5D586105408E08C15236)                                                                                                                    |       0.03 |         1 | 2024-12-16   |
|  682 | [sebastianboegl.de](w/relay/58ED9C9C35E433EE58764D62892B4FFD518A3CD0)                                                                                                           |       0.03 |         1 | 2019-02-18   |
|  683 | [tor822196@gmail.com](w/relay/5A13D8FD24A229360DE96328C756C69F5FC2AA37)                                                                                                         |       0.03 |         1 | 2024-02-06   |
|  684 | [5AC2115B](w/relay/5AC2115B2C6E5A2382484EAEE5D9C7E9C229807A)                                                                                                                    |       0.03 |         1 | 2024-10-27   |
|  685 | [CanisAlpha aa tt PROTON MAIL o COM](w/family/1165dfeece1d389f678cc4d061aa1ed8ecfa6a0a88ab1cf3bd862ae210dfa912)                                                                 |       0.03 |         3 | 2022-03-24   |
|  686 | [5B62E424](w/relay/5B62E4243211E74432D3E38E5A74C373DAEA2C34)                                                                                                                    |       0.03 |         1 | 2024-01-22   |
|  687 | [5B6DAB15](w/relay/5B6DAB1516F3312E7F3E8DACFAABC732A5DF67CC)                                                                                                                    |       0.03 |         1 | 2022-08-21   |
|  688 | [83AF86A9](w/relay/83AF86A91559D6BD097661D4A459BBDA5248A2F2)                                                                                                                    |       0.03 |         1 | 2024-11-05   |
|  689 | [8470EAB3](w/relay/8470EAB36524CA781989E15F04CA6B8F52326554)                                                                                                                    |       0.03 |         1 | 2024-01-22   |
|  690 | [66EEF68A](w/relay/66EEF68A3307E63D59CE34969A710F1FA697DE83)                                                                                                                    |       0.03 |         1 | 2024-10-11   |
|  691 | [w3da5mxwr@relay.firefox.com](w/family/d15de2f4c1be1def9c072f898477588a3a9122f524c970cdac88d36d4f68b10b)                                                                        |       0.03 |         3 | 2023-02-07   |
|  692 | [63B53D61](w/relay/63B53D6186A18BA34B5749C193E92ADFB9395035)                                                                                                                    |       0.03 |         1 | 2023-05-28   |
|  693 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/67DFE854D957701C87F6852B853AF83EE8E0AE34)                                                        |       0.03 |         1 | 2023-08-02   |
|  694 | [dev.null@kryptonit.org](w/relay/68835C57C58F39A9DD22D9444BFE925FBBDC8195)                                                                                                      |       0.03 |         1 | 2024-09-29   |
|  695 | [6B7CEA7C](w/relay/6B7CEA7C2097CAB85E250634053ABD3754481446)                                                                                                                    |       0.03 |         1 | 2024-01-22   |
|  696 | [706F54AC](w/relay/706F54AC939A65DBE31D01E2682BF2145E38A269)                                                                                                                    |       0.03 |         1 | 2024-01-22   |
|  697 | [Tor &lt;tor AT hasselba dot ch&gt;](w/family/9ef4409b1036ceacf608b269c0c2049c1f60c104e520ba0856ba7d38f5d041f4)                                                                 |       0.03 |         2 | 2024-09-04   |
|  698 | [74574575](w/relay/74574575E4C839AEF11AF6A944A855D425FB5280)                                                                                                                    |       0.03 |         1 | 2022-10-10   |
|  699 | [59FDAC19FBC4E692652F3EB0C7B7552BDF21283B Smith &lt;qtornado A T protonmail d0t com&gt;](w/relay/767E444E1FA1DA75F3B77479DB5AE2FA3FFF75CC)                                      |       0.03 |         1 | 2019-02-18   |
|  700 | [7B06C796](w/family/86684d643f042b43d901933a6dc9455e38948cc47943c634ad8e647e3c9ae64f)                                                                                           |       0.03 |         3 | 2024-03-12   |
|  701 | [7DBD27A6](w/relay/7DBD27A6D352722BD3C44FA18202428A33FDD9D0)                                                                                                                    |       0.03 |         1 | 2024-02-16   |
|  702 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/881CC97BF7BA6B2A150931CEBD9F2A2DA5434D0A)                                                        |       0.03 |         1 | 2023-08-02   |
|  703 | [8B09 DE4C E20B AD74 EF9A 11C4 F668 C57D 79DC 827E Vaultboy Admin &lt;Vaultboy AT p](w/relay/91BAB54C6923454F4E5EDC59313C45002B238665)                                          |       0.03 |         1 | 2020-08-31   |
|  704 | [voqelfrei &lt;tor voqel AT pm me&gt; pgp:8018FA5B9E760EF9560DA88531AD8DB3FAD8F4A6](w/relay/8EA364B3BE31A4D365BE535C5C1B80C3664EFA3A)                                           |       0.03 |         1 | 2024-04-02   |
|  705 | [Random Person nobody@tor.org](w/relay/8FD386BF70C5EBA82804A3FD2438BC07B45D0714)                                                                                                |       0.03 |         1 | 2024-02-15   |
|  706 | [Random Person nobody@tor.org](w/relay/8FDAFC439E2D09659A3EC0D723B9C3761EE5596D)                                                                                                |       0.03 |         1 | 2024-02-15   |
|  707 | [abuse-from-tor@polo-uniar.it](w/relay/8BB55A3AFBB7E5D9EB83215DEC8F219E68DF9B6D)                                                                                                |       0.03 |         1 | 2022-04-03   |
|  708 | [precambrien &lt;precambrien AT cestcool dot net&gt;](w/relay/8D5392A1FE568211EF62CCAF257DAE584AA5CDA5)                                                                         |       0.03 |         1 | 2022-06-02   |
|  709 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/9EDE6EC99AE77678CD113BFFFC4303CD20A5111F)                                                        |       0.03 |         1 | 2023-08-02   |
|  710 | [elude acid850@simplelogin.com](w/relay/9F7EBBD54748452E7FC926977B75F2462FA69BDD)                                                                                               |       0.03 |         1 | 2024-10-22   |
|  711 | [galois &quot;d a s h&quot; onion &quot;a t&quot; protonmail &quot;d o t&quot; com](w/relay/A170153BF63A9D2E2FBCA3FCD867286AC3B80CEA)                                           |       0.03 |         1 | 2021-08-06   |
|  712 | [A233051F](w/relay/A233051F685BAC0A1EDF9F7BADFC13C639EA8E17)                                                                                                                    |       0.03 |         1 | 2024-03-25   |
|  713 | [0x5c3732f4942cffc4 Roland van Ipenburg &lt;ipenburg@xs4all.nl&gt;](w/relay/A480D8C9F9B1112E47C24E33DAC0419CAF1A821A)                                                           |       0.03 |         1 | 2019-12-05   |
|  714 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/95D150A7C45BCE9675843E2971209C5663834847)                                                        |       0.03 |         1 | 2023-08-02   |
|  715 | [incognitorelay@proton.me](w/relay/995F99C63FCDE873B34CA1D6D97FF064BD8987A9)                                                                                                    |       0.03 |         1 | 2024-01-21   |
|  716 | [dev.null@kryptonit.org](w/relay/A5CD2AD2A3091BCA98B347077127959E6ADB8155)                                                                                                      |       0.03 |         1 | 2024-09-29   |
|  717 | [admin@cynosure.red](w/relay/A6B53A7E077D4708C8CF8703CA21257D62414AD9)                                                                                                          |       0.03 |         1 | 2024-10-24   |
|  718 | [relay at vonderste dot in](w/family/4058b43dd6074005ef8ef66fd0b5a1e49b31fcc462c4514c3935b9fedf8ee22b)                                                                          |       0.03 |         2 | 2024-08-28   |
|  719 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/A9D620A341A7AE2F6118D1C711AC2518C2CA8A99)                                                        |       0.03 |         1 | 2023-08-02   |
|  720 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/ABBD3528CFC27E15AF4C18F19BC08BBCA16DEAB5)                                                        |       0.03 |         1 | 2023-08-02   |
|  721 | [mandalorian.outpost.222@yandex DOT com](w/relay/DAC825BBF05D678ABDEA1C3086E8D99CF0BBF112)                                                                                      |       0.03 |         1 | 2024-01-29   |
|  722 | [5h098y32 at duck.com](w/relay/E5A935F6A91F39FE184DF2D143869894897E05B7)                                                                                                        |       0.03 |         1 | 2023-06-21   |
|  723 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/B7DAA55B216C9405C6BFCBBC185371C27BD3AD59)                                                        |       0.03 |         1 | 2023-08-02   |
|  724 | [83832@tec.link38.eu](w/relay/B41645F0A6EFB5416F35CFE022C7AD45FD374D35)                                                                                                         |       0.03 |         1 | 2022-06-12   |
|  725 | [systemli &lt;t o r - e x i t .AT. s y s t e m l i DOT o r g&gt;](w/relay/ACEA5C60E4D37D9770246E81C19DB1C3F3CD1A8F)                                                             |       0.03 |         1 | 2023-07-27   |
|  726 | [4096R/1EE96C8A375D94EC46E1F93F12CD89085C726CB4 Jan &lt;jan-tor with jreusch and de&gt;](w/family/a7d768eebe382a6922ffad83f5375f6ff01836f8b07686155a63f8ea32abc3ea)             |       0.03 |         2 | 2019-02-18   |
|  727 | [raphael@gonku.de](w/relay/ADEDEE0DF9BBDF1C6373A24FB47C66C7430912AB)                                                                                                            |       0.03 |         1 | 2024-09-19   |
|  728 | [Tor Admin &lt;sysadmin AT waltoninstitute dot ie&gt;](w/relay/AF6BFD101C0DB57576C767E48A7CFDD75090672A)                                                                        |       0.03 |         1 | 2024-04-13   |
|  729 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/B0543A3DF8D402F53998E03CFE1B35845DB27D9D)                                                        |       0.03 |         1 | 2023-08-02   |
|  730 | [tor at alo dot is tor-relay.co](w/relay/B13C2C569F3FD0C530B7D96E5FF7933DF7A0E834)                                                                                              |       0.03 |         1 | 2019-12-25   |
|  731 | [Random Person nobody@tor.org](w/relay/BBA4AC0A7CC698E97926AF69CE9A58AC26523CF9)                                                                                                |       0.03 |         1 | 2024-02-15   |
|  732 | [relay@nici.gay](w/relay/BE05C5913FB4E70DCAFCB71E83FD926739E3B7FA)                                                                                                              |       0.03 |         1 | 2024-08-18   |
|  733 | [I thought you GNU](w/relay/BE0ABF48A57031C9AFBC49B1F18D9B62B411E5E0)                                                                                                           |       0.03 |         1 | 2024-01-19   |
|  734 | [0xDAC4CCB6722FF7E5 Alexander Bhm &lt;alexander.boehm@malbolge.net&gt;](w/relay/C07DCA0B231BE0554AB4D574AC057C7572BD6EF0)                                                       |       0.03 |         1 | 2022-07-02   |
|  735 | [C1F93754](w/relay/C1F9375437CAA5C5BF1AA4C8E78107BF61883FD5)                                                                                                                    |       0.03 |         1 | 2024-01-21   |
|  736 | [C270F5E0](w/relay/C270F5E09A05E528E1AF13257754A3460130CDA0)                                                                                                                    |       0.03 |         1 | 2024-10-22   |
|  737 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C361B532AD3BBBCF020654151E5F23320D8F8812)                                                        |       0.03 |         1 | 2023-08-02   |
|  738 | [m4j843@gmail.com](w/relay/C5EFF0D9868DFB917032293FC883F7679821D245)                                                                                                            |       0.03 |         1 | 2024-02-16   |
|  739 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C6AABFDBC60356D8AAF268E44C2978117924A887)                                                        |       0.03 |         1 | 2023-08-02   |
|  740 | [5h098y32 at duck . com](w/relay/CD2A63AA540A39B2E3772C7B4E4EB2B82140E8B0)                                                                                                      |       0.03 |         1 | 2024-02-04   |
|  741 | [CD55FF8B](w/relay/CD55FF8B16A8011EF545A600761C4CA59DC170D8)                                                                                                                    |       0.03 |         1 | 2024-03-09   |
|  742 | [CF9BEB3E](w/relay/CF9BEB3E3554C5C343024641A91CC9AE6B849882)                                                                                                                    |       0.03 |         1 | 2022-08-31   |
|  743 | [Jugger Relay jugger-relay@protonmail.com](w/relay/D1C60F9BCF2DBA07A775978F66C9927D3A9490BB)                                                                                    |       0.03 |         1 | 2020-01-04   |
|  744 | [tor-operator@maxwellfarrior.tech](w/relay/D53B7EFD1D481EB2550D03CF822B7E17D058261F)                                                                                            |       0.03 |         1 | 2024-04-13   |
|  745 | [dev.null@kryptonit.org](w/relay/D811B00286CC34E3AEEB1CD8D588681455C2325C)                                                                                                      |       0.03 |         1 | 2024-09-29   |
|  746 | [D8187484](w/relay/D818748485D5F6EFD560615A98FD04D70B4C75D5)                                                                                                                    |       0.03 |         1 | 2024-01-22   |
|  747 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/D855DE28F6524DD0D326027D35531F922E315B0F)                                                        |       0.03 |         1 | 2023-08-02   |
|  748 | [&lt;roger fillipo&gt; rodger.fillipo@mail.com](w/relay/D8A2D0080B0C73E1DC0EC9F33B497F64E5FB3F52)                                                                               |       0.03 |         1 | 2019-02-18   |
|  749 | [tornode@emailfucker.club](w/relay/F022431FC705A7642AE25C8DEAB40109736A0EA6)                                                                                                    |       0.03 |         1 | 2024-12-30   |
|  750 | [F11F59BB](w/relay/F11F59BB31E4624AFFC7D2AC55D4CD4D91FF9658)                                                                                                                    |       0.03 |         1 | 2024-11-19   |
|  751 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/E13B9BD1B368E72C896041136CC2C3986B05C026)                                                        |       0.03 |         1 | 2023-08-02   |
|  752 | [Patrich Stanley Nerdalert78@privatemail.com](w/relay/E1DA0F90454AED535ACE9B415F78C1A1359E29A1)                                                                                 |       0.03 |         1 | 2024-05-31   |
|  753 | [EA9E042A](w/relay/EA9E042A05E851076A657639CD0C84D8DA86A76F)                                                                                                                    |       0.03 |         1 | 2024-01-21   |
|  754 | [EB806B20](w/relay/EB806B20BA699736EE317165323FEEC655A480E6)                                                                                                                    |       0.03 |         1 | 2022-09-20   |
|  755 | [EC16F2B1](w/relay/EC16F2B1D13F65836FD2B7856995828D18F32CC0)                                                                                                                    |       0.03 |         1 | 2022-02-22   |
|  756 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/ECE6033BCA05BC3A593AF9DF2C5CC12D88C7E14A)                                                        |       0.03 |         1 | 2023-08-02   |
|  757 | [ED861855](w/relay/ED861855C655E373547D4C4E86A35C5A313FA497)                                                                                                                    |       0.03 |         1 | 2024-08-20   |
|  758 | [F2899981](w/relay/F2899981E3A601A7B2DDC7DDE02C248069704D9F)                                                                                                                    |       0.03 |         1 | 2019-11-25   |
|  759 | [tor@rkn.life](w/relay/F4A4D78F16E9A0353AD5BBEF4632C7022E20FB20)                                                                                                                |       0.03 |         1 | 2019-02-18   |
|  760 | [F7D5CD0A](w/relay/F7D5CD0A533444BFCBE66E1640D563CF9DD58A1A)                                                                                                                    |       0.03 |         1 | 2024-10-22   |
|  761 | [tor-operator at infosecproject dot org](w/relay/FA85D84F61DCC9E5FAAC177808226A2EDC32B89B)                                                                                      |       0.03 |         1 | 2024-03-24   |
|  762 | [LongLiveTheOnion &lt;longlivetheonion /AT mailbox /dot org&gt; A632B0B269D15241141EE17](w/relay/FCA08FA15437EDB22D37B114E21F04F97E231DCE)                                      |       0.03 |         1 | 2024-10-27   |
|  763 | [00FF9083](w/relay/00FF9083A2736D7E13C2ED8F51A2365BDC1F5C0E)                                                                                                                    |       0.02 |         1 | 2024-11-20   |
|  764 | [01900B2C](w/family/7268e84dd074df9d37c85a0bba99f048350ea3594942425bc829b538e1c54e90)                                                                                           |       0.02 |         4 | 2023-11-02   |
|  765 | [01B8F18C](w/relay/01B8F18C11CE2877E8190FA2C81808CD087515C0)                                                                                                                    |       0.02 |         1 | 2022-02-05   |
|  766 | [01FF9C85](w/relay/01FF9C8571D1C09FA8D2ACCE727D5530FEC10038)                                                                                                                    |       0.02 |         1 | 2020-01-05   |
|  767 | [dhnet.torcontact@gmail.com](w/family/26e6d077612c6c4d5929ff854710fcd98db11d17df91c7b2bd7ba58a32cb6434)                                                                         |       0.02 |         3 | 2022-09-09   |
|  768 | [nomore4thelast@protonmail.com](w/relay/0499CE73E4A26B3C94A519EBEAA06ACF9D325BC5)                                                                                               |       0.02 |         1 | 2024-10-21   |
|  769 | [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/family/e836a284406d5859af570808ef5382ebda7a31f4ff44f871cea5691f79b0c08d)                    |       0.02 |         8 | 2024-12-18   |
|  770 | [fos-admin snokado@gmx.de](w/relay/075D50331B95190A7EC58FC9C570A34761196003)                                                                                                    |       0.02 |         1 | 2024-01-22   |
|  771 | [Henrik Kramselund &lt;hlk AT zencurity dot com&gt;](w/family/e365b0ef10ae8a1fbd5b7a1fe501fbaab5f3b0b8fc9b9880245f320c534a390c)                                                 |       0.02 |         2 | 2021-03-29   |
|  772 | [037B6C60](w/relay/037B6C60DAD4DF32FDA29BF458D5C8C816AA8F3E)                                                                                                                    |       0.02 |         1 | 2019-08-22   |
|  773 | [chaz@chaz6.com](w/relay/02A0D8DDF4DA4E601C1C66143BB0C8A0F2F3C857)                                                                                                              |       0.02 |         1 | 2023-10-28   |
|  774 | [bc1q8jtc0jnvwxw5h4724v04xc3hvnq28s8wme2686 &lt;tor AT grey dot pw&gt;](w/relay/02B2152129686AE0BE05F3D1460591DD71C4BB15)                                                       |       0.02 |         1 | 2022-11-28   |
|  775 | [EF201A39 &lt;nat@makarevitch.org&gt;](w/relay/03BD56B5072FB07D2B4D79E2FB04366D415EF3EC)                                                                                        |       0.02 |         1 | 2021-08-21   |
|  776 | [abuse@srstubes.com](w/relay/0F4DE55998EB3A301ED7B8F66E6244493F63F727)                                                                                                          |       0.02 |         1 | 2025-01-13   |
|  777 | [0F7CA1AC](w/relay/0F7CA1ACC93EFA2F5034F299302894D7823BA56F)                                                                                                                    |       0.02 |         1 | 2024-12-28   |
|  778 | [0FAD8CE4](w/family/1bbcbb1269e2fb8e54bf1601c65f419ef2d09297e74aaefc57467b234880de49)                                                                                           |       0.02 |         2 | 2024-03-19   |
|  779 | [097D8390](w/family/82a1ccf33d3c08abb525f50b0e04f9383724dad0affda45d922eec10dfa5ea73)                                                                                           |       0.02 |         2 | 2022-01-23   |
|  780 | [Dan &lt; xiaoqic at cs dot princeton dot edu &gt;](w/family/230b1dbf20821f89ae34989085e8b04f4da40586e1093f4e8ac927aa685c1fb0)                                                  |       0.02 |         4 | 2023-07-05   |
|  781 | [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/family/91fced5df52f16ecc2bd9ce7cd7ac8d00dd1a94bf15b7f1b0881f840e8f1e8e0)                    |       0.02 |         7 | 2024-12-17   |
|  782 | [tor102 &lt;tor102 AT ip-connect dot info&gt;](w/family/2ef4ee4e3a75dea8060b708c48cac3587c489e9581033fc395d9d73846da5d05)                                                       |       0.02 |         4 | 2023-03-15   |
|  783 | [&lt;tor-relay@ceskar.xyz&gt; s7xwcb5vpszox5a -----BEGIN PGP PUBLIC KEY BLOCK-----mQGNB](w/relay/2D69E1B3FE267639A237E37A847BD0A5A67972F9)                                      |       0.02 |         1 | 2024-11-30   |
|  784 | [vlad at vlads dot me](w/family/b4223ce9db1b75b18bcbf75c4eb10dae3b979fb907939ec31092719fce9fafae)                                                                               |       0.02 |         2 | 2019-02-18   |
|  785 | [The Yeti &lt;yeti AT shokk DOT de&gt;](w/relay/0D45D7CEFF9405A8FDC919F138BD9D7FCA1AB103)                                                                                       |       0.02 |         1 | 2024-12-07   |
|  786 | [freeasinbeer@techie.com](w/relay/1B54D213A5D7E936281D303129D3FB1D5CE64EBA)                                                                                                     |       0.02 |         1 | 2024-07-15   |
|  787 | [1CD86E55](w/relay/1CD86E55B4A707863105AB108A99F307C11892BA)                                                                                                                    |       0.02 |         1 | 2024-02-19   |
|  788 | [&lt;gigi.marian.kent@gmail.com&gt;](w/family/db45d92aeda386138b18f2efdef9b1650cc3b692625c72e9969c4c79b88baae4)                                                                 |       0.02 |         2 | 2023-11-20   |
|  789 | [tor@cabaal.net](w/family/8210ac24820845df5be55d74fccf9f7a252e83e5ad77d2abd58b3bc8663599e1)                                                                                     |       0.02 |         3 | 2023-10-27   |
|  790 | [1324B4C0](w/relay/1324B4C0E741D5786DFD2106F9F71734CAA331F8)                                                                                                                    |       0.02 |         1 | 2024-11-27   |
|  791 | [137DD636](w/relay/137DD6369FCCA88677286A910F173A84B48A73AE)                                                                                                                    |       0.02 |         1 | 2023-12-15   |
|  792 | [176EC378](w/relay/176EC37891794DC7001398A4591FA7F1A77C499D)                                                                                                                    |       0.02 |         1 | 2024-07-27   |
|  793 | [isodiapher /at/ movim / eu xmpp ad9c85ac 5aded378 8fee0468 6680e323 3d3bc641](w/relay/1814DBD5E7E1839CA3F43847683A08F3BF3D5C91)                                                |       0.02 |         1 | 2023-03-25   |
|  794 | [recipe-acl@mit.edu](w/family/d3966715436d6eaad2123016a93fa2f14f4d8fc7404de66e72a6a62183ce6e3e)                                                                                 |       0.02 |         5 | 2023-03-01   |
|  795 | [skirtsandcats@proton.me](w/relay/1A32F188D32DF01890A5EEF4F47243704E593BE6)                                                                                                     |       0.02 |         1 | 2024-06-25   |
|  796 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/1F8C8467BD430D36B9538D8D62F74176A048FE20)                                                        |       0.02 |         1 | 2023-08-02   |
|  797 | [24C312C6](w/relay/24C312C65675E80CFC729E04600D0D9DD27379F4)                                                                                                                    |       0.02 |         1 | 2021-01-08   |
|  798 | [Clara &lt;3 &lt;clara at zergflag dot fr&gt;](w/family/9764ae674104e4529fb78fe72f455f755efc55434bd90ff5a88a1a7e88f9a170)                                                       |       0.02 |         2 | 2024-01-22   |
|  799 | [ContactInfo email:knight AT germancraft dot net url:germancraft.net proof:dns-rs](w/relay/2530E277225FD89CEDA304B36E65759314DEC053)                                            |       0.02 |         1 | 2024-01-22   |
|  800 | [264E8CA3](w/relay/264E8CA388F3D00081CD7E91D6C4272C048B6AF9)                                                                                                                    |       0.02 |         1 | 2022-03-14   |
|  801 | [234B06E4](w/family/2067ac44334d9463a02e5ea6be12d1e8e577e9730e0f300a4a71717d151d4320)                                                                                           |       0.02 |         3 | 2022-04-13   |
|  802 | [1FCCC3FB](w/family/ec0dc7e81269ddb642dd0d82282c5cf1f115ddba9c9841b1b921ee26b29eb2e2)                                                                                           |       0.02 |         4 | 2024-03-05   |
|  803 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/211AD97025CCC8BF59C4BC557B9D95088EE0634B)                                                        |       0.02 |         1 | 2023-08-02   |
|  804 | [&lt;tamanegi AT rainside dot sk&gt;](w/relay/21310F48066A4CAADEB2BFD324F0B38F8E1448D6)                                                                                         |       0.02 |         1 | 2019-02-18   |
|  805 | [c4tdr0ut at duck dot com](w/family/f766ea854f9eecc4c2feef27a4767dfed5addbf205278cc9f9211b11ab547456)                                                                           |       0.02 |         2 | 2025-01-03   |
|  806 | [Tor P. &lt;torp ARROBA sol 42 PUNTO com&gt;](w/relay/30BFB9E2ED011EA4434109DF3A4C9480B7D2F68B)                                                                                 |       0.02 |         1 | 2023-06-03   |
|  807 | [Mr. Leviathan &lt; tor-relay @ lvthn D.O.T win &gt;](w/family/1ef2159034806c4dd12f05eb2daa5db930cb0396c24e1ca354eb031c8d24af93)                                                |       0.02 |         3 | 2022-04-23   |
|  808 | [tor@dnet.ovh](w/relay/2A5746BFF32A363CD3AAD05196C0F10E7143BBB6)                                                                                                                |       0.02 |         1 | 2019-02-18   |
|  809 | [&lt;tor at snehankekre dot com&gt;](w/family/bbffb31668dd5277c8f486b3cd4cf071a7b7dc190337f21862deec2780280566)                                                                 |       0.02 |         2 | 2021-12-14   |
|  810 | [31D270A3](w/relay/31D270A38505D4BFBBCABF717E9FB4BCA6DDF2FF)                                                                                                                    |       0.02 |         1 | 2019-11-05   |
|  811 | [io-tor@twormtwo.com](w/family/d8f2c2f6baa98366462514857802009026b80869f728b8cf8eb9acbfe240cf2f)                                                                                |       0.02 |         2 | 2024-07-17   |
|  812 | [Random Person nobody@tor.org](w/relay/34BA623496287D2E4D3224FF33ED1C6435A73363)                                                                                                |       0.02 |         1 | 2023-01-28   |
|  813 | [cpgs2v97c@mozmail.com](w/relay/37118A947888D3556F2D7CC8D2A53A354ADD459D)                                                                                                       |       0.02 |         1 | 2024-04-25   |
|  814 | [0xE12ECD2E Nicola Ferralis &lt;feranick AT hotmail dot com&gt;](w/family/6ddee272a699a684bbe2efe5d5e036d84123eb50c13ca1c5b0a1858800107879)                                     |       0.02 |         2 | 2019-02-18   |
|  815 | [nsa special projects directorate](w/family/0ecfcace5187c1ab460b9dcf8764119896c7ca113efb1c2a9bdd41f3d331926f)                                                                   |       0.02 |         5 | 2020-09-20   |
|  816 | [not.a@real.email](w/relay/3F477C00E1E1635052EE496A5E337FA7212C6DB1)                                                                                                            |       0.02 |         1 | 2024-12-06   |
|  817 | [breakingbread0@proton.me](w/relay/43548D125655E5312C41AA348D2A71467855115C)                                                                                                    |       0.02 |         1 | 2024-04-01   |
|  818 | [463A4B44](w/family/875c7938398ab01dd55807a08755839d1e8458ef837c5a37042d2e3c117329f9)                                                                                           |       0.02 |         2 | 2022-08-21   |
|  819 | [5B987FF9](w/relay/5B987FF9139F3A6FB433C4D079E15DA1FE9D6B85)                                                                                                                    |       0.02 |         1 | 2024-08-25   |
|  820 | [tor@jednota.party](w/relay/5D31D09B6B92E2E960A6F654671A308772DDFD99)                                                                                                           |       0.02 |         1 | 2025-01-15   |
|  821 | [Moni-Tor &lt;cmVsYXktb3BlcmF0b3JAYXNjaWlhbmRodXRjaC5iZQ==&gt;](w/family/23270fbf5bebcd7069a3c5558486921b3dc042ccf05052aaef482ae8d5149665)                                      |       0.02 |         2 | 2021-10-05   |
|  822 | [5DC40F53](w/relay/5DC40F5357EDF4809A9010828172072C95A73514)                                                                                                                    |       0.02 |         1 | 2019-02-18   |
|  823 | [5DCCC86A](w/relay/5DCCC86AE64A8BFC5F81FFBF2D0C7765B1C7C500)                                                                                                                    |       0.02 |         1 | 2024-12-02   |
|  824 | [493A4023](w/relay/493A402320BA0F4EE453D0098FAE8452723B2EB8)                                                                                                                    |       0.02 |         1 | 2023-03-23   |
|  825 | [&lt;tor@blicky.net&gt;](w/relay/49DC222A7494AEF8E7DBF2E3CAABF23504C77B64)                                                                                                      |       0.02 |         1 | 2019-02-18   |
|  826 | [Cryptobot7 &lt;cryptobot7 AT protonmail dot com&gt;](w/relay/4A32D9D9C0E29275A0584503275658139E844BFF)                                                                         |       0.02 |         1 | 2023-08-08   |
|  827 | [contact@plop.ovh](w/family/ad3c4f5fc836372681620a08ed9b9648d5db703ab63159c110767ce6c9dfaf4e)                                                                                   |       0.02 |         2 | 2024-01-22   |
|  828 | [mikael datanerd.se](w/family/770e1e36e901bb94518034f18671e4730b27bfff944f85ad4a58bffe3c8631bd)                                                                                 |       0.02 |         4 | 2024-10-19   |
|  829 | [Person of good will &lt;nobody - example com for now &gt;](w/relay/4BCAA064723358D133BE9B45EF8436D32BC993E3)                                                                   |       0.02 |         1 | 2024-02-01   |
|  830 | [tor 1 AT online DOT de](w/relay/525EE34C1A7B89AB9DF585246DE30E32702913F5)                                                                                                      |       0.02 |         1 | 2020-01-14   |
|  831 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/52FB884DC2B0825EA9D162365BEEFB6D916648EE)                                                        |       0.02 |         1 | 2023-08-02   |
|  832 | [cerca at swiss-enigma dot ch](w/relay/530BC13FE24D7C4849E16D459631B5A6538DEB11)                                                                                                |       0.02 |         1 | 2023-08-12   |
|  833 | [5h098y32 at duck . com](w/relay/4F510004DAA88E84F60AD991A6A733FF8615CE38)                                                                                                      |       0.02 |         1 | 2023-06-21   |
|  834 | [&lt; pokefamily AT tutanota dot com&gt;](w/family/77da984d569105cc09ef760f66b3b5aa9953dd308d776a2f389dcfc850093a4e)                                                            |       0.02 |         2 | 2022-03-04   |
|  835 | [peTelRobi aT gmaIl DOT cOm&gt;](w/family/4ecac114ecff9dbcb8ecfeb076373c9e0660bf7b79d9f45b273f664033105a0f)                                                                     |       0.02 |         7 | 2024-02-14   |
|  836 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/57588D86F91240BC3D6BA891BDFAF52AF5F6A438)                                                        |       0.02 |         1 | 2024-03-04   |
|  837 | [torkowo@testowo.pl](w/relay/54A29E2BBE66F472813D9A937A103F37966205C7)                                                                                                          |       0.02 |         1 | 2024-04-06   |
|  838 | [54EE5C1E](w/relay/54EE5C1EBB76502CE9C92775FDCB7BC6FE8D6F40)                                                                                                                    |       0.02 |         1 | 2022-10-30   |
|  839 | [iraqizachy@privatemail.com](w/family/365243014e03b2fc5e505a6032813acc81a27f5900e39e91aba88d84df53ac8e)                                                                         |       0.02 |         3 | 2024-06-10   |
|  840 | [614656D1](w/relay/614656D126EC3434046476DB6FD631B71124DAB4)                                                                                                                    |       0.02 |         1 | 2022-05-23   |
|  841 | [CryingOnion-relay@protonmail.com](w/relay/5A9B2EC4C652EC4FF72C8C673937BE27B3486666)                                                                                            |       0.02 |         1 | 2020-10-10   |
|  842 | [kai.sx](w/family/8d23dc68384094e8f7f05f521cb149d7d59bc753078c6f217fdf2c6310203328)                                                                                             |       0.02 |         2 | 2019-02-18   |
|  843 | [FollowMyWay@mail.ru](w/relay/652CC2F03EEDFF84E5F61EF8CD19D3D97DB5E7EF)                                                                                                         |       0.02 |         1 | 2024-06-26   |
|  844 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/668F90D9ECBD73993DDDB6C084B2BD36E97291DF)                                                        |       0.02 |         1 | 2023-08-02   |
|  845 | [Kevin &lt;tor AT kberanek dot com&gt;](w/relay/66C102FA5DDF48C9EEEB048C1630933B66C50ECC)                                                                                       |       0.02 |         1 | 2020-05-13   |
|  846 | [donrichys@riseup.net](w/relay/627823120E3BFC03271EB3B2BC0AFF1627D14D95)                                                                                                        |       0.02 |         1 | 2023-05-06   |
|  847 | [629301C0](w/relay/629301C063FC047171C8A0F1520A9D7CF60308EC)                                                                                                                    |       0.02 |         1 | 2024-05-16   |
|  848 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/63C51065F45A363727FC069D536AC4F576455DD9)                                                        |       0.02 |         1 | 2023-08-02   |
|  849 | [tor101 &lt;tor101 AT ip-connect dot info&gt;](w/family/cb754f1046ce391646e82bf5d4d557a61d5b1b934128ace92c8fe288d5349bfa)                                                       |       0.02 |         4 | 2024-01-22   |
|  850 | [John](w/relay/6C1B288D873C75A696EB70E9FF713B786D37D192)                                                                                                                        |       0.02 |         1 | 2022-01-13   |
|  851 | [6D6B24A5](w/relay/6D6B24A5A3288D62BCB146F4421B6C097443FFB6)                                                                                                                    |       0.02 |         1 | 2024-11-20   |
|  852 | [6DB10460](w/relay/6DB104609C610EF2E1600003DD83821506E2545D)                                                                                                                    |       0.02 |         1 | 2022-10-20   |
|  853 | [Canadian Amateur Radio Operator c/s VA1DER &lt; nameofthisrelay symbol callsign pun](w/relay/6DDDDA309535A1376AE404303B63A25225B62FA4)                                         |       0.02 |         1 | 2024-11-15   |
|  854 | [6E8A208C](w/relay/6E8A208CA020FC4114904EFA294E26614E7D865E)                                                                                                                    |       0.02 |         1 | 2025-01-08   |
|  855 | [torrelay@brave.com](w/family/e573e347ba6a012904ebbacc11ca9df9f2b0499a07580250f865e57cd835605e)                                                                                 |       0.02 |         6 | 2019-02-18   |
|  856 | [tor@eti-net.de](w/relay/71188A034FDAE18DDD0022C5A6BE19A993EB02D2)                                                                                                              |       0.02 |         1 | 2024-02-09   |
|  857 | [idontcheckmyemailanyways](w/relay/724B0F6B4D12E3A0E5AEA0EB9FC1D2410C165001)                                                                                                    |       0.02 |         1 | 2024-01-22   |
|  858 | [72C480E8](w/relay/72C480E844BE33AAD027C5DB0D9CEE2AF67C574B)                                                                                                                    |       0.02 |         1 | 2024-05-29   |
|  859 | [75BFDE08](w/relay/75BFDE081BEEAF99D35B1DC86DD8A7463B1B9DD5)                                                                                                                    |       0.02 |         1 | 2024-12-25   |
|  860 | [7913C398](w/relay/7913C398EFEDC700D08125162FD1977CB5720D26)                                                                                                                    |       0.02 |         1 | 2024-10-14   |
|  861 | [876C7CE4](w/relay/876C7CE43774366250D3E768E690DAB9D4B5D5A3)                                                                                                                    |       0.02 |         1 | 2019-02-18   |
|  862 | [javier.a javi5@gmx.com](w/relay/87DBC90DDA72B9751B021A237D5A173D06F7A409)                                                                                                      |       0.02 |         1 | 2024-01-22   |
|  863 | [avaet1iriejai9duv6aj at gmail dot com tor-relay.co](w/family/e462549470381e0ecaa69b2a0188ef5cf07ecfd7870d7877a6f37e5768f0e8a0)                                                 |       0.02 |         2 | 2019-09-06   |
|  864 | [nomore4thelast@protonmail.com](w/relay/91BB8F6C9FB9C607A553D4DDE32FA4DE96EE2F75)                                                                                               |       0.02 |         1 | 2024-10-21   |
|  865 | [bosslike589 at gmail dot com](w/relay/92988EFE7676BA402296B63AE254968E7AA91980)                                                                                                |       0.02 |         1 | 2022-12-29   |
|  866 | [community.torproject.grief119@passmail.net](w/relay/92B2DA65043D06118A2E4BBEFF87A877C5CF2310)                                                                                  |       0.02 |         1 | 2024-08-16   |
|  867 | [Abuse Poseidon2 &lt;poseidon2.mule134 AT silomails DOT com&gt;](w/family/997d0bb430f4ecddb64ccbc1fd4fe52958ef7aedc0c8a262b1f675a54dac08d7)                                     |       0.02 |         2 | 2024-05-08   |
|  868 | [tor@garrenhax.se](w/relay/9DA5284A51021A711ECAA677C81E5408222B9F2A)                                                                                                            |       0.02 |         1 | 2020-02-13   |
|  869 | [9E2A4B1A](w/relay/9E2A4B1AE7771002DB0CC9A0E7A067AC22E5A121)                                                                                                                    |       0.02 |         1 | 2021-02-17   |
|  870 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/9FAAA5937029C10F612809176DD62EA48917F70C)                                                        |       0.02 |         1 | 2024-03-04   |
|  871 | [pokherchip@mail.com](w/relay/A2E327922875FF477B982200D30759B9A223BA3C)                                                                                                         |       0.02 |         1 | 2024-11-04   |
|  872 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/A44A9974AAEAF814534C2F773D87093C733E417D)                                                        |       0.02 |         1 | 2023-08-08   |
|  873 | [TorRelay.TacticalAtom@gmail.com](w/relay/95A0105031078B387F03596EF6D9FB96B7C99221)                                                                                             |       0.02 |         1 | 2022-12-09   |
|  874 | [tankf33der@disroot.org](w/relay/95CEC8854A6FB514142A7317CFB12B0AD794223C)                                                                                                      |       0.02 |         1 | 2024-04-15   |
|  875 | [email@dvdznf.xyz](w/relay/96428042D3D729B5EA8EA0D41957DACA19B5F633)                                                                                                            |       0.02 |         1 | 2023-04-16   |
|  876 | [0xF1ADC390 Random Tor Node Operator &lt;tor at unterderbruecke dot de&gt;](w/relay/A508096AA0C899F4E6ECD1D9C35037B89008BCBA)                                                   |       0.02 |         1 | 2023-02-17   |
|  877 | [Amsterdam, NL &lt;everybodyswatching@netherlands.nl&gt;](w/relay/A6E4B97CA238DE7E8998D410FB6D2DED07B53509)                                                                     |       0.02 |         1 | 2023-01-28   |
|  878 | [squarebrain--@cocaine--.ninja--](w/family/4d841d22ee3428816ab28fcb237a2f1f913de3648e5c2025e1673690b43ef81c)                                                                    |       0.02 |         2 | 2024-03-16   |
|  879 | [Thias &lt;m DOT buechner AT gmail DOT com&gt;](w/relay/A9E43431EF473BEEF0EEC98DBDDD1B8C3E3FB071)                                                                               |       0.02 |         1 | 2021-12-24   |
|  880 | [nx42.de](w/family/c176fbd3e9e3fa786fb9f52e6b7db0c6a9a82c63f957aa6c6ab9c1d883cb5d8c)                                                                                            |       0.02 |         2 | 2019-02-18   |
|  881 | [AAA7DA4D](w/relay/AAA7DA4D258D055780F4EE496D1154238DF75E04)                                                                                                                    |       0.02 |         1 | 2024-12-23   |
|  882 | [dev.null@kryptonit.org](w/relay/DA79CD34C3B82190CCF063D98254A7A278D94915)                                                                                                      |       0.02 |         1 | 2024-10-17   |
|  883 | [rotor-tor@pm.me](w/relay/DC984437C7560BD4FDBCE0E0C4CD8DB50510AFC9)                                                                                                             |       0.02 |         1 | 2024-05-05   |
|  884 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/E42A20F2DED13F8A22145811133C7E3F63B10607)                                                        |       0.02 |         1 | 2023-08-02   |
|  885 | [email:foxwells riseup.net](w/relay/E4B0CAD11B5487C46293759A3D4B74484CF93509)                                                                                                   |       0.02 |         1 | 2022-09-10   |
|  886 | [support at keybouh dot dev](w/relay/E6060F09E8007FC7CFAC7BC24477F9D878B247DD)                                                                                                  |       0.02 |         1 | 2020-11-29   |
|  887 | [email: bigul AT tutanota DOT com](w/relay/E88DEBDCBD86A71249B4F5EAF30A5E51E3F90B25)                                                                                            |       0.02 |         1 | 2024-04-10   |
|  888 | [E9BE2D99](w/relay/E9BE2D996C5255DFABBAA4E086E5A4BDC192E4AF)                                                                                                                    |       0.02 |         1 | 2024-11-11   |
|  889 | [cookieandtea@cocaine.ninja](w/relay/B8F8E84576DE8CC6CDE136D2374F9385A2AFFAD0)                                                                                                  |       0.02 |         1 | 2024-10-30   |
|  890 | [noc =at= schokomil.ch](w/relay/AC2BEDD0BAC72838EA7E6F113F856C4E8018ACDB)                                                                                                       |       0.02 |         1 | 2019-02-18   |
|  891 | [tor@operapia.org](w/relay/AD97106BA2C903AC2A2A222FEBBB4E645AF6E9AD)                                                                                                            |       0.02 |         1 | 2024-01-22   |
|  892 | [ADC19D08](w/relay/ADC19D080D18C8C7C1157D2F434B4AD626F9C19F)                                                                                                                    |       0.02 |         1 | 2024-05-14   |
|  893 | [ADEC41CA](w/relay/ADEC41CA0EAB7E4D39FD49EF586BE78CACD3110A)                                                                                                                    |       0.02 |         1 | 2024-07-31   |
|  894 | [shadowlynx@example.com](w/relay/AE19F2B7D024EDA73084556467E28A32D4EEA98A)                                                                                                      |       0.02 |         1 | 2025-01-15   |
|  895 | [AE4EB5F6](w/relay/AE4EB5F6F34B0E424AA024D102771D35F954D9F4)                                                                                                                    |       0.02 |         1 | 2024-01-21   |
|  896 | [phillw.net](w/family/4077dd8ff68ab5d3fcd78730f6515d2de78333db2d84dce0211a5946ebf9edbd)                                                                                         |       0.02 |         2 | 2019-02-18   |
|  897 | [abuse@srstubes.com](w/relay/B142A470CF4FD7519E3F89D8FE0E7D5C966A219B)                                                                                                          |       0.02 |         1 | 2025-01-13   |
|  898 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/B1F1CDE96E9DC0AB68F833C0370F7F0F43E29F70)                                                        |       0.02 |         1 | 2023-08-02   |
|  899 | [BD59E773](w/relay/BD59E773639F1AFC856F7688A74430E1E27D6921)                                                                                                                    |       0.02 |         1 | 2024-11-11   |
|  900 | [BF935943](w/relay/BF93594384A02DE7689C4FD821E2638DA2CD4792)                                                                                                                    |       0.02 |         1 | 2022-05-23   |
|  901 | [bftorirelay@gmail.com](w/relay/C30D848B3D8F3E5F4F8A80E6DF69692FE0611D5E)                                                                                                       |       0.02 |         1 | 2024-01-22   |
|  902 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/C30EB051B7838234794CCD3F309123AA0A1FC968)                                                        |       0.02 |         1 | 2024-01-31   |
|  903 | [&lt;roger fillipo&gt; rodger.fillipo@mail.com](w/relay/C5BF27560E4B007365FBA96D32F9E74614218C8E)                                                                               |       0.02 |         1 | 2019-02-18   |
|  904 | [Nobody pudzian-relay at protonmail.com](w/relay/C5E0FF684FA437B905F53AEE45749DAB1868D5D1)                                                                                      |       0.02 |         1 | 2022-02-02   |
|  905 | [machinepfftround4 at protonmail dot com](w/relay/C72B272FD1C5304DF1C0865A4F4F6AA6C1B87FA3)                                                                                     |       0.02 |         1 | 2024-06-09   |
|  906 | [tor at txwx.de](w/relay/C7FF606D59C7F6BECA8A341D3CF11B423F382D5D)                                                                                                              |       0.02 |         1 | 2019-02-18   |
|  907 | [Mi Gibtsdonet &lt;nobody AT example dot com&gt;](w/relay/C93A07D6BDAC150FC437441B6BA331A036E8182D)                                                                             |       0.02 |         1 | 2025-01-15   |
|  908 | [relais06@mailbox.org](w/relay/CAA2BB7232F98457D3B4D2D2EAE62C1460C37651)                                                                                                        |       0.02 |         1 | 2024-12-21   |
|  909 | [Tessier-Ashpool-Tech-Support protonmail com](w/relay/CBD05C5E1EC91AD648B2BE16EC909024F2F096B0)                                                                                 |       0.02 |         1 | 2020-12-09   |
|  910 | [CBFC5270](w/relay/CBFC5270C0C5110CD3DC5DF366358D1A4266943D)                                                                                                                    |       0.02 |         1 | 2024-12-19   |
|  911 | [CD75B876](w/relay/CD75B8768320BB26A52F2B73078271B0D882CC17)                                                                                                                    |       0.02 |         1 | 2024-10-26   |
|  912 | [CD8A6568](w/family/f8cb589037ae47b484da0303d715a15a143309c7fb413839757424d0fd16bfeb)                                                                                           |       0.02 |         2 | 2024-01-21   |
|  913 | [sere04versed@icloud.com](w/relay/CE4C88B2CA700655AC0CC98F093973EA86CAEE4D)                                                                                                     |       0.02 |         1 | 2024-01-22   |
|  914 | [CFE937F5](w/relay/CFE937F5809DEE2C2916A6C54A59CCA5BC5D702A)                                                                                                                    |       0.02 |         1 | 2019-03-30   |
|  915 | [SysCom &lt;syscom =at= snt.utwente.nl&gt;](w/relay/D08660B6D70B6249A57D89BB7A8F2EA2C952BD35)                                                                                   |       0.02 |         1 | 2019-02-18   |
|  916 | [hydra@cock.lu](w/relay/D1CA03021AAF1A8FFE615906661E56A895695B93)                                                                                                               |       0.02 |         1 | 2024-02-04   |
|  917 | [D1E30157](w/relay/D1E30157F356215EF91AA23A2F7317080CAE4C55)                                                                                                                    |       0.02 |         1 | 2024-09-25   |
|  918 | [vstyx@tuta.io](w/relay/EF3BC00F2A5BBC0198A9C29F337973AB85416292)                                                                                                               |       0.02 |         1 | 2024-12-31   |
|  919 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/F11D6B9BE67E65A79B8613834A28D77789AA2D82)                                                        |       0.02 |         1 | 2023-08-02   |
|  920 | [TheStaticTurtle &lt;tor-relay@thestaticturtle.fr&gt;](w/relay/DDDA625FF6C1F1F4554281C2D6DC3FBAD092CB5F)                                                                        |       0.02 |         1 | 2020-01-24   |
|  921 | [DE8E0958](w/relay/DE8E0958DE6209F99B6248EE39E7C583C5532E6B)                                                                                                                    |       0.02 |         1 | 2024-12-28   |
|  922 | [tor at praseodyme dot net](w/relay/E3724FCBE37167609B29FFFC310141F337701467)                                                                                                   |       0.02 |         1 | 2021-01-18   |
|  923 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/ED12CB22CB33C1433CDCD4C5D77AA20E61F3AECE)                                                        |       0.02 |         1 | 2023-08-02   |
|  924 | [toreatsonions@proton.me](w/relay/EDA5E5C0C655BFD4B4410E1612A4D13F398502C9)                                                                                                     |       0.02 |         1 | 2024-11-18   |
|  925 | [F2F8309E](w/relay/F2F8309E8F9B2D816AFB639C86CC2929DEC9459A)                                                                                                                    |       0.02 |         1 | 2021-09-25   |
|  926 | [Jan Weiher &lt;jan buksy de&gt;](w/relay/F4F605AA21C4633CCB5B8DBBC1CEEE5C590C6DCE)                                                                                             |       0.02 |         1 | 2019-02-18   |
|  927 | [torrelaysaregreat@gmail.com xmr:84czj1u2Q4dJ7bzf41TyDFS1i1GPKX5DQGgqZFg85LFge7LL](w/relay/F54250A898FFD6CBB195CA62105AB62FA49B82AA)                                            |       0.02 |         1 | 2024-10-05   |
|  928 | [nomore4thelast@protonmail.com](w/relay/F60D7573896AE71E11A0B764396D4E79EC36A7C5)                                                                                               |       0.02 |         1 | 2024-10-21   |
|  929 | [cyberbits.eu](w/relay/F836446663F1EB816F13708955F105D0B2F5C8E0)                                                                                                                |       0.02 |         1 | 2020-07-22   |
|  930 | [FB3838E0](w/relay/FB3838E0FEE218EE47B3D4F1F264AB9F0E12C9DB)                                                                                                                    |       0.02 |         1 | 2025-01-15   |
|  931 | [nicetrynono@gmail.com](w/relay/FBD40937C6E1523CA717036FC4FD5ECC832A93B7)                                                                                                       |       0.02 |         1 | 2022-01-13   |
|  932 | [abuse@srstubes.com](w/relay/FD3517DFFC281F1430EBB6A62520595A8FF7B378)                                                                                                          |       0.02 |         1 | 2025-01-13   |
|  933 | [FDA67317](w/relay/FDA673176CE83EEB3DD24414A5AD7B411D9165BC)                                                                                                                    |       0.02 |         1 | 2022-09-20   |
|  934 | [torproject.org.masculine802@passmail.net](w/relay/FE05FEFAE7AED4F3D05C3A308999EA2113EC3383)                                                                                    |       0.02 |         1 | 2024-08-27   |
|  935 | [url:https://ricsi.priv.at proof:uri-rsa ciissversion:2](w/relay/FF86A59E35A2CF7F2744DA768DFBE90860868676)                                                                      |       0.02 |         1 | 2022-01-13   |
|  936 | [einSehrNetterHoster](w/relay/FF8B7CAD5F508972509D79F933FB24D2F524AB75)                                                                                                         |       0.02 |         1 | 2022-01-13   |
|  937 | [FFD52CFC](w/relay/FFD52CFC177BC5164DF786409B1FF956085A3A42)                                                                                                                    |       0.02 |         1 | 2024-05-17   |
|  938 | [email:privacyboys@tutanota.com hoster:atomicnetworks cost:64USD donationurl:http](w/family/c1a4e0d4144899fdb5be10d58c15215a01ba0f1692aa5e5b5ab00a937afe42bd)                   |       0.01 |         4 | 2023-07-08   |
|  939 | [csheats@tutanota.com](w/family/d56ed6d53a15c2911dfe3eaa6dfb847557db8462c55ad246217568fbea806673)                                                                               |       0.01 |         3 | 2022-10-25   |
|  940 | [0017A473](w/relay/0017A4738B6FFC5E3D0FC7EE380C10FC2160328A)                                                                                                                    |       0.01 |         1 | 2024-10-11   |
|  941 | [mbox: skylark host: protonmail dot com](w/relay/00240ECB2B535AA4C1E1874D744DFA6AF2E5E941)                                                                                      |       0.01 |         1 | 2020-08-28   |
|  942 | [athenarelay at protonmail dot com](w/family/39928412a46ad9d32002631d68f470cf79f1a5feaec059082975cd19d1a61453)                                                                  |       0.01 |         4 | 2019-07-05   |
|  943 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/family/1ee46b12042a04e1eb26d19f92f803926095ddc828828c152d28d94ce655c5c2)                                                                 |       0.01 |         5 | 2021-09-05   |
|  944 | [servicetor@nexticom.net](w/relay/00B57BF614F7ED3051073B5D4526FF0B23AF217B)                                                                                                     |       0.01 |         1 | 2019-11-22   |
|  945 | [ilovetor14@proton.me](w/relay/0107BFF77A91D06269ECACD1EF40AD8B5B582066)                                                                                                        |       0.01 |         1 | 2025-01-07   |
|  946 | [0178D188](w/relay/0178D1882D43CB524E7C193B8779C141C3633F6D)                                                                                                                    |       0.01 |         1 | 2024-12-12   |
|  947 | [nullvoid.me](w/family/8bba8d94667cbe9b33324dcd35a62a6c3b37a01de9afc4f2e71513fe49edbedb)                                                                                        |       0.01 |         2 | 2017-10-29   |
|  948 | [02264CEE](w/relay/02264CEE8E7D062A910747A7F5D13B16766076D6)                                                                                                                    |       0.01 |         1 | 2024-03-11   |
|  949 | [z9kx21zk855s@protonmail.com](w/family/d302854ffd3517cc7576ce0f2d3fc9bb9d36f4d7815bbce142b3ad36d2cf00c8)                                                                        |       0.01 |         2 | 2023-06-13   |
|  950 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/family/7a977c950fabf147416229eb943925cafba8ada964586e9171a1702e1a3a7600)                                                                 |       0.01 |         3 | 2016-10-24   |
|  951 | [055AB95A](w/family/850c9c7e9cdeb03dfdb7e9ee788585aad62d0a82e924db41f0e5ca615ee4e5c1)                                                                                           |       0.01 |         2 | 2023-10-01   |
|  952 | [Osservatorio Nessuno ODV &lt;exit@osservatorionessuno.org&gt;](w/family/957db25302ea561574b0567ad88159af102f30564915eb44f7800f6af1da5bec)                                      |       0.01 |         6 | 2018-12-21   |
|  953 | [tor-relay-admin@carlos1001.com](w/family/cbce76aa7036390374a9cb68eab4137b14a29d71e4348275ff8e1befe34e149d)                                                                     |       0.01 |         3 | 2022-11-09   |
|  954 | [tor@theyosh.nl](w/relay/064D183D34DECB84F72C4335B0C24D1E8946A9BA)                                                                                                              |       0.01 |         1 | 2014-04-21   |
|  955 | [06B0DAAF](w/family/e013dfeff3b21dc4694d497f1aeb161f682a78359ae70498777d4732ba01c07f)                                                                                           |       0.01 |         3 | 2024-03-11   |
|  956 | [06BC159D](w/relay/06BC159DAA7EB0DB626B2E1B6EFA1E9F0907CD8B)                                                                                                                    |       0.01 |         1 | 2024-09-09   |
|  957 | [Mafra01 AT Safe-mail DOT net](w/family/1def470788d82cca2a304e5f436885a816eb3a9c2c64fa7eebb35e4168919146)                                                                       |       0.01 |         2 | 2019-12-25   |
|  958 | [114F5CD2](w/relay/114F5CD2D75DA75CE02F40EEFFC3508BD8E6ADFB)                                                                                                                    |       0.01 |         1 | 2024-06-17   |
|  959 | [11729833](w/relay/1172983321801BBFC519E081F967B77484CE71E8)                                                                                                                    |       0.01 |         1 | 2023-03-09   |
|  960 | [limoneneis.de](w/relay/0E2F20AA0DBC87C255640E0F4F415B14694DF7A5)                                                                                                               |       0.01 |         1 | 2022-01-26   |
|  961 | [freeflow02.38er5 at slmail dot me xmr:87f14mUNt9EFjgRf2XapivQvti529nDVoGyuira8K](w/relay/106BF05A9D507336DFF8004869088B0F900B4AF2)                                             |       0.01 |         1 | 2023-01-09   |
|  962 | [4096R/1EC9B6F7 baloonasTORrelay &lt;baloona at baloona dot de&gt;](w/relay/10D219897E4F2594AF1EC01C414C2E3754ABA5C8)                                                           |       0.01 |         1 | 2021-01-30   |
|  963 | [screamingpete@jollyfree.com](w/relay/095D042EFEC253DD1B3FAD7F05759A3DD1F01DB0)                                                                                                 |       0.01 |         1 | 2024-06-18   |
|  964 | [katze@kunfoo.org](w/relay/09BFE6A362D2CE435C45F99B56171B6DA486D0F1)                                                                                                            |       0.01 |         1 | 2022-02-23   |
|  965 | [0A4C53B9](w/relay/0A4C53B9D67874C2BAECA2C272BB61EC7A6F54B2)                                                                                                                    |       0.01 |         1 | 2024-12-09   |
|  966 | [email:admin selea.se proof:uri-rsa abuse:abuse selea.se mastodon:@admin@soci](w/relay/419C756F1150ACD57C1A19783AB682FD3CE56E24)                                                |       0.01 |         1 | 2025-01-09   |
|  967 | [4226020F](w/relay/4226020F016082390541440612B24C2228EE6E7B)                                                                                                                    |       0.01 |         1 | 2024-02-18   |
|  968 | [42BF33B3](w/relay/42BF33B3CEBF6ED91A6A267818CC73D7E988F31F)                                                                                                                    |       0.01 |         1 | 2020-12-29   |
|  969 | [ps-tor-operators at listen.informatik.kit.edu](w/relay/2C164169C508C104985551D19D6F76652DC184A6)                                                                               |       0.01 |         1 | 2023-08-02   |
|  970 | [marshtrutizator &lt;nobody@nowhere.com&gt;](w/relay/2C63AAB5B31D757CFC575FC66852AB9715ACD2DE)                                                                                  |       0.01 |         1 | 2024-09-22   |
|  971 | [2CDB2985](w/relay/2CDB29859EA2B2FF18585EA3FEAD988E8CD9727B)                                                                                                                    |       0.01 |         1 | 2024-01-22   |
|  972 | [2D03CA9F](w/relay/2D03CA9F54A00E7DAB9F11616EC1659DDC804C1B)                                                                                                                    |       0.01 |         1 | 2024-12-14   |
|  973 | [voxbox-tor at protonmail dot com](w/relay/2D938F19EAF660D902C656B5E6002F39B45C4BE4)                                                                                            |       0.01 |         1 | 2021-11-04   |
|  974 | [2DFCA202](w/relay/2DFCA202F13A90F91A820B4C3321FC847E269484)                                                                                                                    |       0.01 |         1 | 2022-06-02   |
|  975 | [jfghjgsdjghdsjgf@jabber.ccc.de](w/relay/2E964A7939162CE3BAB41A6567C9EE357B457BD0)                                                                                              |       0.01 |         1 | 2022-10-10   |
|  976 | [torrc](w/relay/2EB79F57C458E2761E7F8D053140586BE4B27BD8)                                                                                                                       |       0.01 |         1 | 2024-03-19   |
|  977 | [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/family/704fcecb4e2a2073adb8c1a35dd152ddbc6b83f29351f65fbcabff44cfb4fe08)                    |       0.01 |         8 | 2024-08-29   |
|  978 | [Random Person &lt;nobody AT example dot com&gt;](w/relay/0C20F273FB538122B21A636EC1FFE99176517BD8)                                                                             |       0.01 |         1 | 2024-02-06   |
|  979 | [0C9B3C68](w/relay/0C9B3C686421C5A8C20BAA0D7369CD929F43A174)                                                                                                                    |       0.01 |         1 | 2013-10-21   |
|  980 | [Nickolai Zeldovich &lt;nickolai AT csail dot mit dot edu&gt;](w/family/d4fc921237e40355aa472e0cc0521170e87f95807070f3f06ef5c292462109fb)                                       |       0.01 |         2 | 2024-05-01   |
|  981 | [0DB4B91C](w/relay/0DB4B91C526F163F480A394DACD8846BF9875A67)                                                                                                                    |       0.01 |         1 | 2022-10-28   |
|  982 | [0E20E3BF](w/relay/0E20E3BFB1BDC3422E568403E37C00249D9BA901)                                                                                                                    |       0.01 |         1 | 2023-09-13   |
|  983 | [Luflosi &lt;tor-relay-2 AT luflosi.de&gt;](w/relay/1AC8884B9C1D1E28DEC7A24610F31E9C6D2C4FA3)                                                                                   |       0.01 |         1 | 2022-01-23   |
|  984 | [tor-exit@mxmla.de](w/family/abc7318e423a5c1ef731e383b14e9886c3e56ac456e653cb232e4e8a8c338e6e)                                                                                  |       0.01 |         2 | 2024-11-06   |
|  985 | [Name &lt;tor.scotch810 AT passmail DOT net&gt;](w/relay/1BA539303E7FBC59F23610D93C8928C5F571702C)                                                                              |       0.01 |         1 | 2024-09-11   |
|  986 | [1BD6462B](w/relay/1BD6462B856754E9C826B220B4C47E59D0479109)                                                                                                                    |       0.01 |         1 | 2022-03-04   |
|  987 | [myFancyRelay@proton.me](w/relay/1C34106064A7345C1C7DFA527D5449AAFC47979E)                                                                                                      |       0.01 |         1 | 2024-09-28   |
|  988 | [toroperator1776@protonmail.com](w/relay/1C7D71A2581DE79C5CFC4ED1FF75D5BE30F01BB7)                                                                                              |       0.01 |         1 | 2019-03-20   |
|  989 | [1CC7363E](w/family/335b4f03ef6ff43278ee40926e2a8655e22b3e278752846409713686e4c82be9)                                                                                           |       0.01 |         2 | 2024-01-22   |
|  990 | [arpsel.ws](w/relay/1D1D23F156944855E0A5FE06E99DA408EED5AE6B)                                                                                                                   |       0.01 |         1 | 2023-06-21   |
|  991 | [Admin &lt;tor.uncharted624@passmail.net&gt;](w/relay/13EFE593ABC3A1EFA50FB2462F03F71434CDC406)                                                                                 |       0.01 |         1 | 2024-06-24   |
|  992 | [14080AF1](w/relay/14080AF1608D3099553AEBC58FBFB695D3314253)                                                                                                                    |       0.01 |         1 | 2024-06-02   |
|  993 | [146E036A](w/relay/146E036A95F8F0A263CBCA742DC14C8A78386E8C)                                                                                                                    |       0.01 |         1 | 2024-12-18   |
|  994 | [ben &lt;AT&gt; uq.ci](w/relay/15CD2C302869242498AFEB2369C0E95882DFCB6A)                                                                                                        |       0.01 |         1 | 2025-01-08   |
|  995 | [santa@claws.com](w/relay/15DAE2F6C1614F30C84A3DF1FD5ABB0218FEE9C0)                                                                                                             |       0.01 |         1 | 2023-10-31   |
|  996 | [16D50447](w/family/156d7dbdf0dc779cbb3d1029790af9f4e27b76b4adc03dba0f01b07f8c527403)                                                                                           |       0.01 |         2 | 2024-01-21   |
|  997 | [Random Person &lt;my-tor-jitsi AT laryllian dot de&gt;](w/relay/11EA7F8A581D7BCD1F77ED5B7526A0B92B003A87)                                                                      |       0.01 |         1 | 2022-03-02   |
|  998 | [121FF0E5](w/relay/121FF0E504C88CDF693821B4F9312C0F349E0B63)                                                                                                                    |       0.01 |         1 | 2023-10-03   |
|  999 | [12961130](w/family/06fcf2a532049653542d5965c6686710fe12ca4bc2988e47ef43300085af7bf8)                                                                                           |       0.01 |         2 | 2022-04-18   |
| 1000 | [12CF84D3](w/relay/12CF84D3D2E30BB9799BFC0E1DDDFDA8D35AF007)                                                                                                                    |       0.01 |         1 | 2015-08-04   |
| 1001 | [FlashTor at e.mail DOT de](w/family/cf6885c388d90be2f6cb872d8ad5c3ab8f74b000ff684400f69584b909b446ac)                                                                          |       0.01 |         5 | 2019-02-18   |
| 1002 | [J Stark &lt;jstark1809 AT keemail dot me&gt;](w/family/2ed2d85a512d4a5ff9df13ec781d6aa0146c2f51af170e15230a20f77ce58613)                                                       |       0.01 |         2 | 2021-11-30   |
| 1003 | [17B40C59](w/relay/17B40C5962AAF8F69667967E8936AE13280B3707)                                                                                                                    |       0.01 |         1 | 2024-05-07   |
| 1004 | [187F555B](w/relay/187F555BA1549E7493DD946181277CC303B0B79F)                                                                                                                    |       0.01 |         1 | 2024-11-18   |
| 1005 | [Fractalia &lt;fractalia at protonmail dot com&gt;](w/relay/18C585E153DFBCC414B8259FE7994BA520B5EB6F)                                                                           |       0.01 |         1 | 2019-02-18   |
| 1006 | [jets843@privatemail.com](w/family/7024a68bf944969260c25e761b44112e643f0bb81e873761c6c72d32f1296616)                                                                            |       0.01 |         6 | 2022-08-11   |
| 1007 | [Stechus Kaktus &lt;stechuskaktus1337@protonmail.com&gt;](w/relay/1F4078E841EC74C92C88D69B296A8E2EAA2349AA)                                                                     |       0.01 |         1 | 2023-07-29   |
| 1008 | [uralta a protonmail punto ch](w/relay/24A818D9F1E09F1845FC1589DE5AAF15C8E0867E)                                                                                                |       0.01 |         1 | 2022-07-12   |
| 1009 | [254C0A96](w/relay/254C0A96A24F639FEFB49A0C94847DEF158AFAAE)                                                                                                                    |       0.01 |         1 | 2022-08-11   |
| 1010 | [Random Person nelleprepared@yogirt.com](w/relay/2589BB85C1C90EF37FCE15639CAB4704F8A49E1E)                                                                                      |       0.01 |         1 | 2024-03-16   |
| 1011 | [katerinagrow@firemail.de](w/family/273a4c05dc67edfb0a6fc9294d8a6458257097068f4f06adc19e80affe3342d8)                                                                           |       0.01 |         2 | 2025-01-14   |
| 1012 | [alissastranger003@firemail.de](w/family/41813acbe6e8c1a51a5c04bfe0018e2e59a05afcca5ce9e66f259dfbf496ae10)                                                                      |       0.01 |         2 | 2025-01-10   |
| 1013 | [23BAB4A9](w/relay/23BAB4A9B1B7F553599CD81AED553FACB7B35210)                                                                                                                    |       0.01 |         1 | 2022-04-03   |
| 1014 | [Steven Murdoch &lt;ephemer-tor-admin@cl.cam.ac.uk&gt;](w/family/f7d97a091fa8a93a612c5f49aa22604ece2a1858b17f65054f4fd57a5e7d6e76)                                              |       0.01 |         2 | 2019-02-18   |
| 1015 | [24523E7B](w/family/3d20a4d0aa4deff1e7c1b29fa00220b6d74663fedc8c28f482c7714681e1d159)                                                                                           |       0.01 |         2 | 2021-03-29   |
| 1016 | [2062C6FE](w/family/8c4195c72febc40a717a2c35cae7ed022eb19c945285aae27993477f5a0131e9)                                                                                           |       0.01 |         2 | 2021-09-05   |
| 1017 | [saptak013@gmail.com](w/relay/206B2B8C1AB1E20C02CFE2A913AA8DE169980FC2)                                                                                                         |       0.01 |         1 | 2020-09-20   |
| 1018 | [221F035A](w/relay/221F035A330AC4231A2E3D901F1CB11483C19F66)                                                                                                                    |       0.01 |         1 | 2019-02-18   |
| 1019 | [223CE391](w/relay/223CE391AEC6DBA4D194566C38C089E329BD709E)                                                                                                                    |       0.01 |         1 | 2024-04-14   |
| 1020 | [&lt;ben tor at graef . in&gt;](w/relay/3004A0135AE7E42F3D1475838F76EFF9BE46294A)                                                                                               |       0.01 |         1 | 2024-12-13   |
| 1021 | [f46edmin@linuxmail.org](w/family/3ea7a11a6bdf49ba121a7992d8da6fb1f0d4361f007b91c38d1c06e4d5ec066a)                                                                             |       0.01 |         3 | 2022-04-13   |
| 1022 | [surveillance.monster](w/family/5677ddace5b31ecef45ba90bca408e0e8867fabebd8ce407e66fe2cdbe8abbb0)                                                                               |       0.01 |         2 | 2024-11-05   |
| 1023 | [Alessandro Greco &lt;alessandro DOT greco DOT 1 AT protonmail DOT com&gt;](w/relay/47B72187844C00AA5D524415E52E3BE81E63056B)                                                   |       0.01 |         1 | 2024-02-02   |
| 1024 | [tor at example dot org](w/relay/4916C94702DB9FE5A94B69657880FCF6D1B2A21B)                                                                                                      |       0.01 |         1 | 2023-06-17   |
| 1025 | [lamast-05.tycke@icloud.com](w/family/d4afcfaa4102aa5b60067fcc1ed1dcd4d3f5db4c296873d9fa5a688a66a22a72)                                                                         |       0.01 |         2 | 2022-08-31   |
| 1026 | [zzif &lt;nospam AT zzif dot net&gt;](w/relay/271A20885414AE00BFEE7158C383817C9521CBB2)                                                                                         |       0.01 |         1 | 2024-11-24   |
| 1027 | [pwcrack@pwcrack.com](w/family/039ba367b64a19b8f58b216948650a0886850955e4cc3c467394380edd958400)                                                                                |       0.01 |         4 | 2023-06-15   |
| 1028 | [email:sysop openinternet.io offlinemasterkey:y ciissversion:2](w/family/e90a81d6ec1b42de71803c6059843c091bbce645ca0e58dd2f11fbefdfee33c5)                                      |       0.01 |         2 | 2019-02-18   |
| 1029 | [quetzalcoatl-relays.org](w/family/a5fff0523301e058a091331f564d2eed0abad225902f0a96fa9ef6f6a11d66c8)                                                                            |       0.01 |         8 | 2021-06-17   |
| 1030 | [xor.st &lt;tor@xor.st&gt;](w/relay/2ACF25EDCB5CAECF2F2AB2A5F9EB1E7600CD8B0D)                                                                                                   |       0.01 |         1 | 2024-07-04   |
| 1031 | [kingvon4@proton.me](w/relay/2B247BA0398DAB74EFFF6DF4AFA7AE4DA4E4B031)                                                                                                          |       0.01 |         1 | 2024-12-23   |
| 1032 | [316DE45E](w/relay/316DE45EFFB53671C9FD53CE0992952846709A29)                                                                                                                    |       0.01 |         1 | 2019-02-18   |
| 1033 | [tor-node-admin@protonmail.com](w/relay/31E3072BE2D7FEC5707F09C351612FE2B7AE48D5)                                                                                               |       0.01 |         1 | 2022-01-23   |
| 1034 | [Alexander &lt;k9u4qCLrTa at protonmail dot com&gt;](w/relay/323BB02A620241842C5A283AD2617D9EFA397FBD)                                                                          |       0.01 |         1 | 2021-12-14   |
| 1035 | [email:spambox bahnhof.se](w/relay/32C1100B5EF19A5BFBB431E8D42781C2D09D31C3)                                                                                                    |       0.01 |         1 | 2020-04-03   |
| 1036 | [32ED1B55](w/family/f4150483affe6d5448767a391289c9740ac0b86c71a2c1c0442450c747f8277c)                                                                                           |       0.01 |         2 | 2021-03-19   |
| 1037 | [Tor Administrator &lt;tor at-sign downtimepatrol.com&gt;](w/family/b0dc3b1964600f48525d87abdfc86e6b10099992e617f2acbefa91ab688730a6)                                           |       0.01 |         2 | 2020-08-11   |
| 1038 | [Honos@outlook.com](w/relay/33D7CEA86FDF5309E6F4A04BCB33DAC40AA26631)                                                                                                           |       0.01 |         1 | 2024-10-07   |
| 1039 | [hey](w/relay/33F221E3A9306FA08A857FE266EBE23720EB6026)                                                                                                                         |       0.01 |         1 | 2022-03-14   |
| 1040 | [3443772C](w/relay/3443772CDE2F4DFF116063DDF64BB2A1884A4287)                                                                                                                    |       0.01 |         1 | 2023-02-07   |
| 1041 | [jimbo263@fastmail.com](w/relay/35335AB58392102637D786641333C7D5DFAC9869)                                                                                                       |       0.01 |         1 | 2022-08-31   |
| 1042 | [360097B0](w/relay/360097B0E61FFBD4B7255A29B3A1A96BC86C48DA)                                                                                                                    |       0.01 |         1 | 2023-08-02   |
| 1043 | [tor107 &lt;tor107 AT ip-connect dot info&gt;](w/family/8f8bfd368f6cb6cd59cacd8cf9f2c1de925acc641295cc77c5ca66fb923ea8e7)                                                       |       0.01 |         4 | 2024-01-22   |
| 1044 | [le1025656haha102vvs210000bnmuiooop11x@protonmail.ch](w/family/ec97f757736ae3627860dc7568043dc6521ac750cec0baeaecaf36658fc4676e)                                                |       0.01 |         2 | 2024-12-05   |
| 1045 | [ziplock &lt;ziplock@riseup.net&gt;](w/relay/38B6C305C159F03E56082F6D6B752516B1040008)                                                                                          |       0.01 |         1 | 2024-06-05   |
| 1046 | [392051FD](w/relay/392051FDD20D371CF90EE7BCA39F4763427B118D)                                                                                                                    |       0.01 |         1 | 2023-04-16   |
| 1047 | [syrian-elephant at syrian-elephant](w/relay/3A9BD4466835668BB3C5D5B168973D95D0C162E0)                                                                                          |       0.01 |         1 | 2024-06-24   |
| 1048 | [0xD2070CB6 admin&lt;at&gt;ajanvier&lt;dot&gt;fr](w/relay/3AF8390D3F4B8103DA297CFD514B35740781B87D)                                                                             |       0.01 |         1 | 2019-03-10   |
| 1049 | [damienjamesh at yahoo dot com](w/relay/3B953203AF332D8FE1452E1CE7CB50A3B5297DB2)                                                                                               |       0.01 |         1 | 2020-07-12   |
| 1050 | [kszczot.pl](w/family/f53b8123c17f4043a0e0b9354f99994b49aea176dc1681adfbe3b69b65ede466)                                                                                         |       0.01 |         2 | 2024-10-30   |
| 1051 | [laser chef proton me](w/relay/3CADFF1E426C41699887B48EFEA375A81E888E3C)                                                                                                        |       0.01 |         1 | 2024-01-21   |
| 1052 | [your@e-mail](w/relay/3CFA3F6B33AD08D42C20EADE313E43E79D97FCF5)                                                                                                                 |       0.01 |         1 | 2023-02-23   |
| 1053 | [3F02E624](w/relay/3F02E62474F376F7EBC8CE6AAA8791BF18DFA5A1)                                                                                                                    |       0.01 |         1 | 2023-03-23   |
| 1054 | [kleft &lt;kleft AT riseup dot net&gt;](w/relay/3F25A8A8070DCCEB7DC9567EED7AA993EEA580B1)                                                                                       |       0.01 |         1 | 2024-03-03   |
| 1055 | [tor106 &lt;tor106 AT ip-connect dot info&gt;](w/family/59006a23ae59bc2c1c741eb365e9454c43d0cdca3d8fb862eee8cd6c3b293480)                                                       |       0.01 |         4 | 2024-01-22   |
| 1056 | [3FB88013](w/family/08bf087c7bd8ec4b9d68c864b5c87e2d9e1c3786eb0fdc08f7279a5458872c40)                                                                                           |       0.01 |         2 | 2024-01-28   |
| 1057 | [potlatch protonmail com](w/family/f4abf23e26d49a1628b4523d07c8ba70cafeb0afd21c0213d9d5d60213ed4de2)                                                                            |       0.01 |         5 | 2019-02-18   |
| 1058 | [406A030C](w/relay/406A030C4A33800DA8E8CDCA72DAFC446A3787AC)                                                                                                                    |       0.01 |         1 | 2024-06-18   |
| 1059 | [gooserider42 at proton dot me](w/relay/40A508BA00D184F8737666DCE88E794AF8B8924D)                                                                                               |       0.01 |         1 | 2022-11-19   |
| 1060 | [436F432D](w/relay/436F432DA1A497234471A0870555097957400091)                                                                                                                    |       0.01 |         1 | 2024-11-18   |
| 1061 | [zann at arklab dot dev](w/relay/43BB4DD60D2E7C8B2E8ACC11044E17D29E3E3EBB)                                                                                                      |       0.01 |         1 | 2025-01-06   |
| 1062 | [ReplaceIwithY &lt;tor AT cIberkommando d0t de&gt;](w/relay/447A24F3402C4774D89E7AAD2D876D0BF64E3267)                                                                           |       0.01 |         1 | 2020-04-03   |
| 1063 | [Dr Andy Hill &lt;support AT drandyhill dot co dot uk&gt;](w/family/3cdf8acf74b582f6f3a59ded20de9540d512ffc1bd12d76bae474b6ba38e09b0)                                           |       0.01 |         3 | 2024-01-21   |
| 1064 | [vollborn@quantentunnel.de](w/relay/44B7B71CE9099D90949723117D74176F8E9714A8)                                                                                                   |       0.01 |         1 | 2023-03-15   |
| 1065 | [Martin Kroell &lt;martin at kroell dot net&gt;](w/relay/44DF1007B545B4D8057F279025EBB33CF99BE227)                                                                              |       0.01 |         1 | 2019-02-18   |
| 1066 | [44FB31D0](w/relay/44FB31D0A2E567E2D52AC92C6BCDA59D03F5B44F)                                                                                                                    |       0.01 |         1 | 2021-07-27   |
| 1067 | [451F5F14](w/family/ace09f13035cac1bc6d24eec28e97bf8a1ed17dc4c4311ae7c225776451c45fa)                                                                                           |       0.01 |         3 | 2024-03-18   |
| 1068 | [45418A62](w/relay/45418A624C233F1831797A7A5B5DDB083864594B)                                                                                                                    |       0.01 |         1 | 2023-02-25   |
| 1069 | [underw00d72@mail.com](w/family/e3fe553237f18ab612f1014a56afe666ffc1bfe8ba974b10f4e1fc309754ec17)                                                                               |       0.01 |         3 | 2022-04-23   |
| 1070 | [5CA88249](w/relay/5CA88249A9BFA77EB4A7FB50AC154FEF34600F5A)                                                                                                                    |       0.01 |         1 | 2023-03-11   |
| 1071 | [tor@schweren.dev](w/relay/4953D65C802860DED172D788B9660BC29DF92235)                                                                                                            |       0.01 |         1 | 2024-01-22   |
| 1072 | [4BDBCEA3](w/relay/4BDBCEA35E84C2C58AA37F030619092A23B638C1)                                                                                                                    |       0.01 |         1 | 2024-12-02   |
| 1073 | [508DE06B](w/relay/508DE06B45D8A8FA0C72A0BF799D42007BD4995E)                                                                                                                    |       0.01 |         1 | 2025-01-15   |
| 1074 | [papakirelay AT proton DOT me](w/relay/51980392C76AFEDED21594F3B442441320BA6E4A)                                                                                                |       0.01 |         1 | 2024-05-04   |
| 1075 | [Contact: Brian Penrose &lt;penr0se@openmail.cc&gt; - 8397 C079 68CD 6455 ECBD 4F85 0A0](w/relay/5262556D44A7F2434990FDE1AE7973C67DF49E58)                                      |       0.01 |         1 | 2019-06-28   |
| 1076 | [trnf AT posteo DOT pm](w/relay/5312D9D6076D15962AFC0E4A834E8F6B9EAA531D)                                                                                                       |       0.01 |         1 | 2025-01-06   |
| 1077 | [knuth &lt;tor AT ethergeist dot de&gt;](w/relay/53412DCC555335B400DB72750ED0BE08D034D779)                                                                                      |       0.01 |         1 | 2019-02-18   |
| 1078 | [a-n-o-n-y-m-e.net](w/relay/4F5D13F8951A1E18BAE1186F9E7849E3DB5B91AD)                                                                                                           |       0.01 |         1 | 2024-07-12   |
| 1079 | [aaston@martin.car](w/relay/56344DEE34D3343090D00AD88CE2D58B50712C81)                                                                                                           |       0.01 |         1 | 2024-02-01   |
| 1080 | [57D0B5A2](w/relay/57D0B5A215824CF1A7414DE61B6559C09526759F)                                                                                                                    |       0.01 |         1 | 2023-04-08   |
| 1081 | [nospam@gmail.com](w/relay/582E9FDCFB6B6573A9EC0EF9F560C4A0245997E7)                                                                                                            |       0.01 |         1 | 2024-03-23   |
| 1082 | [athalis.de](w/relay/584FAA0033A52C4A7091C3D3FDF70A2EFF6C739D)                                                                                                                  |       0.01 |         1 | 2020-10-30   |
| 1083 | [&lt;tor-operator AT dafabhoid DOT de&gt;](w/relay/586803B7EDF9E28D99B54097724287FB7109771A)                                                                                    |       0.01 |         1 | 2020-12-09   |
| 1084 | [53FD4C5B](w/relay/53FD4C5B66EF1A12CE22E897EF1BF58CFEC58037)                                                                                                                    |       0.01 |         1 | 2024-08-22   |
| 1085 | [mRtjR4JX6pgJ@protonmail.ch](w/relay/5424110BF0524432D80605090638D9CA63689BAC)                                                                                                  |       0.01 |         1 | 2022-03-24   |
| 1086 | [5471EB05](w/relay/5471EB0532150597F0EC0B52B077E6167B8486EE)                                                                                                                    |       0.01 |         1 | 2024-06-26   |
| 1087 | [548317F9](w/relay/548317F9261EFE1B953B9B70373EF8AA33142843)                                                                                                                    |       0.01 |         1 | 2025-01-01   |
| 1088 | [hawk at swiss-enigma dot ch](w/relay/5495F0435963D526BFD303120D0BEC72363842F6)                                                                                                 |       0.01 |         1 | 2022-09-20   |
| 1089 | [katerinazamurieva1996964j3cy@mail.ua](w/relay/54DC5D17A960467C699142959FBA28A53AE35298)                                                                                        |       0.01 |         1 | 2025-01-09   |
| 1090 | [tinkywinkytor at proton.me](w/family/4727b453972222b7249150ce35a449f4d9ff81732d641270460c1e526703f8f8)                                                                         |       0.01 |         2 | 2023-01-28   |
| 1091 | [5F6C3212](w/relay/5F6C321216267A086F6B3634BA4664297C504F5E)                                                                                                                    |       0.01 |         1 | 2025-01-01   |
| 1092 | [Stan &lt;favorite0ne@proton.me&gt;](w/family/1cde88e9b09e46b048a9790a8173153428eccf12b0bb70f5e6179e6f68fde6ff)                                                                 |       0.01 |         3 | 2024-08-02   |
| 1093 | [0xB83A02ED Randy Bush &lt;randy AT psg dot com&gt;](w/relay/60E4C5E306D2DB22890EE24A09F9B6C30AF396A8)                                                                          |       0.01 |         1 | 2019-02-18   |
| 1094 | [itzdr4v3n@gmail.com](w/relay/616FAD7872DD878A99B2B31F0F1E31E9B38B4F54)                                                                                                         |       0.01 |         1 | 2024-09-25   |
| 1095 | [0xFFFFFFFF Playstar Network &lt;info AT playstar DOT se&gt;](w/relay/5975858B6A1F37CCC96026B946EACF08E1772D0E)                                                                 |       0.01 |         1 | 2020-05-23   |
| 1096 | [597C985B](w/relay/597C985B67D751BDD2E326532A6E25CD2B54B774)                                                                                                                    |       0.01 |         1 | 2024-07-20   |
| 1097 | [naphthalin quietgarden.net](w/family/f7a820e1ad31a1a36616092d12a99d75aef811413c3e8715f694c24251b5adba)                                                                         |       0.01 |         2 | 2022-10-20   |
| 1098 | [0x3632046A Dmitry &lt;dbaryshkov AT gmail dot com&gt;](w/relay/842B1F6C4B9E41FC9059DF675C5DF5BDA9F0FC73)                                                                       |       0.01 |         1 | 2019-02-18   |
| 1099 | [8449C864](w/relay/8449C8642A9C9A2C2B2218BB26EE26233690E501)                                                                                                                    |       0.01 |         1 | 2022-03-04   |
| 1100 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/856E3A14EC2CAD7412C9A6E8FC0C3FDFD075E8F5)                                                        |       0.01 |         1 | 2024-01-31   |
| 1101 | [mylilrelay at tutanota dot com](w/relay/85C9E4FFF9B69D43CC54FCC706DAC8554C6C9580)                                                                                              |       0.01 |         1 | 2022-03-24   |
| 1102 | [swordsman @ satoshi](w/relay/85CDBC7ADB15D5B64FB4C5989CD510F6869F9206)                                                                                                         |       0.01 |         1 | 2024-01-22   |
| 1103 | [85D141F0](w/relay/85D141F0B127C9517A8C88B15D21F622954AA6AF)                                                                                                                    |       0.01 |         1 | 2023-03-11   |
| 1104 | [letsdoit &lt;letsdoit@gmx-topmail.de&gt;](w/family/18249c31888b063b431f845a68db3a69bf0cbe4d6ad5f128cd455f7400d5d296)                                                           |       0.01 |         4 | 2021-03-19   |
| 1105 | [85F96B5A](w/relay/85F96B5A4054AFD59E97CF83E7FB2D46702B7B90)                                                                                                                    |       0.01 |         1 | 2025-01-14   |
| 1106 | [forester@ro.ru](w/relay/8645638C26B58932B08A2F388D86B3166F6FAE8D)                                                                                                              |       0.01 |         1 | 2024-08-07   |
| 1107 | [shakita@mailfence.com](w/family/fc9135531e4b411f2b9c2bb437a34c4f1bb56401e258e098512a47f728dafa1f)                                                                              |       0.01 |         2 | 2022-01-23   |
| 1108 | [mail plus tor-node &lt;at&gt; bysom dot org](w/relay/65F39CA1E4CEF4BB5EA5D26F687599205AF61502)                                                                                 |       0.01 |         1 | 2021-11-24   |
| 1109 | [&lt;agrialimasmeni@riseup.net&gt;](w/relay/661E08534FABDBE09BA505F7A73848371C6EF732)                                                                                           |       0.01 |         1 | 2019-02-18   |
| 1110 | [Random Person &lt;pitime2038 AT gmail dot com&gt;](w/relay/675EB5F943842126CB34B805F6BDC888B81F8E70)                                                                           |       0.01 |         1 | 2024-04-17   |
| 1111 | [sabotage.net](w/relay/678B3A694071537AD62723BDA96C6CF1358AE67A)                                                                                                                |       0.01 |         1 | 2024-01-22   |
| 1112 | [x1005 AT protonmail.com - 19WuqebhqrywBXy9J7EGU8qoZ8Z5r2fxyu](w/relay/63C81BCA835570069A7FCD48312DEA707F6CBAA2)                                                                |       0.01 |         1 | 2019-02-18   |
| 1113 | [kinitor@espiv.net](w/family/82cebea8e51376ed9239dd81da645264bdcc8bfdf39076bd2261c057612cfc78)                                                                                  |       0.01 |         3 | 2022-11-09   |
| 1114 | [Cedric &lt;chutney dot tor AT gmx dot com&gt;](w/relay/81A59766272894D27FE8375C4F83A6BA453671EF)                                                                               |       0.01 |         1 | 2019-02-18   |
| 1115 | [81B8222C](w/family/7b7f7723f3e48ea5bb3a15075264d23eca6c977d81c091a3470b2e12f31d33ca)                                                                                           |       0.01 |         2 | 2022-06-02   |
| 1116 | [81D4A9FB](w/relay/81D4A9FB174118AA4809B4EE209982FFF215E8A9)                                                                                                                    |       0.01 |         1 | 2024-11-19   |
| 1117 | [jakob AT ybals DOT de](w/relay/81D61DF58DC5EB83B6178CE9474B5CD694A44A48)                                                                                                       |       0.01 |         1 | 2024-01-22   |
| 1118 | [81E8A4F5](w/relay/81E8A4F52F14178E840349FAF92C97AC998DB326)                                                                                                                    |       0.01 |         1 | 2024-11-04   |
| 1119 | [82798874](w/relay/827988742048E7FAA1AE88F3089EE8DCC1139D91)                                                                                                                    |       0.01 |         1 | 2024-03-28   |
| 1120 | [postmaster@yolovision-inc.com](w/relay/831AA2AD749BB28CEC9F75A744F36D0621E4751D)                                                                                               |       0.01 |         1 | 2024-01-21   |
| 1121 | [67CDF7A4](w/relay/67CDF7A4D06E98E55AAE595BBEBF38E64C4CCBF3)                                                                                                                    |       0.01 |         1 | 2019-02-18   |
| 1122 | [May I See The Aurora Borealis at protonmail.com](w/relay/68316B0071729BD5E8D959F922DE66EFBCD0D4D0)                                                                             |       0.01 |         1 | 2022-09-30   |
| 1123 | [68CB49DE](w/relay/68CB49DEF16326E60C4FC8D110E32331C97620B7)                                                                                                                    |       0.01 |         1 | 2023-03-05   |
| 1124 | [68EDAD6E](w/relay/68EDAD6EBF1E019F83BE7203AD303B2046668551)                                                                                                                    |       0.01 |         1 | 2023-06-21   |
| 1125 | [&lt;sinstranger@proton.me&gt;](w/relay/6B16F05645346F795DA66668E2F45DB04F240351)                                                                                               |       0.01 |         1 | 2024-11-20   |
| 1126 | [k8r &lt;tor@trollbox.org&gt;](w/relay/6C50CF56DFCC9B636964FEB7EE3B5051746E3278)                                                                                                |       0.01 |         1 | 2023-02-27   |
| 1127 | [6CB2C00C](w/relay/6CB2C00C8374D6968698A57940245249FC5B1769)                                                                                                                    |       0.01 |         1 | 2023-02-07   |
| 1128 | [vstor@foldr.org](w/relay/6CD04D67F68F65C3C872DA0C8C367B7DB09EC895)                                                                                                             |       0.01 |         1 | 2022-10-30   |
| 1129 | [gutter.duckdns.org](w/family/3004368a2c821cfa6724147f4871ab3cd7c97fb651ea532ac1c7da42ea0160f8)                                                                                 |       0.01 |         2 | 2024-02-23   |
| 1130 | [admin@mnlab.xyz](w/relay/6D5DA44B6648612D9CDFF8B69D640D86EFA38203)                                                                                                             |       0.01 |         1 | 2021-12-24   |
| 1131 | [6DB330B9](w/relay/6DB330B9B6D365687A7C5AF0FA3D3AABFB4132D5)                                                                                                                    |       0.01 |         1 | 2024-07-06   |
| 1132 | [6E402A41](w/relay/6E402A413395D0E8794817C3C50C2B1F7DBF1B0E)                                                                                                                    |       0.01 |         1 | 2024-01-22   |
| 1133 | [6F5B271B](w/relay/6F5B271B9DA53A3535E9EC9AF7686C63963F179B)                                                                                                                    |       0.01 |         1 | 2024-04-04   |
| 1134 | [alex@dumbfucks.se](w/relay/6F671D2E326AB58C0CE7C14BAE7FD8E9A48E5273)                                                                                                           |       0.01 |         1 | 2024-01-24   |
| 1135 | [6F708D57](w/relay/6F708D57E8D34B4BB1E1E2A6143D54BC0B8C8583)                                                                                                                    |       0.01 |         1 | 2022-12-09   |
| 1136 | [6F95E6C5](w/family/a6860100647f63d7b687f2f425b9c34bc5f3ca95a53b06a2aadc433a95d685b3)                                                                                           |       0.01 |         3 | 2022-03-14   |
| 1137 | [torrelaysaregreat@gmail.com xmr:84czj1u2Q4dJ7bzf41TyDFS1i1GPKX5DQGgqZFg85LFge7LL](w/relay/6FBA9F4455D25F096401DCEE6CB0D9A21F8DAABF)                                            |       0.01 |         1 | 2024-09-17   |
| 1138 | [7009E23E](w/relay/7009E23ED3BA23216E7C22F7AA20A84DE937B8ED)                                                                                                                    |       0.01 |         1 | 2024-07-26   |
| 1139 | [72270EB5](w/relay/72270EB58EDEBE727AA29E67417628DBCE889FAE)                                                                                                                    |       0.01 |         1 | 2019-02-18   |
| 1140 | [your@e-mail](w/relay/72409582B43695A8A75EE323D0402086292688A6)                                                                                                                 |       0.01 |         1 | 2024-09-02   |
| 1141 | [732ED61C](w/relay/732ED61C6DA8988B2B4C72F5EBE0E617C28D2A8E)                                                                                                                    |       0.01 |         1 | 2024-08-22   |
| 1142 | [sabotage.net](w/relay/74C0C2705DB1192C03F19F7CD1BB234843B1A81F)                                                                                                                |       0.01 |         1 | 2019-02-18   |
| 1143 | [Thiesi &lt;1thiesi23tor4@5gmail6.7com8&gt; strip all numbers from the email address](w/family/a5526163ef3efc9f58d58dc484cfb87385dcaad0b5ca4dfca43699a6eb1f9a21)                |       0.01 |         2 | 2022-01-03   |
| 1144 | [75C0B7A2](w/relay/75C0B7A2650BD317CE0FF4EE37DEA093AAD9019B)                                                                                                                    |       0.01 |         1 | 2024-08-24   |
| 1145 | [0x602D14C5 tor at rittersporn dot net](w/relay/76CF8195C75BA09D91261149C87E63B9C1316BFE)                                                                                       |       0.01 |         1 | 2024-04-21   |
| 1146 | [T0rNode555Nose koq@protonmail.com](w/relay/7712A1AC21D4B96E2773F4C8F97962E304EC7628)                                                                                           |       0.01 |         1 | 2021-09-05   |
| 1147 | [77DAF63E](w/relay/77DAF63E66E58FB73E2167316DD888D08E0A5695)                                                                                                                    |       0.01 |         1 | 2024-10-28   |
| 1148 | [x0f.org tor admin &lt;tor AT x0f DOT org&gt;](w/relay/77E4693C6364DF39BB117D546440BDD88A1C8608)                                                                                |       0.01 |         1 | 2024-11-03   |
| 1149 | [gorlock@gmx.net](w/relay/79C674E6C1AC90687CCCF644D24C17AC1E535A3C)                                                                                                             |       0.01 |         1 | 2019-02-18   |
| 1150 | [Rob Krupp &lt;tor-krupp AT frijan dot xyz&gt;](w/relay/7ABA6FF5A768C1E04DBD3BE08E41743818DD7067)                                                                               |       0.01 |         1 | 2024-01-22   |
| 1151 | [hwsystems.com](w/relay/7B1EC8B17C5E48D12C39159A595626D610F29377)                                                                                                               |       0.01 |         1 | 2023-01-28   |
| 1152 | [7BD537E6](w/relay/7BD537E65E2B10783B074ABE96F70E64FA301233)                                                                                                                    |       0.01 |         1 | 2024-12-14   |
| 1153 | [648mnd4yg@mozmail.com](w/relay/7BDCD0199688ABA5E11B3E0EB83F04375B3AE8E2)                                                                                                       |       0.01 |         1 | 2024-09-08   |
| 1154 | [7D06BF2C](w/relay/7D06BF2C460DFAFF2181677558C3BC644A139999)                                                                                                                    |       0.01 |         1 | 2024-01-29   |
| 1155 | [tacoenjoyer@tutamail.com](w/relay/7D51141CADFF88CA15E7DE1F5DE73DD234F2CF5A)                                                                                                    |       0.01 |         1 | 2024-08-22   |
| 1156 | [7E1E7281](w/relay/7E1E7281107AF03B4C2C8744C7F82F2924311316)                                                                                                                    |       0.01 |         1 | 2022-03-24   |
| 1157 | [I S &lt;tor AT t01 DOT s-ix DOT net&gt;](w/relay/7E317CFA44E7B6013DE4BC5F837C376A77179C72)                                                                                     |       0.01 |         1 | 2019-02-18   |
| 1158 | [86B346A6](w/relay/86B346A64F98B4EB6A6E370FC720BF236C81E877)                                                                                                                    |       0.01 |         1 | 2024-12-20   |
| 1159 | [ZenGarden369@gmail.com](w/relay/86B7A15398AE36CD050A4FCFA1D93D07C5E628FD)                                                                                                      |       0.01 |         1 | 2024-01-22   |
| 1160 | [tor-admin &lt;tor@mnesys.org&gt;](w/relay/86D924EDE1498B4E1DD08D2260F3E9FE454012E1)                                                                                            |       0.01 |         1 | 2019-02-18   |
| 1161 | [chinquapin single underscore no spaces kype aatt simplelogin com](w/relay/872108C52C52CC10217A351C883E991AEDF7C470)                                                            |       0.01 |         1 | 2020-09-30   |
| 1162 | [send complaints to Putin instead](w/relay/873914828C1161F02771F51AC7D97456317FC041)                                                                                            |       0.01 |         1 | 2024-03-01   |
| 1163 | [f89g65f21@national.shitposting.agency](w/relay/87B3557F3E792217E2BC4E9923EACA4AEC5BA9C3)                                                                                       |       0.01 |         1 | 2019-02-18   |
| 1164 | [0xFFFFFFFF rei toei](w/relay/88D2E6270D4AE200E2869F2FC3A1980A8E601779)                                                                                                         |       0.01 |         1 | 2024-12-12   |
| 1165 | [Leader &lt;leader AT free-hack dot com&gt;](w/relay/88D6A3C0FC28EAE6B9AD0BA1082223C03C1B32FA)                                                                                  |       0.01 |         1 | 2021-10-05   |
| 1166 | [olokerunningtor at protonmail dot com](w/relay/893B42BA688BE6FC7506537CEE4F36C951D3E117)                                                                                       |       0.01 |         1 | 2024-12-27   |
| 1167 | [DDiploma@ro.ru](w/relay/898348F76F6BBD2D81A90DDBA122B89CDAE11DDC)                                                                                                              |       0.01 |         1 | 2024-08-16   |
| 1168 | [mail@no-mail.gov](w/relay/9165301E95F49603BA705CAB9953074F091FECDA)                                                                                                            |       0.01 |         1 | 2023-03-31   |
| 1169 | [tor-exit@vrij-heid.nl](w/family/918760c893166353347a022bae10472e11c44b7d6d1ba844f7556c68df90f45b)                                                                              |       0.01 |         4 | 2024-01-22   |
| 1170 | [Matthias Schmidt &lt;tor@vegms.de&gt;](w/relay/8DB706C9B7ABA89F08FCE919DE18DAC63266EC8D)                                                                                       |       0.01 |         1 | 2024-01-21   |
| 1171 | [8EED46FF](w/family/5eab3ce14318f2ce3234cc1d12b21ec6743bd70b7fbd7d626d71c83ff72569bc)                                                                                           |       0.01 |         2 | 2024-03-19   |
| 1172 | [Email: &lt;cybertransfer@protonmail.com&gt;](w/relay/8F06AD26DFAAC4DC7FCBC7036EF4D9277186DFE7)                                                                                 |       0.01 |         1 | 2024-02-18   |
| 1173 | [Random Person &lt;tor AT conti dash usa dot net&gt;](w/family/339768477452d31456c3ddb50acbbd9abf09d5a7785019be1056cb214c6807b4)                                                |       0.01 |         2 | 2020-12-19   |
| 1174 | [ambroisia &lt;ambroisia@protonmail.com&gt;](w/relay/90668BB3F78B873E60556FCDC00AA80F9D4B8ACC)                                                                                  |       0.01 |         1 | 2024-03-04   |
| 1175 | [8A169EB2](w/relay/8A169EB231D1CCF2F8A9705F8F7C9808AAA32257)                                                                                                                    |       0.01 |         1 | 2021-09-15   |
| 1176 | [FreedomForFamily &lt;freedom for family at proton period me&gt;](w/family/1f75c8b5d3881f59c8aac6270960b3f94d2701c9214ac8fa3024d63a97282783)                                    |       0.01 |         2 | 2024-12-20   |
| 1177 | [peterschwegert at proton.me](w/relay/8D94C37BDE09A51D4D6BD0630F95426957B02B73)                                                                                                 |       0.01 |         1 | 2024-01-21   |
| 1178 | [9E41ED91](w/relay/9E41ED91F065EB9AB8AC8040678ACAEB551AC79F)                                                                                                                    |       0.01 |         1 | 2024-01-19   |
| 1179 | [retouch equity626@simplelogin.com](w/relay/9F74126EDD89BA77459823DFD25343D37EBA4F8D)                                                                                           |       0.01 |         1 | 2024-08-26   |
| 1180 | [Ns27bdd25e@ro.ru](w/relay/9FFE57C231BF3D7CCB15F79FFE1B908EC3700404)                                                                                                            |       0.01 |         1 | 2024-08-29   |
| 1181 | [slm.t33@proton.me](w/relay/A12CD457586B7CA552D75EA80521459401924D79)                                                                                                           |       0.01 |         1 | 2024-12-25   |
| 1182 | [A151005A](w/relay/A151005A71B878158266576DCAE6D82EE5CBCDBC)                                                                                                                    |       0.01 |         1 | 2022-11-09   |
| 1183 | [dusty dustin.tello@privatemail.com](w/relay/A1DD3EF590FBF05EC518E4BD13B7412E29D87934)                                                                                          |       0.01 |         1 | 2024-07-22   |
| 1184 | [tim t.edwards@proton.me](w/relay/A23771EF48EF0F2B992D3A6D95DC1C8449AF51C0)                                                                                                     |       0.01 |         1 | 2024-08-25   |
| 1185 | [A33A5C70](w/relay/A33A5C70CFA86996B1AE7D32B93A1942AAEE6835)                                                                                                                    |       0.01 |         1 | 2024-09-27   |
| 1186 | [torserver at sagorski dot org](w/relay/A4771CB90024F1870D622960519945A3E49B40FE)                                                                                               |       0.01 |         1 | 2024-02-20   |
| 1187 | [Relay Admin &lt;privacheese AT proton.me&gt;](w/relay/A4DB56034A3FEABAFB2CF516BE5D1D4C1A1D6AE8)                                                                                |       0.01 |         1 | 2024-09-06   |
| 1188 | [0xFFFFFFFF Random Person &lt;nobody AT example dot com&gt;](w/relay/9397512E8CA6219F0AB04466453289F622B35DE0)                                                                  |       0.01 |         1 | 2024-05-20   |
| 1189 | [metor at taledo dot games tor-relay.co](w/relay/94F6A4893A80149AEEEB7509BEFCDBA1AE4D5898)                                                                                      |       0.01 |         1 | 2022-03-04   |
| 1190 | [950E02DB](w/family/841093ed7e7609eae2462f172f8ce9627b940b05944c04633e9c397b02094d22)                                                                                           |       0.01 |         2 | 2022-08-11   |
| 1191 | [Xidorn Quan &lt;tor-relay at upsuper org&gt;](w/relay/96070698714DC07AE2B377864625B7EF64E33BF5)                                                                                |       0.01 |         1 | 2019-02-28   |
| 1192 | [96BB4413](w/relay/96BB44138D47BEBCFF928DD2BA9B914452828B18)                                                                                                                    |       0.01 |         1 | 2024-08-07   |
| 1193 | [arma56ko9 /at/ proton /./ me](w/relay/9718C0631100FB537BF136CE4720B8E69EAAB3C1)                                                                                                |       0.01 |         1 | 2024-01-21   |
| 1194 | [97346BB5](w/relay/97346BB50643390275ADE238F9E335728089AF40)                                                                                                                    |       0.01 |         1 | 2024-01-22   |
| 1195 | [CapitainZR@protonmail.com](w/relay/974449742311E39E50CE00BDFF6E3A0B7711AC34)                                                                                                   |       0.01 |         1 | 2022-03-14   |
| 1196 | [ilovetor14@proton.me](w/relay/977AC3C9B1C605CB4703026DE043FAFB9FA6CA06)                                                                                                        |       0.01 |         1 | 2025-01-07   |
| 1197 | [torkowo3@testowo.pl](w/relay/97B326AB73BD5B484F89E976EED9FD9B807CD39F)                                                                                                         |       0.01 |         1 | 2024-11-25   |
| 1198 | [mb-server &lt;tor AT mb-server dot com&gt;](w/relay/982FF2DAC80C1454E826B43F8FF003CF2CDC1CD7)                                                                                  |       0.01 |         1 | 2024-01-21   |
| 1199 | [Random Person nobody@tor.org](w/relay/98782EBE923923866118A5C2C44BC4C1D15E5805)                                                                                                |       0.01 |         1 | 2024-12-29   |
| 1200 | [arvanode.net](w/relay/98EF3981F766F9F87D7C399E6DD0FFC3867711AF)                                                                                                                |       0.01 |         1 | 2024-01-30   |
| 1201 | [chimagamer01@gmail.com](w/family/b75f67e335a55654afc0a8ad8c06e7032867778d72bccef542eda5d5ec574830)                                                                             |       0.01 |         2 | 2024-12-01   |
| 1202 | [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/relay/9AAB8E74CA1D88F1649B33B8C3CD58F3BF522663)                                                        |       0.01 |         1 | 2024-03-04   |
| 1203 | [9BA1289C](w/relay/9BA1289CDCFD907B8D40A8AB12F36BE620DD4085)                                                                                                                    |       0.01 |         1 | 2019-02-18   |
| 1204 | [EMTY &lt;emty.pro AT proton&gt;](w/relay/9D7B2AE5779BA88FD25D828E2CFCBEAFF5C37951)                                                                                             |       0.01 |         1 | 2024-09-20   |
| 1205 | [duelron1001@gmail.com](w/relay/A515B0CD66329BE3755977D3505E2869530757AC)                                                                                                       |       0.01 |         1 | 2024-12-09   |
| 1206 | [davis@terry.com](w/relay/A69EB0900E027DE841A8F1494625739DF229EF18)                                                                                                             |       0.01 |         1 | 2024-12-29   |
| 1207 | [trinity.fr.eu.org](w/relay/A8503903F97FF27F5D1C3CA38817329F581925E6)                                                                                                           |       0.01 |         1 | 2020-06-12   |
| 1208 | [antiglowiemachine9000@proton.me](w/relay/AA80B523EB781CF470CA5A91427200620FFD4281)                                                                                             |       0.01 |         1 | 2024-02-18   |
| 1209 | [4096R/1567BC0F Jesus Cea &lt;jcea@jcea.es&gt;](w/relay/AAFF4A997543DB0D881F4F11638485B7D471FECE)                                                                               |       0.01 |         1 | 2020-01-24   |
| 1210 | [0x641814BB9C9F44AE tor@nicolasmueller.eu](w/relay/AAFFA68AB61238F9044B6ECBA62E25264113EB88)                                                                                    |       0.01 |         1 | 2020-04-23   |
| 1211 | [AB62ED1A](w/relay/AB62ED1A87A54F4193FCEEC587CB991399FADFBD)                                                                                                                    |       0.01 |         1 | 2023-03-03   |
| 1212 | [0xFFFFFFFF Playstar Network &lt;info AT playstar DOT se&gt;](w/relay/ABC5A7A6D5C609512F5D7CD2B490CE7366F00D60)                                                                 |       0.01 |         1 | 2022-02-22   |
| 1213 | [Random Person nobody@tor.org](w/relay/D97F6C950EF607B9D84E5CC040C771A692188194)                                                                                                |       0.01 |         1 | 2024-02-05   |
| 1214 | [Admin &lt;causes.beretta0c@icloud.com&gt;](w/relay/DA3FD24EDEA501C7133307CA73E991AC5B1D76BF)                                                                                   |       0.01 |         1 | 2024-06-16   |
| 1215 | [Mika Schneider &lt;tor AT mikaconor-schneider dot de&gt;](w/relay/DA506D11F5371B6474EE9AD1C0EDA8189D4702FD)                                                                    |       0.01 |         1 | 2023-03-25   |
| 1216 | [DAABB04E](w/relay/DAABB04E4E3336B336B2523D5448DA8B0A43BD7A)                                                                                                                    |       0.01 |         1 | 2024-01-22   |
| 1217 | [DC8E26DB](w/relay/DC8E26DB162AFE036C13EBEC917CDFC97A297A57)                                                                                                                    |       0.01 |         1 | 2023-03-23   |
| 1218 | [Decio &lt;decio@decio.eu&gt;](w/relay/E459E02374D0385D2E2515CBBE707EA208966BCF)                                                                                                |       0.01 |         1 | 2019-02-18   |
| 1219 | [E4C12BFB](w/relay/E4C12BFB3AC2E6F16E4F1F34AA807D11D924E905)                                                                                                                    |       0.01 |         1 | 2022-07-12   |
| 1220 | [John Doe &lt;webmaster aT krypta d0t net&gt;](w/relay/E612306325AE03F0C82C290ACAFB8C724A8B5B91)                                                                                |       0.01 |         1 | 2021-02-07   |
| 1221 | [phantomwave at protonmail dot com](w/relay/E7A3DA42BCA86430F089DD32C3FDA33534E76F19)                                                                                           |       0.01 |         1 | 2021-06-27   |
| 1222 | [E7F8F3DC](w/relay/E7F8F3DC81E74961F7BE0BA5A540DFF75B4F9220)                                                                                                                    |       0.01 |         1 | 2024-01-22   |
| 1223 | [&lt;tor@softwareloft.de&gt;](w/relay/B7526DA046010CF086692745E8BD0528B039C3F8)                                                                                                 |       0.01 |         1 | 2021-08-26   |
| 1224 | [noc@photonspark.net](w/relay/B9F1B18DEB2B6ABBF82521B6F60A27869642C6B1)                                                                                                         |       0.01 |         1 | 2025-01-07   |
| 1225 | [B2FC8F2D](w/relay/B2FC8F2D98DB351599166C4D0E20862730C3426A)                                                                                                                    |       0.01 |         1 | 2024-08-24   |
| 1226 | [B34D07BF](w/relay/B34D07BFCBBF179CD6D0F440293A17778893EB76)                                                                                                                    |       0.01 |         1 | 2020-12-09   |
| 1227 | [your@email.com](w/relay/B45A9DDE16C7B8234C68AE02F4BFDB18CAB9C029)                                                                                                              |       0.01 |         1 | 2024-06-30   |
| 1228 | [your@e-mail](w/relay/B4F1193BECADD10F7EC08DB02C7672FB717987A4)                                                                                                                 |       0.01 |         1 | 2024-10-11   |
| 1229 | [torproject.qj5i9@slmail.me](w/relay/B509091C13925AFEA40606681A87FB50986577DA)                                                                                                  |       0.01 |         1 | 2024-03-01   |
| 1230 | [My Tor Node &lt;mytornode@xn--y9a.net&gt;](w/relay/B54BC0EB7CF821FE2B9A6D7116BEE75217FCEE3C)                                                                                   |       0.01 |         1 | 2022-05-03   |
| 1231 | [B5E973C4](w/relay/B5E973C488AE184E4B01665A6601466D3BEF01AF)                                                                                                                    |       0.01 |         1 | 2024-07-17   |
| 1232 | [B666A4BE](w/relay/B666A4BE4F45D39FA1FD4DD174FC305A46466C4F)                                                                                                                    |       0.01 |         1 | 2025-01-14   |
| 1233 | [AC48C1D7](w/relay/AC48C1D7FF6F927145F7E4320CAFB57EA5C27C3E)                                                                                                                    |       0.01 |         1 | 2024-01-22   |
| 1234 | [Ali Gatorr &lt;Ali DOT Gatorr AT free DOT fr&gt;](w/relay/ACBF3D504CFF3D74D1991AFDF6AC070606232B10)                                                                            |       0.01 |         1 | 2020-04-23   |
| 1235 | [AFEAF3A9](w/relay/AFEAF3A9E0DB1D837BE8FF1983BA0C65A3E71D73)                                                                                                                    |       0.01 |         1 | 2022-07-12   |
| 1236 | [B09695E3](w/relay/B09695E3B4113944EC9C8C595DC173440FEBE143)                                                                                                                    |       0.01 |         1 | 2024-12-14   |
| 1237 | [tor-exit at ewigschlau dot de tor-relay.co](w/relay/B0DB2F173F0DB364BABF7A465D796B3C048F1F33)                                                                                  |       0.01 |         1 | 2020-07-02   |
| 1238 | [B0F17A56](w/relay/B0F17A56FA8686CCB33D3F302FC40F06F463B4AE)                                                                                                                    |       0.01 |         1 | 2019-02-18   |
| 1239 | [platayoro proton me](w/family/4f42ae1c470770182ea1f1d0de7891f59d285c8455b52d9d9327cf38530c74ff)                                                                                |       0.01 |         3 | 2023-02-25   |
| 1240 | [BAD367BA](w/relay/BAD367BA226F2BA8A616F53C2DBDC2471B50DB70)                                                                                                                    |       0.01 |         1 | 2025-01-03   |
| 1241 | [tor@eti-net.de](w/relay/BB826FDA423C70EB140E49F19C0E5AA324262135)                                                                                                              |       0.01 |         1 | 2025-01-10   |
| 1242 | [t0rn0de01@pm.me](w/relay/BD30E1532EE061CA7825FC929D765FFB55C8B889)                                                                                                             |       0.01 |         1 | 2024-11-05   |
| 1243 | [public-tor at foxxiepants.net](w/relay/BE76FBB5F8D1071DBFED77C543150C1C9D8A21C2)                                                                                               |       0.01 |         1 | 2022-01-03   |
| 1244 | [Dan &lt; xiaoqic at cs dot princeton dot edu &gt;](w/relay/BF8E1F5E1907A28DD90ABA40DF364EE092984327)                                                                           |       0.01 |         1 | 2024-11-08   |
| 1245 | [C0C8864A](w/family/62a663dc3a33ec0162e15459cdabd9e1799a9beeceec651a92817564606ff045)                                                                                           |       0.01 |         2 | 2022-05-23   |
| 1246 | [A8F9764C rubefeli &lt;&quot;relay nickname&quot; AT pm.me&gt;](w/relay/C0E4C6914B7C008D550E739D80BF2C3F51C909B2)                                                               |       0.01 |         1 | 2022-12-29   |
| 1247 | [testing2@testowo.pl](w/relay/C0ED540644C7CBE96907518D48C14E898F42BCBC)                                                                                                         |       0.01 |         1 | 2024-01-22   |
| 1248 | [tor relay.7razv@aleeas.com](w/relay/C29621EBA9B52A1C26FA2059D45FB925EF4A6F18)                                                                                                  |       0.01 |         1 | 2024-07-21   |
| 1249 | [tor-relay@vaw-valentin.de](w/relay/C2F3631B1386FD7BA5227B28783315CD52EB1526)                                                                                                   |       0.01 |         1 | 2024-10-12   |
| 1250 | [C3389AB2](w/relay/C3389AB2CDC731B5D134B9E9415A024F28E660EC)                                                                                                                    |       0.01 |         1 | 2023-05-12   |
| 1251 | [C37F87C0](w/relay/C37F87C0125E26E6ACF54366FA2198209E856ABE)                                                                                                                    |       0.01 |         1 | 2019-02-18   |
| 1252 | [C42C51EF](w/relay/C42C51EFC275C45EF94CF810E02BA737FD99F7FA)                                                                                                                    |       0.01 |         1 | 2023-05-16   |
| 1253 | [plasmatrap.com](w/relay/C43827BB94B59CE61987310F80A035C5AB9DF002)                                                                                                              |       0.01 |         1 | 2020-09-10   |
| 1254 | [C43CED2D](w/relay/C43CED2D1C518D968CA2BE09CAB39971EF8EB033)                                                                                                                    |       0.01 |         1 | 2024-04-20   |
| 1255 | [C533D888](w/relay/C533D888733A24089959139BD022492173DBE10B)                                                                                                                    |       0.01 |         1 | 2024-08-23   |
| 1256 | [www.habedieeh.re](w/relay/C683052FD8BACF5230103F794E9694BEED1ED0B4)                                                                                                            |       0.01 |         1 | 2022-12-29   |
| 1257 | [C89976F4](w/relay/C89976F41351B3F0CDA25C385B41ED26A276579A)                                                                                                                    |       0.01 |         1 | 2023-03-09   |
| 1258 | [CA037B9E](w/relay/CA037B9E5174A5DCF1B3E4DB06B22E8DA76A1FE0)                                                                                                                    |       0.01 |         1 | 2024-10-04   |
| 1259 | [CB44E8ED](w/relay/CB44E8ED1FAB648275C39756EB1758060C43BCA4)                                                                                                                    |       0.01 |         1 | 2024-01-22   |
| 1260 | [tor-operator@xor.sc](w/relay/CBCC85F335E20705F791CFC8685951C90E24134D)                                                                                                         |       0.01 |         1 | 2022-08-21   |
| 1261 | [rwood@duck.com](w/relay/CC128E924185348CB6E254C738F9201E7F7F34CA)                                                                                                              |       0.01 |         1 | 2024-01-22   |
| 1262 | [cleshawnlamontegue@gmail.com](w/relay/CD478DBDF96F456C386E2BE52670E76A815EDBF3)                                                                                                |       0.01 |         1 | 2024-07-13   |
| 1263 | [CD5CF125](w/relay/CD5CF125FED4BE5DA5F259F75AF3D4DD182C54D0)                                                                                                                    |       0.01 |         1 | 2019-06-28   |
| 1264 | [abuse@srstubes.com](w/relay/CE1587A234A42EA0A34DE3043CEE41306BF098EB)                                                                                                          |       0.01 |         1 | 2025-01-06   |
| 1265 | [D04EAF44](w/relay/D04EAF4478F265E9DC0C7B49726B90F58914286E)                                                                                                                    |       0.01 |         1 | 2022-08-11   |
| 1266 | [jjaytehjetplane@gmail.com](w/relay/D2F4DAC5918BB082A5CFAC5275B29FAC9B399B2B)                                                                                                   |       0.01 |         1 | 2019-02-18   |
| 1267 | [Aramis@ro.ru](w/relay/D3A55B115FC350DF5A26FFB2C098EB0B30456CAE)                                                                                                                |       0.01 |         1 | 2024-07-29   |
| 1268 | [D5597B37](w/relay/D5597B378D8DCAFFBFA8AABD433361D82BB74D28)                                                                                                                    |       0.01 |         1 | 2022-12-29   |
| 1269 | [D5A2B3AE](w/relay/D5A2B3AE1E8047017A0BBC7209FD624DB84D47CE)                                                                                                                    |       0.01 |         1 | 2019-04-29   |
| 1270 | [stareintodeathandbestill.com](w/family/e010ca788a7e48576c391ae17299259e4e14c728e9512cd44f2e9c6a4c18c530)                                                                       |       0.01 |         2 | 2024-08-24   |
| 1271 | [alien@soylentgreen.eatzz](w/relay/D643181AD9864D8C0C246CFA6C00E07375510A24)                                                                                                    |       0.01 |         1 | 2024-01-22   |
| 1272 | [George Harold &lt;tor-harold AT frijan dot xyz&gt;](w/relay/D6EBF64A4335F44F975ECA23C6D89A795B78DAFF)                                                                          |       0.01 |         1 | 2024-01-22   |
| 1273 | [D6EDD332](w/relay/D6EDD332AC04B1D1E8FEFB3F32F4C050CDB3A95B)                                                                                                                    |       0.01 |         1 | 2022-04-13   |
| 1274 | [admin@localhost](w/relay/D708AAEEAC697A408B991F6BE40F1D5A48D61FA9)                                                                                                             |       0.01 |         1 | 2024-08-27   |
| 1275 | [tor-relay38493016504204532@proton.me](w/relay/D7E1846EBE9B4F2E3359B3768035C9184E8F470D)                                                                                        |       0.01 |         1 | 2024-12-27   |
| 1276 | [D8476A2B](w/relay/D8476A2B13EE8D37F44EDACEB9E188DAF04DB27E)                                                                                                                    |       0.01 |         1 | 2024-11-22   |
| 1277 | [D8514224](w/relay/D8514224881C60572E06351F2BD650BA14ACA75C)                                                                                                                    |       0.01 |         1 | 2024-04-16   |
| 1278 | [juanan cientifico@yahoo.es](w/relay/D87651C9871DF21878BA6FB1F0F54CA069E7C46B)                                                                                                  |       0.01 |         1 | 2024-12-16   |
| 1279 | [D93A701C](w/relay/D93A701CE7F75F882F7A12422BE13F317912101E)                                                                                                                    |       0.01 |         1 | 2024-01-22   |
| 1280 | [Tor Operator &lt;3a2f709c-777e-4c9d-9039-1661cc92e083@anonaddy.me&gt;](w/relay/EDB29CA8E8D01B019FEE9BD075BF0662926D87DC)                                                       |       0.01 |         1 | 2025-01-05   |
| 1281 | [KORVERIK korv@anderstorpsfestivalen.se](w/relay/EE315DBD29B1384C47071C9B6A72CD6481CBA086)                                                                                      |       0.01 |         1 | 2022-01-13   |
| 1282 | [Arbel Arad &lt;arbel@spacetime.technology&gt;](w/relay/EE631F9749C53DC2B5E727B07EF39962A1BE3C54)                                                                               |       0.01 |         1 | 2024-03-09   |
| 1283 | [&lt;samthatmail AT tutanota com &gt;](w/relay/EFF42E8EC2F07C5B288B3701C336A2F2512E41F0)                                                                                        |       0.01 |         1 | 2024-09-27   |
| 1284 | [JennyBreder2003@protonmail.com](w/relay/F00C8B7589FEE52BE84387CDB422C1F1386979C0)                                                                                              |       0.01 |         1 | 2019-10-26   |
| 1285 | [F05114B2](w/relay/F05114B22E66D08581B5936C646F62649485D879)                                                                                                                    |       0.01 |         1 | 2023-04-02   |
| 1286 | [DDCB061A](w/relay/DDCB061A3656BF8C21A8F643D6F8527DB58425F5)                                                                                                                    |       0.01 |         1 | 2024-06-26   |
| 1287 | [DE35BB3C](w/relay/DE35BB3C54CC93105A2701984C54B86B8EB08CF8)                                                                                                                    |       0.01 |         1 | 2023-03-11   |
| 1288 | [manasiwibi.com](w/relay/DE61F3149B93298D8723722CEE6BAC99E547858D)                                                                                                              |       0.01 |         1 | 2021-10-15   |
| 1289 | [Tor-Team &lt;tor at xcv d0t vc&gt;](w/relay/DE74E8C4F3CF0FBBCB7E761BB3072050D1D4DD88)                                                                                          |       0.01 |         1 | 2019-02-28   |
| 1290 | [E08166EE](w/relay/E08166EE25A85FD5C9433D133B39FC5EBDE16D98)                                                                                                                    |       0.01 |         1 | 2022-11-29   |
| 1291 | [tor contact &lt;tor0218@linuxw.info&gt;](w/relay/E11FC7C83F417808A4CDD84A5ABFC112844C477A)                                                                                     |       0.01 |         1 | 2020-06-22   |
| 1292 | [torrelay at vonkuenheim dot de](w/relay/E14B30A83FF80C576B2EC0F2C8A5F29D41B8DC8E)                                                                                              |       0.01 |         1 | 2019-03-20   |
| 1293 | [skynova7421@proton.me](w/relay/E1916EBFB69AB4D432EAF1D2FCB9F413704D3631)                                                                                                       |       0.01 |         1 | 2025-01-15   |
| 1294 | [aestetium@protonmail.com](w/relay/E1B8239725A8886B8662B7047DEDD9C6B0D8AE45)                                                                                                    |       0.01 |         1 | 2023-04-06   |
| 1295 | [terry@davis.com](w/relay/E1FBFC6C0A8D728BE3DFE69B756F84ABA5671C19)                                                                                                             |       0.01 |         1 | 2024-12-29   |
| 1296 | [mapexcavator@proton.me](w/relay/E2E1AAFB65DB0B82F868071FF173DDA28407FDDB)                                                                                                      |       0.01 |         1 | 2024-01-29   |
| 1297 | [Szabo Alexandru-Mihai &lt;tor AT cyberdojotm DOT ro&gt;](w/relay/EA66B98F170DE54A231B33BBFE13EB20983F6DE4)                                                                     |       0.01 |         1 | 2024-02-27   |
| 1298 | [relay@placeq.com](w/relay/EABB390323F80D4457BAA5CEEE511455700E929D)                                                                                                            |       0.01 |         1 | 2019-02-18   |
| 1299 | [lqwer@isapunk.com](w/relay/EBB0880F0FE3E37904D7DE82E296C211BCF24806)                                                                                                           |       0.01 |         1 | 2024-01-31   |
| 1300 | [g30g43br4 at protonmail.com](w/relay/ECD07A8B5FF36C1A6A736822F42B38D772A98190)                                                                                                 |       0.01 |         1 | 2024-02-17   |
| 1301 | [F318BE2B](w/relay/F318BE2B5B5BB72F3140FE37A337FC8F233C977C)                                                                                                                    |       0.01 |         1 | 2025-01-10   |
| 1302 | [tortech123456 &lt;tortech123456 at protonmail com&gt;](w/relay/F3B02517DA093DB92924E951AB77204563D01356)                                                                       |       0.01 |         1 | 2022-12-19   |
| 1303 | [Frank Exchange of Views &lt;f.e.o.v AT pm dot me&gt;](w/relay/F3F3F4900B87CF4A6B4A7F9402502FC457B7B1FC)                                                                        |       0.01 |         1 | 2019-07-18   |
| 1304 | [F4650430](w/relay/F4650430F42F198A101E9FC884338D4C62EAC457)                                                                                                                    |       0.01 |         1 | 2024-11-20   |
| 1305 | [Tor Contact Radboud CS &lt;tor-relay@cs.ru.nl&gt;](w/relay/F4F18711CD684B6BBE8DFDF5F6F1043D43BDD7E3)                                                                           |       0.01 |         1 | 2024-02-12   |
| 1306 | [your@e-mail](w/relay/F539EAE5B51EE745470C3B40522E39A5D94DF72D)                                                                                                                 |       0.01 |         1 | 2024-01-21   |
| 1307 | [abuse@srstubes.com](w/relay/F7CC37F98E25E75EBC97BFD4FA7955053A0370BC)                                                                                                          |       0.01 |         1 | 2025-01-06   |
| 1308 | [James R &lt;jimr1603 AT google dot com&gt;](w/relay/F924F19F3C9DF6F0450F5D230E2F5D2FC1AB81A4)                                                                                  |       0.01 |         1 | 2024-11-11   |
| 1309 | [email:torproxy protonmail.com proof:uri-rsa abuse:torproxy protonmail.com dnsl](w/relay/F98CE40031795D3704365019EA9F8AC56AE2994B)                                              |       0.01 |         1 | 2019-02-18   |
| 1310 | [tor@53c70r.de](w/relay/FA561E534DDDE63830FA0B0A484235ED23BB27A3)                                                                                                               |       0.01 |         1 | 2020-12-19   |
| 1311 | [FA7136FD](w/relay/FA7136FD4F8A727810A22ED2096AF60F872C2F41)                                                                                                                    |       0.01 |         1 | 2024-01-21   |
| 1312 | [pdncogrhslkdnqpd at mail2tor dot com](w/relay/FC4D03403ECD90463198B9F2F81E0B37ED7AFE1D)                                                                                        |       0.01 |         1 | 2020-06-02   |
| 1313 | [domain:proton.me,user:birchbark-relay](w/relay/FC55A83470EB1B7BC4B7BDA06285B8B5430C428C)                                                                                       |       0.01 |         1 | 2023-03-05   |
| 1314 | [VanillaIceCream Admin &lt;VanillaIceCream.Admin@format.ovh&gt;](w/relay/FC705CFB662F770CE359E3DFBCE651DEC03C3396)                                                              |       0.01 |         1 | 2024-10-25   |
| 1315 | [llantfont with g-mail](w/relay/FF3D4B174CE81927E3424C665F761CB6A3C54FBD)                                                                                                       |       0.01 |         1 | 2024-11-06   |
| 1316 | [4b02f3f8327468277442dd4765d8494b5f453a64 Admin &lt;admin AT arviceblot dot com&gt;](w/relay/FF929A01FB58B8988E9AD7A75DE8C414486A82EB)                                          |       0.01 |         1 | 2021-06-27   |
| 1317 | [fakeblackhatter @ proton.me](w/family/afdb5f928914db20defcd7e9e921b4d434b053a45a37e951ea4c37b51ed4a21c)                                                                        |       0    |         2 | 2024-01-12   |
| 1318 | [Effi.org &lt;tor AT effi dot org&gt;](w/family/725a367c290d2590645ff637b94e3eed17544f6a2c8631abdd98e71f7ecb385e)                                                               |       0    |         2 | 2018-11-13   |
| 1319 | [00D2CE3C](w/relay/00D2CE3C2153EA09786F2105F26B138CF759424F)                                                                                                                    |       0    |         1 | 2022-05-27   |
| 1320 | [00EB7CA4](w/relay/00EB7CA42614067FEA9DC54271CEB672ABDAE963)                                                                                                                    |       0    |         1 | 2024-06-26   |
| 1321 | [Roman &lt;sysop DOT homelab AT google DOT com&gt;](w/relay/010AEC93A907E3D7BF4ED4AF63397B05BD9C9E9A)                                                                           |       0    |         1 | 2025-01-04   |
| 1322 | [contact@cypher.re](w/relay/010D853EA9DC7BEAA3BF9B1910D0AF6439C43CAC)                                                                                                           |       0    |         1 | 2024-11-17   |
| 1323 | [alicesmithactrice@protom.me](w/family/9715f47f1e71e4e1f15010a8d58bb909038899020f270c2911e32b29efabd3ab)                                                                        |       0    |         2 | 2024-12-24   |
| 1324 | [unnerve0909@proton.me](w/relay/01870F782E458F124563328DB57EB82F4475BDE0)                                                                                                       |       0    |         1 | 2023-12-14   |
| 1325 | [01C1BC69](w/relay/01C1BC69D2B1EA4B97D06DDE5A1896AE673D44A2)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 1326 | [01D28453](w/relay/01D28453A4906AB5CC97B974B56413B75922B894)                                                                                                                    |       0    |         1 | 2024-04-03   |
| 1327 | [024A48D0](w/relay/024A48D0EAFF4761DAA976248343C44F8223F4CC)                                                                                                                    |       0    |         1 | 2023-12-19   |
| 1328 | [0258BDAE](w/relay/0258BDAE9B351714B0BCC0DABE1D798D662EBA88)                                                                                                                    |       0    |         1 | 2021-05-24   |
| 1329 | [02654B8B](w/relay/02654B8B9803775860CDF2C7F7109FF68A1349AA)                                                                                                                    |       0    |         1 | 2022-02-28   |
| 1330 | [1free as a bird1@proton.me](w/relay/08B1721C699C3EFA050F492A7A5F5E2EB4B18428)                                                                                                  |       0    |         1 | 2024-11-12   |
| 1331 | [tor.tulip943@slmail.me](w/relay/092E5E97AC7FE3FAA02B408EC529DAF90AD23E0B)                                                                                                      |       0    |         1 | 2023-12-31   |
| 1332 | [&lt;DONTPANIC&gt; &lt;gmx.co.uk&gt;](w/relay/0932F9009DCF32EC60FD52F975318D3F6E8E59F9)                                                                                         |       0    |         1 | 2023-12-02   |
| 1333 | [yosu AT riseup.net](w/relay/049852A10805835E9AB2C551D6C438BE6DE8B24C)                                                                                                          |       0    |         1 | 2018-06-18   |
| 1334 | [04DAB3B5](w/relay/04DAB3B5205C0EE19A702EBAFBBBC7AD21C24805)                                                                                                                    |       0    |         1 | 2022-10-26   |
| 1335 | [04DBE60E](w/relay/04DBE60EFE9D078062AC60BB3D9CC019CADA235C)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 1336 | [Objective Meninsky &lt;bowrpgvirzravafxl@areqolangher.qr&gt;](w/relay/056A5A961BBAECC9264FDF35D691668F46C04187)                                                                |       0    |         1 | 2024-11-03   |
| 1337 | [expertje88@hotmail.com](w/family/698c1d56c5d313de1418fd4b91a91f172533662fa18e4a7ffa27734da6009c3c)                                                                             |       0    |         2 | 2024-05-22   |
| 1338 | [075284FB](w/family/017aacd6bf0eda9bb41b30f7c305b59e3241695db4ea74a20283200dc1e75cff)                                                                                           |       0    |         5 | 2024-12-06   |
| 1339 | [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/family/825a40e0353edc3a905ac274e0016604e6dc65e86e6b5f33c460c2bd0f4d7e3e)                    |       0    |         7 | 2024-12-16   |
| 1340 | [07BFC873](w/relay/07BFC87346911415F8BF83B6429A3DE5163F2B28)                                                                                                                    |       0    |         1 | 2024-03-05   |
| 1341 | [tersest 09 realms@icloud.com](w/relay/07C17931AE2E17F95681FA2A91C7F7CDB068BF48)                                                                                                |       0    |         1 | 2023-11-02   |
| 1342 | [0xABCDEF Jeff Backly](w/relay/0824D7C7FB117D5C6AC01581FD798E670C37C804)                                                                                                        |       0    |         1 | 2015-02-23   |
| 1343 | [pastly](w/relay/085527CBD6485FD475AC983FA8683A2D9028BAA8)                                                                                                                      |       0    |         1 | 2020-07-07   |
| 1344 | [Resistance Change Freedom](w/family/1ce19397b939014bc9e4e622565f1f42b1e45413f84f143ddb4199ecd9ff2e75)                                                                          |       0    |         3 | 2020-05-13   |
| 1345 | [hnlexit@bsideshawaii.org](w/family/2e38d9c0bc47fc019d86071bf72fcb809a5df81a1165dc48981ea9fd6770170c)                                                                           |       0    |         8 | 2024-05-13   |
| 1346 | [relaytor at yahoo dot com](w/family/a162faf1b3ad9f3b38d1d1f4802e20504267c9a2e5f38ac7ea70ea237dcb6505)                                                                          |       0    |        11 | 2021-11-04   |
| 1347 | [Nomad, Digital &lt;digitalnomad34@protonmail.com&gt;](w/relay/03216E9498B9688056F68E6F590FC206E9F40771)                                                                        |       0    |         1 | 2025-01-02   |
| 1348 | [quetzalcoatl-relays.org](w/family/93395e779985d1f01b989ce655dd6ff615ceadf02bb0bb81006aaa9a167ed0d0)                                                                            |       0    |         8 | 2023-07-03   |
| 1349 | [timetoreload@protonmail.com xmr:849QhLyrsd9ZVEin7WQMveij5adgcGreo3eSth1Zzq1V5sAu](w/relay/02A8CCB1FB70984226231283596DA734A80E3F6F)                                            |       0    |         1 | 2022-04-27   |
| 1350 | [03C79440](w/relay/03C794401A92F2F033AD5DFB2FC005D445910654)                                                                                                                    |       0    |         1 | 2022-01-11   |
| 1351 | [03CB58CC](w/relay/03CB58CC506894147FFABAF43F6A84C52BDFCECA)                                                                                                                    |       0    |         1 | 2023-03-17   |
| 1352 | [tor at localhost dot lu](w/relay/05FFA39D71DA116F7669EA4EE53A0BAEA315BA7F)                                                                                                     |       0    |         1 | 2015-06-12   |
| 1353 | [06392BF7](w/relay/06392BF7C62C90F90512B120030A17A8B957EB2C)                                                                                                                    |       0    |         1 | 2024-10-06   |
| 1354 | [0645A80A](w/relay/0645A80A17909D33FAFB5548E8A10F80AB38E65E)                                                                                                                    |       0    |         1 | 2022-05-06   |
| 1355 | [065AEEDF](w/relay/065AEEDF470172CA296D388B5D33D26035D320D7)                                                                                                                    |       0    |         1 | 2024-06-19   |
| 1356 | [06FA520E](w/relay/06FA520E5E79D7587AFC956918FFB5D6F6C1CD2E)                                                                                                                    |       0    |         1 | 2022-12-06   |
| 1357 | [04102613](w/relay/04102613D8F998E956A7868D2DE5A532EE2473EA)                                                                                                                    |       0    |         1 | 2023-01-27   |
| 1358 | [The Dude](w/family/a0b6d2d592ae1885f61d9023bdf4f2e38ac9c2a57890f5a2cf226dc6dccd0311)                                                                                           |       0    |         2 | 2019-11-22   |
| 1359 | [10F8A0A6](w/relay/10F8A0A61A80ABDCD8BFBE9053F8FB2E0C507F71)                                                                                                                    |       0    |         1 | 2024-02-03   |
| 1360 | [tor@divided-by-zero.eu](w/relay/1119A89E729DB65839FB232A1E0F8669B0AE84DF)                                                                                                      |       0    |         1 | 2017-09-18   |
| 1361 | [&lt;nobody AT example dot com&gt;](w/relay/1137AB1F84EC2D52DFB1915717F14FF1A10EB392)                                                                                           |       0    |         1 | 2018-11-22   |
| 1362 | [cheese@cheese.com](w/relay/11400CBFE482010934E55581EC4085CF36945096)                                                                                                           |       0    |         1 | 2024-03-10   |
| 1363 | [crackofdawn &lt;AT&gt; posteo DOT de](w/relay/11C9529C9D0671545EAEF80DFE209AD977BCE908)                                                                                        |       0    |         1 | 2017-06-10   |
| 1364 | [tor@silencelen.com](w/family/8fd3409ba7f1e244318ce609ee2504f3078a9ed742c47652a805e63d651a16f4)                                                                                 |       0    |         2 | 2023-09-29   |
| 1365 | [0E32EF31](w/relay/0E32EF318419D3005C3003AFF4D1566A941DA484)                                                                                                                    |       0    |         1 | 2021-06-15   |
| 1366 | [0x5eead6e4206b0ae9 James Kruth &lt;james@kruth.org&gt;](w/relay/0E5D730466E5BB675BC9704C374DBE7E19F06165)                                                                      |       0    |         1 | 2016-10-02   |
| 1367 | [rufo &lt;tor at rufoa dotcom&gt;](w/relay/0E92BF02B3C11B0DD18301A0DE1B164A0546E36F)                                                                                            |       0    |         1 | 2015-05-27   |
| 1368 | [0E947CA9](w/relay/0E947CA987F0D5890E2374556483D59148877C30)                                                                                                                    |       0    |         1 | 2024-05-13   |
| 1369 | [0F03C4B8](w/relay/0F03C4B8C13A312A365856E2541548A70B23F350)                                                                                                                    |       0    |         1 | 2024-10-02   |
| 1370 | [torjockel@mailbox.org](w/relay/0F64A062EEB86CCFD243848263CD69B708BCE805)                                                                                                       |       0    |         1 | 2023-03-26   |
| 1371 | [0F71B014](w/relay/0F71B014AF6A2235BD0D0FBD2D50161F5F933A0E)                                                                                                                    |       0    |         1 | 2022-08-31   |
| 1372 | [0F8D74F8](w/relay/0F8D74F8D416866BBF5C83633CFA8D97C683B7B3)                                                                                                                    |       0    |         1 | 2024-03-19   |
| 1373 | [0FCABB8C](w/relay/0FCABB8C6E412E60CB862FE19A64191A69EB94EC)                                                                                                                    |       0    |         1 | 2019-02-04   |
| 1374 | [halloanjedendenichkenne@gmail.com](w/relay/10231E08F19C03D5A2FE3AAD03D863ABDE2081BC)                                                                                           |       0    |         1 | 2017-10-12   |
| 1375 | [Fruit9555 &lt;l3j7u5bg AT anonaddy DOT me&gt;](w/relay/104944B9596F8D0340790442EC75EBF368375A1F)                                                                               |       0    |         1 | 2023-11-20   |
| 1376 | [Svea Hosting &lt;info@svea.net&gt;](w/relay/10B689D11CDCB8EB74BF394880508C975058C608)                                                                                          |       0    |         1 | 2020-07-28   |
| 1377 | [httpkiller @t web dot de](w/relay/10BE6D891A758670CB130479BA035048ABD3D120)                                                                                                    |       0    |         1 | 2023-07-04   |
| 1378 | [Magician0291@proton.me](w/relay/10CB84C040124EDC58D4707D260D113EBB142BC7)                                                                                                      |       0    |         1 | 2024-07-15   |
| 1379 | [Contact &lt;torrelay@kurzepost.de&gt;](w/relay/09AF5C7A59852EF44FF56D30C01D5F412FD19786)                                                                                       |       0    |         1 | 2022-02-07   |
| 1380 | [09B389B1](w/relay/09B389B16F013B1FE5B66EBCB3290A733CBB169A)                                                                                                                    |       0    |         1 | 2024-10-04   |
| 1381 | [09DC984D](w/relay/09DC984D37468D38824802CCAF16ACCB0ABA77BA)                                                                                                                    |       0    |         1 | 2024-10-21   |
| 1382 | [09F19365](w/relay/09F1936587D5A82ABCD79B11599C044E72C13840)                                                                                                                    |       0    |         1 | 2022-01-12   |
| 1383 | [Random Person &lt;tor-trouble AT boldandbusted dot com&gt;](w/relay/09F64E00F34C88F604163F24D37BEAF9245702EA)                                                                  |       0    |         1 | 2008-10-06   |
| 1384 | [glenn@o2.pl](w/family/ffffbb777d894354cb7ce623b774005f18a3c39e7e14b237e6e33e018c0cb45b)                                                                                        |       0    |         2 | 2022-01-03   |
| 1385 | [07tartar.sop@icloud.com](w/relay/0A2151C0492B8A17FD03ED40598627A7027AE39B)                                                                                                     |       0    |         1 | 2018-01-21   |
| 1386 | [40DDEC46](w/relay/40DDEC464BDC334508ECCDF487C3D68CD0713862)                                                                                                                    |       0    |         1 | 2024-06-26   |
| 1387 | [411361FD](w/relay/411361FDBEE704CEE86BF599257E117BC1F7063B)                                                                                                                    |       0    |         1 | 2024-08-15   |
| 1388 | [&lt;sunshinecowboy56 AT protonmail dot com&gt;](w/family/d4520d9f440bda18174735694989f30764f2f9bd44350b7c908ea1e2ee8a3412)                                                     |       0    |         4 | 2024-01-22   |
| 1389 | [41F29DE3](w/relay/41F29DE3717812CB6B4073D1A4C7DDF8F2C3C7A8)                                                                                                                    |       0    |         1 | 2024-08-27   |
| 1390 | [easyasabcmiddle at proton dot me](w/relay/41F7DE555B6C149A887FB52C77744F5C7F29C7F2)                                                                                            |       0    |         1 | 2025-01-11   |
| 1391 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/42069A5183CF525AEFF737A1CC95F69331381A41)                                                                                          |       0    |         1 | 2024-09-22   |
| 1392 | [Kindly consider donating this node: http://tor.t0m.pl/](w/relay/4267E07E042898737C2B8137814705EC30172DE3)                                                                      |       0    |         1 | 2024-07-15   |
| 1393 | [428140AF](w/relay/428140AF8916B025BB1142F5D707B51FEFBE3AAD)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 1394 | [Admins &lt;forest dot owlet AT riseup dot net&gt;](w/relay/429950DFE3245014BCF30C7144131D4B82D560AC)                                                                           |       0    |         1 | 2024-02-25   |
| 1395 | [42D58335](w/relay/42D58335381BC9BB8C9ED98D390109EB74DBCBC4)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1396 | [Tor Manager &lt;tor@ibiblio.org&gt;](w/family/76fa0fa73af5210648a27e4df2ed67af7fbcd2092a641086a26b9f3797dc3262)                                                                |       0    |         3 | 2019-02-18   |
| 1397 | [431529B2](w/relay/431529B27FBED5817C69A204BB3CA95A307E2244)                                                                                                                    |       0    |         1 | 2022-03-14   |
| 1398 | [432D9C81](w/relay/432D9C81378FF54E50600A8F3F61E104CB77978D)                                                                                                                    |       0    |         1 | 2021-09-05   |
| 1399 | [2BD1936E](w/relay/2BD1936E0B4D5BB615CF99B0CFF74EAF19426888)                                                                                                                    |       0    |         1 | 2019-08-17   |
| 1400 | [2BE75399](w/relay/2BE75399787B664DDD1AA8ACF04C4412982BCD93)                                                                                                                    |       0    |         1 | 2022-04-03   |
| 1401 | [unzane.com](w/relay/2C4E15CD40EE3D2D6F062F04ADFE9B85C8C3C52B)                                                                                                                  |       0    |         1 | 2019-02-18   |
| 1402 | [youcansendmeanemail@t.complaints.7978atgmail.com](w/relay/2C62BB20180279888677FA93E34878E7EFF8A044)                                                                            |       0    |         1 | 2022-11-09   |
| 1403 | [2CE2DEE8](w/relay/2CE2DEE830B954EDA3A6BB57EA7420E0F5EE3C13)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1404 | [2CFFDEAE](w/family/7f29f9ca019d1cfb7ea581a8e2b463edc119ae60a24d961431876b42f5135eb2)                                                                                           |       0    |         2 | 2021-10-25   |
| 1405 | [nezu &lt;tor@nezu.cc&gt;](w/relay/2D172A07B929FCA9CF234768FCE0938B1E7DBB47)                                                                                                    |       0    |         1 | 2024-10-28   |
| 1406 | [Slarty &lt;info at slarty . org&gt;](w/family/7f0d50289a4eda3e9304b9df2196183cc2b64da382204992bc3c4d66f6f1e3c6)                                                                |       0    |         2 | 2019-02-18   |
| 1407 | [0x3104709C support@aa.net.uk](w/relay/2D47F039F04EEC03EABE484CC017796A0AB48240)                                                                                                |       0    |         1 | 2019-02-18   |
| 1408 | [seblonacs --&gt;seblonacs AT protonmail DOT com&lt;](w/relay/2DACC26F1D3BA64F32EEB4185BAD696A88BA832D)                                                                         |       0    |         1 | 2021-05-28   |
| 1409 | [2E4BDDE1](w/relay/2E4BDDE1509B886490E105215B6B08807C721DDF)                                                                                                                    |       0    |         1 | 2024-03-01   |
| 1410 | [cheaporelay57 at proton.me](w/relay/2E774A9909291FFDA38611BB84495D4D1D5130E2)                                                                                                  |       0    |         1 | 2025-01-08   |
| 1411 | [noc@0x7c0.com](w/family/568289c40df335fe3b7195e1c0e950a5626b982b2ad0672880a5844a0bfc61ed)                                                                                      |       0    |         4 | 2024-07-26   |
| 1412 | [0A4EF6AD](w/family/7163c9913aa75ee1d158f45cc4be3bc790d0fff9e59c08e88d8e62ffd05d44f0)                                                                                           |       0    |         2 | 2023-11-08   |
| 1413 | [tor.koishi.io](w/relay/0A84DDF8253A570DC08D760C6754C4D63B9F9590)                                                                                                               |       0    |         1 | 2025-01-13   |
| 1414 | [0ABC1EBF](w/relay/0ABC1EBFF50C8A58279AD07FBD73E183F9E00B86)                                                                                                                    |       0    |         1 | 2021-10-30   |
| 1415 | [Piero V &lt;vogliadifarniente AT gmail dot com&gt;](w/relay/0AC3C86BC9CA2A50C7762EF42ABC6D37575ACFFB)                                                                          |       0    |         1 | 2021-04-12   |
| 1416 | [0AFD832F](w/relay/0AFD832F09B6C2C9E0FE99E78B29E2ED325B0E54)                                                                                                                    |       0    |         1 | 2024-03-13   |
| 1417 | [Bit Vint; BitVint2024@protonmail.com; PGPKey: xjMEZuSyFRYJKwYBBAHaRw8BAQdAiClMTl](w/relay/0B07E5B82401DB8857F46B1C5DA915F7D85111F8)                                            |       0    |         1 | 2024-12-29   |
| 1418 | [0xFFFFFFFF Joe &lt;ovhcontact.matrix415@passmail.net&gt;](w/relay/0B201FA0B435D8969264B4972F3AD03D1D8BC732)                                                                    |       0    |         1 | 2024-10-14   |
| 1419 | [Ranlvor &lt;tor-2024 AT starletp9 dot de&gt;](w/relay/0B45375A2CE8065E8A649D52CC35F39D128745A8)                                                                                |       0    |         1 | 2013-11-06   |
| 1420 | [0BF171D0](w/relay/0BF171D0984EEF35B9ED9D7801941C833DD3853B)                                                                                                                    |       0    |         1 | 2023-03-20   |
| 1421 | [tor.sloppy693@aleeas.com](w/relay/0C68D484C72C44E8F1ABEF8637C156F69DE8F08B)                                                                                                    |       0    |         1 | 2023-10-31   |
| 1422 | [0C96F2BB](w/relay/0C96F2BB53E20B66529D2ACCA0DD70551E0B6B6B)                                                                                                                    |       0    |         1 | 2024-08-27   |
| 1423 | [onkel-wurst@gmx.de](w/relay/0CC9264836EF01407B4934D06B6CD537D441A62A)                                                                                                          |       0    |         1 | 2021-09-27   |
| 1424 | [0CF2F07F](w/relay/0CF2F07FF0581EBBCCDF209E655694358A98D816)                                                                                                                    |       0    |         1 | 2022-08-05   |
| 1425 | [xxxBLN47xxx@magenta.de](w/relay/0CF9E59BAC26D045DFF898EDF4266B7209BD6011)                                                                                                      |       0    |         1 | 2024-03-25   |
| 1426 | [flowerstotheworld at proton dot me](w/relay/0D11B4CA3B66C696CFEC5769BD64B8067C664F95)                                                                                          |       0    |         1 | 2025-01-14   |
| 1427 | [&lt;relay operatah AT proton mail dot com&gt;](w/relay/0D836533BDC08E4F07A197197C3199E3BC90A81B)                                                                               |       0    |         1 | 2024-11-23   |
| 1428 | [a-n-o-n-y-m-e.net](w/relay/0D9C0A3DCBF188F3CC364937EE2C16BAEFAA83AE)                                                                                                           |       0    |         1 | 2024-08-13   |
| 1429 | [0DB5DF7A](w/relay/0DB5DF7A029A6F56D06D4046388B0619B85D42E3)                                                                                                                    |       0    |         1 | 2024-12-22   |
| 1430 | [0DD04EF0](w/relay/0DD04EF0B081BBFDE3082D4ECC8A63FD0022FCAF)                                                                                                                    |       0    |         1 | 2015-10-22   |
| 1431 | [slavy991 at protonmail.ch](w/relay/1AAC8733A118351B56FCBBD532E1D6F47A95022B)                                                                                                   |       0    |         1 | 2023-07-19   |
| 1432 | [email: bigul AT tutanota DOT com](w/relay/1AB8133A5F42C0505A6352FC162A20270233CA98)                                                                                            |       0    |         1 | 2024-06-13   |
| 1433 | [admin@grzb.de](w/relay/1AC45083EBC7E02720C13254CEA3F7B032C248E2)                                                                                                               |       0    |         1 | 2021-06-07   |
| 1434 | [1AD5D1AB](w/relay/1AD5D1AB1932F683B6CE40D85021FB4CA830E7F2)                                                                                                                    |       0    |         1 | 2024-07-02   |
| 1435 | [MAILTO peratoso DOT hice AT hopfen DOT space](w/relay/1AFC99ECD56BF792E2DC89FB9D419B3580D6D89B)                                                                                |       0    |         1 | 2022-12-09   |
| 1436 | [1B0C838A](w/relay/1B0C838A971F14AADAB2DF6A27947D4665759767)                                                                                                                    |       0    |         1 | 2024-03-19   |
| 1437 | [1B3E48D7](w/relay/1B3E48D75E7F7E61D1B9BBE24BA15A38B454380D)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1438 | [1B625B05](w/relay/1B625B05FFE54F2E548ABCDD72DB4CF358976D7A)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1439 | [maniacal att&amp;t jewwwwwdotws](w/relay/1B6ACD3A0FB58240E86AB49ABC486DCA984EC69A)                                                                                             |       0    |         1 | 2024-07-18   |
| 1440 | [Tor Admin &lt;tor AT nomadlogic dot org&gt;](w/family/80e05eb494aca182e377c23bc93771983e7f329b5309b72fa40cee51fcefcff4)                                                        |       0    |         3 | 2021-03-29   |
| 1441 | [admin@caspervk.net](w/family/a3ef1f9ae6d38e7651876a19438279f1ae36e6e689cb9b1c75a87edf855c4b87)                                                                                 |       0    |         4 | 2023-08-06   |
| 1442 | [none](w/family/61e220eaee3d8178d795911892ffe9fe5f11c15ad1abf99b803865d70745fa18)                                                                                               |       0    |         2 | 2024-08-29   |
| 1443 | [1C0F66CF](w/relay/1C0F66CF2F67777858D95D2F8AEC6141EA34040A)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1444 | [barren wasteland at proton me](w/relay/1C84C89198911D0C8962AA65C3E4E6530075396E)                                                                                               |       0    |         1 | 2019-11-05   |
| 1445 | [tor2024@red-green.com](w/relay/1C9B7C0FB4C505C07B65F5CC32DE814DC157F67B)                                                                                                       |       0    |         1 | 2024-12-03   |
| 1446 | [mg321@mailbox.org](w/relay/147321EDE839D266601E65A7FAAD306749B1EEC5)                                                                                                           |       0    |         1 | 2022-08-10   |
| 1447 | [peoplesliberation@proton.me](w/relay/14AE2154A26F1D42C3C3BEDC10D05FDD9F8545BB)                                                                                                 |       0    |         1 | 2023-07-06   |
| 1448 | [14B00A28](w/relay/14B00A280F21F89E28AD1E4762691841E528DC8A)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 1449 | [15627B91](w/relay/15627B91E7B969EDD50E033CC6CF14B749283EDA)                                                                                                                    |       0    |         1 | 2024-03-22   |
| 1450 | [cpbtor@proton.me](w/relay/157613F129BF4E838ABA00C27BDA41C3BF00BA26)                                                                                                            |       0    |         1 | 2023-09-14   |
| 1451 | [15AE3D6B](w/family/8d9615ed7e80b282708fc6c037ce9fe27fffd5ca369196e9eafe4f0f3c5c0901)                                                                                           |       0    |         2 | 2022-10-07   |
| 1452 | [15BF3EF1](w/relay/15BF3EF17618344CB50DFB5832A24BFE3EC7F7B8)                                                                                                                    |       0    |         1 | 2024-07-30   |
| 1453 | [akacha@cock.li](w/relay/162293A53A3893460B5B4A12CFB6B30825938521)                                                                                                              |       0    |         1 | 2024-11-20   |
| 1454 | [163C07F4](w/relay/163C07F42EB06B65410E82A0AB1D14DEDD826C0F)                                                                                                                    |       0    |         1 | 2021-09-27   |
| 1455 | [steve@degga.net 8C78 85A0 3092 16F0 C403 DF2B 4AFE 11D8 9477 C19B](w/relay/167CEF79F018CB97E845535BCDCEA1ED51DF1561)                                                           |       0    |         1 | 2023-07-09   |
| 1456 | [16824F88](w/relay/16824F885D72B4FA7A5090E08D877E5404BC214D)                                                                                                                    |       0    |         1 | 2019-12-05   |
| 1457 | [16D0620A](w/relay/16D0620AB08A091C93BA448769477E4C109FF570)                                                                                                                    |       0    |         1 | 2022-04-03   |
| 1458 | [obey at goawaycia dot nowhere](w/relay/16E8F1E37F191C0DB45F81F30D17B69E60415F61)                                                                                               |       0    |         1 | 2024-01-22   |
| 1459 | [apps-at-name-of-relay-dot-be](w/family/ccac2000b3841bedbf0cf5b08344b3e3378eff8f6910deef9a8ffc14bce11c6a)                                                                       |       0    |         3 | 2021-05-28   |
| 1460 | [Korrupt &lt;richie AT zuviel dot org&gt;](w/relay/11FC7D9C7D8DF74326B90EC71C10173279738B8F)                                                                                    |       0    |         1 | 2022-08-05   |
| 1461 | [11FD2466](w/relay/11FD24668A0A515E355E1B88FEAC87ABA4096946)                                                                                                                    |       0    |         1 | 2023-03-09   |
| 1462 | [Relay Ops &lt;tor AT as6145 DOT net&gt;](w/relay/12223104F985F6B9D6A688A6555CE7042C38DA74)                                                                                     |       0    |         1 | 2024-01-22   |
| 1463 | [1232C803](w/relay/1232C803D36CC7823913F8764D16486B4C7AFCC3)                                                                                                                    |       0    |         1 | 2024-07-02   |
| 1464 | [127E0D7B](w/relay/127E0D7BB53AF622E1C80FCB62821C00B62708C6)                                                                                                                    |       0    |         1 | 2025-01-13   |
| 1465 | [&lt;developing ATT keemail dott me&gt;](w/relay/127F6358F68FFB7E437DBA51D6D4DAC47B9F78A7)                                                                                      |       0    |         1 | 2021-05-26   |
| 1466 | [Bartosz Waszak &lt;waszi@httpx.pl&gt;](w/relay/132395E199674BC4E65EA90DA0150D51D12B8221)                                                                                       |       0    |         1 | 2022-03-04   |
| 1467 | [&lt;TorRelayRep&gt; no bs plz at mailfence.com](w/relay/1363EB2417A5A3A64DD0D3A735594A2D019E1A86)                                                                              |       0    |         1 | 2024-09-01   |
| 1468 | [torusyeetus@protonmail.com](w/relay/13B69C76175B3E99725DE46D9B17D8B2DCC37990)                                                                                                  |       0    |         1 | 2024-09-15   |
| 1469 | [me okr765 com](w/relay/13DC00AF2267554908CE0FCA82687B44968A701F)                                                                                                               |       0    |         1 | 2022-11-29   |
| 1470 | [salmon at pm dot me](w/relay/1776B82878E571E3969A6A7F7EA140A8853F11DB)                                                                                                         |       0    |         1 | 2024-01-21   |
| 1471 | [sunshinecowboy56 at protonmail.com](w/relay/1793C1E9E27BF46A4F161F0FB13A0ECECFF36E45)                                                                                          |       0    |         1 | 2024-11-11   |
| 1472 | [email me if you gotta u89b47 AT proton mail](w/family/6118f07fcd042e78056e8f5afb1f117e0066c3d2360cdb6f1de3e0e903c2a9f6)                                                        |       0    |         2 | 2022-02-02   |
| 1473 | [tor-relay-001@schulte.org](w/relay/1841CB960128806151B61FC6D87AFBE9A98B99D7)                                                                                                   |       0    |         1 | 2019-02-18   |
| 1474 | [358npyhXKrv834iyqtjHthudXRc5NjQcvm xmtx tor](w/relay/1850585BE9BCA1F80D0A051909C94E49D1C49ED3)                                                                                 |       0    |         1 | 2019-02-18   |
| 1475 | [Steve &lt;dartme18tor@gmail.com&gt;](w/relay/185FD1D7A8E3B7888E5647DE6306A1FC658A7D5A)                                                                                         |       0    |         1 | 2024-12-18   |
| 1476 | [18FFCE6F](w/relay/18FFCE6F75DF7FCCDBA427253D9D7834A361097C)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1477 | [1909BBDC](w/relay/1909BBDC9D94D90807793A1DD41F5314D7B50ECB)                                                                                                                    |       0    |         1 | 2024-06-07   |
| 1478 | [19173006](w/relay/19173006B05B6119D966B73AE7677D71EF529CF6)                                                                                                                    |       0    |         1 | 2020-12-29   |
| 1479 | [dave@tamasi.com](w/relay/1983E5CBD3F84D3F5124AA38084602387E20017B)                                                                                                             |       0    |         1 | 2024-01-22   |
| 1480 | [19B2AB23](w/relay/19B2AB23AC228703D814F0DCA41059342CB3EA07)                                                                                                                    |       0    |         1 | 2024-09-12   |
| 1481 | [c0wb0y @ aol . com](w/relay/19C64AF24E40C2CE5E3CA5231509213230B46F70)                                                                                                          |       0    |         1 | 2023-06-21   |
| 1482 | [lostmc1@mail.ru](w/relay/1A020A414D8AB25F54415C8C1E75A5562A9DD9A6)                                                                                                             |       0    |         1 | 2019-02-18   |
| 1483 | [1A087365](w/relay/1A0873654174FF8B1D66B02DA82D46ADDD46AC4B)                                                                                                                    |       0    |         1 | 2020-06-22   |
| 1484 | [z@z.com](w/relay/1A2EC12F1D5ACDB2C71B6EE5CA5A5214EA709215)                                                                                                                     |       0    |         1 | 2024-10-14   |
| 1485 | [1A4BBA04](w/relay/1A4BBA04D9C7D9BAF716371D10A59756AA4CB0CC)                                                                                                                    |       0    |         1 | 2024-08-04   |
| 1486 | [1A66C02A](w/relay/1A66C02A119D6F842F550685E0051C4AE23B8BE8)                                                                                                                    |       0    |         1 | 2022-06-12   |
| 1487 | [1D57E179](w/relay/1D57E1799E90B6AA30A84E4198E57DC92D8B66E5)                                                                                                                    |       0    |         1 | 2024-03-12   |
| 1488 | [1D8ACC1F](w/relay/1D8ACC1F5F28D52446303D1E197A1A3B9FD81505)                                                                                                                    |       0    |         1 | 2022-08-31   |
| 1489 | [jveecom@gmx.net](w/relay/1D8E0893A6FE967D12A94EA78E6DC7540E75E159)                                                                                                             |       0    |         1 | 2024-12-28   |
| 1490 | [floede@protonmail.com](w/relay/1D8ED54EA9DF2D46558AD0096DD5D9DD297F13A8)                                                                                                       |       0    |         1 | 2019-06-08   |
| 1491 | [willieblade@proton.me](w/relay/1DB53696279202C2F13373D0C47A8D1F0C2DE0A6)                                                                                                       |       0    |         1 | 2024-07-01   |
| 1492 | [Random Person nobody@tor.org](w/relay/1DCB2AF8C11D28750F72EE37F9AACD0790EE1A50)                                                                                                |       0    |         1 | 2024-10-10   |
| 1493 | [1DE70504](w/relay/1DE70504C6E9BB223E2EC4FAD45C68C07A6AE9FB)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1494 | [xplato@pm.me](w/relay/1DFF614CEEFDB936861CEE6CC5A6223F2762F68D)                                                                                                                |       0    |         1 | 2024-06-08   |
| 1495 | [Random Person blobster@tuta.io](w/relay/1E073339919F3AD1E82755A909CF458CCC6252D1)                                                                                              |       0    |         1 | 2022-10-20   |
| 1496 | [1E621629](w/relay/1E6216290622210EB40B8FB65D9CE1800DB10712)                                                                                                                    |       0    |         1 | 2024-04-11   |
| 1497 | [blauskaerm@protonmail.ch](w/relay/1E7FE364A814340CBD79AA2B3365E718D3B1A67C)                                                                                                    |       0    |         1 | 2020-08-01   |
| 1498 | [1E972A04](w/relay/1E972A04E92869EE1C180BBA8553CC1DE89C4808)                                                                                                                    |       0    |         1 | 2024-06-30   |
| 1499 | [&lt;tilgorekrout@yahoo.com&gt;](w/relay/1EFF2704D19BF45305BBCCA53E2B59A3D17A6EE3)                                                                                              |       0    |         1 | 2019-02-18   |
| 1500 | [hyperreal@moonshadow.dev](w/relay/1F783ACB4814A532AD8DF02F34D9417CF1723783)                                                                                                    |       0    |         1 | 2024-09-08   |
| 1501 | [1FA37EC5](w/relay/1FA37EC504C0E09489BDCFA9555AF6064E46BBFB)                                                                                                                    |       0    |         1 | 2024-11-02   |
| 1502 | [izella.blackford@freemailonline.us](w/relay/1FB717B728B872D378EEA0A8A4AA7784CFBA6AA8)                                                                                          |       0    |         1 | 2024-01-22   |
| 1503 | [0xF0D76F487F82CEE9B57DAE3B56D4B779518F68A2 ILoveFoxes TorRelay &lt;tor-relay@ilovef](w/relay/1FC0E182D07CF47A25DD4F6176C9F3671C56CD88)                                         |       0    |         1 | 2024-02-17   |
| 1504 | [oong3gvct@mozmail.com](w/relay/24BF2D6E5F5AC4FD3AE589CC1D88047BE75A72BE)                                                                                                       |       0    |         1 | 2025-01-12   |
| 1505 | [253E7C68](w/relay/253E7C6802F75BD54616872693A5922ED2A1534D)                                                                                                                    |       0    |         1 | 2022-03-24   |
| 1506 | [257984B1](w/relay/257984B15ACFC8A987D861BCD1BC48C134F6BA5C)                                                                                                                    |       0    |         1 | 2024-04-29   |
| 1507 | [worldofmatthew.com](w/relay/259078C74CB230969A6AFCD8535C0B35AECFF868)                                                                                                          |       0    |         1 | 2020-08-31   |
| 1508 | [tor2407@aatebueli.ch](w/relay/25E0F7010C4B40462159830F60E9ACE3FBF571E4)                                                                                                        |       0    |         1 | 2023-08-08   |
| 1509 | [a-n-o-n-y-m-e.net](w/relay/25FC41154DCB2CAE3ABD74A8DFCD5B90D2CFFD57)                                                                                                           |       0    |         1 | 2024-01-30   |
| 1510 | [265651B2](w/relay/265651B222307E87AF2BD8434FA01AA2D5274697)                                                                                                                    |       0    |         1 | 2024-08-31   |
| 1511 | [Relay Operator &lt;tor-relay@mkn7787.com&gt;](w/relay/2683A6EB5F2DAB673CE92858904862EE1CEB4CB7)                                                                                |       0    |         1 | 2025-01-08   |
| 1512 | [22E12A0E](w/relay/22E12A0E0B0804D62100DAF0249F641D53C22199)                                                                                                                    |       0    |         1 | 2024-04-24   |
| 1513 | [tor-relay.fastquake@com swap characters](w/relay/22E975935BA77EA59A28EA1AA8387F906034FCBE)                                                                                     |       0    |         1 | 2019-02-18   |
| 1514 | [2322F9A6](w/relay/2322F9A66D456AD9C880D14ECEA83960D36541D4)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1515 | [tor@invisible-internet.com](w/relay/236255FE7F91D37CBA3A915EEB4573788DBC28D0)                                                                                                  |       0    |         1 | 2024-06-17   |
| 1516 | [mentor@palokaj.co](w/relay/23899620429B1B0E726AC927EF86BEBDE10F1D0C)                                                                                                           |       0    |         1 | 2023-07-27   |
| 1517 | [239E1393](w/relay/239E139385B9D4136D373D29411F5E471FFDB808)                                                                                                                    |       0    |         1 | 2024-01-28   |
| 1518 | [23AC0EA5](w/relay/23AC0EA54801361858D879CF4C29EDF195A758CF)                                                                                                                    |       0    |         1 | 2024-08-29   |
| 1519 | [241A9F4C](w/relay/241A9F4C316903B88DC2F6F833D0472AE8E280D3)                                                                                                                    |       0    |         1 | 2024-09-08   |
| 1520 | [blublufkfk AT inbox dot lv](w/relay/24733C4F64D092586A533F1BE852199D9983C3C2)                                                                                                  |       0    |         1 | 2025-01-13   |
| 1521 | [abuse at miner dot dk see https://www.miner.dk](w/relay/248A96B2A88A3EAB14699B9096CE6ABF77D0606A)                                                                              |       0    |         1 | 2020-07-02   |
| 1522 | [tor@husky.xyz](w/relay/24A15273E70C8CC7D7716AB874CC9C1A688B3EAC)                                                                                                               |       0    |         1 | 2024-01-22   |
| 1523 | [my@e-mail.com](w/relay/1FF059BF40A22ED6E4E5434CA76D246901B07FE9)                                                                                                               |       0    |         1 | 2024-10-11   |
| 1524 | [20179B14](w/relay/20179B1437897ABEF54B4EA4B24721F123A33A0E)                                                                                                                    |       0    |         1 | 2024-03-06   |
| 1525 | [2022BCB3](w/relay/2022BCB37453DC168E6CB7B4DAD119AC072F2DEE)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1526 | [0xA90AFCF81406CC27 &lt;sjk@dredel.com&gt;](w/relay/2037A6568C5771A5D8FF5C64FC1819247E6FEE7B)                                                                                   |       0    |         1 | 2019-02-18   |
| 1527 | [205312D3](w/relay/205312D3230B8F48D5E971315A9682319E5622EB)                                                                                                                    |       0    |         1 | 2024-09-05   |
| 1528 | [gleebear@proton.me](w/family/cdd3fc6a9b3c2f0bb0182ed668f0d2fdb28bbd59477e1924785393fd58ce066e)                                                                                 |       0    |         2 | 2022-12-09   |
| 1529 | [Random Person nobody@tor.org](w/relay/2083E72F003A9F2088829864F256DAC6DE438374)                                                                                                |       0    |         1 | 2024-12-29   |
| 1530 | [215E26D4](w/relay/215E26D4C9BA6A1F10266B7B2213A808AB2A8444)                                                                                                                    |       0    |         1 | 2024-08-04   |
| 1531 | [2185F7F6](w/relay/2185F7F67ED533CE4AA58C12203CC588671267C7)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 1532 | [219BD3D1](w/relay/219BD3D1F11BEE8ED4AD70CFE1F08C697048870D)                                                                                                                    |       0    |         1 | 2023-08-12   |
| 1533 | [21B38662](w/relay/21B386624BF256B27906B3DE86AA0281A8C91995)                                                                                                                    |       0    |         1 | 2024-03-15   |
| 1534 | [4096R/5C06D153 John Leach &lt;john@johnleach.co.uk&gt;](w/relay/21B55072C00F4522857655FBB0F3E25D75A5357B)                                                                      |       0    |         1 | 2019-02-18   |
| 1535 | [eyeman@posteo.ae](w/relay/221E976B546E60048A01950250399B8534D4E4B7)                                                                                                            |       0    |         1 | 2019-02-18   |
| 1536 | [2258FE0E](w/relay/2258FE0EBD574DFCA17670E1B47EDE5A75D974CB)                                                                                                                    |       0    |         1 | 2022-07-22   |
| 1537 | [229B8F73](w/relay/229B8F737A97AD2089512DBB40408D8EDBD8DE6D)                                                                                                                    |       0    |         1 | 2024-06-24   |
| 1538 | [citadel@airmail.cc](w/relay/2ED2665726DE9391254D038742A995C45B64E930)                                                                                                          |       0    |         1 | 2024-11-07   |
| 1539 | [accvio &lt;accvio@gmx.net&gt;](w/relay/2ED8654AD1B8C25F3EB83156B07EA35BE6132F0C)                                                                                               |       0    |         1 | 2020-07-02   |
| 1540 | [2EE7B018](w/relay/2EE7B0181C4BAC7E130DF1B63DDD9E09A165A9A2)                                                                                                                    |       0    |         1 | 2024-08-26   |
| 1541 | [NutNinja tornutninja at protonmail dot com](w/relay/2EE7F49728D03F8BC0DC1D67558499290C5F09FF)                                                                                  |       0    |         1 | 2022-08-21   |
| 1542 | [2F271015](w/relay/2F2710152A2344B1DE3EF619E85CB1B298643D27)                                                                                                                    |       0    |         1 | 2024-11-13   |
| 1543 | [PGP:3f2ce2a67dcf7e955e5a4e2d0fec8dc32541e09b mail:node.nyxcz&x27;AT&x27;pm.me BTC:bc1q52](w/family/692e8c876675bb70f5351bb932d2c0e3bf5df7cd68e101c29b625c8c3df6e311)           |       0    |         2 | 2024-09-19   |
| 1544 | [2F645FDE](w/relay/2F645FDE1C46826E14E8D72D715D3EB55DBE6F98)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 1545 | [testing@testowo.pl](w/relay/2F66685743A941A19580131D62119C7261CFDC3E)                                                                                                          |       0    |         1 | 2022-11-19   |
| 1546 | [valient thor at yahoo dot com tor-relay.co](w/relay/2F9473EC839A036B15401B43F5C06ACC189462EA)                                                                                  |       0    |         1 | 2024-02-02   |
| 1547 | [a-n-o-n-y-m-e.net](w/relay/2FF8FFB28EAA635E291D623E03F231AC265F28F9)                                                                                                           |       0    |         1 | 2024-05-14   |
| 1548 | [0x022F0FF2CB0423427178334FBA3F9725266CDD10 Christopher Kerr &lt;chris.kerr@mykolab.](w/relay/300CA9E17D250BAD6C3C3EE6578B193493BF02DA)                                         |       0    |         1 | 2021-03-19   |
| 1549 | [3018498D](w/relay/3018498D945665829287BD9F59E7C8FFBA51830D)                                                                                                                    |       0    |         1 | 2024-05-11   |
| 1550 | [stubbornoxen at thewellinspired dot com tor-relay.co](w/relay/304229B6F0C10A4465F5B32D080159CB360FDD15)                                                                        |       0    |         1 | 2020-07-02   |
| 1551 | [Jerome Schnitzler &lt;SOTorRelayUK01@secmail.one&gt;](w/relay/305AC5CBD9868FF0F75DD18E2220A0345FBF3904)                                                                        |       0    |         1 | 2024-11-11   |
| 1552 | [tor@camille.mozmail.com](w/relay/30D1F00CAB6BC6065E01A6E2869DB2DA700B9EC8)                                                                                                     |       0    |         1 | 2023-07-19   |
| 1553 | [30D922C5](w/relay/30D922C52EFEEC8AEE6A107E36DCDC6648012DBB)                                                                                                                    |       0    |         1 | 2022-06-22   |
| 1554 | [tor@tel.dk](w/relay/311EE5DD2F2B992A2FC80BEE79226359F17DED9D)                                                                                                                  |       0    |         1 | 2024-11-04   |
| 1555 | [pleadnan@proton.me](w/family/2d092a346e8bea4a40036c34153fb2807b7dd93ba69ee2967d8ed54e989e9724)                                                                                 |       0    |         2 | 2024-12-19   |
| 1556 | [466058DF](w/relay/466058DF87C45EFECF07BDC9D823FF12ED7B6890)                                                                                                                    |       0    |         1 | 2021-04-18   |
| 1557 | [tor at d-ku dot de - 0x86d7bbcc54cbb356](w/relay/467D7417FFA611BC20227FE347494CE5F61218FB)                                                                                     |       0    |         1 | 2019-10-26   |
| 1558 | [tor at system-of-rampage dot online](w/relay/46BACCCE4BC3CAA63D2FE770DA2AE3CF401B9CF0)                                                                                         |       0    |         1 | 2021-11-14   |
| 1559 | [46F9FB94](w/relay/46F9FB943917858F618F2648595DEACD931D4400)                                                                                                                    |       0    |         1 | 2024-02-07   |
| 1560 | [UCAS@duck.com](w/relay/4711610AA1D22275F3E5188074EE84A03D197F10)                                                                                                               |       0    |         1 | 2024-09-20   |
| 1561 | [Random Person &lt;info AT fortong dot de&gt;](w/relay/4721AFABDBE29512A47A998E683A3EEACD1446A7)                                                                                |       0    |         1 | 2022-09-20   |
| 1562 | [copia297@proton.me](w/relay/4746E2B86718D5391CCF18C258460C321945DBD8)                                                                                                          |       0    |         1 | 2022-10-30   |
| 1563 | [eldernorn@gmail.com](w/relay/4780749994B23557F74586BA128B4DC01A546676)                                                                                                         |       0    |         1 | 2019-02-18   |
| 1564 | [47A9ADA8](w/relay/47A9ADA86843137BA1A1E29B0A32325DE05F6B49)                                                                                                                    |       0    |         1 | 2024-03-21   |
| 1565 | [47D19F85](w/relay/47D19F85216F1239529521E0265085394DF201B9)                                                                                                                    |       0    |         1 | 2022-07-12   |
| 1566 | [toastertor@gmail.com](w/relay/47DB5B84541A3ADE70911D7B3B5407C82780BF8C)                                                                                                        |       0    |         1 | 2024-12-13   |
| 1567 | [dtwst2@gmail.com](w/relay/48085FD5ECE14454BC7349E484602CB7C1036D82)                                                                                                            |       0    |         1 | 2022-08-01   |
| 1568 | [emeraldonion.org](w/relay/481313B7E49931D893B9DD4898AE6218C3172D99)                                                                                                            |       0    |         1 | 2024-07-26   |
| 1569 | [482F359A](w/relay/482F359A7A84A1EAAE14A6D5F8D497913F87EE51)                                                                                                                    |       0    |         1 | 2020-12-29   |
| 1570 | [&lt; asara AT devvul DOT com &gt;](w/family/cec4787c2479f891d95fb1ed20ba65765f236255d8f3ebb45926a249d08adabe)                                                                  |       0    |         3 | 2022-09-30   |
| 1571 | [tor@zapner.anonaddy.com](w/relay/488E663B4A88C12E6DE6C12F7A6053F09BF7A61A)                                                                                                     |       0    |         1 | 2019-11-15   |
| 1572 | [frogs go ribbit &lt;frogs-go-ribbit AT posteo dot com&gt;](w/relay/48951F116EAA769A8D7AE78B160615F70E8AEB90)                                                                   |       0    |         1 | 2024-12-05   |
| 1573 | [yummycusard@proton.me](w/relay/48AFAF561D48B14579C909939550166838405CD2)                                                                                                       |       0    |         1 | 2022-09-30   |
| 1574 | [7be58bbb-2028-4549-923c-93325619a0f1@anonaddy.me](w/family/588ab26502807550c11d60951958a6fcf1070439c5c436a6fb9fe873d4690b35)                                                   |       0    |         2 | 2024-11-10   |
| 1575 | [26CE0AE5](w/relay/26CE0AE5F373CBCBA24471D603BB5BE6A25593C1)                                                                                                                    |       0    |         1 | 2024-01-31   |
| 1576 | [David Kabo &lt;mytorrealy@proton.me&gt;](w/relay/26F5D0F28B756CDB8FEF0081C8F0A26FCEB5F943)                                                                                     |       0    |         1 | 2025-01-16   |
| 1577 | [2703E99A](w/relay/2703E99A85767DBDF7CFC46CF798AB5B4F08E358)                                                                                                                    |       0    |         1 | 2025-01-14   |
| 1578 | [270A22B3](w/relay/270A22B37FD94BFE381B982206CFDF3C4C2C670C)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1579 | [27132CE9](w/relay/27132CE932038B4F34F3BB50299C8D8805735512)                                                                                                                    |       0    |         1 | 2024-02-23   |
| 1580 | [blas.harjaberhtaz outlook.com](w/relay/27A3C6E301B9803F0F57856ADA5FD834DB0412FD)                                                                                               |       0    |         1 | 2024-01-21   |
| 1581 | [support@free.de](w/relay/27A3CAFA37040D78DBEC606A768AB0E7A4B36FF7)                                                                                                             |       0    |         1 | 2022-11-29   |
| 1582 | [aze at qsd dot com](w/relay/2847099403067F3F8ACB4273AEF72E96AB9689AA)                                                                                                          |       0    |         1 | 2024-10-04   |
| 1583 | [0x8acbab2d00b6adef81416beaf815d5cd87d25b75 Likogan admin at likogan dot dev](w/relay/292FCACE773DC259B799914A23BE65A6A6178E8F)                                                 |       0    |         1 | 2024-01-22   |
| 1584 | [295D9205](w/relay/295D920528E918FE99F5421467D8116A04539DBF)                                                                                                                    |       0    |         1 | 2024-02-29   |
| 1585 | [0xD5792C4C8C6F8DE8377949D1F48380B2EC8F9449 Tor Operator &lt;tor@teaparty.net&gt;](w/relay/2A36005A811C8B420F380D67C4A9D630655F0900)                                            |       0    |         1 | 2019-02-18   |
| 1586 | [2A800EC6](w/relay/2A800EC6DA529CFEA1F6293D6AC67914F95C8D86)                                                                                                                    |       0    |         1 | 2024-08-25   |
| 1587 | [mega.avish@deecie.com](w/relay/2AE88489A504EF7750F95A8125F35B435A0954B0)                                                                                                       |       0    |         1 | 2024-01-22   |
| 1588 | [2AF74AFE](w/relay/2AF74AFEE6BF6BE6DAE9106077BB86A411A89D16)                                                                                                                    |       0    |         1 | 2024-09-06   |
| 1589 | [&lt;dhtf35&gt;@&lt;tutamail.com&gt;](w/relay/2B14E50E6B1AF0C526DCCF02C00390A3FB67F880)                                                                                         |       0    |         1 | 2024-11-09   |
| 1590 | [cris.sanders22@protonmail.com](w/relay/2B31FB827D4CEA734B9F78C16137CFD6F8AEBB7B)                                                                                               |       0    |         1 | 2019-02-18   |
| 1591 | [2B34099E](w/family/28c4e9c7fe351acd9a417cc3f199e2bc15b373bf71b5cca5d7743aad17929621)                                                                                           |       0    |         3 | 2019-04-29   |
| 1592 | [Random Person &lt;thud erasure020@simplelogin.com&gt;](w/relay/2B4D5AA9997D4DDFF02BC52E173CF0C8FFFD1B9C)                                                                       |       0    |         1 | 2024-01-21   |
| 1593 | [2B6DE17E](w/relay/2B6DE17E1CF6533F3917CA335F614D0F56B00BA4)                                                                                                                    |       0    |         1 | 2024-10-20   |
| 1594 | [2B8D6F22](w/relay/2B8D6F2243B2FB74BFEAD40781C439B4DBC2D592)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1595 | [tor at dereferenced net](w/relay/2BA2C8E96B2590E1072AECE2BDB5C48921BF8510)                                                                                                     |       0    |         1 | 2019-02-18   |
| 1596 | [turtlecute @ horsefucker . org](w/relay/2BBE11EC7CE623B4D76C9762D2BE28DF569B3E26)                                                                                              |       0    |         1 | 2022-12-09   |
| 1597 | [0xA178459DC4EC1DA3 Ryan Omasta &lt;abuse dash tor AT ryand dot ca&gt;](w/family/fbd3b01cff05f3d1ec9dd788094c1db151c482ed2433e04143c451f7e0728149)                              |       0    |         2 | 2024-12-21   |
| 1598 | [31362147](w/relay/313621479C809A7A2DD2E8A601BE96292046DC65)                                                                                                                    |       0    |         1 | 2023-07-17   |
| 1599 | [4725@ro.ru](w/relay/3148F87C035020745517ECDB7195FCC2BF1A6C32)                                                                                                                  |       0    |         1 | 2024-09-10   |
| 1600 | [jumpthrow at protonmail dot com](w/relay/3151FB419FAB0FD86D7BE4F7DFD620E99E105D92)                                                                                             |       0    |         1 | 2020-09-20   |
| 1601 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/315D1201A80DCA0AB6D5BA6514F9152FDEFEA0E0)                                                                                          |       0    |         1 | 2024-09-22   |
| 1602 | [318CAD1A](w/relay/318CAD1A00B33D2F65958210B09B8937836E99AF)                                                                                                                    |       0    |         1 | 2024-01-31   |
| 1603 | [31944CF9](w/relay/31944CF948F6A7FDB267B639734861FEEEE2E033)                                                                                                                    |       0    |         1 | 2024-08-30   |
| 1604 | [quetzalcoatl-relays.org](w/relay/31AB04A3080091FECCAFD6B02B3D46BE9DB82FE5)                                                                                                     |       0    |         1 | 2020-12-29   |
| 1605 | [katerinazamurieva1996964j3cy@mail.ua](w/relay/31D3C271A10B94EA0271810E5AFD52BC67066B24)                                                                                        |       0    |         1 | 2025-01-09   |
| 1606 | [4716@ro.ru](w/relay/32210651C9E78B631FA98A16DB4E7C5BDDF02A08)                                                                                                                  |       0    |         1 | 2024-09-18   |
| 1607 | [bananen@tuta.io](w/relay/322BB33F4887230B0767F54BA08A450B68D777F2)                                                                                                             |       0    |         1 | 2019-02-18   |
| 1608 | [Torenzo priminerd @ gmail . org](w/relay/3266A186B59A6E0F4C03F5F82ADCC6C63B4F31A7)                                                                                             |       0    |         1 | 2024-01-21   |
| 1609 | [32742AD5](w/relay/32742AD57C3D243DA0713BB6DFD82118DF573D2E)                                                                                                                    |       0    |         1 | 2022-06-12   |
| 1610 | [Relay Ops &lt;tor AT as6145 DOT net&gt;](w/relay/335D789D1730F8B19AB2FEB56E7594036BBA2974)                                                                                     |       0    |         1 | 2024-01-22   |
| 1611 | [Ivan CHEREL &lt;lambdhack AT lambdhack dot bzh&gt;](w/relay/337911D5DAA727609126B0759E886A888D80F02B)                                                                          |       0    |         1 | 2025-01-01   |
| 1612 | [quetzalcoatl-relays.org](w/family/27acefdf1fbded4b9aa8ba7f51dc2cb58c7f087f8e4224690664149886e9f0fb)                                                                            |       0    |         8 | 2023-06-03   |
| 1613 | [343E94C2](w/relay/343E94C28226E839ADCD5B4484AA39EC7B035B18)                                                                                                                    |       0    |         1 | 2024-08-23   |
| 1614 | [34618D94](w/relay/34618D946B2FF6CD88F5E5A1471B571B54AFCFA7)                                                                                                                    |       0    |         1 | 2024-02-05   |
| 1615 | [349B1E09](w/relay/349B1E09C516ACDA5E828E2235031236969CEDA9)                                                                                                                    |       0    |         1 | 2024-08-04   |
| 1616 | [VictorCrypto at the University of Michigan &lt;victorcrypto AT umich dot edu&gt;](w/relay/3514268910D8D6F69A060518DCD239362F9D361E)                                            |       0    |         1 | 2024-01-22   |
| 1617 | [35513B1D](w/relay/35513B1D2EA70649346C3C6D34F63D6982E3948A)                                                                                                                    |       0    |         1 | 2019-03-30   |
| 1618 | [Rich Russon &lt;tor@russon.org&gt;](w/relay/355340273E78DAC664B2328EC46D61998D797141)                                                                                          |       0    |         1 | 2019-02-18   |
| 1619 | [35671868](w/relay/35671868DB73AE262535A39FB601D643E7D7C52A)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1620 | [35872480](w/relay/358724800E6F7B569F0A04CF70C7D5579669ACEA)                                                                                                                    |       0    |         1 | 2024-09-22   |
| 1621 | [&lt;tor@taz.de&gt;](w/relay/35919E197C6C7F372A26C747D66ACA6A39642B3E)                                                                                                          |       0    |         1 | 2019-02-18   |
| 1622 | [torguy &lt;torguy@efreetsystems.de&gt;](w/relay/359A5D5005539D69A98EBE29F3C72E8FDC79FFBC)                                                                                      |       0    |         1 | 2024-01-22   |
| 1623 | [xmr:4AuKENt7AKt2HYuDTESThbFBbvREVhFM93nvLkpUd9gwQVu7giktvFEKAurXoUXwgx4Bz5Ric3BH](w/relay/36414078C521BA19168260F6DF23C97995976289)                                            |       0    |         1 | 2019-02-18   |
| 1624 | [ContactInfo &lt;shitruss@gmail.com&gt;](w/relay/366DFDE7CE8CE295AD53E66FD3651A55BD91357A)                                                                                      |       0    |         1 | 2022-07-12   |
| 1625 | [3684B867](w/relay/3684B8673A30B73FED280359C5FBA9F954690D4C)                                                                                                                    |       0    |         1 | 2024-01-31   |
| 1626 | [a-n-o-n-y-m-e.net](w/relay/36E4BEA3E092D05DC25F4CD29A9A5C7D9D0C7571)                                                                                                           |       0    |         1 | 2024-06-11   |
| 1627 | [ALiteralBird &lt;tor meusartis ca&gt;](w/relay/373FFA51BD83F65D10C9B984F22FCBA3DD40B812)                                                                                       |       0    |         1 | 2022-10-10   |
| 1628 | [Random Person &lt;rasptorpipi AT members dot fsf dot org&gt;](w/relay/37535409102DFFE92F3DAC809E470E62BC27F1DF)                                                                |       0    |         1 | 2019-02-18   |
| 1629 | [dontinterceptmebro.com](w/family/0d4a56a5bce5cfb867d306ab332a2a556a792b6ffd4a4ccc159ce9f38e7a03fe)                                                                             |       0    |         2 | 2019-02-18   |
| 1630 | [0x5AB387D3 Martin Kepplinger-Novakovic &lt;martink@posteo.de&gt;](w/relay/37686F3641BCDA1AD0FD657D96CD5B46F8B1855F)                                                            |       0    |         1 | 2024-10-02   |
| 1631 | [imgoingbed at googles email service uplinkbw:100 trafficacct:unmetered ciissvers](w/family/3519c0972b8efe28257675804d692160fa21140415524f8cee4f6d6b728c64d1)                   |       0    |         2 | 2022-10-30   |
| 1632 | [no](w/family/9662035810c738e760ef8ab03f60f1ba6f935111b56735d0baecce4217fc0390)                                                                                                 |       0    |         2 | 2024-01-22   |
| 1633 | [torzpi222 AT gmail dot com](w/relay/37DA4E982D98F675CD6A818F82EBA3473C7E1882)                                                                                                  |       0    |         1 | 2023-05-08   |
| 1634 | [gut morgen@: chumli26 at mail , 0//](w/relay/3816B2B2F6E23AEAF8EF7070476F6AB6B96AAF8B)                                                                                         |       0    |         1 | 2022-09-20   |
| 1635 | [stackTrace &lt;stack Trace admin AT proton DOT me&gt;](w/relay/383BC82F7560326BB9641DD1859A7A5AD7B1339F)                                                                       |       0    |         1 | 2024-04-26   |
| 1636 | [38580179](w/relay/38580179A84F44467C8C90B14B8E764D5AF42135)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1637 | [393D39B4](w/relay/393D39B40DBB557078CEF4921DBCF8CD2B8F7383)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1638 | [39B1854E](w/relay/39B1854EF3126C17E8E1A3F7CE44DDE8FB4DC2E8)                                                                                                                    |       0    |         1 | 2024-09-05   |
| 1639 | [39B521C5](w/relay/39B521C5F16C984400EECC4E2F83BF26E73F1D1D)                                                                                                                    |       0    |         1 | 2024-02-16   |
| 1640 | [39C2201A](w/relay/39C2201AE58F7EF3F6BF2C8A1BB5630ABF06FBF9)                                                                                                                    |       0    |         1 | 2024-02-13   |
| 1641 | [39DAFD42](w/relay/39DAFD42C4FDE8C26350226ED7F52F954606FB8B)                                                                                                                    |       0    |         1 | 2024-08-01   |
| 1642 | [Relay Operator &lt;tor AT jo-bu DOT eu&gt;](w/relay/39EAABC82D57DCBD2E2F063817B04F049ECEDC21)                                                                                  |       0    |         1 | 2024-12-16   |
| 1643 | [0xBDE438068A2BD353 postmaster@shh.sh](w/relay/39F096961ED2576975C866D450373A9913AFDC92)                                                                                        |       0    |         1 | 2019-02-18   |
| 1644 | [3A8EFB9F](w/relay/3A8EFB9F44CBC8A67408C525B3FEC9D3D73203C8)                                                                                                                    |       0    |         1 | 2024-03-24   |
| 1645 | [pasquino.cyblings.on.ca](w/relay/3A94EFBF4A220B35A92D0A5B4A80D6324C3C306A)                                                                                                     |       0    |         1 | 2024-02-27   |
| 1646 | [3B1A05FF](w/relay/3B1A05FFA64E53FE031D098DAD0C527563945741)                                                                                                                    |       0    |         1 | 2021-12-04   |
| 1647 | [3B557E3F](w/relay/3B557E3F0C29D4339A904AD8C641F582151FEF71)                                                                                                                    |       0    |         1 | 2022-06-02   |
| 1648 | [a-n-o-n-y-m-e.net](w/relay/3B5B6351330FA96EF3527A1BBB3F389C2310E8E6)                                                                                                           |       0    |         1 | 2024-05-05   |
| 1649 | [3BFB3C1C](w/relay/3BFB3C1C19B5E40D3889093DBD39000FE1D66FF3)                                                                                                                    |       0    |         1 | 2023-03-15   |
| 1650 | [3C19F134](w/relay/3C19F13472B01A86DCABD564D2E03C9DA99D61CC)                                                                                                                    |       0    |         1 | 2024-10-09   |
| 1651 | [0x18FFB9259E11C3BC69ABC8857E65272B32D3C971 f19.4jbg3@gmail.com](w/family/74683fef530f0a3be5f4e282087a726edf769b9665252a8f8f114dfd10283fd8)                                     |       0    |         2 | 2024-01-22   |
| 1652 | [3C931221](w/relay/3C9312214FBEFA1961B973DBBA5B3BE72AB52C39)                                                                                                                    |       0    |         1 | 2024-09-21   |
| 1653 | [dune.sheep5324@eagereverest.com](w/relay/3CB043214E1146F0AA7D98461D957E73DB6EA2BF)                                                                                             |       0    |         1 | 2024-12-20   |
| 1654 | [3CBC541F](w/relay/3CBC541F2A763ADD7BF742919229251E2C065E4E)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1655 | [js755956 at googles mail](w/relay/3CC1EFC9915CF181DAAE0A7B2EA1CC09C0E41588)                                                                                                    |       0    |         1 | 2024-08-17   |
| 1656 | [&lt;sunshinecowboy56 AT protonmail dot com&gt;](w/relay/3CEEAF497D470A560E4FC9A4523242F35A1594D0)                                                                              |       0    |         1 | 2024-05-12   |
| 1657 | [name is Blaze --- blazeready@Mail.com](w/family/947a6df30c23c6b66753dae9d0af9deb7359ad72e98709fb339ad9e5447fb6ba)                                                              |       0    |         2 | 2024-01-21   |
| 1658 | [Ralph Copeland &lt;copelandhosting AT pissmail dot com&gt;](w/relay/3D01CE600B2DC5C719684800E8C6990FE4CB8F9A)                                                                  |       0    |         1 | 2024-03-12   |
| 1659 | [fulloffaith -SPAM-CUTTOFF- @gmx.com](w/relay/3E26373D9F491C3C11FAE484E2A705611D019C02)                                                                                         |       0    |         1 | 2024-01-22   |
| 1660 | [Administrator &lt;torrelay dot photon AT mkfs dot xyz&gt;](w/relay/3EE79DA2EFC7F1728F8AA00460528C7699DFC9D0)                                                                   |       0    |         1 | 2024-06-29   |
| 1661 | [Admin &lt;mirror-admin AT nycbug DOT org&gt;](w/family/58d855d9c5405f0ab63d6a29b3910912676167b0b7b890728e39f168420f5969)                                                       |       0    |         2 | 2019-02-18   |
| 1662 | [3F1B13B1](w/relay/3F1B13B101DB4D043D0DA18272B8646D3132EE47)                                                                                                                    |       0    |         1 | 2023-03-11   |
| 1663 | [torowner@userzap.de](w/relay/3F7923F2971AC0FE591A854BAF21479026DC9A9A)                                                                                                         |       0    |         1 | 2022-06-22   |
| 1664 | [3FA8931A](w/relay/3FA8931AC69A0957F1C4F56DF8659FD3BBE42667)                                                                                                                    |       0    |         1 | 2024-06-19   |
| 1665 | [cbvhkks831@tormails.com](w/relay/3FBB6F16075E45BE8BC9BB7034D03A9B4EB6B6C7)                                                                                                     |       0    |         1 | 2024-01-22   |
| 1666 | [email:rascal washboard539 AT aleeas DOT com pgp:DF0FF776D2D70719405BBAB5827A](w/relay/4050E7CA7EA55A70CBB43A3A936BCC123CDE203F)                                                |       0    |         1 | 2024-03-04   |
| 1667 | [Jeroen Haadenvelt &lt;relay@otr.dreamhosters.com&gt;](w/relay/408234F6CC9B176A11005E39758D8C2C02A25C33)                                                                        |       0    |         1 | 2023-02-21   |
| 1668 | [408C9D2F](w/relay/408C9D2F1653D9EF3AF139C153CB27E8FFDB7612)                                                                                                                    |       0    |         1 | 2021-05-18   |
| 1669 | [torproject.disjoin051@8shield.net](w/relay/408FB77704942B1DDB836335B42C25BEA47BE59A)                                                                                           |       0    |         1 | 2024-12-04   |
| 1670 | [438731B8](w/relay/438731B8EFEDB1E592C8034934A55F532DEABAA9)                                                                                                                    |       0    |         1 | 2021-03-19   |
| 1671 | [auditore.ium@gmail.com](w/relay/441102D645B3496BEA4FA1F0DD98493CFCDE34BC)                                                                                                      |       0    |         1 | 2024-09-26   |
| 1672 | [obtusegiraffe proton me](w/relay/4422C3D7D2D5B1B8022B3EA300A9F79BEABA30D7)                                                                                                     |       0    |         1 | 2024-10-29   |
| 1673 | [442696DE](w/relay/442696DEADE7CC8D7A9AEAFED8865D5577C15174)                                                                                                                    |       0    |         1 | 2024-12-09   |
| 1674 | [44730B24](w/relay/44730B2450213BC3E2DAA4854458D134F0644FF2)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1675 | [447D96D3](w/relay/447D96D398F7E340B31D46347DB68E7FE83F8A5A)                                                                                                                    |       0    |         1 | 2021-03-09   |
| 1676 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/44D9262953FF8D30AA6638A995F2BCD3A2F9FACC)                                                                                          |       0    |         1 | 2021-09-05   |
| 1677 | [4561FC08](w/relay/4561FC085C3F3A7271FE960317F02DCD1E9C1188)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1678 | [jello@mail.ru](w/relay/457C05E39F2FE8DEB4A072259D63FF2FBF2945D4)                                                                                                               |       0    |         1 | 2024-07-10   |
| 1679 | [Jobi-Wanker-Nobi &lt;help me dot jobi wan AT gmail dot com&gt;](w/relay/460229771C96996C6BAB88070D11FA7135820378)                                                              |       0    |         1 | 2024-09-20   |
| 1680 | [Abuse at Texas4Tor dot com tor-relay.co](w/relay/4625F385CA5364CDD63C791893973B0CAD49C4E0)                                                                                     |       0    |         1 | 2021-02-07   |
| 1681 | [ricoswavez2@gmail.com](w/relay/4634824CE3F04CFAF30B0131D3E792CFC9007E53)                                                                                                       |       0    |         1 | 2024-01-22   |
| 1682 | [Bob &lt;exit000bob@gmail.com&gt;](w/relay/4637E79752D5086DD832564924DD455FC7D74683)                                                                                            |       0    |         1 | 2024-01-22   |
| 1683 | [beq90qfl@duck.com](w/relay/5B7800D3DD04094E9DAD7BEE5EABEA0BF785194B)                                                                                                           |       0    |         1 | 2024-06-08   |
| 1684 | [imreeil42gmailcom](w/relay/5BE0E93B27D10CF81C4B8CF437C818174DA103D9)                                                                                                           |       0    |         1 | 2022-12-19   |
| 1685 | [5BE910FB](w/relay/5BE910FB8F48C07136EAADDB9B053715556F001C)                                                                                                                    |       0    |         1 | 2024-08-28   |
| 1686 | [5C5A8CAF](w/relay/5C5A8CAFF797C413678D65A6B4B3F313DC796C75)                                                                                                                    |       0    |         1 | 2024-04-03   |
| 1687 | [garnettkirk@gmx.net](w/relay/5C7BCF29BFEA8779147F1E3EAD9A942B3105DC40)                                                                                                         |       0    |         1 | 2024-01-22   |
| 1688 | [root@bred.rocks](w/relay/5CD6007FB6EE485474409680B90F034E6B925A3B)                                                                                                             |       0    |         1 | 2022-05-13   |
| 1689 | [yumpy&lt;at&gt;fastmail&lt;.&gt;net](w/family/0816458e9ae0c4d79b32e3a0ec888b66a854d6d2c78a9f3cdaa1c12794949bed)                                                                |       0    |         2 | 2024-01-22   |
| 1690 | [1024D/CF154167 Eirik Oeverby &lt;ltning dash tor AT anduin dot net&gt;](w/relay/5D263037FC175596B3A344132B0B755EB8FB1D1C)                                                      |       0    |         1 | 2019-02-18   |
| 1691 | [Some Jerk &lt;heresy300 NOTAT gmail PERIOD com&gt;](w/relay/5D78D7D2A16F6B4D3166FD9D1FD4A715B14A56DF)                                                                          |       0    |         1 | 2018-11-20   |
| 1692 | [f3nrir fenrircodes@gmail.com](w/relay/5D94BAF4CA6315419937989D88E4E3143FDA1362)                                                                                                |       0    |         1 | 2024-12-14   |
| 1693 | [Random Person &lt;collard tethers0r AT icloud dot com&gt;](w/relay/5D95800B6875192F7CA94383A47450B34B291E08)                                                                   |       0    |         1 | 2024-01-22   |
| 1694 | [5E776347](w/relay/5E776347E2C27D12B0B49E141AD82834DF2E7B8D)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1695 | [andr788k at airmail dot cc tor-relay.co](w/relay/4954B51AF0CBADA08E4BC389DF1E3E419535165A)                                                                                     |       0    |         1 | 2021-02-17   |
| 1696 | [&lt;hellguard3 at gmx.de&gt;](w/relay/499FA01433320491216225801FE0589C250B4D6D)                                                                                                |       0    |         1 | 2019-02-18   |
| 1697 | [dangdongdai@lortemail.dk](w/relay/49CC8033C445AA0B05AD6C977BBC8DBDF4C519D1)                                                                                                    |       0    |         1 | 2024-01-22   |
| 1698 | [edd8990 AT gmail D0T com](w/relay/49D13F9940F1548219C4094AEF263995D616C875)                                                                                                    |       0    |         1 | 2023-02-07   |
| 1699 | [eliaseinarssontor@gmail.com](w/relay/49E2C213C6C2E1D8EA04DF7C9D959858AF1AED76)                                                                                                 |       0    |         1 | 2024-12-14   |
| 1700 | [postmaster@km30701-02.keymachine.de](w/relay/4A3B874F0187F2CF0DA3C8F76063B070F9F7A14F)                                                                                         |       0    |         1 | 2024-10-07   |
| 1701 | [4A4EFB3E](w/relay/4A4EFB3E9347189B6AB9453844692CCA1F46A4C7)                                                                                                                    |       0    |         1 | 2021-06-17   |
| 1702 | [4ADFDCEC](w/relay/4ADFDCEC41CFD3788FE7F3F3D3E4EA747B0C7045)                                                                                                                    |       0    |         1 | 2023-07-15   |
| 1703 | [Tor Operator &lt;tor-nodes at ventricle dot us&gt;](w/relay/4B0ABCCF8E5C3F69EBB821DD1BC1B4AE5118543B)                                                                          |       0    |         1 | 2024-11-10   |
| 1704 | [Tor-Admins &lt;toooor AT all DOT de&gt;](w/relay/4B170476D09459328438F3E68ED19516C9F75A80)                                                                                     |       0    |         1 | 2019-02-28   |
| 1705 | [sgtor AT protonmail dot com](w/relay/4B22C4A56F805C97D2F7D76F08EDA694EEFFC10D)                                                                                                 |       0    |         1 | 2022-01-03   |
| 1706 | [4726@ro.ru](w/relay/4B5CCD305BD5F1D7A5CA91733FF2BE3C8973091D)                                                                                                                  |       0    |         1 | 2024-09-18   |
| 1707 | [amerdude &lt;amerdude AT protonmail dot com&gt;](w/relay/4B5F487F893D6B77646CF8185B0B66A302AC2A65)                                                                             |       0    |         1 | 2022-07-12   |
| 1708 | [pazcthy@mail.com](w/relay/4B61EC04E1797D8688475BD24EDA450914497D84)                                                                                                            |       0    |         1 | 2023-07-31   |
| 1709 | [4B8AFF36](w/relay/4B8AFF36E16E664DCD9D793F4166CB2723D8454D)                                                                                                                    |       0    |         1 | 2024-04-11   |
| 1710 | [gizmo tor@proton.me](w/relay/4BC4F3CFFBCB96B31EE525633ABCC827BC8BFA94)                                                                                                         |       0    |         1 | 2024-02-01   |
| 1711 | [georgecartlidge@protonmail.com](w/relay/4BED68DF9EAF6C111D8778E19CC9AC7AFEC4FC02)                                                                                              |       0    |         1 | 2019-02-18   |
| 1712 | [4C114424](w/relay/4C11442493AB263FDBB8442BEAF76B52E83F5D0F)                                                                                                                    |       0    |         1 | 2025-01-05   |
| 1713 | [508D3420](w/relay/508D342041A247FFFA3A43A1E6993047052CF956)                                                                                                                    |       0    |         1 | 2024-08-27   |
| 1714 | [50E23506](w/relay/50E23506E5DC8576EB4E8F60751644364A3E13CE)                                                                                                                    |       0    |         1 | 2021-09-25   |
| 1715 | [pharoiste at protonmail dot com](w/relay/511432D725B79B1DB832865EFA87BE6C441CCF7E)                                                                                             |       0    |         1 | 2024-10-05   |
| 1716 | [Admin &lt;TOR AT tritonbase DOT com&gt;](w/relay/51374C8DA459C67329FFD5C7502CCAE4194910CC)                                                                                     |       0    |         1 | 2019-02-18   |
| 1717 | [tor@apt96.com](w/relay/5157D91F108496ED3BB97368BEEAA0C50E18EB48)                                                                                                               |       0    |         1 | 2024-01-22   |
| 1718 | [Random Person nobody@tor.org](w/relay/5160C286891817761B2EE225F8B1E9B701677E8A)                                                                                                |       0    |         1 | 2024-12-29   |
| 1719 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/family/1f7f9c9baf5b5f4fdaa721047a9dfe6ef5b94c621cd88413a864fba26e80a594)                                                                 |       0    |         2 | 2021-09-05   |
| 1720 | [51A8A229](w/relay/51A8A22944F228EA2D601434D127864B1B0B0F8C)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1721 | [51C009EB](w/relay/51C009EB367DA72E9EB64184E74CF5FDD5B39FF6)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1722 | [info@syndicateguys.com](w/family/146ce69c201710c56e7ada04fca862df4953fe8e52ed49d99c60e30688b398d0)                                                                             |       0    |         3 | 2024-01-20   |
| 1723 | [527BFB3C](w/relay/527BFB3CE819BE8D74C2A488B83A2F4332B878B5)                                                                                                                    |       0    |         1 | 2024-05-28   |
| 1724 | [52E6BF8C](w/relay/52E6BF8CD74CD1991520D04383D816AF2E921794)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 1725 | [Justagettingit@yahoo.com](w/relay/4C46583DDD0F1E8DA11E6E433EC0D10531F05AA2)                                                                                                    |       0    |         1 | 2024-12-06   |
| 1726 | [4C8302C3](w/relay/4C8302C3A6C80081C12BC5A8F9A38917BD923FBE)                                                                                                                    |       0    |         1 | 2024-09-08   |
| 1727 | [Tor Admin &lt;seijyaku@protonmail.com&gt;](w/relay/4C8E5F5558A496FF1DB20ADDC7AD263D36D9B250)                                                                                   |       0    |         1 | 2024-07-06   |
| 1728 | [4C9A5BC3](w/relay/4C9A5BC3351B59DE51107E61C0B2E28F67703F3A)                                                                                                                    |       0    |         1 | 2024-03-11   |
| 1729 | [kl &lt;kl.forwarder@gmail.com&gt;](w/relay/4CD4DFFEF3971C902A22100D911CAC639BE2EF5C)                                                                                           |       0    |         1 | 2019-02-18   |
| 1730 | [4D0D7918](w/relay/4D0D791850B7AA49C0E4520BF9445EBB3DC94563)                                                                                                                    |       0    |         1 | 2024-01-29   |
| 1731 | [4D4A285A](w/relay/4D4A285A4C122057A09D531FA1BB7958A99C1B74)                                                                                                                    |       0    |         1 | 2024-07-31   |
| 1732 | [4DB106F8](w/relay/4DB106F8F91EB1372EE4037DF37BC282E0BF20EE)                                                                                                                    |       0    |         1 | 2024-08-26   |
| 1733 | [4DC7A4FA](w/relay/4DC7A4FA8E26E2D49D03C5085B2E1E06DCF77E6D)                                                                                                                    |       0    |         1 | 2024-11-12   |
| 1734 | [4DECB03B](w/relay/4DECB03BD1176F5753E5301D9FC2ED7E68410B3B)                                                                                                                    |       0    |         1 | 2024-01-31   |
| 1735 | [4E41B00F](w/relay/4E41B00F930F3E72530F339EF4C911CE97D2AE9E)                                                                                                                    |       0    |         1 | 2020-02-13   |
| 1736 | [FlashTor at e.mail DOT de](w/family/c69eb69c89478a423d98d1b1c12972d03be66e1e59ff85a5163a740eb64c07e2)                                                                          |       0    |         2 | 2024-03-05   |
| 1737 | [4E5B4306](w/relay/4E5B4306A183F233908DD699C0D734A81EC28669)                                                                                                                    |       0    |         1 | 2023-05-18   |
| 1738 | [chirkrity6@privatemail.com](w/relay/4ED3097F3BACEE6DDCF761D6DEB132B63E50499D)                                                                                                  |       0    |         1 | 2024-12-20   |
| 1739 | [localvoid@tfwno.gf](w/relay/4EE61DA19F1F377058710DCCA78CEE265D18ED7F)                                                                                                          |       0    |         1 | 2024-09-24   |
| 1740 | [dandelionsavanna@memeware.net](w/relay/4EF43AE588B1EBA647742ED4431EB8E705140557)                                                                                               |       0    |         1 | 2024-03-30   |
| 1741 | [protonmail anel99anel99](w/relay/4F0E831A998B6442BAF41B6FB33D0B445E6AB238)                                                                                                     |       0    |         1 | 2022-04-03   |
| 1742 | [privacy@tor-for-privacy.com](w/relay/4F4341441DDB5410FE6F9346A760DB8DBC90A8A1)                                                                                                 |       0    |         1 | 2024-01-22   |
| 1743 | [theeric@yahoo.com](w/relay/4FC4CA86F9D892968F57D0D20E3B8B8FF6BB21EB)                                                                                                           |       0    |         1 | 2024-11-13   |
| 1744 | [jingojngo@gmail.com](w/family/d1de3a542de6090eb8734f1b76cc94fab5477b8f735eaf791a4dff05c1be0bcb)                                                                                |       0    |         4 | 2022-12-19   |
| 1745 | [John Packet admin@terrorism.network](w/relay/5603B5C58114835F2F35FBA5939EE2F25781779C)                                                                                         |       0    |         1 | 2024-08-08   |
| 1746 | [papayaowo ATSIGN tutanota D0T c o m](w/relay/56377E958B14C1FBAB4461966F3B4CFE594513BF)                                                                                         |       0    |         1 | 2022-11-29   |
| 1747 | [b0hazfsa@proton.me](w/relay/564FEF22CA0F1232D19AAD81051D2555585AF36B)                                                                                                          |       0    |         1 | 2024-12-08   |
| 1748 | [lay4play@protonmail.com](w/relay/568638C5B6A391BD274795C1EF1A567AFBC67CC4)                                                                                                     |       0    |         1 | 2023-08-18   |
| 1749 | [favorite0ne @proton.me](w/relay/56E9E80B813A69AA6B72E4B464A7154142EC45F6)                                                                                                      |       0    |         1 | 2024-01-21   |
| 1750 | [viator acht tuta daught io](w/relay/56F23D4E4BBDB89F4DE2774683961C9253EA4D8C)                                                                                                  |       0    |         1 | 2024-12-03   |
| 1751 | [5783B5ED](w/relay/5783B5EDC8F4E84FA04E6E5E249A03F271BB35C3)                                                                                                                    |       0    |         1 | 2023-01-18   |
| 1752 | [tor@as200490.net](w/relay/57C2A05132FA464CAAAD8D9B7323BF7702F91943)                                                                                                            |       0    |         1 | 2024-01-22   |
| 1753 | [unicron4687@proton.me](w/relay/57FCCBA36ECE0C6F9E17239B2051AC7CD77A5ACF)                                                                                                       |       0    |         1 | 2024-02-19   |
| 1754 | [580D16BB](w/relay/580D16BB71218090560F05FC77CFF900CCF5E6FD)                                                                                                                    |       0    |         1 | 2023-04-26   |
| 1755 | [tor-exit-1.allium.dev](w/family/273870e0e7e5969842469e42d16711e0711f142a033b9573ef7a58a99d2755c5)                                                                              |       0    |         2 | 2022-08-21   |
| 1756 | [torrelayoperator@tutanota.com](w/relay/58698C5E518D428DCA4D9780AD8379BB63B57B42)                                                                                               |       0    |         1 | 2022-04-13   |
| 1757 | [586D9093](w/relay/586D90935DF5C0F11DE8475B5A8D294F812A33C2)                                                                                                                    |       0    |         1 | 2025-01-05   |
| 1758 | [iblech@quasicoherent.io](w/relay/58A9921DD0A1389356634625C5B14ACC1194A95C)                                                                                                     |       0    |         1 | 2019-02-18   |
| 1759 | [bf two zero nine @mailbox.org](w/relay/58B81035FC28AACA8F0E85E46C8EBAD7FCFA8404)                                                                                               |       0    |         1 | 2024-01-22   |
| 1760 | [53CD0E93](w/relay/53CD0E93140E8E5C2AD2B14FBDFB0F402DB86CD6)                                                                                                                    |       0    |         1 | 2022-10-20   |
| 1761 | [fulffybunny690 at proton dot me](w/relay/53F65A431202F921693BCC295EFD96E1A1E03A53)                                                                                             |       0    |         1 | 2024-01-21   |
| 1762 | [tor-relays &lt;you know what belongs here&gt; mmap &lt;and here&gt; at](w/relay/541BCC842D0DAE9117F8CA2C19EF2B05034843E9)                                                      |       0    |         1 | 2021-12-14   |
| 1763 | [54406707](w/relay/5440670796CA7FCBF33C43EA681ED8142F3E2424)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1764 | [54713A1E](w/relay/54713A1E54A819E3C6CC0EBCAF725F285640F252)                                                                                                                    |       0    |         1 | 2023-07-07   |
| 1765 | [a-n-o-n-y-m-e.net](w/relay/54FAC042C6F2FDEB449DD5B9EDE6833D155C538B)                                                                                                           |       0    |         1 | 2024-02-02   |
| 1766 | [55125574](w/relay/5512557491F87D888FC485FF6484265A754ABF53)                                                                                                                    |       0    |         1 | 2019-02-28   |
| 1767 | [torowisko@grubelek.pl](w/relay/5558F546D2A996DD2F4B6A62A218DF23848452E3)                                                                                                       |       0    |         1 | 2024-03-02   |
| 1768 | [micah.sherr@georgetown.edu](w/relay/55808BA9B4228678BC1D300DF7A5479C5ED236D1)                                                                                                  |       0    |         1 | 2024-01-22   |
| 1769 | [Tor node&lt;t0r-n0d3@protonmail.com&gt;](w/relay/5582BBEC12380E34D7DFB8C237939A0B317B205E)                                                                                     |       0    |         1 | 2019-02-18   |
| 1770 | [jag@aangat.lahat.computer](w/relay/5589C16812A8E9C5BF1EB25EEC8060B877E24F56)                                                                                                   |       0    |         1 | 2023-07-19   |
| 1771 | [55A3EE1D](w/relay/55A3EE1DAFC4ED4C3BE761B563BE13D130A7A9BE)                                                                                                                    |       0    |         1 | 2024-08-14   |
| 1772 | [torop &lt;at&gt; viking-sec &lt;dot&gt; xyz PGP:3297FA41D3C0E3E5FFD17DE9ADA62A499CB344B0](w/relay/55C6187EB2BEBC968F4C89D25F4350889E6BC251)                                    |       0    |         1 | 2024-11-02   |
| 1773 | [top@imap.cc](w/relay/5E91569DFB8FEC2B5ACE8B9D7D0C17B2C7BE1C04)                                                                                                                 |       0    |         1 | 2021-11-04   |
| 1774 | [newMauriceKSanders@proton.me](w/family/4f093393dce0c42e39728455c69c3ef44df76e2c221b4e4f8c9bad5f387ba3e0)                                                                       |       0    |         2 | 2024-12-25   |
| 1775 | [your friendly tor relay operator/ Ulie Dein / CommanderDein @ proton.me](w/relay/5EF4629DB729712EF7FECBA74533BBF06704E00D)                                                     |       0    |         1 | 2024-02-24   |
| 1776 | [5F1027BC](w/relay/5F1027BC25FA7E6389329737C78437A0C3617C78)                                                                                                                    |       0    |         1 | 2024-10-27   |
| 1777 | [andronikos sys@mail.ru](w/relay/5F6FBB9B007F7E5F6E73BCD2012437815E23139F)                                                                                                      |       0    |         1 | 2024-02-05   |
| 1778 | [5F875CFB](w/relay/5F875CFB7E2ED0D24E85A5A8B8904A3650AB1ED8)                                                                                                                    |       0    |         1 | 2021-10-05   |
| 1779 | [torop &lt;at&gt; viking-sec &lt;dot&gt; xyz PGP:3297FA41D3C0E3E5FFD17DE9ADA62A499CB344B0](w/relay/5F9642ECCF123EB013DCB974785D89AEAB66EFA5)                                    |       0    |         1 | 2024-11-02   |
| 1780 | [605761CF](w/relay/605761CFF0C98AA44548D5F63D2F4EEADF2E752B)                                                                                                                    |       0    |         1 | 2024-03-08   |
| 1781 | [petrarca.codeberg.page](w/relay/605EE4375EE4C38215C8949F5808863749FD4F4A)                                                                                                      |       0    |         1 | 2019-02-18   |
| 1782 | [606546BC](w/relay/606546BC4777C92E87F58254ACBDA4ADE59139B4)                                                                                                                    |       0    |         1 | 2024-10-21   |
| 1783 | [6078F300](w/relay/6078F300B379D8DEBCF02DBE80881C94777E24BF)                                                                                                                    |       0    |         1 | 2021-01-18   |
| 1784 | [onemillionbeersplease@proton.me](w/relay/60D623304BE6149222724663DAFABCED3DF40F5C)                                                                                             |       0    |         1 | 2024-12-15   |
| 1785 | [60F2139E](w/relay/60F2139EA3E06410A05CBD6E8254E60A9063AD9D)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1786 | [60F9F46C](w/relay/60F9F46CBC80FF396BDD86B43A6DCBE5F4411B30)                                                                                                                    |       0    |         1 | 2023-01-28   |
| 1787 | [Aqua Ray Tor Operators &lt;tor-operators-fr at aquaray dot com&gt; 19rUv8F1y1xc2fL](w/relay/616081EC829593AF4232550DE6FFAA1D75B37A90)                                          |       0    |         1 | 2019-02-18   |
| 1788 | [vollborn@quantentunnel.de](w/relay/6169E481F106F1A2CAA6D9DB77B86DFF6546224A)                                                                                                   |       0    |         1 | 2024-06-08   |
| 1789 | [0xDEADBEEF Dead Beef &lt;ops@not.org&gt;](w/relay/616A3C5B3B3AB09547768C063D2D324B19CF2744)                                                                                    |       0    |         1 | 2022-06-02   |
| 1790 | [6184E90C](w/relay/6184E90C75184C4B6BD6D5E3823C58A4B9CB5ED6)                                                                                                                    |       0    |         1 | 2024-01-21   |
| 1791 | [torservers.net](w/relay/59267EC3DC757CF850DA0F5AF03AB5E69C75FEB7)                                                                                                              |       0    |         1 | 2023-01-08   |
| 1792 | [59844561](w/relay/5984456114AE4F8FA73E0BE8BF441A347C878CDD)                                                                                                                    |       0    |         1 | 2024-06-21   |
| 1793 | [quetzalcoatl-relays.org](w/relay/59A5BACFE32B6CA0F8F67B6621B3E8B89312CB7A)                                                                                                     |       0    |         1 | 2020-12-29   |
| 1794 | [59E87D02](w/relay/59E87D02E0CE173608EE4FF14A6F8621CE8A71E9)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1795 | [5A19FE57](w/relay/5A19FE5784EBB6A9EA848163E8A403C85B8CF530)                                                                                                                    |       0    |         1 | 2024-03-25   |
| 1796 | [thomsonrichard316@gmail.com](w/relay/5A2CF712561C87BDECB4F5AFCEF673401C994CB1)                                                                                                 |       0    |         1 | 2024-01-21   |
| 1797 | [tartedge2 @ gmx.com](w/relay/5A3319CD08B9334B21A3A2D0A51435BB88E46672)                                                                                                         |       0    |         1 | 2022-09-30   |
| 1798 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/5A6AD8BFBA74F646822996EC03FD3484353A41B3)                                                                                          |       0    |         1 | 2021-09-05   |
| 1799 | [&lt; onion-exit @ /stagingdomain- dot -name&gt;](w/relay/5AA6370205AA611CED967BDB4D8EBCB9D5DB57A9)                                                                             |       0    |         1 | 2021-06-27   |
| 1800 | [none](w/relay/5AAE8FF69FD816A47D5A48D0EB6F75176921DBA4)                                                                                                                        |       0    |         1 | 2022-11-29   |
| 1801 | [5ABC06A8](w/relay/5ABC06A8B1276EC851958237260EAE88DA07631E)                                                                                                                    |       0    |         1 | 2024-03-18   |
| 1802 | [fuentescielo@cock.li](w/relay/5AC002A3FE3FFCF0FCC66A75FCFFC1F4B3786BDD)                                                                                                        |       0    |         1 | 2024-04-16   |
| 1803 | [5AF1D601](w/relay/5AF1D6019200F1F9D0F9ECB4DD0724862ABE7B20)                                                                                                                    |       0    |         1 | 2023-06-07   |
| 1804 | [poppy434@proton.me](w/relay/5B3B3E09BA5F1EB6F72A04FEAD81D9ACB88F8934)                                                                                                          |       0    |         1 | 2024-01-29   |
| 1805 | [SPEEVES gmx.com](w/relay/5B5ADDC0911F5B5184DE6601308A655DDBA724B1)                                                                                                             |       0    |         1 | 2024-01-21   |
| 1806 | [mineestasedmateo@proton.me](w/relay/832B026E81B2DBDCA820C3DF1951DE9DBE181F7E)                                                                                                  |       0    |         1 | 2024-08-30   |
| 1807 | [8330C8C5](w/relay/8330C8C52A4DC562135369D317D86887BBFE1685)                                                                                                                    |       0    |         1 | 2022-03-24   |
| 1808 | [greorod1206@gmail.com](w/relay/83394E5B57988EFAD5102F1AF0E19E6FFCF8842A)                                                                                                       |       0    |         1 | 2023-06-03   |
| 1809 | [Vm9ydCA8dnZvcnRAeWFuZGV4LnJ1Pg==](w/relay/835FFE642EFA3BB7936663D2365A15D319FB6226)                                                                                            |       0    |         1 | 2019-02-18   |
| 1810 | [Random Person &lt;collard tethers0r AT icloud dot com&gt;](w/relay/83BADBCC825EAC0661592831ED4D30214C5B997F)                                                                   |       0    |         1 | 2024-01-22   |
| 1811 | [8404E8B8](w/relay/8404E8B8AAB98208FAEFB1727B637133AD9C6FAF)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1812 | [elzpiraten.de](w/relay/841A6A7A53432F8A6B36D6A3083FE0E29899469C)                                                                                                               |       0    |         1 | 2021-09-15   |
| 1813 | [84D065ED](w/relay/84D065EDDA84FF530EEBC0757FDE82F08DA905C9)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 1814 | [Tor Person &lt;daotorrelay X gmail.com&gt;](w/relay/84E9A6110F9D4DB7727DCEF5AFD5D05CCEEC627C)                                                                                  |       0    |         1 | 2023-04-04   |
| 1815 | [remops@frell.theremailer.net](w/relay/852E575AB1E18815595112414879734F8DFA6952)                                                                                                |       0    |         1 | 2024-01-29   |
| 1816 | [gregorywilliams@firemail.de](w/family/ce5e67933f8846ea5df9c6da127f1c597ca6f1ac751778f6728c62eb346cc5d8)                                                                        |       0    |         2 | 2025-01-16   |
| 1817 | [86157CEC](w/relay/86157CEC3B63D506E6F3AF3B9AB872E395164A3B)                                                                                                                    |       0    |         1 | 2024-06-19   |
| 1818 | [86592C7B](w/relay/86592C7B50D952634852C814FA43C745EE55F947)                                                                                                                    |       0    |         1 | 2023-07-15   |
| 1819 | [6565F31D](w/relay/6565F31D9EC0C7DFFEA1920BE3BA4C73EF35B5C4)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1820 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/658DC209748B0292D4EDE90082256CB3E9658585)                                                                                          |       0    |         1 | 2024-09-22   |
| 1821 | [abuse at texas4tor dot com tor-relay.co](w/relay/65CD45F3FAB6CCE8D71A5A9D2EE010A52B369068)                                                                                     |       0    |         1 | 2021-10-25   |
| 1822 | [email:Contact.HexaNode@protonmail.com ciissversion:2](w/relay/666666E5355E4716F27B1A630EF6A7B4D6D3BAB9)                                                                        |       0    |         1 | 2024-10-15   |
| 1823 | [anus@anus.null](w/relay/66715F3BA8DF67A43AAB17B19235A987A9E803F8)                                                                                                              |       0    |         1 | 2024-10-20   |
| 1824 | [meno@mnins.rsa](w/relay/668FEE54D1219AEE0CE2F361AFAC844E97A78E70)                                                                                                              |       0    |         1 | 2024-12-09   |
| 1825 | [669102E6](w/relay/669102E6FA8E116AC05FE823B0634B44499944E3)                                                                                                                    |       0    |         1 | 2021-03-19   |
| 1826 | [66B1DB0E](w/relay/66B1DB0E5E49DDFF3D5BF7DD3E7D8B3B9E2D92A6)                                                                                                                    |       0    |         1 | 2024-10-15   |
| 1827 | [&lt;me@nasrag.com&gt;](w/relay/66C7803C5F95CEC0D78004E15A0E4399CD0E4787)                                                                                                       |       0    |         1 | 2024-04-12   |
| 1828 | [unshakled@proton.me](w/family/c06f3ff86419a99bdc578f4ca7dec103dde023f41fcc437a297dc801ac2fbb97)                                                                                |       0    |         2 | 2024-11-15   |
| 1829 | [email: bigul AT tutanota DOT com](w/relay/66FB8688C203C247CEA828209FB4901D4BDCF4B9)                                                                                            |       0    |         1 | 2024-08-17   |
| 1830 | [phase 06 wheeled@icloud.com](w/relay/66FF7CD265B576EFE202F0AEB6E579AD08C40501)                                                                                                 |       0    |         1 | 2024-01-22   |
| 1831 | [email:mikefloyd2 protonmail.com](w/relay/671A68ABADA1402FB00676055F48EA123B9B060C)                                                                                             |       0    |         1 | 2020-03-04   |
| 1832 | [671D4E22](w/relay/671D4E22D6BD3846A4167107927E6984326357FF)                                                                                                                    |       0    |         1 | 2024-08-02   |
| 1833 | [67300B05](w/relay/67300B05F32FEC914DA6EFDC5C59F8722A1A763C)                                                                                                                    |       0    |         1 | 2023-01-08   |
| 1834 | [6755C086](w/relay/6755C086E6D13A245D280257D1DB51FF72043821)                                                                                                                    |       0    |         1 | 2024-10-31   |
| 1835 | [676AC4EF](w/relay/676AC4EFC828DCC303DF90076DA54532DE852356)                                                                                                                    |       0    |         1 | 2022-10-20   |
| 1836 | [67734744](w/relay/677347441FDD2AEA22BD364A7174D277E929B255)                                                                                                                    |       0    |         1 | 2022-08-31   |
| 1837 | [6189F069](w/relay/6189F0691D8AD1CBB373CAD3906E72238AC4364F)                                                                                                                    |       0    |         1 | 2021-01-18   |
| 1838 | [belldaddy@tuta.io](w/relay/61E4AFF2B1DEDDE340BBEA099A8CE4795D0DC8D8)                                                                                                           |       0    |         1 | 2024-03-10   |
| 1839 | [620562B7](w/relay/620562B7EA252030D579134EDC5045BA83C5F10D)                                                                                                                    |       0    |         1 | 2024-01-25   |
| 1840 | [6214C736](w/relay/6214C7367A88EFC1894A6A3F25DB06B795B7A47A)                                                                                                                    |       0    |         1 | 2025-01-07   |
| 1841 | [Wytchwulf tor.unblock472@passinbox.com](w/relay/626CB9465F7E6EDE19930CBAE26A55D5A4E2F8DF)                                                                                      |       0    |         1 | 2024-10-19   |
| 1842 | [6280442F](w/relay/6280442F50474BE281F26A507F45CE6F22147650)                                                                                                                    |       0    |         1 | 2024-01-27   |
| 1843 | [62A123B8](w/relay/62A123B8631CA66D8061D5001DDA5DD5D2947C85)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 1844 | [sysadmin@klaxzy.net](w/relay/62D44E798DD7167E32CE2B3B18ADBFCB8590EDEB)                                                                                                         |       0    |         1 | 2025-01-15   |
| 1845 | [yourEmail@example.com](w/relay/62D6C002FA771B40C62C352406EABABACD2C0C58)                                                                                                       |       0    |         1 | 2025-01-14   |
| 1846 | [biff](w/relay/62DFE044582D796FF0DDF4D8382210AD01C6CAC6)                                                                                                                        |       0    |         1 | 2024-07-01   |
| 1847 | [tor@gnu.style](w/relay/62E4B756B23DFA3B26555A12D0EA4C641CF0C19F)                                                                                                               |       0    |         1 | 2024-01-21   |
| 1848 | [d@guyone.net](w/relay/630C50D3449206B7F2A536098BB2A9C7B4326AD9)                                                                                                                |       0    |         1 | 2023-03-17   |
| 1849 | [creepychris @ protone.me](w/relay/6319F26F9707CC74495C271C47DBE07A94775621)                                                                                                    |       0    |         1 | 2024-02-21   |
| 1850 | [authentic-tor@yahoo.com](w/relay/635AA7ACB5FD046A0082C72DABD9AE9D123B4ECC)                                                                                                     |       0    |         1 | 2024-01-21   |
| 1851 | [Eric L &lt;tor@inconnu.club&gt;](w/relay/637A3233320D57D969841BF5D8D0AD82CABFDB46)                                                                                             |       0    |         1 | 2023-01-18   |
| 1852 | [637CAFD5](w/relay/637CAFD50F46D4E1127CD97BD2F32CEF108134A0)                                                                                                                    |       0    |         1 | 2024-10-21   |
| 1853 | [63DC9A6E](w/relay/63DC9A6E8C908502EA3F741108BA7A4652958FCB)                                                                                                                    |       0    |         1 | 2024-09-19   |
| 1854 | [red0queen tor@red-net.info](w/relay/63E7D653A264A96CBF7C207AADB3D17D96485F6A)                                                                                                  |       0    |         1 | 2024-11-08   |
| 1855 | [644A1E27](w/relay/644A1E27DE0868FD04C1E2D3C732F12E069C57A1)                                                                                                                    |       0    |         1 | 2024-11-20   |
| 1856 | [cl1ps.geamy at protonmail dot com](w/relay/6465578393CD74400E68E8A9F09B5375C1BB5C24)                                                                                           |       0    |         1 | 2025-01-16   |
| 1857 | [64B05F9A](w/relay/64B05F9A2122B5DB4ADCB0E6F083193F3170A902)                                                                                                                    |       0    |         1 | 2024-10-08   |
| 1858 | [spamd20@gmail.com](w/relay/64CB2B32C10ADD4B93D725B7DED238CCCD6D6DBA)                                                                                                           |       0    |         1 | 2024-02-18   |
| 1859 | [middleanony1552@proton.me](w/relay/64E0CFFB86ECF5519EFDAF00C0DDA5672DB2C806)                                                                                                   |       0    |         1 | 2024-04-05   |
| 1860 | [sillasombrosa pm me](w/relay/64E7278703021709E9187232BE779058D2D431A1)                                                                                                         |       0    |         1 | 2023-01-28   |
| 1861 | [7FE13A85](w/relay/7FE13A85EDA30177E2D74E28EE21230E0599C82F)                                                                                                                    |       0    |         1 | 2024-11-22   |
| 1862 | [no@autographs.for.you.local](w/relay/7FE42BCEB4EBFB33458FB37B388502C4C7D7225D)                                                                                                 |       0    |         1 | 2024-09-23   |
| 1863 | [fritohlays@fastmail.com](w/relay/7FE7D3A5B11CCA6D2BC37F83B5674CF28F4B2FAD)                                                                                                     |       0    |         1 | 2024-01-22   |
| 1864 | [jajtor@comcast.net](w/relay/804B194853453589A80FB9A7D42AE65C19223D9C)                                                                                                          |       0    |         1 | 2024-01-21   |
| 1865 | [806778E1](w/relay/806778E173CC7111767B89CA5F34CAF197E6CB3A)                                                                                                                    |       0    |         1 | 2023-04-24   |
| 1866 | [806E6AB6](w/relay/806E6AB6E4BCFFA3A37F837DE94AFF6EB18CE94A)                                                                                                                    |       0    |         1 | 2024-04-03   |
| 1867 | [unixeno@cubicchaos.net](w/relay/80914004BD527CE984A1576CA63AAA77944D9D2B)                                                                                                      |       0    |         1 | 2024-01-22   |
| 1868 | [TARS@ro.ru](w/relay/813358AB9526F59E92B710C8A8DA79D870670E07)                                                                                                                  |       0    |         1 | 2024-08-22   |
| 1869 | [81484BEC](w/relay/81484BECE824F7E25856264F8B69D2F341ECEB9E)                                                                                                                    |       0    |         1 | 2024-10-21   |
| 1870 | [815AE924](w/relay/815AE924755F1E63986E434A92A88EA1F75A60A3)                                                                                                                    |       0    |         1 | 2021-01-08   |
| 1871 | [81AE230D](w/relay/81AE230D4E2915CC562C0D202D19B3F0F385144A)                                                                                                                    |       0    |         1 | 2022-03-14   |
| 1872 | [81F95687](w/relay/81F95687D4557BC9D72D9A6E939BA3DF5A3F8B38)                                                                                                                    |       0    |         1 | 2024-10-30   |
| 1873 | [email: bigul AT tutanota DOT com](w/relay/820C5B32755B70C32BACE0A4ABAB82E3B8099AF0)                                                                                            |       0    |         1 | 2024-06-13   |
| 1874 | [rgzxwythod at p dot monash dot edu](w/relay/82431709D1C0284A93FF09B090FE00E627A2F8BB)                                                                                          |       0    |         1 | 2024-06-01   |
| 1875 | [art4096 proton mail](w/relay/825365C44650897970F158574AF29D42A33DE541)                                                                                                         |       0    |         1 | 2022-09-30   |
| 1876 | [825A21F2](w/relay/825A21F2436B203A6A91A0D107A75DAD19FE4DF7)                                                                                                                    |       0    |         1 | 2024-01-21   |
| 1877 | [&lt;tormuks AT proton dot me&gt;](w/relay/8294950D56499310A753AFCCD1F3D53F236EE845)                                                                                            |       0    |         1 | 2025-01-05   |
| 1878 | [chicken at national.shitposting.agency](w/relay/82A4D90F294126A0A66B5BD66AAD313FE5EB3C22)                                                                                      |       0    |         1 | 2024-05-05   |
| 1879 | [sabotage.net](w/relay/82E2708957A41EDA0819EE1C5FFC3E2DC38B9FE9)                                                                                                                |       0    |         1 | 2024-01-22   |
| 1880 | [shallotrelay at fedora dot email](w/relay/831DD5C974E0152DFDF731A694DEDBF4D0D5F5E5)                                                                                            |       0    |         1 | 2024-01-21   |
| 1881 | [Admin &lt;tor.uncharted624@passmail.net&gt;](w/relay/6796C85E7E1D547CAEC9D5CED6DE9068187288C6)                                                                                 |       0    |         1 | 2024-01-21   |
| 1882 | [Scott Maxwell tor-contact-2022-delphi at scottmaxwell dot org](w/relay/67A6C08D99EAF6180AF3FB1C6026FC6B7B2A7632)                                                               |       0    |         1 | 2022-11-19   |
| 1883 | [emeraldonion.org](w/relay/686486E748AA8C360A57E81E4ED915479740AF61)                                                                                                            |       0    |         1 | 2024-07-26   |
| 1884 | [68A1D590](w/relay/68A1D590EBD398679DF883DFEFB3C90EE9B547A8)                                                                                                                    |       0    |         1 | 2022-10-30   |
| 1885 | [690C1908](w/relay/690C190822B240351DD1A19D0337E8373B1290E8)                                                                                                                    |       0    |         1 | 2020-07-02   |
| 1886 | [692DFAD6](w/relay/692DFAD65AB8F44690B6F55DBB9C9F594ACED3AC)                                                                                                                    |       0    |         1 | 2024-09-16   |
| 1887 | [696D1020](w/relay/696D1020A9112D3F9F188BC632234A18F9268C17)                                                                                                                    |       0    |         1 | 2024-10-07   |
| 1888 | [698B8708](w/relay/698B8708CF4EA02D27CA09274F3351B4F66A5834)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 1889 | [tor-operator@theu.li](w/relay/69B632F8B2BD3B59B3849C8072DB097A53A2D71A)                                                                                                        |       0    |         1 | 2024-11-15   |
| 1890 | [sepherimorth@protonmail.com](w/relay/69D836A3A3FA83F192A47278905A83E72213C85E)                                                                                                 |       0    |         1 | 2024-01-22   |
| 1891 | [Tobias Meggendorfer Mail:&lt;tobias .AT. meggendorfer .DOT. de&gt; PGP:B8FBA00C](w/relay/6A1AF5C55985A32E44462D3F5CFEB1701418D9DC)                                             |       0    |         1 | 2020-08-31   |
| 1892 | [tor at rbuc dot de](w/relay/6A365870758A1E3E7A9EE0E82BCC0D6226A9EAAA)                                                                                                          |       0    |         1 | 2020-01-04   |
| 1893 | [6A6F6DDA](w/relay/6A6F6DDA0C1F07FEC3A21E4401EE235336EC6ED9)                                                                                                                    |       0    |         1 | 2021-01-08   |
| 1894 | [none](w/family/16faf099921a0d55d301748d269f9dc1c9068108023f9d99e3e8e02924f1753e)                                                                                               |       0    |         2 | 2024-02-01   |
| 1895 | [torrelay2112@pm.me](w/relay/6ADF49B3CFDF755B7DD8F8976C7AD45AF3750A06)                                                                                                          |       0    |         1 | 2024-03-11   |
| 1896 | [reversed: em tod notorp ta yalermar](w/relay/6BBCEDA64F82850616E09BCA9AC9A0DB5089FD0E)                                                                                         |       0    |         1 | 2024-07-23   |
| 1897 | [your@e-mail.com](w/relay/6BBDA77856BEF16F35EA8606C6C9DC8312426811)                                                                                                             |       0    |         1 | 2024-12-25   |
| 1898 | [4727@ro.ru](w/relay/6C1295065C5AFE74BDC49779050CD6D476FB901C)                                                                                                                  |       0    |         1 | 2024-09-02   |
| 1899 | [Random Person &lt;nobody AT example dot com&gt;](w/relay/6C69CDA6BDD0C747DD6B89BCAB355A618A60705B)                                                                             |       0    |         1 | 2024-08-03   |
| 1900 | [blualism@pm.me](w/relay/6C81102090DCB8228DD717046FF2C05494A045C0)                                                                                                              |       0    |         1 | 2024-04-03   |
| 1901 | [&lt;PabloReturnss@protonmail.com&gt;](w/relay/6C880630B43354514049DCFEE37A05D80766A72F)                                                                                        |       0    |         1 | 2022-04-03   |
| 1902 | [no-spam@example.com](w/relay/6C8FAF1A64CF7D4B956FC20FB94F8D1F94D18FFE)                                                                                                         |       0    |         1 | 2025-01-15   |
| 1903 | [segfault123@protonmail.com](w/relay/6CB09DD5F42B741F416BDB6BE0E0CD3792CF3947)                                                                                                  |       0    |         1 | 2024-08-08   |
| 1904 | [6D6F015D](w/relay/6D6F015D41025CFF1565BF32B02A228FA45B1309)                                                                                                                    |       0    |         1 | 2024-12-20   |
| 1905 | [6DA6D574](w/relay/6DA6D5747A1BDD4F9CFCB26F9572B035BA78AD14)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1906 | [Jordan Belfort &lt;StrattonsOakmont@proton.me&gt;](w/relay/6DB45655F558E300E59683EF55E2E39B3605F8DF)                                                                           |       0    |         1 | 2024-01-21   |
| 1907 | [a-n-o-n-y-m-e.net](w/relay/6F6CE59AC456500E505D82AF09ADFC583022DB87)                                                                                                           |       0    |         1 | 2024-01-22   |
| 1908 | [cheery.bed9346@fastmail.com](w/relay/6FA99E37157B0580413F696A714D84DE935BFE5B)                                                                                                 |       0    |         1 | 2023-02-27   |
| 1909 | [0xDE54A0BA TOR Admin &lt;jandrese@vt.edu&gt;](w/relay/6FC8D3B152054906417CB1EE0642265747C7F689)                                                                                |       0    |         1 | 2019-02-18   |
| 1910 | [tor.yyzz.dev](w/relay/6FF69B7CBB0EB8B905F343AC6B1A3215471E4E42)                                                                                                                |       0    |         1 | 2023-04-22   |
| 1911 | [tor.saru.moe](w/relay/7040C1F5728746C5FB5E12845101A26EE8636D7E)                                                                                                                |       0    |         1 | 2022-06-22   |
| 1912 | [4096R/0xC1FD909980E93558 L29Ah &lt;l29ahtor@riseup.net&gt; - bc1q650syxwaygmzw3793j9k](w/relay/7044955A4D7B04CF70011D73B467B13CE5E69D41)                                       |       0    |         1 | 2019-02-18   |
| 1913 | [contact@lmtlabs.com](w/relay/706B5CF92E3FFF58034B8551573E8CCE80582661)                                                                                                         |       0    |         1 | 2025-01-15   |
| 1914 | [7155DE90](w/relay/7155DE90C1C3C9BF4D637580C7F027E57227BD30)                                                                                                                    |       0    |         1 | 2022-08-21   |
| 1915 | [dumpma1l at proton-me](w/relay/715A025049C00AEF0B1F003F10E26D2740F1AA5C)                                                                                                       |       0    |         1 | 2024-05-05   |
| 1916 | [relay@ro.ru](w/relay/71C29CA53C9F913B3692B8DD957D245E10AA7EB6)                                                                                                                 |       0    |         1 | 2024-08-08   |
| 1917 | [c3rax &lt;c3rax@chaos-system.de&gt;](w/relay/71EE3FE7DCC3F088309361A4E35843B6080C9EA5)                                                                                         |       0    |         1 | 2022-08-11   |
| 1918 | [Nobody &lt;nobody AT null dot com&gt;](w/relay/720880F971521B0046F1D346B34631B6AB30F204)                                                                                       |       0    |         1 | 2024-08-30   |
| 1919 | [720DCBD0](w/relay/720DCBD01B20848C180AE0705CBFE25F8A78162C)                                                                                                                    |       0    |         1 | 2024-01-30   |
| 1920 | [tor2.xn--sb-lka.org](w/relay/72614C16C578D6732A9D9079A0905E8159BC44E4)                                                                                                         |       0    |         1 | 2020-08-21   |
| 1921 | [ramin dot schreur at mail dot com](w/relay/7265075D62051D8125661309062B92AE136BB216)                                                                                           |       0    |         1 | 2022-04-03   |
| 1922 | [7292A50B](w/relay/7292A50BE1A74C32C578CB430E65A9CFBADBCB71)                                                                                                                    |       0    |         1 | 2024-11-28   |
| 1923 | [txrworlds.net](w/relay/730219EC37A77E2A9C3564BCFE32A8B2F4189BA3)                                                                                                               |       0    |         1 | 2024-07-07   |
| 1924 | [1187 EF45 9760 66ED 5AB5 5D50 9755 3391 D0BF 49BA Norris Thomlinson &lt;norris@akti](w/family/cf7b416eeab8270c1e96ebeeb97ecf1b46fc63d03b99a499342e6491de9f1d9d)                |       0    |         2 | 2019-02-18   |
| 1925 | [73A32BE0](w/relay/73A32BE001B5085C30DEBDD06B2728BB0AB6436A)                                                                                                                    |       0    |         1 | 2021-03-09   |
| 1926 | [dodo.pm](w/family/eee7a20ad89ef7bc0995558984d79f14d8c9af9f6495263a42b5c8a92256a552)                                                                                            |       0    |         2 | 2021-02-27   |
| 1927 | [anarchyrelay@proton.me](w/relay/74B328088AF5F0170B19034CAEB335F920DAADAA)                                                                                                      |       0    |         1 | 2024-08-25   |
| 1928 | [74B7B2DD](w/relay/74B7B2DD3F912DBF074A21C23E38909F1C9AB757)                                                                                                                    |       0    |         1 | 2024-01-29   |
| 1929 | [EdK &lt;ed@atl.org&gt;](w/relay/74DFE78731F875B6665E04E5751BB667C66784DB)                                                                                                      |       0    |         1 | 2023-05-02   |
| 1930 | [tor-admin-d8ufaqtfj3x7@xutrox.com](w/relay/74EF2F2181B0F9A2AC08EBE1C3F5AC2C6FFFFA94)                                                                                           |       0    |         1 | 2024-01-29   |
| 1931 | [7502C638](w/relay/7502C6382100A6FF1D40DC3546733116FFD66576)                                                                                                                    |       0    |         1 | 2024-08-19   |
| 1932 | [75979637](w/relay/759796379B0EFF08487F3265B0E1B3BE2CE2343C)                                                                                                                    |       0    |         1 | 2024-06-21   |
| 1933 | [75F0AC44](w/relay/75F0AC44A8C6702FEA5D7C08B8440EA8B83E84D6)                                                                                                                    |       0    |         1 | 2024-08-16   |
| 1934 | [uwu.relays.presoak798@passinbox.com](w/relay/765F64FBF878DCBCFC9D12A135BC389AD6BE2024)                                                                                         |       0    |         1 | 2024-02-12   |
| 1935 | [teitel.net](w/family/0c8dbd3e2711faa5e704ffd38cb72f4fe72f22cb7f5795170f35d60178eac38f)                                                                                         |       0    |         2 | 2019-12-25   |
| 1936 | [&lt; roswell a ufoencounter - site &gt;](w/relay/770894EB400F609B1F95A14A4A5FE163236EA333)                                                                                     |       0    |         1 | 2024-11-04   |
| 1937 | [noc@as210630.net](w/family/ae873d10502be5fc88dbe7f89e590ff9a8f66b8263fbb6c5d71c3e0ad9cab8be)                                                                                   |       0    |         3 | 2025-01-10   |
| 1938 | [Any Body &lt;info@vif.com&gt;](w/relay/77299CB6688C4ACE0FEE06CDC8EC4C922978C7FF)                                                                                               |       0    |         1 | 2022-01-23   |
| 1939 | [7754F613](w/relay/7754F613669B52EF674DD7D8F18D712DD7A40D5A)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1940 | [scofflaw@mailfence.com](w/relay/77D85A7CE40DA25AEDB73AA2D8762C547BE287F2)                                                                                                      |       0    |         1 | 2024-11-05   |
| 1941 | [the most average person@proton.me](w/relay/785059BC7B4A27A96868C675040FFC119AE9A79C)                                                                                           |       0    |         1 | 2025-01-02   |
| 1942 | [7872E9CC](w/relay/7872E9CC5E23E9B0A24F22FA382D7E4D647BAC82)                                                                                                                    |       0    |         1 | 2024-12-17   |
| 1943 | [78793B4C](w/relay/78793B4CFED62273486E64A0DCAF83E5B7AA3DF5)                                                                                                                    |       0    |         1 | 2025-01-09   |
| 1944 | [&lt;uncharted update304 at simplelogin dot com&gt;](w/relay/78B4BA1A252CDC0623FBCAC3420BC19F0105F4FE)                                                                          |       0    |         1 | 2024-09-02   |
| 1945 | [n3r10@proton.me](w/relay/78B73BE8CB084111E2DC3B64CC4E2F78E61CEB42)                                                                                                             |       0    |         1 | 2024-01-22   |
| 1946 | [Nicolas Christin https://cylab.cmu.edu/directory/bios/christin-nicolas.html](w/relay/78C7C299DB4C4BD119A22B87B57D5AF5F3741A79)                                                 |       0    |         1 | 2019-02-18   |
| 1947 | [78CCB6F1](w/relay/78CCB6F1327C46D6C0266471D7CE42CA8541A13D)                                                                                                                    |       0    |         1 | 2022-04-23   |
| 1948 | [&lt;cocolinofan@protonmail.com&gt;PGP: D8E7 0DAC 2CB9 F4DE 2728 00D5 8CCA F633 B685 9E](w/relay/78CFF6C66B9AF5CB6ED30472ED3BC39C423F0000)                                      |       0    |         1 | 2025-01-11   |
| 1949 | [796B60AC](w/relay/796B60ACBE33A07D492FFC34DC14E0F394272161)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 1950 | [79A736CF](w/relay/79A736CF9E509FD79A39ACC24A3F4AF7AD103533)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1951 | [1024D/F9CD0B8F Peter Buzanits &lt;peter AT icb dot at&gt;](w/relay/79DEB4E02FD08AE1AEB4D8594AAB082375E9062D)                                                                   |       0    |         1 | 2019-02-18   |
| 1952 | [a dot habith at gmail dot com tor-relay.co](w/relay/7A32B3567937361A9FB2C9BDB4D667EF99475A6F)                                                                                  |       0    |         1 | 2024-10-27   |
| 1953 | [7A875D79](w/relay/7A875D79DB10C0F20D5FD3FCBDA94A26806A1C6D)                                                                                                                    |       0    |         1 | 2024-08-01   |
| 1954 | [mikael datanerd.se](w/relay/7AFFC971486FEADE7583170A616EA97DECA11190)                                                                                                          |       0    |         1 | 2024-10-19   |
| 1955 | [tor at thewellinspired dot com tor-relay.co](w/relay/7B67A3AD2395536FD15CB97588A0BC1A015AC267)                                                                                 |       0    |         1 | 2020-10-10   |
| 1956 | [thatgaydragon@protonmail.com](w/family/7dd61baf6a9c03e4d83ff52a0d20783265e90c180dffa3791fc9b8d8c7b83493)                                                                       |       0    |         2 | 2024-08-24   |
| 1957 | [AhFei &lt;tor@vfly2.com&gt;](w/relay/7BE827E2731327CED58F5294E3A432176571313B)                                                                                                 |       0    |         1 | 2023-07-19   |
| 1958 | [&lt;tor AT busybear DOT se&gt;](w/relay/7BE9E2EF2BB41BB662D9A3CD68289B9E3DBF8A08)                                                                                              |       0    |         1 | 2019-02-18   |
| 1959 | [7C9B6D51](w/relay/7C9B6D51C2E129F64A7D2A6FA29A650C4B94812F)                                                                                                                    |       0    |         1 | 2022-09-20   |
| 1960 | [hello@relaymagic.org relaymagic.org/contact](w/relay/7CBDC9CFB443830CF73202912F3E4E6EF1598DEB)                                                                                 |       0    |         1 | 2023-01-28   |
| 1961 | [adam.chacey@hotmail.com](w/relay/7CF3E930961F20A5AD552E3EA696BB9122C9182A)                                                                                                     |       0    |         1 | 2024-11-17   |
| 1962 | [tor@jakami.de](w/relay/7D0B5D9A4AF241540D2586F5DC1DD3311318B9D0)                                                                                                               |       0    |         1 | 2024-07-28   |
| 1963 | [7D33FC2D](w/relay/7D33FC2D047493C6A514F5A4C1D70FCA54EA55DD)                                                                                                                    |       0    |         1 | 2020-09-30   |
| 1964 | [&lt;statusquo@mailbox.org&gt;](w/relay/7D4389DC3BA69BECAB418D11E5E6B999014A70F7)                                                                                               |       0    |         1 | 2024-05-03   |
| 1965 | [Party Horse &lt;partyhorse UNDERSCORE tor at proton dot ME&gt;](w/relay/7D832D4D5D9C5A0E0B8AF9478C970043048D5C2F)                                                              |       0    |         1 | 2024-01-21   |
| 1966 | [clau.fisch AT t-online DOT de](w/relay/7DA31D79E52D12685BBE8544E3C557F176B0FC84)                                                                                               |       0    |         1 | 2019-02-18   |
| 1967 | [info@timo-klein-web.de](w/relay/7DEB6D40BEF1C0A09C18EA973FC6D50F6A777F55)                                                                                                      |       0    |         1 | 2024-07-06   |
| 1968 | [7E33C702](w/relay/7E33C702C95FB4A3D2C203DB4A40D330C5029D81)                                                                                                                    |       0    |         1 | 2024-03-29   |
| 1969 | [7E9D7A63](w/relay/7E9D7A6366ACB3561913D36830C2C5D229F38886)                                                                                                                    |       0    |         1 | 2024-07-30   |
| 1970 | [judas priest doamin here](w/relay/7F0541B21603F5D4A17A75C5326CEBC37E8E9D74)                                                                                                    |       0    |         1 | 2024-09-01   |
| 1971 | [a-n-o-n-y-m-e.net](w/relay/7F59D722055FEE84ED7095E33FD2A42D967A5E34)                                                                                                           |       0    |         1 | 2024-07-03   |
| 1972 | [northboot@mailbox.org](w/relay/7FC6853385AC10CD4C74BFCED25B6C30F440A3C3)                                                                                                       |       0    |         1 | 2021-11-24   |
| 1973 | [Netium &lt;info AT netium.pl&gt;](w/relay/8699371415DC052A60BCA3AAD68E55D9B759CAE0)                                                                                            |       0    |         1 | 2019-02-18   |
| 1974 | [staten eiwit.0n AT icloud.com](w/relay/869B087EA5B33FD1F30775756B8DE67B1E8BED5C)                                                                                               |       0    |         1 | 2024-04-12   |
| 1975 | [your@e-mail.com](w/relay/8712E17FBD0D6BBAB60E3E897B326FAE51E15B09)                                                                                                             |       0    |         1 | 2024-02-20   |
| 1976 | [guard9385@firemail.cc](w/relay/876F62721A6D421C8263975EFC94C6E84952C442)                                                                                                       |       0    |         1 | 2024-10-06   |
| 1977 | [tor@torzero.anonaddy.com](w/relay/8863E8AFFDDBF61A878B8DAA075F3ED8155FC2D6)                                                                                                    |       0    |         1 | 2024-12-18   |
| 1978 | [emeraldonion.org](w/relay/887CB7C9DD87ADD7B0A2771280AC17ED913136A5)                                                                                                            |       0    |         1 | 2024-07-26   |
| 1979 | [889944F5](w/relay/889944F540C155E7E32C909B9E1424677689AD4D)                                                                                                                    |       0    |         1 | 2020-11-29   |
| 1980 | [889EDCB1](w/relay/889EDCB19B237F20ADB525960C39E0B00398D6B1)                                                                                                                    |       0    |         1 | 2024-05-06   |
| 1981 | [88AFF04D](w/relay/88AFF04D5C06F82410D5EF386F6BE677D418EE40)                                                                                                                    |       0    |         1 | 2024-07-14   |
| 1982 | [platernary tutanota com](w/relay/88D31EC57EBD4377EA7F4CC8284125B0F968DEF5)                                                                                                     |       0    |         1 | 2023-03-01   |
| 1983 | [creideikitor@ferretporn.se](w/relay/88D5F0BD87F9BC1A96FCBFDCEDB1C0E6BAB1D14E)                                                                                                  |       0    |         1 | 2019-02-18   |
| 1984 | [abuse t at digital-filestoredotde](w/relay/88E8B8CBB101B6249C44A0481B3BD79C5A46DE38)                                                                                           |       0    |         1 | 2022-03-04   |
| 1985 | [donatello@cocaine.ninja](w/relay/88EF3F81A4936A3D5C619F852C70A2A673FA754A)                                                                                                     |       0    |         1 | 2024-03-26   |
| 1986 | [ss aT EFF d0t ro](w/relay/896364B7996F5DFBA0E15D1A2E06D0B98B555DD6)                                                                                                            |       0    |         1 | 2019-02-18   |
| 1987 | [8982D544](w/relay/8982D5441E4CFD8A1D6A74056739AB2DA98D77A2)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 1988 | [89999C2F](w/relay/89999C2F1D64A4620FC0CD601FC44C5F8E736286)                                                                                                                    |       0    |         1 | 2023-03-09   |
| 1989 | [91394645](w/relay/91394645FB067A5008F5129305DE243903A6A7BF)                                                                                                                    |       0    |         1 | 2024-03-26   |
| 1990 | [917C4C9F](w/relay/917C4C9F62C83A5F08DA4A4C04DD42FD7C9BE701)                                                                                                                    |       0    |         1 | 2024-01-21   |
| 1991 | [tata at sud-ouest dot org](w/relay/91BDB92C02C3BFD6485F04B4A1095A8DC00DA48A)                                                                                                   |       0    |         1 | 2024-01-22   |
| 1992 | [Pine Relay &lt;noderelaypine@gmail.com&gt;](w/relay/91DB14220E972A576C76FA1C291429D09FE4BEFC)                                                                                  |       0    |         1 | 2024-10-20   |
| 1993 | [nextgenpriv at pm . me](w/family/cb57a08e687853f36a06b2720d789db30f7b0a414252646ca0feb0594341fed1)                                                                             |       0    |         2 | 2022-08-21   |
| 1994 | [9279F00D](w/relay/9279F00D4C3CDC5D3F46EA837F6CF537BC186CD0)                                                                                                                    |       0    |         1 | 2021-06-27   |
| 1995 | [your@e-mail](w/relay/927BEE8EEC30D1456052972380861889A659CA21)                                                                                                                 |       0    |         1 | 2024-07-03   |
| 1996 | [fuchs7@riseup.net](w/relay/92B037E7FCAF291301B42BB3420D277014D4869C)                                                                                                           |       0    |         1 | 2024-01-22   |
| 1997 | [gruene.social/@b90g](w/relay/92FB51C00F849470D7CF511AECD67E56D96F7227)                                                                                                         |       0    |         1 | 2024-11-03   |
| 1998 | [935EAE38](w/relay/935EAE38CBDE6D1FEF381CD76F078E171CCE07A6)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 1999 | [937CAFC3](w/relay/937CAFC317E8DC0F05E2AA314DA3DADBEDD509D2)                                                                                                                    |       0    |         1 | 2023-03-23   |
| 2000 | [tor at dapor dot de](w/relay/8E3FB3F53A9A4B49CCF2DC8A7817D247D8BE139F)                                                                                                         |       0    |         1 | 2024-11-28   |
| 2001 | [m781@tutanota.com](w/relay/8E6581B1261B28F0AA95E0A8E19CE959925E5ADA)                                                                                                           |       0    |         1 | 2022-10-10   |
| 2002 | [8E9E3239](w/relay/8E9E3239EC9A082F5337C5F45A8E706A86BA19B0)                                                                                                                    |       0    |         1 | 2024-02-28   |
| 2003 | [8EBE832C](w/relay/8EBE832C42A19DF77334C326926B373CB5356394)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 2004 | [8F16229D](w/relay/8F16229D5425774DCA566D7737596178153DB838)                                                                                                                    |       0    |         1 | 2020-04-03   |
| 2005 | [Julian Kassat &lt;tor@xenu.chickenkiller.com&gt;](w/relay/8F1D70DE42C72120CE8E49287414DFCF94FFF1F2)                                                                            |       0    |         1 | 2020-05-03   |
| 2006 | [honey3031@rambler.ru](w/relay/8FB4F3DB65CBB602116BA34A3296FDD0847D67F1)                                                                                                        |       0    |         1 | 2024-07-24   |
| 2007 | [paddedpride@gmail.com](w/relay/900C1B471776BFEEBFB3556DBC238898359EBF62)                                                                                                       |       0    |         1 | 2023-05-08   |
| 2008 | [maxzrbn AT protonmail DOT com](w/family/b02865586c455fecc750dc75ac9cdfd02795ec56f5d92f5c107cd849a8532c26)                                                                      |       0    |         4 | 2024-05-12   |
| 2009 | [Just another Morron &lt;jimytutcnd@use.startmail.com&gt;](w/relay/9044253AE00A3E9C26AE2C58EB182FA14975E866)                                                                    |       0    |         1 | 2023-08-18   |
| 2010 | [9064866C](w/relay/9064866C9633472B01C6BDA2E9B5B946A9084A93)                                                                                                                    |       0    |         1 | 2024-06-19   |
| 2011 | [&lt;c4t2816 at protonmail . ch&gt;](w/relay/90668E0C9E0E46E017D7D8FB842A2D23E9004E84)                                                                                          |       0    |         1 | 2023-06-29   |
| 2012 | [a-n-o-n-y-m-e.net](w/relay/90705D63956EDD5904D173F1998F421C5FC5B6FC)                                                                                                           |       0    |         1 | 2024-05-30   |
| 2013 | [haxalicious5 at gmail dot com](w/relay/90AAC6245388A9A9EC7050810775503004FE40BF)                                                                                               |       0    |         1 | 2022-02-02   |
| 2014 | [90C330DE](w/relay/90C330DE8F4381DD71D58E19A9C0CF3BC964CE01)                                                                                                                    |       0    |         1 | 2024-04-29   |
| 2015 | [90CCB439](w/relay/90CCB4395B7674B7F265B7DF2CEAAB274D9BBE8A)                                                                                                                    |       0    |         1 | 2023-06-27   |
| 2016 | [90E23FDA](w/relay/90E23FDAE5A70E43528A0005EE9792F75503F645)                                                                                                                    |       0    |         1 | 2024-09-27   |
| 2017 | [8A427993](w/relay/8A4279932506574BC3AAF00390C1A2E1109669A5)                                                                                                                    |       0    |         1 | 2024-12-20   |
| 2018 | [mlejkowskisocialmedia@gmail.com](w/relay/8A493BD341F76260A54F0B6A81D1101EAD360413)                                                                                             |       0    |         1 | 2023-06-11   |
| 2019 | [0x9EF906D803716AB65B48F01870005293EF5D0AE2 ldrewes &lt;webmaster AT ldrewes DOT de&gt;](w/relay/8A5E7C2D09835974B4D58252BAD51FD8AD54F9CE)                                      |       0    |         1 | 2020-01-14   |
| 2020 | [example@gmail.com](w/relay/8AAC77DAB50AAAD19FD46A187E38BD87CF8221A9)                                                                                                           |       0    |         1 | 2024-10-02   |
| 2021 | [gutbesserwasser &lt;support@gutbesserwasser.com&gt;](w/relay/8AD12BDB0CD1A1DF7FE38B97D649A46B73275D2B)                                                                         |       0    |         1 | 2022-11-09   |
| 2022 | [privat at pato dot ch](w/relay/8B0C858DD20236104D6981F3F95201EF732BF0BF)                                                                                                       |       0    |         1 | 2022-03-14   |
| 2023 | [&lt;tutelrelay AT protonmail DOT com&gt;](w/relay/8B188CA8AC660A2E4008D8FDD72C37E10B1F3B09)                                                                                    |       0    |         1 | 2024-02-13   |
| 2024 | [8B5E282D](w/relay/8B5E282D0A7DA16E644D17ABE3C9E37A14F7E376)                                                                                                                    |       0    |         1 | 2020-12-29   |
| 2025 | [B34ch B0y &lt;kal4f0rni4@protonmail.com&gt;](w/relay/8BCC134CA1EA40BD8236B8493CF8D9C20E03CF2D)                                                                                 |       0    |         1 | 2023-06-23   |
| 2026 | [8C2B3692](w/relay/8C2B3692123A24D19D012821501AA2C44F5A4D85)                                                                                                                    |       0    |         1 | 2024-06-26   |
| 2027 | [b450m @ proton dot me server cost me 50 bucks](w/relay/8C88990D44239803692CFAA68DDC74FEB5E6E9C7)                                                                               |       0    |         1 | 2024-08-24   |
| 2028 | [mybluesnode](w/relay/8CD3F8019FAFAC6D18C56E51DD143D8794E08D4D)                                                                                                                 |       0    |         1 | 2021-06-27   |
| 2029 | [8D009640](w/relay/8D009640352E83C251F994E980CAD0C5B0B83156)                                                                                                                    |       0    |         1 | 2024-06-27   |
| 2030 | [8D1085E8](w/relay/8D1085E818D0473EC693E3B0911FF18741F1F2DF)                                                                                                                    |       0    |         1 | 2024-01-29   |
| 2031 | [ac1dburn ac1dburn@tuta.io](w/relay/8D8DAD240CECFE9B48DC5F2C6EA20D042D5B8733)                                                                                                   |       0    |         1 | 2022-10-20   |
| 2032 | [8D8F82E1](w/relay/8D8F82E1C4E290928689E9FA39B7224D8FE36405)                                                                                                                    |       0    |         1 | 2024-01-23   |
| 2033 | [tor &x27;at sign&x27; rymdfartstyrelsen &x27;dot&x27; se](w/relay/8D90585CC705F05CD9F92D22E9B5F3AEF0E5477F)                                                                    |       0    |         1 | 2025-01-13   |
| 2034 | [8DB2A65B](w/relay/8DB2A65B5B9691CD9722D2D497784BC3528F9413)                                                                                                                    |       0    |         1 | 2025-01-08   |
| 2035 | [laladee@posteo.net](w/relay/9DBD92C848EEC352D542FBAC89DE2439271F699B)                                                                                                          |       0    |         1 | 2024-12-04   |
| 2036 | [9DD7CF55](w/relay/9DD7CF559C1B177A774295DDE883BA36D6231009)                                                                                                                    |       0    |         1 | 2024-08-26   |
| 2037 | [Jeff Burrows Jeff@privacywarrior.org](w/relay/9DFF7F006FA33615DADD4EA775E1CEF73E7D7630)                                                                                        |       0    |         1 | 2024-01-13   |
| 2038 | [9E328584](w/relay/9E328584CD2B85D328FF7EFB4BF96997F85C9B7B)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2039 | [luminoso &lt;luminoso AT protonmail dot com&gt;](w/relay/9EA65D1BB607ADA4B9A6B2A58BAA2C960DF8BDEA)                                                                             |       0    |         1 | 2020-01-04   |
| 2040 | [0x4F8ACED4 Marcel Menzel &lt;mail@typhoon31.de&gt;](w/relay/9EB3FD84065E5622A57EFEF14E41A01B5B99A022)                                                                          |       0    |         1 | 2019-02-18   |
| 2041 | [9EB48A27](w/relay/9EB48A27C90A2DC052625B923766E85BDCB21F88)                                                                                                                    |       0    |         1 | 2024-07-07   |
| 2042 | [MIYOP @tutanota.de](w/relay/9EE1970E1AD558CF0F297537E32A449EB740CB9D)                                                                                                          |       0    |         1 | 2024-01-16   |
| 2043 | [9EEAA02E](w/relay/9EEAA02E338CDF5919F983F3245AA95A790B9B6C)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 2044 | [courbevoie@orange.fr](w/relay/9F99E46997BC4530420387867E5C253F98E3293D)                                                                                                        |       0    |         1 | 2024-01-21   |
| 2045 | [9FAA9CEE](w/relay/9FAA9CEEDFF11FD68AC0CF389054A64BA1F3B034)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2046 | [secure-communications-zachary@protonmail.ch](w/relay/A00E3AAF5A24DC69740FA7A3A1C4A0ECB7972722)                                                                                 |       0    |         1 | 2023-01-18   |
| 2047 | [A0121D63](w/relay/A0121D63745E226F2D88EEDD57560FF996EE723F)                                                                                                                    |       0    |         1 | 2024-04-01   |
| 2048 | [A0393557](w/relay/A0393557D81F954EA77C1A3E0F32B40968054B6C)                                                                                                                    |       0    |         1 | 2022-11-19   |
| 2049 | [sorcier at tutanota dot com tor-relay.co](w/relay/A0C59410B9030AC1385C4CA44C8DBFE13AF4BC9B)                                                                                    |       0    |         1 | 2020-02-13   |
| 2050 | [a-n-o-n-y-m-e.net](w/relay/A0E1C5DBA20040BE6E291EE32B7949925159DEF4)                                                                                                           |       0    |         1 | 2024-07-20   |
| 2051 | [davio 2000 at gmx dot com](w/relay/A1177D4BF4698A74B926AE1E0FC533578FA55667)                                                                                                   |       0    |         1 | 2022-06-22   |
| 2052 | [Admin &lt;admin AT tor-relay dot io&gt;](w/relay/A13281DBD8F8E484E95DD273B3EE7FC14C1B0A7A)                                                                                     |       0    |         1 | 2019-02-18   |
| 2053 | [Random Person &lt;nobody AT ostehaps dot dk&gt;](w/relay/A1526DD0BACC4499101AE59586298DFD55D2534A)                                                                             |       0    |         1 | 2022-07-22   |
| 2054 | [A192A255](w/relay/A192A25545ED951597975F5611C1DA062D5C2703)                                                                                                                    |       0    |         1 | 2025-01-06   |
| 2055 | [A194375B](w/relay/A194375B7CA23D81C939336CC4A3CD0B49CE6D35)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 2056 | [A1A29241](w/relay/A1A2924158198592C3E88CB0DF23C14D9FE64328)                                                                                                                    |       0    |         1 | 2020-11-19   |
| 2057 | [torservers.net](w/relay/A1A78BE5F0A6698301913D08DDB76535D5E6D2AA)                                                                                                              |       0    |         1 | 2023-01-08   |
| 2058 | [jayden@jaydenha.uk](w/relay/A1B96BB76E3E20F84860DC36730034752EEE8BD3)                                                                                                          |       0    |         1 | 2024-10-02   |
| 2059 | [email:fossdd pwned.life pgp:80E2164367131107A806C897BB8C8A81 mastodon:https://c](w/relay/A1C0187FE43E0A6FB8C38CC76769DEEACD56B757)                                             |       0    |         1 | 2024-01-22   |
| 2060 | [el-brujo@elhacker.net](w/family/7b284fb5439eeebf20c4ef2a392557413b7debede2787fda7c4d09f595ae401c)                                                                              |       0    |         2 | 2021-11-14   |
| 2061 | [3kh0 &lt;tornode AT 3kh0 dot net&gt;](w/relay/A23C1BF9AD35397D26E525185281C984C9A156BE)                                                                                        |       0    |         1 | 2024-10-23   |
| 2062 | [0xCCA1331895B6562393A651D93B67825FE6F79D24 tor@maxhost.io](w/relay/A282E67AE5575E920D214BC2D0A8FAB3A82B4CBF)                                                                   |       0    |         1 | 2024-01-22   |
| 2063 | [A2900F5B](w/relay/A2900F5B985D318DAE45BFAC18B1F8421FB09387)                                                                                                                    |       0    |         1 | 2024-08-23   |
| 2064 | [jello@ro.ru](w/relay/A2BE3C7F0ABCD8E945B8C8CF6DAF9EF48B5D0565)                                                                                                                 |       0    |         1 | 2024-10-14   |
| 2065 | [A2C85DB6](w/relay/A2C85DB6C3D64D7178D24848FD8A0E59347F2E6D)                                                                                                                    |       0    |         1 | 2022-04-03   |
| 2066 | [riqoiaki1@mozmail.com :3](w/relay/A2CEE3773458EB9C60ECBA768C830389DB5623D3)                                                                                                    |       0    |         1 | 2024-01-22   |
| 2067 | [A2D63C32](w/relay/A2D63C32574A5376EC1E6CBAE0ABDB1538782541)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2068 | [TOR EXIT &lt;SUCK.IT&gt;](w/relay/A30C7006422806CBF18196C51024AF70F2F43BD1)                                                                                                    |       0    |         1 | 2024-10-14   |
| 2069 | [A38625F8](w/relay/A38625F86DD9F8DFA2C6CA4D7CB47DB801FBD7E0)                                                                                                                    |       0    |         1 | 2024-04-29   |
| 2070 | [Random Person phil@beaconlab.uk](w/relay/A3FB592BD87C9D09CE450C356100BF16516B1ECF)                                                                                             |       0    |         1 | 2024-01-22   |
| 2071 | [contact@sachin.cool](w/relay/A42A6ECDEFE2EA450852F4AFC670AFEE99BEB64E)                                                                                                         |       0    |         1 | 2024-01-22   |
| 2072 | [A489D370](w/relay/A489D37070A5081D814C1F112139EEF0DDC03A48)                                                                                                                    |       0    |         1 | 2022-08-31   |
| 2073 | [A4A508B3](w/relay/A4A508B3DDFADD263864E9AF3ED31DE113904743)                                                                                                                    |       0    |         1 | 2024-08-25   |
| 2074 | [A4B46EFF](w/relay/A4B46EFF50EB828D6D2E33ED0F7B9A5525EBC1A5)                                                                                                                    |       0    |         1 | 2024-06-25   |
| 2075 | [tor.relay.scorch322@passmail.net](w/relay/940DF65C1C5B3781B582C69CFF76E3EE031AE066)                                                                                            |       0    |         1 | 2024-08-17   |
| 2076 | [949C43F6](w/relay/949C43F6BD325F678E5E693E6D0CE6F8B535741A)                                                                                                                    |       0    |         1 | 2024-01-21   |
| 2077 | [94AEA880](w/relay/94AEA88028F06871AAB76AE026D139F3678398BB)                                                                                                                    |       0    |         1 | 2024-10-24   |
| 2078 | [vollborn@quantentunnel.de](w/relay/94AEB0597B5A6981939A560ADDD2AF5721FA70E7)                                                                                                   |       0    |         1 | 2023-03-15   |
| 2079 | [Tor Admin &lt;tor -at- cs -dot- bu -dot- edu&gt;](w/relay/94C4B7B8C50C86A92B6A20107539EE2678CF9A28)                                                                            |       0    |         1 | 2019-02-18   |
| 2080 | [951DE6AC](w/relay/951DE6AC9ED3F857DB0A00B37F84B9EDF55E253C)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2081 | [9522118C](w/relay/9522118C25AE03D84811095DA03E54F8C3C79DAE)                                                                                                                    |       0    |         1 | 2024-06-29   |
| 2082 | [95333D86](w/relay/95333D86240F6402656D2EB96716255634F6C007)                                                                                                                    |       0    |         1 | 2022-03-14   |
| 2083 | [Five Boxing Wizards &lt;FiveBoxingWizards AT gmail DOT com&gt;](w/relay/9554FC0CF9A5200542E3375C8AE4E939C4594228)                                                              |       0    |         1 | 2019-04-19   |
| 2084 | [ev2000@mailfence.com](w/relay/95550D70A3AF121399C681E69DD08C71FF3EAFC7)                                                                                                        |       0    |         1 | 2024-10-31   |
| 2085 | [nibirutard@gmail.com](w/relay/95557A30988CFC5F02F40257F45A5BE74ACE3BCA)                                                                                                        |       0    |         1 | 2024-02-05   |
| 2086 | [johnson blake 1 at gmail PUNKT com tor-relay.co](w/relay/956B0D08024639F9D7F3F333283ED4480B807D8D)                                                                             |       0    |         1 | 2021-12-04   |
| 2087 | [your@e-mail](w/relay/959C5AE1A34683F60C2DF7F4F48FEA24406E31E8)                                                                                                                 |       0    |         1 | 2024-11-04   |
| 2088 | [aze &lt;tor at aze dot wtf&gt;](w/family/92e43be76980b1e42d4277abd8ed7630d58813f7eaf54c09dbd564941f83a602)                                                                     |       0    |         2 | 2024-02-09   |
| 2089 | [k3n &lt;tech-tor@point0.net&gt;](w/relay/962675FB45115C1CAF996FB54135266356D93E69)                                                                                             |       0    |         1 | 2024-08-22   |
| 2090 | [emilysmith1996yo@proton.me](w/family/efb7e9ff7c7f5b8b30b6b89a88f7a8810144662915c4f280a8cda0a6edec3512)                                                                         |       0    |         2 | 2024-12-18   |
| 2091 | [a-n-o-n-y-m-e.net](w/relay/969F1D67A2115F571D31EFF9F3832829ED7C9C05)                                                                                                           |       0    |         1 | 2023-08-12   |
| 2092 | [Woozy@ro.ru](w/relay/96D27621DC77623C20F58A433C10286E62CE1FB4)                                                                                                                 |       0    |         1 | 2024-08-13   |
| 2093 | [oymyakon.overvalue938@passinbox.com](w/relay/96D457EBF4CC36F9F195CA61E4EAECFD6541C0EF)                                                                                         |       0    |         1 | 2024-09-16   |
| 2094 | [Jon Proulx &lt;jon AT csail dot mit dot edu&gt; GPG Key ID 0x37C6224D225BCD7D Finger P](w/family/b6bc3225e7dcd53ca2822b20c1ed430dd4845446d42f4a4cbffc5ef3540d88fd)             |       0    |         2 | 2019-02-18   |
| 2095 | [Random Person &lt;zr10utf3 AT anonaddy DOT me&gt; xmr:8BtynUbpW7DJ4Wq4VjSHmHAHdGopwqUs](w/relay/97188863FDFF9D21F7560AED3F037F316CA6AE20)                                      |       0    |         1 | 2023-06-17   |
| 2096 | [panthera000 AT xmail DOT net](w/relay/97828A82F4A1ACBA2C1F6B860E5436286BC2D623)                                                                                                |       0    |         1 | 2025-01-05   |
| 2097 | [ryguy7246 PLUS tor AT gmx.com](w/relay/97CD4CCF76AFCD753403B24149F49AE3AD3F0C23)                                                                                               |       0    |         1 | 2024-11-29   |
| 2098 | [97DBCB7E](w/relay/97DBCB7E03C56888ABA733D8AD0688927FC30925)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2099 | [Unnamed1@mail.ru](w/relay/980C4C77F3A7492061A194577016BB5B822BF05D)                                                                                                            |       0    |         1 | 2024-07-02   |
| 2100 | [Relay Info &lt;relay-ops AT tuta dot io&gt;](w/relay/981DF882842207A759FAC8CE57651B8DE8A21CC4)                                                                                 |       0    |         1 | 2022-06-22   |
| 2101 | [9876581B](w/relay/9876581B626B34034AB642A1B0F66A094DBB5D6C)                                                                                                                    |       0    |         1 | 2024-08-27   |
| 2102 | [987CFC56](w/relay/987CFC56FD7BE2B940B91D087C88F82386453663)                                                                                                                    |       0    |         1 | 2022-05-23   |
| 2103 | [98BD4713](w/relay/98BD4713A6D1E0F4C7AAE8C34CE7D843576D3F0E)                                                                                                                    |       0    |         1 | 2024-01-30   |
| 2104 | [98DFD727](w/relay/98DFD7275B6193F3198518F0DC97C5D60103EE3F)                                                                                                                    |       0    |         1 | 2024-08-28   |
| 2105 | [sabotage.net](w/relay/9928E342EF92F2411D8D68ADC18F6D2B5367171D)                                                                                                                |       0    |         1 | 2024-01-18   |
| 2106 | [&lt; loik93 @ mail 2 &gt; dot co](w/relay/99317933558461828D54706B64752830448EA124)                                                                                            |       0    |         1 | 2024-12-30   |
| 2107 | [ponelogic@gmail.com](w/relay/995362C04EAFB214BC96BE9D8F0F0B712D3BB763)                                                                                                         |       0    |         1 | 2022-05-13   |
| 2108 | [orangemaster674@proton.me](w/relay/9965E826830CC05485DC22EC8E210AC9859C4D26)                                                                                                   |       0    |         1 | 2024-12-25   |
| 2109 | [0xFFFFFFFF Random Person &lt;tor AT kornnatter.dedyn.io&gt;](w/relay/9990BD426A0142F0A963E25AB8B7F40A9E81786E)                                                                 |       0    |         1 | 2022-11-29   |
| 2110 | [99B7D114](w/relay/99B7D1149FC551C4C8FE327F5F53ABF7B0C9CE24)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2111 | [ms192@gmx.de](w/relay/99BE56DECE65D4F6A29282A1554CB505C8BF7B6F)                                                                                                                |       0    |         1 | 2024-01-21   |
| 2112 | [complaint@toluris.fr](w/relay/9A2A7E55CC21DF2C6171068FD9DF6B35AB504132)                                                                                                        |       0    |         1 | 2024-01-31   |
| 2113 | [9AAB2688](w/relay/9AAB2688BC9334C72AA19ECBEAE71E346A896562)                                                                                                                    |       0    |         1 | 2022-01-23   |
| 2114 | [contact@einfachzocken.eu](w/relay/9AB236151BE7C47E61569D3B2558D1D93B71673F)                                                                                                    |       0    |         1 | 2024-10-20   |
| 2115 | [Santas Helper &lt;torrelay AT lager3 dot net&gt;](w/relay/9AB5C1389CEC633AF5391C781339ED6107B5CC86)                                                                            |       0    |         1 | 2024-01-21   |
| 2116 | [Administrator &lt;admin AT anonymousbits DOT net&gt;](w/relay/9B78292678AB262EF285E0612D251E663D2C141E)                                                                        |       0    |         1 | 2024-09-17   |
| 2117 | [9B7A16AA](w/relay/9B7A16AABCAFA62B6F10E7877B9F5728C838891B)                                                                                                                    |       0    |         1 | 2024-09-03   |
| 2118 | [9B8EAB1F](w/relay/9B8EAB1FA37AE31D680A3C1F79EC4820CBDDD9DB)                                                                                                                    |       0    |         1 | 2024-08-21   |
| 2119 | [intern &lt;me@theintern.pw&gt;](w/relay/9BA8092290FC85C7E530646AA6BE63FBF80BFDF4)                                                                                              |       0    |         1 | 2024-01-22   |
| 2120 | [ineatery-calator openmail D cc](w/relay/9BAAA9CBA3109C2C807F2E84D5C9C0C8C147DCE6)                                                                                              |       0    |         1 | 2020-03-24   |
| 2121 | [9BB6B685](w/relay/9BB6B6855BFFB7B2C628B4C8611C87A9B6CF8E79)                                                                                                                    |       0    |         1 | 2022-03-24   |
| 2122 | [tor@kavaro.net](w/relay/9BDA5310B77A73C6F8B53A44F5CD015682C5DB4A)                                                                                                              |       0    |         1 | 2023-07-27   |
| 2123 | [9BF90C46](w/relay/9BF90C46E61D86DD0E85B051EEC8568875E9D662)                                                                                                                    |       0    |         1 | 2024-10-10   |
| 2124 | [clan.gardner at protonmail dot com](w/relay/9C24A441000E6636D4041FFFD669C8DD16672CBC)                                                                                          |       0    |         1 | 2022-08-11   |
| 2125 | [webmaster@wienhold.berlin](w/relay/9C8AD9A02AA166EACB8A8E50FF7B2A2BAA439603)                                                                                                   |       0    |         1 | 2024-11-27   |
| 2126 | [devnull@omegazero.org](w/relay/9C98A82DDC57AB4DF954751C1B3A04198ABFC5B5)                                                                                                       |       0    |         1 | 2024-02-03   |
| 2127 | [9C9B2A36](w/relay/9C9B2A363EA04E554D73CC8FBAC157EC81F41AEE)                                                                                                                    |       0    |         1 | 2023-06-09   |
| 2128 | [9CA70A32](w/relay/9CA70A32C8D1AC456FA1227DB27ECE598894BE86)                                                                                                                    |       0    |         1 | 2024-08-02   |
| 2129 | [9CE094A0](w/relay/9CE094A0C66BAECDB232BC3B34AEBF96BADACDAD)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2130 | [9CFBB7CD](w/relay/9CFBB7CD580869C594623BC3F0E6D5C51A582858)                                                                                                                    |       0    |         1 | 2024-07-30   |
| 2131 | [9D4094BF](w/relay/9D4094BFF36B6E32C732DD242C079D61ED0A1949)                                                                                                                    |       0    |         1 | 2024-08-19   |
| 2132 | [3ipfnszc at duck.com](w/relay/A50BC58C32D37168C040B50BE977F7F74DD81480)                                                                                                        |       0    |         1 | 2021-10-25   |
| 2133 | [A5424DEE](w/relay/A5424DEEDD5A913146E7177A79EE48FAF7CB861A)                                                                                                                    |       0    |         1 | 2022-07-22   |
| 2134 | [A5AD4BE5](w/relay/A5AD4BE51923B5C613DACF4D2B802CFD9F0843A6)                                                                                                                    |       0    |         1 | 2024-11-12   |
| 2135 | [halanamili at pm dot me](w/relay/A5AEBB58BD8E17F74DEC3F6F8B8ACF410A8B1A9A)                                                                                                     |       0    |         1 | 2023-07-31   |
| 2136 | [A5B15D59](w/relay/A5B15D590C207446BFB6F739FCA67DE8C176F431)                                                                                                                    |       0    |         1 | 2019-05-19   |
| 2137 | [a-n-o-n-y-m-e.net](w/relay/A5CF1EAF3C0C3D998A99C8127046FCA0F8B69723)                                                                                                           |       0    |         1 | 2024-10-26   |
| 2138 | [A62B3F47](w/relay/A62B3F47B732077DE405830782D49141AFEA6FEA)                                                                                                                    |       0    |         1 | 2024-03-13   |
| 2139 | [kassu.h@yahoo.com](w/relay/A6B458074E2D20A2BEAFB18369477CC001538058)                                                                                                           |       0    |         1 | 2024-06-13   |
| 2140 | [h0tch0c @caramail.fr](w/relay/A6CD7CA239580522C4B6ED93AFB9A058B275AD9E)                                                                                                        |       0    |         1 | 2023-07-29   |
| 2141 | [j.r &lt;tor AT jugendhacker dot de&gt;](w/relay/A76B8398293DE18EF766C79D898DAB1DE958949C)                                                                                      |       0    |         1 | 2021-12-24   |
| 2142 | [promotos gmx de](w/relay/A775F529F5D22BC6DD27F59C44738A8C4953365D)                                                                                                             |       0    |         1 | 2024-11-06   |
| 2143 | [RonnyH182 on Twitter de](w/relay/A77D838099B4E248C836FB516C08BB34EA3FE489)                                                                                                     |       0    |         1 | 2024-03-05   |
| 2144 | [torcontact viper78fr AT gmail dot com](w/relay/A79F378864C8AF1A6775A9D35876F60E4FC677BC)                                                                                       |       0    |         1 | 2024-11-19   |
| 2145 | [A7F8FBDC](w/relay/A7F8FBDCB5D91093E6AFCD6480D48A97A24A5B71)                                                                                                                    |       0    |         1 | 2024-03-16   |
| 2146 | [A80E5638](w/relay/A80E56389F18FBB7067A0262BA3D6E4B0833DE4F)                                                                                                                    |       0    |         1 | 2024-01-29   |
| 2147 | [lord@mzte.de](w/relay/A87BE4B9458A073A7AA51DB67480CDFFF5CAC2AB)                                                                                                                |       0    |         1 | 2024-08-26   |
| 2148 | [D-3t4c42twdawcrktbn4vsmlyoj8uwe2fgi7j3tb9mx7rqt&lt; a &gt;flashbox.5july.org](w/relay/A87EAE2F095095568FCF4E83FC3C0E54F946C330)                                                |       0    |         1 | 2021-08-16   |
| 2149 | [A8AC6619](w/relay/A8AC661915ED33A2DFD393533DC0A44848F6D1D7)                                                                                                                    |       0    |         1 | 2024-07-30   |
| 2150 | [A8C00073](w/relay/A8C0007306ADA0BAC9AD9FCF2E854078812E02AE)                                                                                                                    |       0    |         1 | 2024-08-21   |
| 2151 | [A8D34CA0](w/relay/A8D34CA04DDEFAB78F6D5341B1DE00C5D4D7D91C)                                                                                                                    |       0    |         1 | 2022-01-13   |
| 2152 | [DONT SPAM DONT SPY legalizeprivacy protonmail com](w/relay/A92D83E8F98941335076FFA47660BB87EB0AF2E2)                                                                           |       0    |         1 | 2023-05-24   |
| 2153 | [A95CF2AF](w/relay/A95CF2AF43D6A45C88AFC31BBBA571B3860D00B1)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 2154 | [ashlygrp@mail.com](w/relay/A9C1886D47A57EB11D85D8635089B71EE7102DE7)                                                                                                           |       0    |         1 | 2023-02-21   |
| 2155 | [auster d o t predator425 &lt;a t&gt; passinbox dot &lt;c o m&gt;](w/relay/A9D5FBD4DB002E0311ACF26D240FE8907FA09E97)                                                            |       0    |         1 | 2024-06-12   |
| 2156 | [tor at leenux dot de](w/relay/A9E1A888F383AEE001A13FF2F0D76FC9B5CBD2DE)                                                                                                        |       0    |         1 | 2024-04-01   |
| 2157 | [justagettingit@yahoo.com](w/relay/AA55B1F67922A2BCAE9BE491981BC9DA9167CE03)                                                                                                    |       0    |         1 | 2023-01-08   |
| 2158 | [abuse &lt;nomdidju at protonmail.com&gt;](w/relay/AA616315BA97729EA47DAD8718FA59269C7229E7)                                                                                    |       0    |         1 | 2019-04-09   |
| 2159 | [George Shammas &lt;tor@fu.io&gt;](w/relay/AA876FF84E0F035F1D20BDF0150C045156168619)                                                                                            |       0    |         1 | 2024-12-30   |
| 2160 | [blipp46@fastmail.com](w/relay/AAA2822835CE85D0C623134AFF01093947D73176)                                                                                                        |       0    |         1 | 2022-12-09   |
| 2161 | [matrixrevolution@mail2tor.com](w/relay/AAA9D692D1B3BE6788C7E86EA6ABEE3AB17C8289)                                                                                               |       0    |         1 | 2024-11-10   |
| 2162 | [LuxuryWood &lt;luxurywood at safetymail.info&gt;](w/relay/AB3227DB470B17883D24D830EA84EBFBDC7D5815)                                                                            |       0    |         1 | 2019-02-18   |
| 2163 | [ABDD25A3](w/relay/ABDD25A3D6FCD104F13F05A0AEB6027CE32B7A19)                                                                                                                    |       0    |         1 | 2022-06-12   |
| 2164 | [AC07E869](w/relay/AC07E869EA65BB03E07EA8B48E23F7152E1B53C7)                                                                                                                    |       0    |         1 | 2024-01-21   |
| 2165 | [D99BCDDA](w/relay/D99BCDDA7B218FE05198BAA7B84E7EB814151A0B)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2166 | [francois &lt; tor AT zof.sh&gt;](w/relay/D9C55AC5549BF4940BE0ABBBE0E34CCC8D6D06E5)                                                                                             |       0    |         1 | 2021-05-18   |
| 2167 | [tor-operator@frerebeau.com](w/relay/DA50A3C74DE52F303E9F9993468FD133DB6ADE72)                                                                                                  |       0    |         1 | 2024-08-22   |
| 2168 | [Mark Kamichoff &lt;prox AT prolixium dot com&gt;](w/relay/DA5207D1EF49621B326ED754940732BD507DB8A9)                                                                            |       0    |         1 | 2024-04-07   |
| 2169 | [DA6290D5](w/relay/DA6290D57B110BE08E833EDD8B7C3026F56723C4)                                                                                                                    |       0    |         1 | 2023-07-07   |
| 2170 | [DA661D57](w/relay/DA661D5797E3228B17F1C6F1007AB9E5F8D4DA1C)                                                                                                                    |       0    |         1 | 2024-01-21   |
| 2171 | [tapatapatapa-at-bobot-dot-lol](w/relay/DA91C260D6A78F748BDF17131A1F1D18443BE1EB)                                                                                               |       0    |         1 | 2019-02-18   |
| 2172 | [nobody@example.com](w/relay/DAB418CB83885497E6F48AFC0C438CB8E3ECE650)                                                                                                          |       0    |         1 | 2024-10-09   |
| 2173 | [flowerstotheworld at proton dot me](w/relay/DAB938592E18820E54E50FE136171613125F4885)                                                                                          |       0    |         1 | 2025-01-14   |
| 2174 | [grihsgbabbflasfhuf at onionmail dot org](w/relay/DAD11910D00BBDBE51C69B438F22C405910F24AC)                                                                                     |       0    |         1 | 2023-06-21   |
| 2175 | [DAFBFF13](w/relay/DAFBFF13A8B0963E9A0FC7F2A5AE3D555A9483B7)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2176 | [tor.noddy@proton.me](w/family/7d133f24d0493c8d732ccf21a0df1d19dd6c0fe64f9e614cf1cfdefe73a768da)                                                                                |       0    |         2 | 2024-02-20   |
| 2177 | [tor@tor.org](w/relay/DBD0F5C45280770BC16AFDEC3428C757FF4541E1)                                                                                                                 |       0    |         1 | 2024-02-22   |
| 2178 | [DBDFE627](w/relay/DBDFE62789221B037B58B833B7594D5B585D71F3)                                                                                                                    |       0    |         1 | 2024-04-25   |
| 2179 | [DC229615](w/relay/DC229615E19235E08E97228B49F29EC8BB689344)                                                                                                                    |       0    |         1 | 2025-01-02   |
| 2180 | [DCC6F8CE](w/relay/DCC6F8CEF4A305D3DC3CC481E94FF74ED980B9ED)                                                                                                                    |       0    |         1 | 2024-02-15   |
| 2181 | [Sina Rabbani &lt; sina redteam net &gt;](w/relay/E3E42D35F801C9D5AB23584E0025D56FE2B33396)                                                                                     |       0    |         1 | 2023-08-20   |
| 2182 | [alexanderkaihansen@proton.me](w/relay/E3F2B761DD85FABBA7D0246CF74756243171041D)                                                                                                |       0    |         1 | 2024-04-02   |
| 2183 | [support@xmission.com](w/relay/E41B16F7DDF52EBB1DB4268AB2FE340B37AD8904)                                                                                                        |       0    |         1 | 2019-02-18   |
| 2184 | [tor-relay@metanohi.name](w/relay/E41B228C32DA9C2B11AA2D6EAC18F3457162E66F)                                                                                                     |       0    |         1 | 2020-12-19   |
| 2185 | [E45EFBF7](w/relay/E45EFBF7C109C268E7DD0655AA1EDB6869803210)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2186 | [0xA821E3B2A0544BCCE4358697E097A42A55F3CF22 Adam Badran &lt;adam at dr00tb dot com&gt;](w/relay/E47E04E69E6B7552FE9361292117D58C82D50208)                                       |       0    |         1 | 2022-09-30   |
| 2187 | [ciissversion:2 email:tor mailink.org memory:32768 virtualization:baremetal os:d](w/relay/E4B41C92D25338AC9456B8A9C9EDC56221E64C39)                                             |       0    |         1 | 2024-11-03   |
| 2188 | [leadnan@proton.me](w/relay/E4C6E31D745BE31F9E150F3BEEE19235D9629FC9)                                                                                                           |       0    |         1 | 2024-12-18   |
| 2189 | [E4C87B4F](w/relay/E4C87B4F9F5672BB8E33A9A547A50DC2288CF8E9)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2190 | [E5423318](w/relay/E542331891C76F64CEBB67219EF6482BA72DAD3B)                                                                                                                    |       0    |         1 | 2024-07-31   |
| 2191 | [frei.raum Technikkollektiv &lt;roland.k AT disroot DOT org&gt; &lt;https://frei-raum.epiz](w/family/6eb4e863c875c944fd902a6d0e3e9b8fc4d5e36f89de53804bf428182d574dbf)          |       0    |         2 | 2019-09-16   |
| 2192 | [E59529B3](w/relay/E59529B3A2CC13F0DE3617B9A9D4E24C7A0A9D68)                                                                                                                    |       0    |         1 | 2024-03-08   |
| 2193 | [E5DEA9F6](w/relay/E5DEA9F6570207DB9841CA04C240BCDCFEC3200D)                                                                                                                    |       0    |         1 | 2020-12-19   |
| 2194 | [E654E2ED](w/relay/E654E2EDE363362BCEBC50BAAA294C7BA50BF069)                                                                                                                    |       0    |         1 | 2024-10-25   |
| 2195 | [torop &lt;at&gt; viking-sec &lt;dot&gt; xyz PGP:3297FA41D3C0E3E5FFD17DE9ADA62A499CB344B0](w/relay/E6B561B875C4744D64F5627F76087A86EFD93B72)                                    |       0    |         1 | 2023-07-15   |
| 2196 | [E74FAEA7](w/relay/E74FAEA7DDF6B61F05E5882462F25CBDD1221016)                                                                                                                    |       0    |         1 | 2024-09-26   |
| 2197 | [E87DCB2B](w/relay/E87DCB2B8CA9E62B45F8189C8AD21F62B84E09DB)                                                                                                                    |       0    |         1 | 2024-01-29   |
| 2198 | [metormay@vfosnar.cz](w/relay/E98ED785193F73C7C67E671A503FE085098FE5FA)                                                                                                         |       0    |         1 | 2024-11-09   |
| 2199 | [differNoiseHarmony-relay@pm.me](w/relay/B695F4E81148F682A0CDED076D0B6EC699F6C2BD)                                                                                              |       0    |         1 | 2024-01-22   |
| 2200 | [7fa3b767c460b54a2be4d49030b349c7](w/relay/B6B4EA2527622849BA981D80669B06C61FF8F946)                                                                                            |       0    |         1 | 2024-10-16   |
| 2201 | [tor@lienk.fr](w/relay/B6B697E206D69E520E87081F880128F655AB87C4)                                                                                                                |       0    |         1 | 2024-11-07   |
| 2202 | [captainsonic-tor @ protonmail.com](w/relay/B6C2BE9B7200F521172693A36C007BF5381DB541)                                                                                           |       0    |         1 | 2024-10-01   |
| 2203 | [fightmaxime at protonmail dot com](w/relay/B6E40167BE842F279B11B2A0F594718387AA75E5)                                                                                           |       0    |         1 | 2020-04-03   |
| 2204 | [B6FB68B2](w/relay/B6FB68B2A6863801D29A9E4266E61A2088EC2529)                                                                                                                    |       0    |         1 | 2024-08-21   |
| 2205 | [B369 6A4B 2017 8226 9C8F F34D 799E 755B F77A 6C3A Weston Reed &lt;tor@westonreed.co](w/relay/B707C9853B2958C79FFEA9B812E547B47EE1683C)                                         |       0    |         1 | 2022-04-23   |
| 2206 | [B71E68A8](w/relay/B71E68A80C5156745DDE7741F6DE5E3202ABD092)                                                                                                                    |       0    |         1 | 2019-02-28   |
| 2207 | [B72663DD](w/relay/B72663DDF48F7047003DE6E3927936994DA44152)                                                                                                                    |       0    |         1 | 2024-03-25   |
| 2208 | [Wyliefowler at g mail dot com](w/relay/B7327B559CA1531D182386E21B4868FCB7F0F456)                                                                                               |       0    |         1 | 2021-12-04   |
| 2209 | [B7DB49B4](w/relay/B7DB49B44DD933C964B47C399A50F5D50FDF918C)                                                                                                                    |       0    |         1 | 2022-07-12   |
| 2210 | [B8CE7258](w/relay/B8CE72588C2314C6513BF4B3817856A4EB314F6D)                                                                                                                    |       0    |         1 | 2024-08-28   |
| 2211 | [hot.taco.relay@protonmail.com](w/relay/B8E18CA62C1B7F6D077BAF2F92548ECA9E2DA0CA)                                                                                               |       0    |         1 | 2024-04-03   |
| 2212 | [babysharkdootdoot@proton.me](w/relay/B8F50C7C673B72845001FD8D2EE6FD179F56D162)                                                                                                 |       0    |         1 | 2024-01-22   |
| 2213 | [&lt;tor at nep dot soy&gt;](w/relay/B8FE0483E17A4FA629600310A003044CAC82B285)                                                                                                  |       0    |         1 | 2024-07-13   |
| 2214 | [B985BC38](w/relay/B985BC389FE2C0372366A4234875C74B709DFCBC)                                                                                                                    |       0    |         1 | 2024-08-14   |
| 2215 | [snapserv.net](w/relay/B9A84F621FF04D3B3A96BB314D27C14BFA54A6D7)                                                                                                                |       0    |         1 | 2022-09-10   |
| 2216 | [soulsacrifice proton.me](w/relay/B9C7E9F8597F37AF448584D235A195F63B93A781)                                                                                                     |       0    |         1 | 2024-01-22   |
| 2217 | [B9F1C02D](w/relay/B9F1C02DC390C6B9E8832B41F1693684471667EB)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2218 | [B9FAB575](w/relay/B9FAB5757ABF0D387DCDAE396BF68E11AE5D3DB4)                                                                                                                    |       0    |         1 | 2024-12-05   |
| 2219 | [BA44DFFE](w/relay/BA44DFFE3396FA9B9C77CF37A40594CFF72ACB53)                                                                                                                    |       0    |         1 | 2024-08-16   |
| 2220 | [admin@datcom-unibw.de](w/relay/BA481A3C80447EFB67811938DDD39B1F79E1C06E)                                                                                                       |       0    |         1 | 2019-09-26   |
| 2221 | [johnnybravo@gmail.com](w/relay/BACFA38C79327D1AC018F7C8D777960D84C57C21)                                                                                                       |       0    |         1 | 2024-01-22   |
| 2222 | [B2371F3B](w/relay/B2371F3BD82B8214CDD9F6C4CB704F0B53203270)                                                                                                                    |       0    |         1 | 2024-08-21   |
| 2223 | [B25E0201](w/relay/B25E02013A30693556480274240B8B392AB04179)                                                                                                                    |       0    |         1 | 2020-10-20   |
| 2224 | [B27115A2](w/relay/B27115A20B05D40730A4020145EFA63381D9D51B)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 2225 | [Benjamin &lt; tor@bennybyte.de &gt;](w/relay/B274A8018F580CA5AB19DE1E5DE6425EEE2E9C0E)                                                                                         |       0    |         1 | 2020-05-03   |
| 2226 | [B2761C17](w/relay/B2761C17016D097FF5FA51AFD544E15FCD9E9F32)                                                                                                                    |       0    |         1 | 2023-01-18   |
| 2227 | [ur PINGAS](w/relay/B29BBE0627BE0B2D1E28F1AC53BEC1A690C7A511)                                                                                                                   |       0    |         1 | 2024-06-05   |
| 2228 | [B3004A9A](w/relay/B3004A9A9F083C269212D6D2FE42F063DFD9D4D8)                                                                                                                    |       0    |         1 | 2023-07-27   |
| 2229 | [chicken at national.shitposting.agency](w/relay/B3158B86301A01DE48D8A3CFB8EFEBF80C3D5CB0)                                                                                      |       0    |         1 | 2024-05-05   |
| 2230 | [B350F747](w/relay/B350F747B37EF527C1D9C2D52113A00280C347CF)                                                                                                                    |       0    |         1 | 2024-06-24   |
| 2231 | [B3A722F0](w/relay/B3A722F05F3FCBB1491BC6CC039E74E4283CDA9E)                                                                                                                    |       0    |         1 | 2024-09-16   |
| 2232 | [yaraksan &lt;ZmF0YWwtZnVycnkubmVwaGV3NDEyQHBhc3NpbmJveC5jb20=&gt; base64 encoded mail](w/relay/B3CA62427654C23F99DA9100D7B0916E6E0FE365)                                       |       0    |         1 | 2024-07-09   |
| 2233 | [Digineo GmbH &lt;tor AT digineo dot de&gt;](w/relay/B49649340BAABF74E9CA5D5014E45155382E0A13)                                                                                  |       0    |         1 | 2024-05-23   |
| 2234 | [B4A2D7BF](w/relay/B4A2D7BF0AC14B81A276E2FD27E1ABA63D96E536)                                                                                                                    |       0    |         1 | 2022-11-29   |
| 2235 | [mikael datanerd.se](w/relay/B5410AF840A3DA3DCDA1EEC093167311CEB432EF)                                                                                                          |       0    |         1 | 2024-12-07   |
| 2236 | [daddycool69@duck.com](w/relay/B573564FBC6923A3B0ADDE73982EBECA618A7A70)                                                                                                        |       0    |         1 | 2024-09-05   |
| 2237 | [zuzan@cock.li](w/relay/B5CDCE60218E99E5D1964B41D1BC307B54913C79)                                                                                                               |       0    |         1 | 2024-09-29   |
| 2238 | [B6339F95](w/relay/B6339F959AB98D45E311A08E422E9A15DF795B13)                                                                                                                    |       0    |         1 | 2024-08-15   |
| 2239 | [B63626A3](w/relay/B63626A3CA6F0521847853DDEC6D4044C80B903E)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 2240 | [xjfkytxy@duck.com](w/relay/B636837E9432EE15729978B24F1958D644D5B0D6)                                                                                                           |       0    |         1 | 2023-03-21   |
| 2241 | [&lt;mwaechter AT mac dot com&gt;](w/relay/B6526852EF18FB54BC91437B54055D16FD581898)                                                                                            |       0    |         1 | 2022-12-19   |
| 2242 | [AC2D10FD](w/relay/AC2D10FD514ED4CC417BCDD5773A1BCEDAC324D5)                                                                                                                    |       0    |         1 | 2024-10-02   |
| 2243 | [ACD2A656](w/family/75a6b9753a38d90b5409c98219021de128411e7887f7ee2305e7b3fee12d8aaa)                                                                                           |       0    |         2 | 2024-02-28   |
| 2244 | [e5bd61de-e40c-432e-8bbe-543843074571@tordiversity.anonaddy.com](w/relay/ACF8FC6C14032A045B44F6B98525EE5C0472DD50)                                                              |       0    |         1 | 2020-01-24   |
| 2245 | [torrelay.60doj@8shield.net](w/relay/AD13AFE5D4A6A68A2498F3735D0401C968EA8CD0)                                                                                                  |       0    |         1 | 2024-01-22   |
| 2246 | [myLittleTorRelay on proton period me](w/relay/AD3F7BAD12BE185C837B6CEBB325B3B1BE75A555)                                                                                        |       0    |         1 | 2024-02-27   |
| 2247 | [AE3CED88](w/relay/AE3CED885E8822F6E3FF4EF6A62118FF4F4151D8)                                                                                                                    |       0    |         1 | 2024-01-21   |
| 2248 | [&lt;toradmin at rlogin.net&gt;](w/relay/AE4FAE2EB5DC5D078458F0FCBF2B37F5D73F0868)                                                                                              |       0    |         1 | 2019-02-18   |
| 2249 | [AE8E77AD](w/relay/AE8E77AD98EC3EFA3F228CF373A29F9624CBBF63)                                                                                                                    |       0    |         1 | 2024-08-14   |
| 2250 | [torvarval@proton.me](w/relay/AF2CBADAB74AD6661EDA68162EC5407A3B5B010E)                                                                                                         |       0    |         1 | 2024-02-01   |
| 2251 | [DuckSounds31@aol.com](w/relay/AF4997738E0CFC014CD04FB09A670D2C5F1E79A4)                                                                                                        |       0    |         1 | 2019-02-18   |
| 2252 | [nah](w/relay/AF69EADAF6905DB800955204587B5A77C5F24DBF)                                                                                                                         |       0    |         1 | 2024-01-21   |
| 2253 | [tor-NLfreedom@protonmail.com](w/relay/AF8DB275960279B87F098B16CC9C78092E118DB3)                                                                                                |       0    |         1 | 2022-03-04   |
| 2254 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/AF1C02D6BF9827BB956F09C454C28B431B1EFFE7)                                                                                          |       0    |         1 | 2019-07-18   |
| 2255 | [AFBAFBD8](w/relay/AFBAFBD810CD4E965E5B4902B8111D1AD3E14326)                                                                                                                    |       0    |         1 | 2024-07-30   |
| 2256 | [AFCF9FB5](w/relay/AFCF9FB55FA76D6942AA081F4BC1C47B1BF62CE3)                                                                                                                    |       0    |         1 | 2024-09-05   |
| 2257 | [AFFD147D](w/relay/AFFD147DBCC065A5CEF7258BC1367CC35855A431)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 2258 | [Tor Manager &lt; forest DOT owlet AT riseup dot com&gt;](w/relay/B00A2DE75DEB8ABB3058290CE311A3D9D096797A)                                                                     |       0    |         1 | 2024-01-21   |
| 2259 | [B03D9DA5](w/relay/B03D9DA59686ED8195E25C4CC98E8765F445F142)                                                                                                                    |       0    |         1 | 2024-03-06   |
| 2260 | [tor at zyron dot de](w/relay/B09B5E352D85A34C199B2899FB38430F121429B6)                                                                                                         |       0    |         1 | 2022-09-30   |
| 2261 | [lemongrab@posteo.de](w/relay/B0AD9C3F75C994CEEB9CFC1BD6985F6DC82753B1)                                                                                                         |       0    |         1 | 2023-03-03   |
| 2262 | [0x6EE6A3CB856843C0CBBD5BA413ED656CAFBC258B carchecks oobal &lt;carchecks oobal AT s](w/relay/B0C2AC493F8806920FEA00429533292309EEC39F)                                         |       0    |         1 | 2022-08-31   |
| 2263 | [4mdeh8uy7pidm16 &lt;tor abuse@MalShare.com &gt;](w/relay/B0E93B10BD817250A818ABF7F5C2444AF364DD67)                                                                             |       0    |         1 | 2021-12-24   |
| 2264 | [B12322D4](w/relay/B12322D40E4B3ED9AFBA37B75829E96AA854B4E8)                                                                                                                    |       0    |         1 | 2024-09-03   |
| 2265 | [&lt;8uk54nt0 AT gmail DOT com&gt;](w/relay/B125B20FCCA2A54422C50DC2156E872D5B45A368)                                                                                           |       0    |         1 | 2024-03-30   |
| 2266 | [makeitfoss@proton.me](w/relay/B13BF9FB86663B2D587611B5F3369873919AC54F)                                                                                                        |       0    |         1 | 2022-11-19   |
| 2267 | [x12413@proton.me](w/relay/B196603D5593B557D2FB8735A44C1D947AF793EE)                                                                                                            |       0    |         1 | 2024-10-13   |
| 2268 | [idom@cock.li](w/relay/B1AA9E3D8D07DB5873E2036BDBEE079BFA263EB4)                                                                                                                |       0    |         1 | 2024-12-25   |
| 2269 | [B1B687C3](w/relay/B1B687C3C4EF46249D638DCE77DDC7AAA39F2996)                                                                                                                    |       0    |         1 | 2022-02-02   |
| 2270 | [ParseThisClever tor insertSymbols dirasad withEnding de](w/relay/B1F410C0F1C2139E7013FC8DCA6CC1F3F11C2D54)                                                                     |       0    |         1 | 2023-06-07   |
| 2271 | [lenkasykorova47@gmail.com](w/relay/B2208BEAAFE62665A727F3D142CB4DCE3DCBC57A)                                                                                                   |       0    |         1 | 2023-07-25   |
| 2272 | [BAE70B5A](w/relay/BAE70B5A61B12A3D31DEE94E697AF1FDA9A9B82D)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 2273 | [BAF223E9](w/relay/BAF223E9DF62D3261F1675C6CFC4E5D50F15FA57)                                                                                                                    |       0    |         1 | 2020-02-13   |
| 2274 | [BB504941](w/relay/BB5049414D9C6C3BEE418081FB6AAE145EDFDC3D)                                                                                                                    |       0    |         1 | 2024-08-21   |
| 2275 | [BB5E140E](w/relay/BB5E140E531D419E5075ABA52EA15DA845745C2A)                                                                                                                    |       0    |         1 | 2024-06-26   |
| 2276 | [BB6E1A7A](w/relay/BB6E1A7AC8702EC624DFF9BB6DC4AF3097E57CA6)                                                                                                                    |       0    |         1 | 2021-06-17   |
| 2277 | [bob &lt;thereddale69 AT outlook.com&gt;](w/relay/BB93B8F50B98C718901F0242DB34C6852E33B0A5)                                                                                     |       0    |         1 | 2022-10-20   |
| 2278 | [admin at wakegi dot net](w/relay/BB9C5D15BC3B77C8AF5CBC733F7E54553A1B7BD5)                                                                                                     |       0    |         1 | 2019-02-18   |
| 2279 | [mo@tor.nonze.ro](w/relay/BBBBBAD453263D786EC34AB68A06214288910345)                                                                                                             |       0    |         1 | 2015-07-09   |
| 2280 | [BBCCB09B](w/relay/BBCCB09BD4F1EE2E4DE793113552E107EED72D43)                                                                                                                    |       0    |         1 | 2024-08-01   |
| 2281 | [BBD8F4DF](w/relay/BBD8F4DF8FF5C69A6A989DB8C1EE2CA7ADFE0755)                                                                                                                    |       0    |         1 | 2024-09-17   |
| 2282 | [BC5D9898](w/relay/BC5D9898817E3F07CDD4292B35DA6819368710B7)                                                                                                                    |       0    |         1 | 2024-09-26   |
| 2283 | [BC85F046](w/relay/BC85F04685B217151385DD0A27FE55D55DC6591F)                                                                                                                    |       0    |         1 | 2024-04-23   |
| 2284 | [w6eeehrjq &lt;&lt;at&gt;&gt; mozmail &lt;&lt;dot&gt;&gt; com](w/relay/BCBCB4A80D2930759A0212DEC5F8B15306AD6D31)                                                                |       0    |         1 | 2024-08-16   |
| 2285 | [@](w/relay/BCC3D533825ED44E3F95102F0E3277E5CBEBCCA1)                                                                                                                           |       0    |         1 | 2022-04-23   |
| 2286 | [mailto:iangtornode@cs.uwaterloo.ca - 12UfuXzi5m3PmW5ask1Pc6BnBNe3cgKQan](w/relay/BCEDF6C193AA687AE471B8A22EBF6BC57C2D285E)                                                     |       0    |         1 | 2019-02-18   |
| 2287 | [t.yeerum@yahoo.com](w/relay/BD610AAEAE179EC259B022A178A75C70042407FB)                                                                                                          |       0    |         1 | 2024-04-10   |
| 2288 | [email:fossdd pwned.life pgp:80E2164367131107A806C897BB8C8A81 mastodon:https://c](w/relay/BDA597D6E4912672C2D34E8792B5DD8DF4D580EC)                                             |       0    |         1 | 2024-12-19   |
| 2289 | [BDD003B8](w/relay/BDD003B8B9CFC66BF868D3AE6805B8409684470A)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2290 | [Spam Trap &lt;tor ATTTT r4v3n dot dot dot net&gt;](w/relay/BDD09D5DB782B6023791DBFFD46F100B1F023ABB)                                                                           |       0    |         1 | 2022-02-02   |
| 2291 | [email: bigul AT tutanota DOT com](w/relay/BDF94785D94FA9B2E5DFC382826818BED61E5EB8)                                                                                            |       0    |         1 | 2024-08-17   |
| 2292 | [BE106F94](w/relay/BE106F9438D93083629682113A8F566179BF1B44)                                                                                                                    |       0    |         1 | 2024-09-29   |
| 2293 | [BE1114D1](w/relay/BE1114D1B41895C2D67C5962CE356AE689CE0CD1)                                                                                                                    |       0    |         1 | 2022-08-11   |
| 2294 | [MakeTorGreatAgain@gmail.com](w/relay/BE7AE02B0DCD38FC77A7EA420DFF3FF5F0F0B8B0)                                                                                                 |       0    |         1 | 2024-07-20   |
| 2295 | [BF155CD2](w/relay/BF155CD2E38AA2306B72D789C1952C8373C490E8)                                                                                                                    |       0    |         1 | 2024-02-13   |
| 2296 | [BF281E46](w/relay/BF281E46342A0C582E415DEFBD9DDB530C526F6F)                                                                                                                    |       0    |         1 | 2024-06-26   |
| 2297 | [BF7F6B20](w/relay/BF7F6B2009971F07EDA206EA69E0EAB707030AE5)                                                                                                                    |       0    |         1 | 2024-08-23   |
| 2298 | [&lt;tor AT b4ne dot de&gt;](w/relay/BFC1305C8B37E5161C2E37135DF2D4E53CC38ACE)                                                                                                  |       0    |         1 | 2019-02-18   |
| 2299 | [BFD6FBF3](w/relay/BFD6FBF3D405DCE67704D54D8DC46986CF75FC55)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2300 | [NO SOLICITING ////// jimbo263 ///// @fastmail.com ------](w/relay/BFF8AE91EA09B2207432CA4C60E449F3516E7C3D)                                                                    |       0    |         1 | 2024-03-15   |
| 2301 | [0xFFFFFFFF Yerfren](w/relay/C0100C150EA96E1CBBBFB3B770EFCD50C5F55F8F)                                                                                                          |       0    |         1 | 2024-11-25   |
| 2302 | [Justagettingit@yahoo.com](w/relay/C02B959A115AEA7CC44E83E0DC0794CD2AC5F821)                                                                                                    |       0    |         1 | 2024-12-06   |
| 2303 | [Amer Dude &lt;amerdude AT protonmail dot com&gt;](w/relay/C03BAA3238792C65EEECCB9791C543164F23AB91)                                                                            |       0    |         1 | 2024-03-29   |
| 2304 | [noctor@tritan.gg](w/relay/C077CE0ECBA0AB9B58410777CE16CF9B5F875BAE)                                                                                                            |       0    |         1 | 2024-02-06   |
| 2305 | [C0916071](w/relay/C0916071FA0D0B4FA357D19D09C5A7EA6722DB7A)                                                                                                                    |       0    |         1 | 2024-03-11   |
| 2306 | [email:abuse-zuluu at protonmail dot com url:http://tor-exit.zuluu.net](w/relay/C09DFF947C9ED5C479B371C3BCAE7FF7D573F98C)                                                       |       0    |         1 | 2023-08-20   |
| 2307 | [torrelay@drkt.eu](w/relay/C0F05AF3B4347631F92200B2DB987B5B73AC71C9)                                                                                                            |       0    |         1 | 2022-07-12   |
| 2308 | [a.1@blackbase.de](w/relay/C1154ABA79D89595B861C9C9794F88E68396D767)                                                                                                            |       0    |         1 | 2022-01-23   |
| 2309 | [Marco &lt;mmtr@dorfdsl.de&gt;](w/relay/C12BEA9AE8848A90FBC36403B25E32BBE5F3DD2F)                                                                                               |       0    |         1 | 2025-01-02   |
| 2310 | [exactlee &lt;exactlee AT kir dot dev dot gmail dot com&gt;](w/relay/C148A3CCBAC39858FFA631BD0EF07EA4044662FF)                                                                  |       0    |         1 | 2022-10-30   |
| 2311 | [sink1999@gmail.com](w/relay/C171B79FF282D3394129D66D83AFEA85548138D1)                                                                                                          |       0    |         1 | 2024-01-22   |
| 2312 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/C1BB67D3FBED68D4BAD400D1A49C5B79ECE3965E)                                                                                          |       0    |         1 | 2024-09-22   |
| 2313 | [C1DCC470](w/relay/C1DCC470C80F6D702C5ED11515936444BD3A0255)                                                                                                                    |       0    |         1 | 2020-04-23   |
| 2314 | [planetpower AT earthmate DOT to](w/relay/C28363EA6BA475D5E0A5EFB35BA8CA2A38A9ECE4)                                                                                             |       0    |         1 | 2024-01-22   |
| 2315 | [C2FB7025](w/relay/C2FB7025B740EB376CD8A84E9692E80C66EC8880)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2316 | [C2FBCAE5](w/relay/C2FBCAE5D74140DC18A348E077CAA02B191B5793)                                                                                                                    |       0    |         1 | 2024-09-04   |
| 2317 | [email:DicedOnions airmail.cc pgp:44518269EE80A8CD8519F4206CAF73918253E26B os:de](w/relay/C3233B1747A970F7043F090409F5893A9064EDE1)                                             |       0    |         1 | 2021-09-25   |
| 2318 | [Waka &lt;waka AT waka dot com&gt;](w/relay/C34AD7C63192F710D72D5CFD7B810C34C944C03C)                                                                                           |       0    |         1 | 2023-01-28   |
| 2319 | [C3503770](w/relay/C3503770F465DA6F549F6065AFF7B8CFBF62C222)                                                                                                                    |       0    |         1 | 2019-11-15   |
| 2320 | [a-n-o-n-y-m-e.net](w/relay/C36595014939C7B211BCD87502CA37431AF9C15E)                                                                                                           |       0    |         1 | 2024-05-29   |
| 2321 | [Jordan &lt;jordan zero three two one AT gmail dot com&gt;](w/relay/C366391E67A29CE959A15193D0CF2F9ED94F3578)                                                                   |       0    |         1 | 2020-09-30   |
| 2322 | [skelly1178 AT proton DOT me](w/relay/C44FEBCAF4C83731742479149670812F7AC95936)                                                                                                 |       0    |         1 | 2024-10-03   |
| 2323 | [C4663EA5](w/relay/C4663EA5C3EA666514AA3E92A453578BC6E591BB)                                                                                                                    |       0    |         1 | 2024-04-24   |
| 2324 | [C4ECFD56](w/relay/C4ECFD56A447F7F32907683873A28287EA3A1E06)                                                                                                                    |       0    |         1 | 2024-02-19   |
| 2325 | [FlashTor at e.mail DOT de](w/relay/C4F793FFE2D8421052D3F317C5FB8A686B1DA8F5)                                                                                                   |       0    |         1 | 2024-11-28   |
| 2326 | [C540D5E0](w/relay/C540D5E0AE404DA6DDF01040FA427508948C89DC)                                                                                                                    |       0    |         1 | 2024-10-14   |
| 2327 | [a-n-o-n-y-m-e.net](w/relay/C54BBA45D25E64037CAA107C3699F327D9934A67)                                                                                                           |       0    |         1 | 2024-05-07   |
| 2328 | [C554EB32](w/relay/C554EB32BA74A27626BCE864F738457071725719)                                                                                                                    |       0    |         1 | 2024-06-26   |
| 2329 | [postmaster@floerens.eu](w/relay/C56929A52A4BF66E146794187BFD592491B565F9)                                                                                                      |       0    |         1 | 2022-10-10   |
| 2330 | [C5ADD0D1](w/relay/C5ADD0D14EB1B6A7F0125486FFA121ADF53C5CB4)                                                                                                                    |       0    |         1 | 2024-07-26   |
| 2331 | [C5B58715](w/relay/C5B5871594E1E656CC87C1B9C3EE2BAD8258F7B7)                                                                                                                    |       0    |         1 | 2023-06-09   |
| 2332 | [jp-relays@proton.me](w/relay/C600CE01A3684FAAEC1F0EDE122C13DFBFCD59CA)                                                                                                         |       0    |         1 | 2024-11-19   |
| 2333 | [Sys Admin &lt;SIBLING NICK NAME AT proton dot me&gt;](w/relay/C60F0BE03DECFAEAEA0398362F985B39DAAF4A54)                                                                        |       0    |         1 | 2023-06-11   |
| 2334 | [dns@opennameserver.org](w/relay/C6763FBA664E0A4CE434850FAAFA59A6B9C63478)                                                                                                      |       0    |         1 | 2022-10-20   |
| 2335 | [C6BAD239](w/relay/C6BAD2390A255AA204827E6639201CDD38A51296)                                                                                                                    |       0    |         1 | 2024-02-09   |
| 2336 | [free.anonymous@internet.com](w/relay/C6CA977DCA63F7808F6300CCB985FB722AD499B0)                                                                                                 |       0    |         1 | 2024-01-22   |
| 2337 | [C6E93004](w/relay/C6E93004D57F6C8ECD9F5938D860390DAA046AB8)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 2338 | [chromacy@pm.me](w/relay/C6FFE2AB0CFFA86FB161DCB5BC72DA6A764E545E)                                                                                                              |       0    |         1 | 2024-07-18   |
| 2339 | [&lt;tor-admin AT tma-0 DOT net&gt;](w/relay/C72A5061DD5EB229CDF16BADA740943EEAEEFE51)                                                                                          |       0    |         1 | 2020-06-12   |
| 2340 | [C75A9693](w/relay/C75A9693422A2C19786B6F84BE6EA0EECA58A269)                                                                                                                    |       0    |         1 | 2024-06-03   |
| 2341 | [eandy@gmx.de](w/relay/C78689CFDC3EFB435FD62BE874639AEAAC9C353F)                                                                                                                |       0    |         1 | 2024-01-22   |
| 2342 | [C8177AD2](w/relay/C8177AD2FF4935E981BC547DCD8EA58B63C7784B)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2343 | [Nihal Jere &lt;tor aT nihaljere DoT xyz&gt;](w/relay/C81A067DAC337ED70D25F1A3CD2C241FD23A7723)                                                                                 |       0    |         1 | 2024-03-17   |
| 2344 | [C858338D](w/relay/C858338DE4A0A76BA37DD60FDFEF252A3E3169A6)                                                                                                                    |       0    |         1 | 2024-09-24   |
| 2345 | [chapman.shoop@riseup.net](w/relay/C899F20DC8005037C86B0E447857383D95FC7422)                                                                                                    |       0    |         1 | 2022-08-31   |
| 2346 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/C8DE26D2D119BE7F509E672EE1A3D5FB25DCBA97)                                                                                          |       0    |         1 | 2024-09-22   |
| 2347 | [C90A0A41](w/relay/C90A0A41CE492723902DC55B2512A608FE733F0E)                                                                                                                    |       0    |         1 | 2024-11-13   |
| 2348 | [topshelfcircadian@proton.me](w/relay/C91C195DC11CD64F33AFCE18307BBB930BE0B05B)                                                                                                 |       0    |         1 | 2025-01-04   |
| 2349 | [5h098y32 at duck . com](w/relay/C930451331FE2A3BE423C62E45F5C43EA7D06207)                                                                                                      |       0    |         1 | 2024-08-28   |
| 2350 | [C9A5FBC2](w/relay/C9A5FBC2C469AD66347BE0A7E88CCB95897C2BE6)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 2351 | [C9C1D11A](w/relay/C9C1D11A40D6F42C1942CACED6CF7AE270065A4C)                                                                                                                    |       0    |         1 | 2022-03-04   |
| 2352 | [C9C8F183](w/relay/C9C8F1838AA2C5BB7E940D9063458301F555A54C)                                                                                                                    |       0    |         1 | 2024-08-02   |
| 2353 | [C9D614B9](w/relay/C9D614B9EC02B6FFCC45920C800CB72676CEDB7D)                                                                                                                    |       0    |         1 | 2024-02-13   |
| 2354 | [0x3FBCCE84D378F232223CCF6637E31222F67A9925 TorOnCampus &lt;toroncampus at uni-goett](w/relay/C9D9FA7EC056D62CC9671F4804F22A0926A11873)                                         |       0    |         1 | 2021-07-27   |
| 2355 | [CA0AF3B5](w/relay/CA0AF3B52DA7C89E9A7BFCCD27FAAB889CC9928C)                                                                                                                    |       0    |         1 | 2024-03-25   |
| 2356 | [abuse@nycmesh.net](w/relay/CA52E423ECBF7D07BB8E1139A39B4D8668CFE2A4)                                                                                                           |       0    |         1 | 2020-07-12   |
| 2357 | [reverse individual parts &lt;rot@gniretseptnatsni.ten&gt;](w/relay/CA5E1C0163FFF18B788172BE0311C7115C927BE9)                                                                   |       0    |         1 | 2023-03-07   |
| 2358 | [CA9BCCB4](w/relay/CA9BCCB47B777BE459D0449E2AA6130C2DBA508D)                                                                                                                    |       0    |         1 | 2024-01-21   |
| 2359 | [0xFFFFFFFF &lt;boogly91mailfencecom&gt;](w/relay/CAAF196BBD92CA8BE0F64868D16B7DCD4A629A0F)                                                                                     |       0    |         1 | 2022-09-20   |
| 2360 | [fliegen dot franz at web dot de](w/relay/CAF555E9B3C9D2767F475834A60EE3AFB7A26B8D)                                                                                             |       0    |         1 | 2024-12-11   |
| 2361 | [CB0BD833](w/relay/CB0BD83327C924650CCFBDCAD50EC2FC48792098)                                                                                                                    |       0    |         1 | 2024-02-19   |
| 2362 | [blockchain@localhost](w/relay/CB6C681E1CE8E963B32193122B01D6639D023261)                                                                                                        |       0    |         1 | 2025-01-07   |
| 2363 | [Random Guy &lt;nobody AT example dot com&gt;](w/relay/CBC8D277C35BCE9512BA45479CF8141FC6A2CD73)                                                                                |       0    |         1 | 2022-09-30   |
| 2364 | [namelessuncookedfish@gmail.com](w/relay/CBF59EF62DAD30A2ED6F37439A30CD92250F986D)                                                                                              |       0    |         1 | 2024-11-22   |
| 2365 | [Osservatorio Nessuno &lt;exit AT osservatorionessuno dot org&gt;](w/relay/CBFD3B3032BFB9C2F8B21A0CD0D4E7D098A6317B)                                                            |       0    |         1 | 2024-12-20   |
| 2366 | [CC3113E6](w/relay/CC3113E6D50D2CC7A1CAC94624DD2D6C0021F56F)                                                                                                                    |       0    |         1 | 2021-03-29   |
| 2367 | [CC514DD6](w/relay/CC514DD6345634655B8AED3DE4B3A48A2B42C624)                                                                                                                    |       0    |         1 | 2024-07-10   |
| 2368 | [CC81D47E](w/relay/CC81D47ED10C214720E06D993B50E0FB24FC58DA)                                                                                                                    |       0    |         1 | 2024-06-19   |
| 2369 | [bigsnoozefestATprotonDOTme](w/relay/CD07AB6F26892A7CAF10B1FD5B9C3E4A6A7BCB3F)                                                                                                  |       0    |         1 | 2024-01-22   |
| 2370 | [url:carson.riker.me email:c &lt;at&gt; rson.riker.me](w/relay/CD6E152C0C16550DC3B1CD099F6F1956658F031F)                                                                        |       0    |         1 | 2023-03-23   |
| 2371 | [N/A](w/relay/CD94752BFBC94EC82F081B86E95241BB71D7CF99)                                                                                                                         |       0    |         1 | 2024-01-29   |
| 2372 | [Zighinetto &lt;tor -a t- zi ghi netto dot org&gt;](w/relay/CDD296D8C38EAA6A94242FCF03293E0D6EC4A0D0)                                                                           |       0    |         1 | 2019-02-28   |
| 2373 | [tor@anarchosyndical.org](w/relay/CDE6F0F6977872319BCFFA14085ED13C0A8DA37C)                                                                                                     |       0    |         1 | 2024-12-21   |
| 2374 | [CE301561](w/relay/CE3015614E7A23600B86FFF7F865B0D173B57B54)                                                                                                                    |       0    |         1 | 2024-06-09   |
| 2375 | [staaf@protonmaildotch](w/relay/CE9ED7FB244F80F6310A6DC399F904C202FD8068)                                                                                                       |       0    |         1 | 2023-08-14   |
| 2376 | [justin.brisceaux@protonmail.com](w/relay/CEAD826E0C9C867EDCE24D8B77B47D34758F09BA)                                                                                             |       0    |         1 | 2024-03-06   |
| 2377 | [CEE1DAFD](w/relay/CEE1DAFD2B3603083DDCBE8781FB8A4A0417681E)                                                                                                                    |       0    |         1 | 2024-08-16   |
| 2378 | [&lt;sunshinecowboy56 AT protonmail dot com&gt;](w/relay/CF32AA6FAD3A4C01A446CEF8E1382BED88CA56F3)                                                                              |       0    |         1 | 2024-05-11   |
| 2379 | [squeegee@protonmail.com](w/relay/CFD098963298EFFB2113008F810557B733EEFB75)                                                                                                     |       0    |         1 | 2024-10-01   |
| 2380 | [CFE1CB23](w/relay/CFE1CB239402FE41AC0A57A378144741890785DE)                                                                                                                    |       0    |         1 | 2021-10-05   |
| 2381 | [D0886A4A](w/relay/D0886A4AF140123E476D7804EF51CA74BAE1CE5F)                                                                                                                    |       0    |         1 | 2022-01-13   |
| 2382 | [tor@breakpointingbad.com](w/relay/D0997AF3E07807542187BA0935AC08DD9FD520D4)                                                                                                    |       0    |         1 | 2024-07-09   |
| 2383 | [D0BEAF48](w/relay/D0BEAF489E339783A0146DA7575241A2E7F52C45)                                                                                                                    |       0    |         1 | 2025-01-08   |
| 2384 | [onionmaster.alongside579@8shield.net](w/relay/D0C42D598EE74D9F43F4955DC00D4EB322D81438)                                                                                        |       0    |         1 | 2024-12-01   |
| 2385 | [&lt;orogom.online.de&gt;](w/relay/D0D93D5E8B46BD72B68617B402E2DBC16F8AA040)                                                                                                    |       0    |         1 | 2019-02-18   |
| 2386 | [email: bigul AT tutanota DOT com](w/relay/D0E8151159DFD72F7E0DB7EC2B72F2E822672C29)                                                                                            |       0    |         1 | 2024-06-13   |
| 2387 | [D11A3C11](w/relay/D11A3C113BBD6CC7A89CC6AB6FD7783F7749CB65)                                                                                                                    |       0    |         1 | 2022-03-14   |
| 2388 | [noc@august.tw](w/relay/D130B7A9322906D397C9CB41BC21450D3D64B324)                                                                                                               |       0    |         1 | 2022-03-24   |
| 2389 | [D142F47F](w/relay/D142F47F8DC559953F66199F1FE7C7C4BA1AE6EE)                                                                                                                    |       0    |         1 | 2022-02-02   |
| 2390 | [notashamed@privatemail.com](w/relay/D14C11B7D2E733F982DF7D74CC4995E722008774)                                                                                                  |       0    |         1 | 2024-06-28   |
| 2391 | [filip@fkomarek.eu](w/relay/D1751073A8BE912F7F288C059D86853BF0C393ED)                                                                                                           |       0    |         1 | 2023-01-18   |
| 2392 | [D1B300B4](w/relay/D1B300B4ED80412BB9CEFAB4323DA92671B06818)                                                                                                                    |       0    |         1 | 2022-07-22   |
| 2393 | [bofh &lt;info@sig9.ch&gt;](w/relay/D22F93E2675F17BFF6D232F479B59E788FEAF903)                                                                                                   |       0    |         1 | 2022-08-01   |
| 2394 | [social@supergsego.com](w/family/cb348ac7dd2e219987d17e1b3e5a6d8457686188b71dd90197464815b40729df)                                                                              |       0    |         2 | 2024-07-14   |
| 2395 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/D293946CD36646BCE6431EC8DFC2577EB72444D9)                                                                                          |       0    |         1 | 2024-09-22   |
| 2396 | [D2F8E54F](w/relay/D2F8E54FCF8E4E806AD3A57D34C85A3A73128122)                                                                                                                    |       0    |         1 | 2024-06-26   |
| 2397 | [heinrich5991 &lt;heinrich5991@gmail.com&gt;](w/relay/D30E9D4D639068611D6D96861C95C2099140B805)                                                                                 |       0    |         1 | 2019-02-18   |
| 2398 | [D33B263A](w/relay/D33B263A5BC3CED71EC6E0A30570E87407177E11)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 2399 | [abuse@zachmaier.de](w/relay/D349E0A7C940A16FACEEE8BB932CB732ED4619C7)                                                                                                          |       0    |         1 | 2024-01-22   |
| 2400 | [KurumiKira.github.io](w/relay/D3F30647183C1A20DB58107ECFBAF1F77C1BEEBD)                                                                                                        |       0    |         1 | 2023-02-07   |
| 2401 | [D412DEE6](w/relay/D412DEE6C99237D2A169229B0CD0222639A7BCAE)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 2402 | [subtype@protonmail.com](w/family/f77dc921d86415554392d8770fdf80dfd618b63798ba5e28a02cc69ff992925c)                                                                             |       0    |         2 | 2019-10-16   |
| 2403 | [Random Person &lt;xplato1 AT proton.me&gt;](w/relay/D4AF8B3C4BDD74606715F6CC5E702A730249FAA9)                                                                                  |       0    |         1 | 2024-10-20   |
| 2404 | [Random Person &lt;collard tethers0r AT icloud dot com&gt;](w/relay/D4B9ACCA7821A2CD4F0FA173A7ABE8F6E8058A94)                                                                   |       0    |         1 | 2024-11-19   |
| 2405 | [ms192@gmx.de](w/relay/D4C16732E765EB52EB0B749DB35DC14C8E0DF996)                                                                                                                |       0    |         1 | 2019-02-18   |
| 2406 | [torrelaysaregreat@gmail.com xmr:84czj1u2Q4dJ7bzf41TyDFS1i1GPKX5DQGgqZFg85LFge7LL](w/relay/D4DC70B25409B8E4B0FD482B8A70CA6A3F4A123C)                                            |       0    |         1 | 2020-08-01   |
| 2407 | [tor.pencil373@passinbox.com](w/relay/D4F0C88E27A6A50C4601E4E4F409121D07AB764B)                                                                                                 |       0    |         1 | 2024-06-02   |
| 2408 | [oniontears@tuta.io](w/relay/D505BC2332A52DC0FF9AD729B746764D01F981DB)                                                                                                          |       0    |         1 | 2022-09-20   |
| 2409 | [zukalt@proton.me](w/relay/D515C71F884D5350967E7260565A7211CD97F08C)                                                                                                            |       0    |         1 | 2024-10-19   |
| 2410 | [D5228FA5](w/relay/D5228FA5AA9FDB3825E6F199AFA9F9E6F9526A17)                                                                                                                    |       0    |         1 | 2019-02-28   |
| 2411 | [Privacy Is @ Human Right Two](w/relay/D53C431C0C194310553C2C780B5733BF223B1078)                                                                                                |       0    |         1 | 2025-01-06   |
| 2412 | [D58ABC85](w/relay/D58ABC85644F021638010310C3C4B3511A8A4142)                                                                                                                    |       0    |         1 | 2022-06-02   |
| 2413 | [D6473D96](w/relay/D6473D96B9F08F45DAF008E9B7CB2E2623D93407)                                                                                                                    |       0    |         1 | 2024-08-02   |
| 2414 | [974530@proton.me](w/relay/D691FC2D73D6DF38823B0BD40F70E5C1F8AFA96D)                                                                                                            |       0    |         1 | 2024-11-10   |
| 2415 | [someonesneighbor1@protonmail.com](w/relay/D698261BC1B4A80E24BD050909552C7FE9464CD2)                                                                                            |       0    |         1 | 2022-05-03   |
| 2416 | [FluentDuck &lt;Fluent Duck@proton.me&gt;](w/relay/D6D89229B54C18CB117C9418329EB97D8C471EFF)                                                                                    |       0    |         1 | 2024-12-17   |
| 2417 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/D70A5E01EC14D078164D5E587608949F85FD771B)                                                                                          |       0    |         1 | 2024-09-22   |
| 2418 | [4096R/34650013 La Quadrature du Net &lt;tor@laquadrature.net&gt;](w/relay/D71B1CA1C9DC7E8CA64158E106AD770A21160FEE)                                                            |       0    |         1 | 2019-02-18   |
| 2419 | [kalebmii2 at proton dot me](w/relay/D76D33B4866F2B61166E007C1DEFFEA82C5F1CDF)                                                                                                  |       0    |         1 | 2024-10-22   |
| 2420 | [0xFFFFFFFF Random Person &lt;Neblo d-o-t giovaskonin at googl&gt;](w/relay/D796A1698BF4A7F7E6B0BD981AF25582190C2971)                                                           |       0    |         1 | 2024-06-13   |
| 2421 | [ContactInfo torop &lt;at&gt; viking-sec &lt;dot&gt; xyz PGP:3297FA41D3C0E3E5FFD17DE9ADA62A49](w/relay/D7C20E4523BBBA6E6678FDB647E950EE0E9801AA)                                |       0    |         1 | 2024-11-02   |
| 2422 | [anon1mous54@hotmail.com](w/relay/D7F156D1A77B9E5CB59EFEB9CBBB6EC93734DBA1)                                                                                                     |       0    |         1 | 2022-11-19   |
| 2423 | [badgerfighter at proton dot me](w/relay/D7F59CFB13A93E4C0BF867374B66547E226A7255)                                                                                              |       0    |         1 | 2023-08-10   |
| 2424 | [D80A1696](w/relay/D80A169627F8819A8814A134A6CDA9B6E553CF42)                                                                                                                    |       0    |         1 | 2024-08-16   |
| 2425 | [D83307C7](w/relay/D83307C7C76637B62BF7D2897251AADB55786EE2)                                                                                                                    |       0    |         1 | 2024-08-16   |
| 2426 | [D9088D7D](w/relay/D9088D7D53CCEA555CE718199CC36EF5C5EE7C5C)                                                                                                                    |       0    |         1 | 2024-08-20   |
| 2427 | [biurolultornode@gmail.com](w/relay/D91074DFA38C1A2402DBCE45EE3FB1B21EAEFE19)                                                                                                   |       0    |         1 | 2024-11-23   |
| 2428 | [D9311BAC](w/relay/D9311BACD65E06683CE296FD857581248E9ED2DB)                                                                                                                    |       0    |         1 | 2024-11-22   |
| 2429 | [EE93AAEC](w/relay/EE93AAEC8AFBEAAC1FEE62D85062AB4A6A3E50A9)                                                                                                                    |       0    |         1 | 2024-08-16   |
| 2430 | [EEDD95DE](w/relay/EEDD95DEBF72F944265423B7E017A68CA4691AFF)                                                                                                                    |       0    |         1 | 2024-09-26   |
| 2431 | [TorManager &lt;tor@hint.de&gt;](w/relay/EF09163EC3F03C2F63A865BBBF1CE5642C6595A3)                                                                                              |       0    |         1 | 2019-02-18   |
| 2432 | [nomore4thelast@protonmail.com](w/relay/EF2D1A251634CFA7BC8883A8DD90C0548CFF2EF5)                                                                                               |       0    |         1 | 2024-10-21   |
| 2433 | [EF6B1864](w/relay/EF6B1864CBB379B708DE35C1605171832CA50D5D)                                                                                                                    |       0    |         1 | 2024-12-21   |
| 2434 | [Tor &lt;tor@plutex.de&gt;](w/relay/EF9C4611FAA7C21155A8BA2A721DDC3D27816035)                                                                                                   |       0    |         1 | 2019-02-18   |
| 2435 | [0x485EF628CB85CDD4CB7CFF0D52F5127650733A18 thican-tor &lt;thicantor AT thican DOT](w/relay/EFA4C5E7E9215E8A3C7A8F3C74D3139667DA92A5)                                           |       0    |         1 | 2024-08-04   |
| 2436 | [anon](w/relay/EFC68FF70A36CF8DE5E8437F2DCCFADF7A94A421)                                                                                                                        |       0    |         1 | 2024-01-22   |
| 2437 | [EFE57C38](w/relay/EFE57C3886F5348338B4503F128734212644DDF6)                                                                                                                    |       0    |         1 | 2024-03-26   |
| 2438 | [Pie4fusael0f &lt;AT&gt; vouti &lt;dot&gt; es](w/relay/EFE89ECF4EE11613A19248777EBBA28719BF5FF7)                                                                                |       0    |         1 | 2021-10-05   |
| 2439 | [tor support@nixuge.me](w/relay/F009AAD577E31AD444FF115F3206852ACC0EA87F)                                                                                                       |       0    |         1 | 2024-11-26   |
| 2440 | [tor.rawbit.ninja](w/relay/F00EC2E0A2CA79A57FE7A0918A087987747D772D)                                                                                                            |       0    |         1 | 2019-02-18   |
| 2441 | [F0248E8A](w/relay/F0248E8AB32DF624B11C2F39B35B6544BC6385FF)                                                                                                                    |       0    |         1 | 2022-04-03   |
| 2442 | [F02759CC](w/relay/F02759CC0746360CD69F01A493655001EBCF40A3)                                                                                                                    |       0    |         1 | 2024-05-14   |
| 2443 | [Tor Admin &lt;toradmin A@T esponde D0T net&gt;](w/relay/F0A1E8A5DFE14C18DAFBE99736F28AA3693C3117)                                                                              |       0    |         1 | 2023-07-11   |
| 2444 | [TorNode &lt;tornode AT parkbenchindustries dot com&gt; - 1PjwyggxcsmWJDqsq6G7hqgiLC2ia](w/relay/F10BDE279AE71515DDCCCC61DC19AC8765F8A3CC)                                      |       0    |         1 | 2019-02-18   |
| 2445 | [tor AT ppdlv DOT net](w/relay/F147C130DE74FF86460548E2ABFFF7EC10E19C3F)                                                                                                        |       0    |         1 | 2025-01-06   |
| 2446 | [thistoradm@thismirror.uk](w/relay/DD0B8B4A648AE5541AF5C73F354C8E149CEDD4DD)                                                                                                    |       0    |         1 | 2023-12-12   |
| 2447 | [kibbleandbits@protonmail.com](w/relay/DD824D94DD5AD7B6966911212D308BBD38AFF282)                                                                                                |       0    |         1 | 2024-08-06   |
| 2448 | [DF885E50](w/relay/DF885E50651903A212EE519BE5A58397AD2E0975)                                                                                                                    |       0    |         1 | 2022-07-22   |
| 2449 | [UHJpdmFjeSBpcyBhIGh1bWFuIHJpZ2h0IC0gUmVsYXlPcGVyYXRvcjgzNDg2NzJAcHJvdG9ubWFpbC5j](w/relay/DF8D5C8BA8CBA68D86CC0B3A58010E0C2A5EFAB4)                                            |       0    |         1 | 2024-01-22   |
| 2450 | [middlenode-sumsumbrrr do an at sign here stachelkaktus.net](w/relay/DFF8CBC1D9DA6C5091E9652C7268A6B6C8D7E599)                                                                  |       0    |         1 | 2022-01-03   |
| 2451 | [DFFB05E9](w/relay/DFFB05E90076F47A452563EC8250D8BB5921AE97)                                                                                                                    |       0    |         1 | 2025-01-01   |
| 2452 | [E0286D88](w/relay/E0286D8886D7710A995DC160B1CE98CCA360970C)                                                                                                                    |       0    |         1 | 2023-07-17   |
| 2453 | [c4sey.dadot at protonmail dot com](w/relay/E029FF0A9723031FC1139D557357C07A211BFE4E)                                                                                           |       0    |         1 | 2025-01-16   |
| 2454 | [E036313A](w/relay/E036313A3D629CF347CE36EB0C8BBAB3AEEE70C6)                                                                                                                    |       0    |         1 | 2024-06-27   |
| 2455 | [tor@themainten.net](w/relay/E0599418E161933E66CBBC83D0142C594340491A)                                                                                                          |       0    |         1 | 2024-01-22   |
| 2456 | [FlashTor at e.mail DOT de](w/relay/E063B40D1194210D705D2292BD697D5DDCC0887A)                                                                                                   |       0    |         1 | 2024-11-03   |
| 2457 | [E0688984](w/relay/E068898472A6FAC41D424FB5E124136C4BA69507)                                                                                                                    |       0    |         1 | 2023-07-01   |
| 2458 | [E06EC752](w/relay/E06EC752F35CED9A44438719DA7FEC6EB24AED24)                                                                                                                    |       0    |         1 | 2022-06-12   |
| 2459 | [tor4freedom-at-protonmail-dot-ch](w/relay/E09604188906B9E531847BA4809E171C35902149)                                                                                            |       0    |         1 | 2024-01-22   |
| 2460 | [David Stroud &lt;tor AT dapper period cod3s&gt;](w/relay/E09782C5F119131D5DF3C77B83E3214697AB6376)                                                                             |       0    |         1 | 2021-10-05   |
| 2461 | [carter@sullynode.com](w/relay/E0999C5F42D12204AA8038653DBACDCE1F40E7FF)                                                                                                        |       0    |         1 | 2024-01-29   |
| 2462 | [sysop](w/relay/E0A3471C24C9021CC58FBF774203046FD2BC893F)                                                                                                                       |       0    |         1 | 2020-07-12   |
| 2463 | [E0D22F3B](w/relay/E0D22F3B5A988AAB566B8292A6D3D97B7BE54E04)                                                                                                                    |       0    |         1 | 2022-07-22   |
| 2464 | [E1A7B34D](w/relay/E1A7B34DA2E8B25AE800B67BE90633C67BB01A93)                                                                                                                    |       0    |         1 | 2024-06-24   |
| 2465 | [NIEN SPAM rgrwilco @ mailc.net](w/relay/E1B79753AAD5227001AA1CC697590B7A7CB82BB2)                                                                                              |       0    |         1 | 2023-07-31   |
| 2466 | [the dude ------------------@---------------------- gmx.com](w/relay/E1C5E4857CD8E918FA03B1E15F1076D0A235B075)                                                                  |       0    |         1 | 2024-02-16   |
| 2467 | [E1C7847B](w/relay/E1C7847B5DB6407B0765CF07A98AE98AF812D4F0)                                                                                                                    |       0    |         1 | 2024-05-12   |
| 2468 | [a-n-o-n-y-m-e.net](w/relay/E1D7AEBD5218953FB8558056E13B25125CBE2B48)                                                                                                           |       0    |         1 | 2023-06-09   |
| 2469 | [E1DFA3F2](w/relay/E1DFA3F26F15E13E114A039137257786F008F899)                                                                                                                    |       0    |         1 | 2024-08-14   |
| 2470 | [tor@moritzwm.de](w/relay/E1E32C01926FAF7E046DF112A0385196A5125EC0)                                                                                                             |       0    |         1 | 2023-06-15   |
| 2471 | [4ebrv4vf4cnk6lfg4fatxa6p2ryd@hidefrom.us](w/relay/E204CAA69282ABCFF3AC0F9FA58FA4F1F62B7677)                                                                                    |       0    |         1 | 2025-01-02   |
| 2472 | [tor @ metalhearf . fr](w/relay/E21336A5D5B02839C63E1F68DC1CE03B067BACC8)                                                                                                       |       0    |         1 | 2021-09-05   |
| 2473 | [torcontact viper78fr AT gmail dot com](w/relay/E21FDE82F5298413C55550933B0D3441EE51F830)                                                                                       |       0    |         1 | 2024-11-22   |
| 2474 | [abuse at maxko dot org url:maxko-hosting.com](w/relay/E236F07D76472C914B09B8BA52930EED3555E6AF)                                                                                |       0    |         1 | 2022-07-02   |
| 2475 | [E2A4DE34](w/relay/E2A4DE345A25C84B5D8BB997951978020DE27D84)                                                                                                                    |       0    |         1 | 2024-02-29   |
| 2476 | [Random Person &lt;collard tethers0r AT icloud dot com&gt;](w/relay/E2B723BFE7CA5524DA64B56E3FE122E87E62F220)                                                                   |       0    |         1 | 2024-01-22   |
| 2477 | [temp1](w/relay/E2E55764B4920CE21AC46E26F3F3ADC14865231E)                                                                                                                       |       0    |         1 | 2025-01-08   |
| 2478 | [Teknikal Domain &lt;jack &quot;&quot; tazrly ATSIGN t d storage bay dot com &gt;](w/relay/E2E7A9FD0B9B2D4A861B46B68AE41AA3536C45AB)                                            |       0    |         1 | 2024-01-22   |
| 2479 | [94f8607f@queer.cat](w/relay/E304E897BA0D84ED978CBF579DA5C3180B9B0067)                                                                                                          |       0    |         1 | 2024-08-23   |
| 2480 | [&lt;spiritbomb2050 AT protonmail DOT com&gt;](w/relay/E354F57FB7468D87ABFE6B435950AEAA35909F44)                                                                                |       0    |         1 | 2024-05-31   |
| 2481 | [email:comotion hackeriet.no uri:cereal.hackeriet.no proof:uri-rsa ciissversion:](w/relay/E379A6CACEFAFE1B8EA68503BFCFF1215BF1EE7F)                                             |       0    |         1 | 2019-02-18   |
| 2482 | [tor at plasmanetworks dot net](w/family/da6a3d844c94ec7bacedaea559f3574b64e2e1add26c19fa5e425ca994096dba)                                                                      |       0    |         2 | 2021-04-28   |
| 2483 | [EA4DDBF7](w/relay/EA4DDBF70B690805C8A60C04AEED8E343628E3E4)                                                                                                                    |       0    |         1 | 2024-08-14   |
| 2484 | [EA5D809F](w/relay/EA5D809F2D7CBC9EDC53DC7A1F961426B154798C)                                                                                                                    |       0    |         1 | 2024-06-25   |
| 2485 | [torproject.disjoin051@8shield.net](w/relay/EA7370AB3A12A65D8DDCBB5FFDE29D2E1D692A08)                                                                                           |       0    |         1 | 2024-11-29   |
| 2486 | [michatux@e-mail.de](w/relay/EAD251CB824BD7634EF9FD47B835DE3B0B91BA06)                                                                                                          |       0    |         1 | 2024-04-26   |
| 2487 | [0xmose@proton.me](w/relay/EAD5F73946AE15D842050DE9A0277D489D6F0478)                                                                                                            |       0    |         1 | 2024-07-11   |
| 2488 | [Jerome Schnitzler &lt;SOTorRelayDE01@secmail.one&gt;](w/relay/EB42676A474B79E2F6F804DBA457EC7E13BBB938)                                                                        |       0    |         1 | 2024-11-16   |
| 2489 | [0xFFFFFFFF BotheredSoul &lt;botheredsoul@protonmail.com&gt;](w/relay/EB53BBCE030204968743E76EAD956A2D8E13BDC6)                                                                 |       0    |         1 | 2022-12-19   |
| 2490 | [tankf33der@disroot.org](w/relay/EB5F7ABB14C2C32DF540A9EDA0AD3672434B6BE9)                                                                                                      |       0    |         1 | 2022-10-20   |
| 2491 | [EB920694](w/relay/EB9206947D854D14FF8D0B61C79904D766181C91)                                                                                                                    |       0    |         1 | 2023-06-23   |
| 2492 | [EC4E56B2](w/relay/EC4E56B2FA1E1D59EA0881CA83414D6D67AE4A67)                                                                                                                    |       0    |         1 | 2024-03-28   |
| 2493 | [operator@ambient8.xyz](w/relay/ECE831534426279E32E530CDC9279D36E2A6AC60)                                                                                                       |       0    |         1 | 2022-05-03   |
| 2494 | [sMWEhyEpJQYwddk7@proton.me](w/relay/ED1B970A7C27D00C6783D6C8C166453ACCAEA017)                                                                                                  |       0    |         1 | 2024-08-20   |
| 2495 | [torzpi222 AT gmail dot com](w/relay/ED43B78B647367E8601F094B3B7238C5E9C45930)                                                                                                  |       0    |         1 | 2022-10-20   |
| 2496 | [ED50516F](w/relay/ED50516FB478E1EAC8C42933D1459A87C1C15EEC)                                                                                                                    |       0    |         1 | 2024-05-20   |
| 2497 | [MatrixOperator &lt;matrixoperator AT protonmail dot ch&gt;](w/relay/ED56784CA6686229534003F01F869D30720B14DB)                                                                  |       0    |         1 | 2024-07-02   |
| 2498 | [Top &lt;s8pn910sokiig0cc76bl2qud at systemli.org&gt;](w/relay/ED6801386BEC025CD6AB759B144A1CA0E81932D1)                                                                        |       0    |         1 | 2024-01-21   |
| 2499 | [Andsec Team &lt;security AT andsec dot ch&gt;](w/relay/ED8A3806CE0B2B7F52B0BFF06BFF089A6918402B)                                                                               |       0    |         1 | 2025-01-11   |
| 2500 | [abuse-tor@lists.kau.se](w/relay/EDAF30C58D6CCF359EA062C668C7180A17076440)                                                                                                      |       0    |         1 | 2019-08-17   |
| 2501 | [F25C8649](w/relay/F25C864917C1314FADCC8EBD1D2B1DCEE0EA666C)                                                                                                                    |       0    |         1 | 2024-12-01   |
| 2502 | [wm7alhb4jyqlajs2@0box.eu](w/relay/F2D6EB211744D41DC41CCB62BF1C3246D24B42A2)                                                                                                    |       0    |         1 | 2019-02-18   |
| 2503 | [F2E60DE0](w/relay/F2E60DE0F39BEA826B50EB619A014ADCE9619359)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 2504 | [Peter Rodge &lt;peter.rodge20 AT protonmail dot com&gt;](w/relay/F2ED5032B52021E7BADBBB82E6594F1A872FFD09)                                                                     |       0    |         1 | 2019-02-18   |
| 2505 | [Vulnix &lt;tor-contact AT vulnix dot net&gt;](w/relay/F319E2C484E2DE9001E6485F25064562D7EA8C6A)                                                                                |       0    |         1 | 2025-01-05   |
| 2506 | [F3201361](w/relay/F32013617A9D103353A3D188FCCE0495E5950230)                                                                                                                    |       0    |         1 | 2024-09-06   |
| 2507 | [F3280741](w/relay/F3280741F352866D86B2662D60E650D3A1EB3781)                                                                                                                    |       0    |         1 | 2024-01-22   |
| 2508 | [none@none.com](w/relay/F394083E8B87BC6535DEF52583B270B005514BBC)                                                                                                               |       0    |         1 | 2024-12-11   |
| 2509 | [F39B2BE0](w/relay/F39B2BE0F0B9DCFD3D43AAA12D6BE16B14B13A79)                                                                                                                    |       0    |         1 | 2022-06-22   |
| 2510 | [F41CFF18](w/relay/F41CFF189DA8C4C0029ACCAE5A3993065218C8EA)                                                                                                                    |       0    |         1 | 2022-05-23   |
| 2511 | [F434D536](w/relay/F434D53685923FE2A83D671A7D07B81DE5D01666)                                                                                                                    |       0    |         1 | 2024-08-05   |
| 2512 | [freenetwork AT protonmail dot com](w/relay/F46854EDACCD16828FEAAFC6C6EDDC07DDF04411)                                                                                           |       0    |         1 | 2019-02-18   |
| 2513 | [lelis -at- zoho.com](w/relay/F485E06EE00880E89C21D10086AABF07776591CD)                                                                                                         |       0    |         1 | 2023-08-08   |
| 2514 | [F4CD29F4](w/relay/F4CD29F48C34A88F771096FBFDBDE91B3CC2D911)                                                                                                                    |       0    |         1 | 2023-02-27   |
| 2515 | [USERPART tor DOMAINPART wh4f dot de](w/relay/F5165CF26965A27C90B62B016141C60E3E6DD9F5)                                                                                         |       0    |         1 | 2024-09-05   |
| 2516 | [Just another Morron &lt;jimytutcnd@use.startmail.com&gt;](w/relay/F648CDC2BC28B6C9FF2886FF4160D008F05FCD2D)                                                                    |       0    |         1 | 2023-08-18   |
| 2517 | [paulmataruso@dhitechnical.com](w/relay/F6E24FDB0D208D40292ED9274FEB7FAFA529AC25)                                                                                               |       0    |         1 | 2021-02-27   |
| 2518 | [aeon@oppai](w/relay/F732303DAE01A4EF9AF28127425950B494C59927)                                                                                                                  |       0    |         1 | 2024-01-29   |
| 2519 | [YoyoYankee &lt;american AT protonmail dot com&gt;](w/relay/F745D5A34A289EF0C88544D0DC400B21120F5E81)                                                                           |       0    |         1 | 2024-07-21   |
| 2520 | [A1D43308B65F647AF925CF37D8C32E50B43539C6 &lt;frost 055 a-t protonmail d0t com&gt;](w/relay/F7B387348CA9073A3F5D2AC16EA1CD0C80A44C50)                                           |       0    |         1 | 2022-12-09   |
| 2521 | [F8212628](w/relay/F82126287D1E83F41214090BAD9FF6D6BB0257C6)                                                                                                                    |       0    |         1 | 2024-09-04   |
| 2522 | [F8412946](w/relay/F84129468721879EC0904A1A8CC69CD9D8422B41)                                                                                                                    |       0    |         1 | 2024-06-25   |
| 2523 | [Random Person &lt;collard tethers0r AT icloud dot com&gt;](w/relay/F85B80C40360CFB0D4D894CBBB12BB75FF548FAB)                                                                   |       0    |         1 | 2024-01-22   |
| 2524 | [Major Runabout &lt;majorrunabout221010 at duck.com&gt; cannot reply to gmail.com addre](w/relay/F8C3AA6C93EE4F461B26E5FF325A7E2B5EA891BC)                                      |       0    |         1 | 2022-10-10   |
| 2525 | [F9860DED](w/relay/F9860DEDCEB62B74A728B50EE374293AC48386DA)                                                                                                                    |       0    |         1 | 2022-02-22   |
| 2526 | [sabotage.net](w/relay/F9D235DA3EE3C5568A063DDDBC2A89890F71E708)                                                                                                                |       0    |         1 | 2022-12-09   |
| 2527 | [F9D4704D](w/relay/F9D4704D8E89D4657603D88D572783F6876471F9)                                                                                                                    |       0    |         1 | 2025-01-08   |
| 2528 | [ShowMyWay@mail.ru](w/relay/FA3EC05000800EB7C49A9222C232115C4DA2F01B)                                                                                                           |       0    |         1 | 2024-06-25   |
| 2529 | [tor a.t napshome DO.T net](w/relay/FB0D29424A03E91E6953706D4549F9335A5ABCB1)                                                                                                   |       0    |         1 | 2024-07-06   |
| 2530 | [mrfreeman.tor@proton.me](w/relay/FB2A9727A7CFCF04E00EB551316DAABCC63DA1A5)                                                                                                     |       0    |         1 | 2024-12-03   |
| 2531 | [mctwisted.yf@gmail.com](w/relay/FB32976F43501FC5ABB8588531979B9D195E37F7)                                                                                                      |       0    |         1 | 2024-01-30   |
| 2532 | [FB8DAEA4](w/relay/FB8DAEA4AA0B845D518423753C6E125167BAAC64)                                                                                                                    |       0    |         1 | 2022-07-02   |
| 2533 | [tor@cs.uchicago.edu](w/relay/FB9F38024DCAB1D205373C7A21E850EE41994EDA)                                                                                                         |       0    |         1 | 2024-02-22   |
| 2534 | [FBC5D4C0](w/relay/FBC5D4C0B1826FA6A5BAB75008E292349D2BCC18)                                                                                                                    |       0    |         1 | 2022-08-21   |
| 2535 | [tor.rm6g4@slmails.com](w/relay/FBFA502FE2DFF5D1A8802EA372FAAF90B111AE62)                                                                                                       |       0    |         1 | 2024-11-14   |
| 2536 | [oneup1@gmail.com](w/relay/FC83153EA2FF3807029506A4B30A27D953DD98D4)                                                                                                            |       0    |         1 | 2024-04-09   |
| 2537 | [SexWarrior &lt;tor@omgomg.eu&gt;](w/relay/FCCCECDC44273C67FB374200138464F38DDF39AC)                                                                                            |       0    |         1 | 2019-05-09   |
| 2538 | [FCE5FFBF](w/relay/FCE5FFBFA528DE4BD8674ACFAA5AEE19DD9E0BAF)                                                                                                                    |       0    |         1 | 2022-07-22   |
| 2539 | [FD127D10](w/relay/FD127D1014ED3D36AFE50558A88BD5E8DB34A645)                                                                                                                    |       0    |         1 | 2020-06-02   |
| 2540 | [vollborn@quantentunnel.de](w/relay/FD7712D3ADD0AC652695B31643228A6A4ACA1455)                                                                                                   |       0    |         1 | 2024-06-08   |
| 2541 | [tor@mail.amiba.me](w/relay/FD81C299B8C3F7770A64AD21C054C863EFD9E130)                                                                                                           |       0    |         1 | 2024-01-21   |
| 2542 | [graven.dev](w/relay/FDAB3722A4EA6A86E35D9AC84222F3E11F2F6D6D)                                                                                                                  |       0    |         1 | 2019-12-05   |
| 2543 | [qfhlrud0@mailite dot com](w/relay/FDAFA1BD6B45D8FE09D62F6D282748F7919C8B0C)                                                                                                    |       0    |         1 | 2023-08-12   |
| 2544 | [ShadowExit@proton.me](w/relay/FE277F2B34C90904C1A2D704ED2A46FC0802400C)                                                                                                        |       0    |         1 | 2024-08-30   |
| 2545 | [immensefloat@protonmail.com](w/relay/FE39F7C17C1EED7CD10D84F9986A458E180C0F13)                                                                                                 |       0    |         1 | 2022-03-04   |
| 2546 | [FE857C30](w/relay/FE857C3043412FD5454ED5FEF55C4C572E5B70CF)                                                                                                                    |       0    |         1 | 2019-04-09   |
| 2547 | [FEAC1FFC](w/relay/FEAC1FFC11AF246AB20464DF06AB212C0AA457B8)                                                                                                                    |       0    |         1 | 2024-12-03   |
| 2548 | [FEC0BFE6](w/relay/FEC0BFE69CDBB940829BA6CC5F8074412F0AA3FD)                                                                                                                    |       0    |         1 | 2024-03-05   |
| 2549 | [FF3059E7](w/relay/FF3059E77E5D22F1C3B20CCBE125691AD27588DD)                                                                                                                    |       0    |         1 | 2019-02-18   |
| 2550 | [root@mlfh.org](w/relay/FF6F17FDB179F2EB9849463B1EE2EFE9E241EA01)                                                                                                               |       0    |         1 | 2024-02-01   |
| 2551 | [1AKfiFWajSckVrArTVh21KkdPuegordE3E](w/relay/FF84A1908508952A858140E82ED0FC3BFF65D012)                                                                                          |       0    |         1 | 2024-09-22   |
| 2552 | [FFBB2A09](w/relay/FFBB2A09942196BBF099D39C85612386597FDB50)                                                                                                                    |       0    |         1 | 2024-08-05   |

<div class="datatable-end"></div>

### Relay Families by Consensus Weight

<div class="datatable-begin"></div>

|      | Authenticated Relay Operator ID or Contact (unverified)                                                                                           |   CW Fr.(%) |   Exit(%) |   Guard(%) |   #Relays | First Seen   |
|-----:|:--------------------------------------------------------------------------------------------------------------------------------------------------|------------:|----------:|-----------:|----------:|:-------------|
|    0 | [nothingtohide.nl](w/family/cdd109daf1976d63204efd66d89354222d57f8fbbca75cbaacd8e801fe56a9fa)                                                     |        7.87 |     19.91 |       1.99 |       292 | 2020-07-02   |
|    1 | [artikel10.org](w/family/d3b1b3c59c4f50b9a9e46ca76abbea6995af6410b3c159a77f9bc8de76254716)                                                        |        4.25 |     12.76 |       0    |       160 | 2021-02-27   |
|    2 | [email:admin prsv.ch url:https://prsv.ch/ proof:ur](w/family/87119f7e2b1b336fdf6429d53ff38a1619451120836f7fa20c35460a511607f5)                    |        4.1  |      1.72 |       5.47 |       272 | 2024-03-03   |
|    3 | [quetzalcoatl-relays.org](w/family/e53b96a2e713f195c40b23066c02855e52d4b8312ec428806181618b988f9dbc)                                              |        3.14 |      7.81 |       0.81 |       350 | 2020-11-08   |
|    4 | [tuxli.org](w/family/688bf759a396dc0c171b2fcdcf8302cbd4dd913f4a1e29f7d0ac763471968014)                                                            |        2.74 |      2.64 |       2.82 |       104 | 2020-06-02   |
|    5 | [applied-privacy.net](w/family/6ba1ad9b8a5c8d91ade07a067299de03a3ab01adb55dca778dd858fa7bddb798)                                                  |        2.56 |      7.68 |       0    |       104 | 2018-04-15   |
|    6 | [for-privacy.net](w/family/8b0a1698e9701148fe1f4f49cb27c1f579dce411952de942b889d4d08bfd2f68)                                                      |        2.45 |      3.33 |       2.23 |        86 | 2019-03-05   |
|    7 | [www.f3netze.de](w/family/41de79b6591980723300320038e764274aa76efdba8d97331c8253c630ff707b)                                                       |        1.75 |      4.36 |       0.45 |        24 | 2019-02-18   |
|    8 | [digitalcourage.social](w/family/402d73786074e99e7d2ea8e637aca732fbe55256f2ed5a122047d18bb537ceac)                                                |        1.38 |      3.43 |       0.35 |        30 | 2020-07-12   |
|    9 | [email:support rdp.sh url:https://rdp.sh proof:uri](w/family/ce5bc1f05a9359fb0051f7df9fe7364ff70709c0d46255f596c2354651a6a99a)                    |        1.36 |      0    |       2.29 |        96 | 2024-07-04   |
|   10 | [www.cccs.de](w/family/5401b5c6fd3deb946e9864f7b2bfba241f1dabc0ee0b1ddae2be44e6b49687e7)                                                          |        1.3  |      3.23 |       0.33 |        42 | 2022-01-16   |
|   11 | [tor.r0cket.net](w/family/9393a5f7c52867fae73a02e65231b3fcf7bd473937f68d1409509045b5cdb03a)                                                       |        1.04 |      2.74 |       0.19 |        80 | 2024-09-26   |
|   12 | [09AEBB99](w/family/15125c2a65904ef495f636be6faf122f3a426b074fbf3a45ec2b61e711fe0c1a)                                                             |        0.77 |      0    |       1.31 |        25 | 2019-02-18   |
|   13 | [nos-oignons.net](w/family/d1c45eefa93e9afcc06447683ab4bbeb2a5f00a628053335ae7c868ce7242f25)                                                      |        0.74 |      1.84 |       0.19 |        39 | 2019-02-18   |
|   14 | [email:torix protonmail.com url:https://torix-rela](w/family/d6793cfc497962f8d9fd4d00366a2bebdbeda5b7d72ab1809ef11b7e81b0531d)                    |        0.72 |      1.8  |       0.18 |        76 | 2021-08-26   |
|   15 | [KeFF NOC &lt;noc AT keff dot org&gt;](w/family/7eedfa16e179476528b51ccc4e17a8d0860e3645b279dc421c1c445f6ca78836)                                 |        0.49 |      1.23 |       0.12 |        26 | 2020-07-28   |
|   16 | [dfri.se](w/family/6fb7a0af3654ec1c23c01edf49ae4770b655cf73b5309f2ebd6a29f844ee7387)                                                              |        0.47 |      1.17 |       0.12 |        32 | 2021-11-04   |
|   17 | [Brandon Kuschel &lt;tor AT NOSPAM brandonkuschel dot](w/family/098593149ac40b486e17384a6a7e36388d541e5ba4fa446bdf75649451945b8b)                 |        0.47 |      0.55 |       0.47 |        48 | 2021-04-08   |
|   18 | [artikel5ev.de](w/family/112404eed179f708ec241c1243dc451989f66248bd61fa2a2da6cb9fc5f36039)                                                        |        0.44 |      0.8  |       0.27 |        31 | 2016-10-19   |
|   19 | [tor vidister de](w/family/360c14adcf6b21bdcf9a425811d44d2f948b6158a1052a685e658ff222b709a3)                                                      |        0.43 |      0    |       0.74 |         8 | 2023-11-11   |
|   20 | [biogeobizz@nikora.biz.st](w/family/abf08ab4dc3090081c36891260774be8236a7bc709f39cc7d7dca10dfe7d1407)                                             |        0.43 |      0    |       0.74 |        29 | 2024-12-13   |
|   21 | [ftp.halifax.rwth-aachen.de](w/family/886498b8b4381f76b4ad48f4d45079c31755564d5cbddb8282e3697168c106ec)                                           |        0.42 |      0    |       0.73 |         9 | 2021-07-17   |
|   22 | [tor-operator@theu.li](w/family/5773405908235e49290e70f81c4bd220e1256242b3c8a5749fac3ad03331f769)                                                 |        0.42 |      0    |       0.67 |        20 | 2022-12-31   |
|   23 | [shadowbrokers.eu](w/family/ef1a383fb7611508270f5449270081df029d1c254dc1e03b5dbfe98f6cd5fde4)                                                     |        0.4  |      0    |       0.68 |        27 | 2023-02-17   |
|   24 | [relay // at // pommespanzer // dot // cc](w/family/5724f24f4e9f0c64d26ed28486f85199f1d7b2b7d3e55d2b62ee73d194891fc7)                             |        0.4  |      0    |       0.68 |        26 | 2024-06-03   |
|   25 | [gus@riseup.net](w/family/449ce42d7162a845a95e9ae91858ec62218e44be1f8bfa24597bbc9bc7099d63)                                                       |        0.39 |      0    |       0.66 |        24 | 2022-08-31   |
|   26 | [Hurdy-Gurdy &lt;admin AT my-mail dot rocks&gt;](w/family/1e225bfaffcc58003d2ae588f3a8216c92d6fa8c70c3de756b6a0d6b99706293)                       |        0.36 |      0.11 |       0.56 |         7 | 2023-05-10   |
|   27 | [dotsrc.org](w/family/9865b6a9911eeb03241484047e1a87e8cf56ab5dd8b307f9f88c9025629a74a0)                                                           |        0.33 |      0.58 |       0.23 |        12 | 2020-09-10   |
|   28 | [email:torrelay limoneneis.de url:limoneneis.de pr](w/family/9006e8d0ca3c103507258cea792a44e106afa540748f48d53c6b82eca4441fd0)                    |        0.32 |      0    |       0.53 |        10 | 2024-04-21   |
|   29 | [middelstaedt.com](w/family/7cdf3fadd53acd400f32861a800244204f1f24ed05a3fc7712adec1122d67daf)                                                     |        0.29 |      0.44 |       0.24 |        19 | 2022-10-20   |
|   30 | [kopfschusskorl@gmail.com](w/family/7c4aea12435a2ac1794c5e70f9999b4f7ae3498fc44132d47b9902c489479c18)                                             |        0.28 |      0    |       0.39 |         6 | 2024-04-09   |
|   31 | [cp tor mailfence dot com](w/family/6828d6cf95ae89f65a2472965a2bbd708862390633ad4d08703c7fc4a9d9a382)                                             |        0.28 |      0    |       0.44 |        28 | 2022-04-03   |
|   32 | [arbitrary.ch](w/family/aba671450d3f201e72fa3c7554efa89884374c584cdb0a599e076465fa838350)                                                         |        0.27 |      0    |       0.25 |        14 | 2019-02-18   |
|   33 | [735B3810](w/family/08e05139158c2c30db407a4e94c7657be9ff5c55ead3933438c7daaa01f4189d)                                                             |        0.27 |      0    |       0.46 |         5 | 2024-08-18   |
|   34 | [BMTY90VKYRQPUJZOTH @ Safe-mail.net](w/family/600c46e2ea3f5e74058bde039f03520e077048d7a8265452c5fc8ee1af76bcd7)                                   |        0.26 |      0    |       0.42 |        34 | 2019-02-28   |
|   35 | [gojira-family.dedyn.io](w/family/e385ad57ec3f8c820899564eacef183c6ac9f2af63c66d51e4134fe1ab084a13)                                               |        0.25 |      0    |       0.43 |        12 | 2022-04-03   |
|   36 | [lokodlare.com](w/family/319484775b244a3b771e32435accb18b4ab42a702608f6e74eee8b9d644dbd5b)                                                        |        0.23 |      0.23 |       0.26 |        12 | 2021-11-14   |
|   37 | [Viktor &lt;vnikolov AT vnikolov dot cz&gt;](w/family/3e64411d4e8695d1aa1d6a86b95025db4d7a711e6529489e0db667ce2588f0fd)                           |        0.23 |      0    |       0.39 |         6 | 2022-09-20   |
|   38 | [j.abrahim99 at proton dot me](w/family/a2efd0e5df084c324d6a06e9aff0ad80ee19f14210460bb93fb982ead49cf2c4)                                         |        0.22 |      0    |       0.38 |         9 | 2022-07-12   |
|   39 | [old memes222 AT pm.me](w/family/099f5ac9a4923e0867054c890eb0d29d5eb3ffb130c49d7d0a5860b2a22a1e1b)                                                |        0.21 |      0.53 |       0.05 |         6 | 2025-01-07   |
|   40 | [www.digitale-gesellschaft.ch](w/family/2b347e140ca2083820b8065a4c36cd001295daa6ec54149e0ae66528173ab16d)                                         |        0.21 |      0.53 |       0.05 |         9 | 2015-05-22   |
|   41 | [unredacted.org](w/family/d483e43e3415af923180ae140e4e9bde334d217288881f842616adde5dec8995)                                                       |        0.21 |      0.53 |       0.05 |        30 | 2021-11-07   |
|   42 | [FlokiNET &lt;noc@flokinet.is&gt;](w/family/771c968d16497365c3b229607b130bbbfe46817a410549a7757b3718698fe175)                                     |        0.21 |      0.53 |       0.05 |         9 | 2021-11-24   |
|   43 | [email:fuwafuwapankeki@proton.me](w/family/3e6f6a3a768bb5af85fe44c66d20619c0cafc166e3e4a3fa77652b3276482c8b)                                      |        0.2  |      0    |       0.35 |        12 | 2023-07-21   |
|   44 | [hviv.nl](w/family/cd4836da405366bd79a30ced489dd18364b379db15ae344919ff93fd5e09e49a)                                                              |        0.2  |      0.49 |       0.05 |        14 | 2018-04-27   |
|   45 | [tor@dedi.zone](w/family/356f987ad26ef01a7843d3ca7d2811de63790be5ef299f5f35f18d7018fe7116)                                                        |        0.19 |      0    |       0.33 |         3 | 2024-08-17   |
|   46 | [TNinja &lt;abuse-team at tor dot ninja&gt;](w/family/11ff631d37c696436fd62e0f22a4f9b803022ba62876b5633f1001eff431ab99)                           |        0.19 |      0.48 |       0.05 |         3 | 2024-06-03   |
|   47 | [flowjob at protonmail dot ch](w/family/5aaf65f12d37f8ebf3f0336bda3c3caf317478ff89ab180d48eed7b70358fde5)                                         |        0.19 |      0    |       0.32 |         9 | 2019-05-29   |
|   48 | [Neel Chauhan &lt;neel AT neelc DOT org&gt;](w/family/5c65a303311d5601d6ef10465e209b1c8ec964ea0305c45d61d1d273b215adb3)                           |        0.18 |      0.4  |       0.07 |        20 | 2024-01-22   |
|   49 | [Contact at SilSte on Twitter tor-relay.co](w/family/9a28c6ad85dcf18af077cd6ed1e289f70449f36f80aa7ac708fd145d1eb1e1b7)                            |        0.18 |      0    |       0.31 |         8 | 2019-12-15   |
|   50 | [zwiebeltoralf.de](w/family/4f3fa866afc831a87abb270958d0f9b6d8123de8430184c5e1de712b30c4af02)                                                     |        0.17 |      0    |       0.3  |         9 | 2019-02-18   |
|   51 | [mentor@palokaj.co](w/family/20f6ae6ad5a6efcb15166c95a223f78065811919028d285edae71497e5b03ffe)                                                    |        0.17 |      0.42 |       0.04 |         7 | 2023-03-22   |
|   52 | [torarbert@delroth.net](w/family/1f7ea8be879a8b3668d3096408eaed6b89e3515dd981b5f1d402031859490bac)                                                |        0.16 |      0    |       0.28 |         4 | 2019-02-18   |
|   53 | [orezmila@gmail.com](w/family/f97618d64becaa3ed1c6a8f7aa90d70d699d70394cfde780b8568586473e266e)                                                   |        0.16 |      0    |       0    |        10 | 2023-07-04   |
|   54 | [mikael datanerd.se](w/family/104fba39fb82697b595ac32d291f192d3cf0d991b095973c697a037b9f5fc5ae)                                                   |        0.16 |      0.4  |       0.04 |         9 | 2024-12-07   |
|   55 | [axstet.de](w/family/271f84a2bd6b1aa06652c0c7e47cf275b9a33ff33a13cde69200674dd0d0a948)                                                            |        0.16 |      0    |       0.27 |         9 | 2022-01-13   |
|   56 | [relayon.org](w/family/d1137d559358c10bd38cd83034b5c8362dfa9caf8433787d4945d00968b4f2fd)                                                          |        0.15 |      0    |       0    |         4 | 2020-10-19   |
|   57 | [0xFFFFFFFF &lt;tormaster AT kkb-clan dot de&gt;](w/family/5348cbd1a28ed72a9635c5cb3d04f778a0dd3b1bce7c091a4978de94e88169ac)                      |        0.15 |      0    |       0.19 |        11 | 2019-02-18   |
|   58 | [FreeExitProvider at protonmail dot com tor-relay.](w/family/c134040cc073b7bc5bbf298c91946c2506f827ea59aae767100751b6b99423b2)                    |        0.15 |      0.38 |       0.03 |         8 | 2021-08-26   |
|   59 | [freiraum TK AT protonmail DOT ch](w/family/bc06f13b559c75195a3db6da53d6f7d3312da7d80be6b1f1ff89c979345c4cd4)                                     |        0.15 |      0    |       0.21 |        23 | 2019-02-18   |
|   60 | [2BCA0A8B](w/family/37aebda412cf7e37e30391b69c0e329324eec0d6ec2ba419f80be7234d5d19f0)                                                             |        0.15 |      0    |       0.25 |         2 | 2022-04-03   |
|   61 | [Dave Null &lt;dave@null.net&gt;](w/family/5b3c94da5157c4a6e5c864f3e7c9f8588b9eb15c01c0d933df7b55d1125b8ff3)                                      |        0.15 |      0    |       0.25 |         8 | 2024-01-16   |
|   62 | [AA1474F6](w/family/cf77495b914cedf0b3851ac0ff2979b1988d4edf7ebf7d6d93e1fd89a7bd6c67)                                                             |        0.14 |      0    |       0.25 |         3 | 2024-12-10   |
|   63 | [4496A8EE](w/family/b8f52aa5b9c73f5143103fd776e830a1100a2a2e6140e190375e87d2caac9a51)                                                             |        0.14 |      0    |       0    |         3 | 2024-04-16   |
|   64 | [urquanrelays proton me](w/family/025cdd425a26b8f2209018b6a9ddccf4777e52d216fee19be0ec009d3bc17353)                                               |        0.14 |      0    |       0.24 |         2 | 2017-10-06   |
|   65 | [5h098y32 at duck.com](w/family/2d4cac92bd559e3c7e23ffb47b46247a3fb29be6d00c5dc2d8e4ed825c2b14f5)                                                 |        0.14 |      0    |       0.24 |         2 | 2024-11-02   |
|   66 | [6ACAECCF](w/family/0e407d7640030a3047dbdf015b1d1fa06f51d530cb97bec61693d958cf3543a1)                                                             |        0.13 |      0    |       0.23 |         2 | 2022-07-02   |
|   67 | [GeoDB Tor Service &lt;tor DOT svc AT geodb DOT org&gt;](w/family/55610d1e88d35a4a178844863378be3da858de352a56523ae5ae1a3d018d13b5)               |        0.13 |      0    |       0.23 |         4 | 2022-04-03   |
|   68 | [mikael datanerd.se](w/family/4a1c6a86b8dd087bd3a926c4a3669d12cf0e5e99b0223ad7acef96d39234dd4e)                                                   |        0.13 |      0.33 |       0.03 |         7 | 2024-10-19   |
|   69 | [Behemoth Project Anonimity &lt;make-tor-great-again@e](w/family/42cc31523fd2cfbcf7d66c2ae311466f7267670b888c61679341d52b71e86ed4)                |        0.13 |      0.11 |       0.16 |         7 | 2024-07-21   |
|   70 | [louis.weebl.me](w/family/b8631a298db619584598f1434693b073c563026efad0ad63ac1481395be3e6a3)                                                       |        0.13 |      0    |       0.22 |         3 | 2019-02-18   |
|   71 | [Strelnikov@bahnhof.se](w/family/9d509066d8cb44632d062db6a87132d3b13b6859abf46d287f20e398d593db22)                                                |        0.13 |      0    |       0.19 |         4 | 2020-07-12   |
|   72 | [Sponsored by https://tor.foundation](w/family/12cc8fc8f08c15c96c23569f758262b6d2b4d4bc6ec0e97c46e477d9e7192e9e)                                  |        0.13 |      0    |       0.18 |        11 | 2024-07-19   |
|   73 | [dike &lt;at&gt; tor.rndsh &lt;dot&gt; it](w/family/9f8ee33eaba6a51518bb4e049e9de77c1dd2de45df8034feab5674d8bf0f1cf0)                             |        0.12 |      0    |       0.2  |        10 | 2018-11-25   |
|   74 | [StayStrongServer &lt;staystrongserver AT yandex dot](w/relay/ED9A731373456FA071C12A3E63E2C8BEF0A6E721)                                           |        0.12 |      0    |       0.22 |         1 | 2020-06-12   |
|   75 | [Nicholas Merrill &lt;nick AT calyx dot com&gt; BTC - 14w](w/family/e4f17008b5301250340182d45bb2d6379545bb51db0d2550ab36a3cb274ba134)             |        0.12 |      0.31 |       0.03 |        19 | 2013-11-12   |
|   76 | [PRQ Hosting &lt;info AT prq dot se&gt;](w/family/56e60f347003e42be7ebee6d2b15d5bca94e726d9874ab74307c1b3f0b9cf255)                               |        0.12 |      0.3  |       0.03 |         9 | 2024-10-20   |
|   77 | [Sh4d0wC1ph3r@proton.me](w/family/6c9a0f9665c0613aae7e30f1a87347badceac2e8a063c9dc5104d18e7a01f2d7)                                               |        0.12 |      0    |       0.2  |         2 | 2024-01-21   |
|   78 | [terjan.net](w/family/a465262fd9e3cf34ce3351bd3e38c24eee2710c8b93562f8c8924fbd20035707)                                                           |        0.12 |      0    |       0.18 |         6 | 2019-02-18   |
|   79 | [alps at AT protonmail dot com](w/family/a3f29a1c0b0a9e30fadecd8dfff57bcc5840fe9d6a2a0b1d0d007d9708f0c951)                                        |        0.11 |      0    |       0.19 |         2 | 2023-12-29   |
|   80 | [bigbonesy@proton.me](w/family/abf65ed0eb222739c96308a1bdcea7f8007f7bbb0fcab3778e526a1b575e80a1)                                                  |        0.11 |      0    |       0    |         4 | 2024-05-21   |
|   81 | [null-f.org](w/family/2b28b41d99847a068c31f55a77b3786bb5a3fc915689e4e5eb31e14b02c4446d)                                                           |        0.11 |      0    |       0.19 |        13 | 2024-11-27   |
|   82 | [0xFFFFFFFF Random Person &lt;nobody AT example dot co](w/relay/BD2BC415D5D8AE3C34430E70EC82CF3B0C61BDDF)                                         |        0.11 |      0    |       0.19 |         1 | 2024-12-01   |
|   83 | [Jonas Hess &lt;tor@jonashess.net&gt;](w/family/f6cc8651b3993a77c0accc4efe55f739df0691f1e066f3c80de5ee9d24ee3dfc)                                 |        0.11 |      0    |       0.18 |         7 | 2023-01-28   |
|   84 | [info AT dxx dot eu](w/relay/F538DBEA80CA7DA733537166CA364D98CBE9E1D1)                                                                            |        0.1  |      0    |       0    |         1 | 2024-11-20   |
|   85 | [enkidu-6.github.io](w/family/d8a71212edf7eb8706ca181cf241a9d709de5954d0b32b2ca2b8be7951630124)                                                   |        0.1  |      0    |       0.18 |         6 | 2022-06-12   |
|   86 | [9DC0D644](w/family/38264420453f84b58a927217fea72d23a820583cfcc355f80ab8fe4ee9bd4362)                                                             |        0.1  |      0    |       0.17 |         2 | 2023-07-01   |
|   87 | [torserver at xs4all](w/family/e8fac2642c4149b5b7b436ad074122e81f86ef8f0dc3b0ec2ebffd58b7ac103d)                                                  |        0.1  |      0    |       0.17 |         2 | 2024-02-05   |
|   88 | [infokoopa@hacktivism.ch](w/family/4aa45f8f00087386e592795d221e10391c34c7166fff774c62ee9fcec1c52e47)                                              |        0.1  |      0    |       0.08 |         3 | 2024-11-14   |
|   89 | [email:Quetzalcoatl relays proton.me url:https://q](w/family/e836a284406d5859af570808ef5382ebda7a31f4ff44f871cea5691f79b0c08d)                    |        0.1  |      0.25 |       0.02 |         8 | 2024-12-18   |
|   90 | [Sponsored by https://tor.foundation](w/family/1ec1fd5607f5e48a6e99f5ade53ebaa84b26ee5a4b96d0c1763a72853a59417b)                                  |        0.1  |      0    |       0.17 |         4 | 2024-07-22   |
|   91 | [Alexander abuse@spynode.cc 8E28C7AAD6360D19802D6D5](w/family/e91fd03ca577044f7808ab20a046fe5f0cba38ea55ad1f7d62c51346106172b7)                   |        0.1  |      0.09 |       0.12 |         2 | 2024-11-13   |
|   92 | [zwiebelrouter.net](w/family/8351dcb820f7a11072837aa3bff2c6426561820438ab84b7b88b45928fe79b33)                                                    |        0.1  |      0    |       0.17 |         5 | 2022-03-14   |
|   93 | [tor-mgmt@netc.fr](w/family/d05b5ba4a1ee4b4de807149450a5a804e904239df01f3157ceb41681574607ee)                                                     |        0.1  |      0    |       0    |         3 | 2024-12-12   |
|   94 | [0xFFFFFFFF Random Person &lt;niels AT nldo dot nl&gt;](w/relay/A7C2DF525D373D6A0C4F2540C3927ADF511124CC)                                         |        0.1  |      0    |       0.17 |         1 | 2024-05-07   |
|   95 | [Ariazonaa &lt;torproject@ariazonaa.net&gt;](w/relay/C9DE3C0F2BA06E8BB5F24152584E725E4AC79C6F)                                                    |        0.1  |      0    |       0.17 |         1 | 2024-08-25   |
|   96 | [DFA46FE6](w/relay/DFA46FE65F01E255D544EF3E7DA9217D51096142)                                                                                      |        0.1  |      0    |       0.17 |         1 | 2024-02-15   |
|   97 | [wagner1.johannes@web.de](w/family/83124115cc9ff66aaca676c3baa34620f68b2dab922a6787102a8123972fb7af)                                              |        0.09 |      0    |       0.16 |         4 | 2024-08-16   |
|   98 | [Alexander Faeroey &lt;ahf@0x90.dk&gt; 0x61A208E16E7CB43](w/family/f0e3b270e7948a8f377d211520d341dc91824e47b1cb69e1a1045d1fc897a831)              |        0.09 |      0    |       0.16 |         2 | 2019-02-18   |
|   99 | [vaino-relays at ywzmb dot top cii:2](w/family/9c727a5b5bf03fd4a689a35b3206ef350aad039db1e479edc3bfc5f1b50d9b2c)                                  |        0.09 |      0    |       0.12 |        13 | 2025-01-05   |
|  100 | [max at freifunk-dresden dot de tor-relay.co](w/family/eb935c8a6aeb44cbf90f0c45b19f2d5a1edbeae48887a38a2b65d6780ffa1fce)                          |        0.09 |      0    |       0.16 |         2 | 2021-02-14   |
|  101 | [19662E68](w/family/fd57ee037c627319820143168252077736a816d229f7692fb86ed2226cd36e3e)                                                             |        0.09 |      0    |       0.16 |         7 | 2024-09-24   |
|  102 | [Abuse Poseidon2 &lt;poseidon2.mule134 AT silomails DO](w/family/997d0bb430f4ecddb64ccbc1fd4fe52958ef7aedc0c8a262b1f675a54dac08d7)                |        0.09 |      0.23 |       0.02 |         2 | 2024-05-08   |
|  103 | [www.privex.io](w/family/bd6a90ee09451b7622b29ba5321dbefc2c140e806e1b798d4f3475b5706a0bbb)                                                        |        0.09 |      0.1  |       0.09 |         3 | 2019-06-28   |
|  104 | [lucaswerkmeister.de](w/relay/91892720F9262CB37B91A7176D3D2280F7AF14BE)                                                                           |        0.09 |      0    |       0.15 |         1 | 2021-01-08   |
|  105 | [gk@torproject.org](w/family/1bafbc87ed9119eccb1b9800ea9623515a6ac04356c931830a9aee9a6d5e5055)                                                    |        0.09 |      0.04 |       0.13 |         2 | 2021-11-24   |
|  106 | [James Taylor &lt;contact AT tor-servers dot fornoreas](w/family/fb7df9fe244c138f712046cc3ca0dcb3c8b7383c82eed15b4c9827baa23eb6fa)                |        0.09 |      0    |       0.15 |         4 | 2019-02-18   |
|  107 | [99027C42](w/family/9e32965c7d0beb2cfdafb160a615ed55a195b389162f89c61a4955ec5b48fb49)                                                             |        0.09 |      0    |       0.15 |         2 | 2024-01-22   |
|  108 | [0xa1&lt;:at:&gt;mailbox&lt;:dot:&gt;org](w/family/f637ae76c6bdde6ea13c37362757745dd44622b611714e17caf4792932d21eb2)                              |        0.09 |      0    |       0.15 |         5 | 2020-03-01   |
|  109 | [6520532F](w/family/e411dab74dc7c4c16528a631abc4e03228660a5765922e1123d92a5eebcc1c09)                                                             |        0.09 |      0    |       0.15 |         2 | 2023-08-04   |
|  110 | [darmstadt@fridaysforfuture.de](w/family/c9929371a06f2e5e4e6db8a98ec49f86d28368be45a7bd0db96ac1a1f91aeeb4)                                        |        0.08 |      0    |       0.15 |         3 | 2024-11-07   |
|  111 | [4D0F2ADB](w/family/3864fe35065724fee1c5367a331a10f9d71f6b6e7b4eab2066b325eb5908262a)                                                             |        0.08 |      0    |       0.14 |         2 | 2024-01-21   |
|  112 | [email:Quetzalcoatl relays proton.me url:https://q](w/family/91fced5df52f16ecc2bd9ce7cd7ac8d00dd1a94bf15b7f1b0881f840e8f1e8e0)                    |        0.08 |      0.21 |       0.02 |         7 | 2024-12-17   |
|  113 | [doedelkiste.de](w/family/f00c457b1d2c994980771dba0aceb02010833b4695fb3370f2508e9489348d32)                                                       |        0.08 |      0    |       0.14 |        11 | 2015-10-18   |
|  114 | [&lt;thebunny.zone&gt; &lt;wintieria proton me&gt; &lt;B9F2F77BA5D](w/family/9872f3b08842256c74da76d5b55d78f2cd4dbc8522f2910b694634d99e397655)    |        0.08 |      0.02 |       0.09 |        10 | 2024-08-11   |
|  115 | [admin@tor-relay.utilizer.de](w/family/a96e66fb24d413e3c7604fdac7bef94cdead3ba8ebb239bccd41681cd0646d30)                                          |        0.08 |      0    |       0.06 |         4 | 2024-06-05   |
|  116 | [email:relaycontact l33tn0de.cc hoster:hetzner xmr](w/relay/67A54EDB7DADDBBC1E8A07F1EF82364BDAA896B7)                                             |        0.08 |      0    |       0.14 |         1 | 2021-11-14   |
|  117 | [email: ammirelay at boatmail.cc confmgmt:ansible c](w/relay/9BD0EE79BB9878DD6D8D8EA2A288D5E301E5C136)                                            |        0.08 |      0    |       0.14 |         1 | 2022-08-01   |
|  118 | [email:antifaang@freenode.cc](w/relay/BFC4044119080D8BEE70218978EE83C3FC16AE7A)                                                                   |        0.08 |      0    |       0.14 |         1 | 2021-11-24   |
|  119 | [email:peeps@arktis.cc btc:1bR2BRgZ3GgwL1iCW5rGr9Hv](w/relay/C45FE5C41ACC37E4EA4687FFC54A74F124739DAF)                                            |        0.08 |      0    |       0.14 |         1 | 2021-11-24   |
|  120 | [&lt;tor AT sutsuj dot com&gt;](w/relay/CC701FCE86D6AF95FC3D5B71645D3430794910C1)                                                                 |        0.08 |      0    |       0.14 |         1 | 2020-09-10   |
|  121 | [dplus26@fastmail.com](w/family/75d73ca37ce20dc74688b57cc5e1226c273300505622a284436a1bcdc3ee1808)                                                 |        0.08 |      0    |       0.14 |         3 | 2023-01-05   |
|  122 | [Fabian Keil &lt;fk@fabiankeil.de&gt; 8BA2371C](w/family/1e6ae302dff3e61cf137fb954a580428d2918e6618cc66582cd407bcf88578bf)                        |        0.08 |      0    |       0.07 |         4 | 2019-02-18   |
|  123 | [B587EEC1](w/family/4beaa1074121e922bb346e4c00539d1a2a73be2c48b7382db1e4d094b5410d8a)                                                             |        0.08 |      0    |       0.14 |         2 | 2024-01-21   |
|  124 | [StarApps GmbH, Switzerland](w/family/ce91cf12e4533f61a113535cab243eef081e9c077f77898c8f0c3533aed3fc36)                                           |        0.08 |      0    |       0.13 |         3 | 2021-10-01   |
|  125 | [Henrik Kramselund &lt;hlk AT zencurity dot com&gt;](w/family/e365b0ef10ae8a1fbd5b7a1fe501fbaab5f3b0b8fc9b9880245f320c534a390c)                   |        0.08 |      0.2  |       0.02 |         2 | 2021-03-29   |
|  126 | [peTelRobi aT gmaIl DOT cOm&gt;](w/family/4ecac114ecff9dbcb8ecfeb076373c9e0660bf7b79d9f45b273f664033105a0f)                                       |        0.08 |      0.2  |       0.02 |         7 | 2024-02-14   |
|  127 | [mikael datanerd.se](w/family/770e1e36e901bb94518034f18671e4730b27bfff944f85ad4a58bffe3c8631bd)                                                   |        0.08 |      0.19 |       0.02 |         4 | 2024-10-19   |
|  128 | [tor@setsun.org](w/relay/2AA5F598F9A1812F01CD99E3B59BB87362ED7438)                                                                                |        0.07 |      0    |       0.13 |         1 | 2019-12-25   |
|  129 | [Taj Rumbinji contact: taj@tajjina.cc](w/relay/0AE076CD2A4201BF2D90C325211A10D2C8DD6CE9)                                                          |        0.07 |      0    |       0.13 |         1 | 2024-05-27   |
|  130 | [3544DD8F](w/relay/3544DD8F61D3BDEC8E812B80B61177FBD958ECCC)                                                                                      |        0.07 |      0    |       0.13 |         1 | 2024-10-29   |
|  131 | [3A04AC89](w/relay/3A04AC8969E55DF51C8D11C49ABF18A0CC847FC0)                                                                                      |        0.07 |      0    |       0.13 |         1 | 2022-05-13   |
|  132 | [queso/loco/at/tutanota/dot/io](w/relay/453D690B2108B814E237418FFF694D978BB63119)                                                                 |        0.07 |      0    |       0.13 |         1 | 2024-07-17   |
|  133 | [Hi Mom im on TV bigmanstu at hidemymail dot xyz](w/relay/494E5000BA79F0078DFA05E610911C2AC525572F)                                               |        0.07 |      0    |       0.13 |         1 | 2022-12-09   |
|  134 | [ELON TUSK &lt;frosty at ovinet dot org&gt;](w/relay/50B7C4F6C18A3E5FC1D4E2ECE6B7B316B29FB26C)                                                    |        0.07 |      0    |       0.13 |         1 | 2022-11-29   |
|  135 | [chocolatebyte.mvb0y@slmails.com](w/relay/67BE9A0658EF0106FCCB98FF1C68D6AAFFFC3CA9)                                                               |        0.07 |      0    |       0.13 |         1 | 2024-01-21   |
|  136 | [Patrice Mail: patricerice@protonmail.com](w/relay/727EDD6ED7E462532417034475C16E552F14E7E3)                                                      |        0.07 |      0    |       0.13 |         1 | 2024-12-22   |
|  137 | [Sebastian Hahn &lt;tor@sebastianhahn.net&gt;](w/family/37d7f3cda2f6ae5b10f56e84e56b77b358bc4d641149ae2918b536f37fd26be4)                         |        0.07 |      0    |       0.13 |         2 | 2019-02-18   |
|  138 | [mkg20001.io](w/relay/9EEE861CD8A5FE26A1F276879323172F5B91082C)                                                                                   |        0.07 |      0    |       0.13 |         1 | 2021-05-08   |
|  139 | [email:gh0sthalo@moltencore.org btc:146KFigj4Lc6JjS](w/relay/B3D398B386FAF2CB78B447FBA46BF2648C3F48CD)                                            |        0.07 |      0    |       0.13 |         1 | 2021-11-14   |
|  140 | [email:chuckyhorror sublimestorm dot xyz Donate at](w/relay/AF0E2DF4861795CD4CECE2A25686D2BC70C96D03)                                             |        0.07 |      0    |       0.13 |         1 | 2022-11-29   |
|  141 | [contact me at : darkknight &lt;AT&gt; binaryvault &lt;DOT&gt;](w/relay/CA1684516B7FECF3DB76D43FD02F56D8B95E8A69)                                 |        0.07 |      0    |       0.13 |         1 | 2022-08-01   |
|  142 | [Contact: peabodysrv AT odinbox DOT xyz 1GLB7QLpc4N](w/relay/D8F4634366466972842F5102FE44738326E43DF0)                                            |        0.07 |      0    |       0.13 |         1 | 2022-11-29   |
|  143 | [EE2A6210](w/relay/EE2A621042994B29452C12FF3B6F62D9E957758C)                                                                                      |        0.07 |      0    |       0.13 |         1 | 2022-05-13   |
|  144 | [Osservatorio Nessuno ODV &lt;exit@osservatorionessuno](w/family/957db25302ea561574b0567ad88159af102f30564915eb44f7800f6af1da5bec)                |        0.07 |      0.2  |       0.01 |         7 | 2018-12-21   |
|  145 | [Sponsored by https://tor.foundation](w/family/6b81a191fa91658d339a3eca8a33e7d179ffd8dfe330497281a813beee1743c6)                                  |        0.07 |      0    |       0.13 |         3 | 2024-07-22   |
|  146 | [0320c8867fccd45d6a6f7a577ed09773f8929a6e CSGuard &lt;](w/family/b89a9ab59f5dc9c3b1d04f6ddfcc501b2a66cce875c052a9affb7008554cdea6)                |        0.07 |      0    |       0.13 |         2 | 2019-02-18   |
|  147 | [haku19-@-mail.com](w/family/eb6d1efa4fc8d3bef3069eecc5d89f5cbbff3a464ee58fb3baa30f833fa85571)                                                    |        0.07 |      0    |       0.13 |         4 | 2022-03-14   |
|  148 | [tor-exit@vrij-heid.nl](w/family/918760c893166353347a022bae10472e11c44b7d6d1ba844f7556c68df90f45b)                                                |        0.07 |      0.18 |       0.01 |         4 | 2024-01-22   |
|  149 | [Markus &lt;markus AT mdfnet dot se&gt;](w/family/205be7ee0ce698b34926b0968def3a494ec5fe7234f98190a7824e3835bc7f91)                               |        0.07 |      0    |       0.12 |         3 | 2014-06-16   |
|  150 | [tor at milkywan dot fr](w/family/e2110c1ef8b31a0bdb16029b9ffc360f1db69ae7fb6c212f6fa76e7040800a9f)                                               |        0.07 |      0    |       0.12 |         2 | 2019-02-18   |
|  151 | [sloetor@gmail.com](w/family/f0d1e3a89d81d3206f08835582ec93f65c4e7951ceb3caf0707747b49f3dd3da)                                                    |        0.07 |      0    |       0.12 |         4 | 2022-01-03   |
|  152 | [disabled](w/family/75012dc64d71c0eee344a03f6be06d3c4a929f75a033ca38b69de5e4fcb73611)                                                             |        0.07 |      0    |       0.12 |         2 | 2024-12-02   |
|  153 | [Random Person &lt;tor-server@mikitsu.me&gt;](w/family/b8cd068b2dde4e7baf2c280f64a3daafd2888bf2e26911411ceba5ee0522e8de)                          |        0.07 |      0    |       0.12 |         2 | 2022-07-22   |
|  154 | [stareintodeathandbestill.com](w/family/e010ca788a7e48576c391ae17299259e4e14c728e9512cd44f2e9c6a4c18c530)                                         |        0.07 |      0.18 |       0.01 |         2 | 2024-08-24   |
|  155 | [Mi Gibtsdonet &lt;nobody AT example dot com&gt;](w/family/ee02907dd96de44d6c0c4b7c7a42db6e699c6ae1e278b4f0784fb3094d96e5b2)                      |        0.07 |      0    |       0.12 |         4 | 2022-05-23   |
|  156 | [b0at dot build3r at proton dot me](w/family/a14831ea64fd44e82b1c81b2c234e9ed470d7f361b95e4304066e4a576ff9db0)                                    |        0.07 |      0    |       0.12 |         2 | 2022-07-22   |
|  157 | [email:m1dn1ght foxxynodes.com ciisversion:2 btc:1](w/relay/03D1EF3EF2BE5145150C58ACC72519DD860E61BA)                                             |        0.07 |      0    |       0.12 |         1 | 2021-11-13   |
|  158 | [playboicarti at chunguswire.me B.T.C: 1Nvp7LbJ8JsN](w/relay/427526EBD012CFE50FCFFCBFE221EFFE199AFA8C)                                            |        0.07 |      0    |       0.12 |         1 | 2022-12-09   |
|  159 | [siroxcw@proton.me](w/relay/5A598836FE112DC9BAA7C5D6FCCFC419581B91C1)                                                                             |        0.07 |      0    |       0.12 |         1 | 2024-11-25   |
|  160 | [2048R/B640BF1A Tor Relay &lt;tor AT sec dot nl&gt;](w/relay/844AE9CAD04325E955E2BE1521563B79FE7094B7)                                            |        0.07 |      0    |       0.12 |         1 | 2019-02-18   |
|  161 | [Gaara Patrick M naruto AT wafflehaus DOT org](w/relay/A7A6BAAE17FB162164327C34229E7D0D81D4DC82)                                                  |        0.07 |      0    |       0.12 |         1 | 2022-11-29   |
|  162 | [email:churrodawgsworld](w/relay/AC7C88D67339B90F2C10FF7B702DCB1EF3B8D663)                                                                        |        0.07 |      0    |       0.12 |         1 | 2022-08-01   |
|  163 | [Support &lt;support at lunoxia dot de&gt;](w/relay/FE1AB3C4F9F90E13F85D9E4C7F915DD7DBC28CDE)                                                     |        0.07 |      0    |       0.12 |         1 | 2024-05-20   |
|  164 | [tzancauraganul@proton.me](w/family/4e6589a6c8c007e2a36be6c558990010f0cf53fdcf1a58490bb542833bfb5bed)                                             |        0.07 |      0    |       0.12 |         8 | 2024-01-21   |
|  165 | [8or8ty8 8or8ty8email@mir4ge.cc](w/relay/049091E0582A6439D7AC7E157D32AB9319B8B78C)                                                                |        0.07 |      0    |       0.12 |         1 | 2024-05-26   |
|  166 | [mcgraw feathers@wensleydale.cheese](w/relay/00030309EF47C06C3F0FDDA11067CD206092798D)                                                            |        0.07 |      0    |       0.12 |         1 | 2024-12-31   |
|  167 | [2048R/B640BF1A Tor Relay &lt;tor AT sec dot nl&gt;](w/relay/ED2338CAC2711B3E331392E1ED2831219B794024)                                            |        0.07 |      0    |       0.12 |         1 | 2019-02-18   |
|  168 | [anders.io](w/family/8e6ea473c6e046a85c5763d1e3214f7e42848ddf488353cad13c124878c8e3d7)                                                            |        0.06 |      0    |       0.11 |         4 | 2023-06-17   |
|  169 | [Relay run by GhostBros ghostbros at sublimestorm](w/relay/2955D8C86F5848FD3469E3F38A027D3E169359D8)                                              |        0.06 |      0    |       0.11 |         1 | 2022-11-29   |
|  170 | [enigma aet s0ny d0t net](w/relay/42B4F52C5B11E4D39855F654955425B0D5A0598B)                                                                       |        0.06 |      0    |       0.11 |         1 | 2019-02-18   |
|  171 | [broekemabent@protonmail.com](w/relay/62AFE393020CC3AA3AA30CA78902F5D40E760926)                                                                   |        0.06 |      0    |       0.11 |         1 | 2022-04-03   |
|  172 | [iwpjx9ay2@mozmail.com](w/relay/8639EC2D472AEC280B11288ADADBCC9A6711EC1B)                                                                         |        0.06 |      0    |       0.11 |         1 | 2024-11-04   |
|  173 | [mail: atl4st1me@protonmail.ch](w/relay/CFBE80FBC371BBCAEE9F6B70C5A0333AB54376D8)                                                                 |        0.06 |      0    |       0.11 |         1 | 2024-12-26   |
|  174 | [WELCOME TO THE CHUMBUCKET pl4nkton @ froggydispa](w/relay/00DA4A3852EA5EF6841B8B4372DB0EFD3AB0BE92)                                              |        0.06 |      0    |       0.11 |         1 | 2022-12-04   |
|  175 | [Maria &lt;maria.mariposa1&lt;@&gt;protonmail&lt;.&gt;com&gt;](w/relay/5E52B6E15B81AB6428245080D007F4507C88E15D)                                  |        0.06 |      0    |       0.11 |         1 | 2024-12-25   |
|  176 | [psYchotic](w/relay/8D41994D1D18E94403C3F67D0699E4C9D2248D4A)                                                                                     |        0.06 |      0    |       0.11 |         1 | 2019-02-18   |
|  177 | [Eliana Routhampia &lt;eli@novacloudapp.net&gt;](w/relay/8D0E575C7C5E6B8075891121368244C283CBC65A)                                                |        0.06 |      0    |       0.11 |         1 | 2024-05-25   |
|  178 | [freeiranandtheworld@outlook.de](w/relay/9308F49A225022FA39011033E1C31EFF5B7B5000)                                                                |        0.06 |      0    |       0.11 |         1 | 2024-01-22   |
|  179 | [not-real dot gmail.com](w/relay/0155DD3B3E26673F7EB1AA22E0A904BA434D1F00)                                                                        |        0.06 |      0    |       0.11 |         1 | 2024-11-06   |
|  180 | [Abuse and contact address: turik at odinbox dot xy](w/relay/8284C8A45D22F2981C4B6287C7FB4367116E7CCE)                                            |        0.06 |      0    |       0.11 |         1 | 2022-03-04   |
|  181 | [pl8 tektonix at proton.me](w/family/0874140e316d60806199560536ab8db83c146e53c03c0622dd925ab0b247271b)                                            |        0.06 |      0    |       0.11 |         2 | 2024-07-25   |
|  182 | [Totoro4219 &lt;totoro4219 AT mailbox dot org&gt;](w/family/35e7ab3681cad2b3603a12db4c92dd523f4bb21b6263df91e51fa8d92c5e4d3f)                     |        0.06 |      0    |       0.11 |         2 | 2024-02-02   |
|  183 | [Lou Tschaier e98c29f1-04e6-46f6-9fc2-fab537bbc120@](w/family/ca8b85bdf2466b611c9c25cdf27ccf42113dbb07c866d0178fa984ba9a48cf7d)                   |        0.06 |      0    |       0.11 |         2 | 2024-01-22   |
|  184 | [0x4F8ACED4 Marcel Menzel &lt;mail@typhoon31.de&gt;](w/family/3b82e9aaaf846fedf969922a58f5de29970e4c185737b4c9b27f919d87169fa6)                   |        0.06 |      0    |       0    |         2 | 2019-02-18   |
|  185 | [tor bruzzzla.de](w/family/0bd21ee35ee0c19775a0012e1b129db75b998a54c3b5096bbdeac4a61817ecb0)                                                      |        0.06 |      0.01 |       0.1  |         4 | 2024-10-10   |
|  186 | [2269C990](w/relay/2269C9905B04530E251186FAD6F56033654E5C99)                                                                                      |        0.06 |      0    |       0.11 |         1 | 2024-11-11   |
|  187 | [le1025656haha102vvs210000bnmuiooop11x@protonmail.c](w/family/ec97f757736ae3627860dc7568043dc6521ac750cec0baeaecaf36658fc4676e)                   |        0.06 |      0.16 |       0.01 |         2 | 2024-12-05   |
|  188 | [chappie7 AT riseup.net Donate here: https://pa](w/relay/669E9D3CF2C1BF3A9E7A0B7FD89F8B4B5E1EF516)                                                |        0.06 |      0    |       0.11 |         1 | 2024-01-21   |
|  189 | [email:pabs@dropbears.cc abuse:pabs@dropbears.cc ci](w/relay/DAE65AD32A074CECB30AD3FBB7504F0CDC616CD1)                                            |        0.06 |      0    |       0.11 |         1 | 2022-03-04   |
|  190 | [Snorlax &lt;pokemon365 at arktis dot cc&gt;](w/relay/5C386C4F91FD616F0F60F4E6D674D9E3F192C931)                                                   |        0.06 |      0    |       0.11 |         1 | 2022-11-29   |
|  191 | [Dieter - deeburger@zohomail.com](w/relay/6A84C1DB4C50934A57E13FC7F93EA5217BA0DAB6)                                                               |        0.06 |      0    |       0.11 |         1 | 2022-05-23   |
|  192 | [email:nuremberg2tor protonmail.com ciissversion:2](w/relay/7EEDD54E5457DA009E46C91BBF1F443DCEE01968)                                             |        0.06 |      0    |       0.1  |         1 | 2021-11-14   |
|  193 | [Kuro email:shinobi tntrelays.xyz xmr:47aUBkGxpr2j](w/relay/94F5629AE5F2DC409CD44668176597FF48296BA1)                                             |        0.06 |      0    |       0.1  |         1 | 2021-11-24   |
|  194 | [B023FAE9](w/relay/B023FAE9B986080159F0365867B038B4E07B75D7)                                                                                      |        0.06 |      0    |       0    |         1 | 2024-09-26   |
|  195 | [uncertain krait AT proton . me](w/family/9adb3e4903c3354048574fbe0a3e7501e58bb502494a38f60eb9d73fdce1edc1)                                       |        0.06 |      0.19 |       0    |         3 | 2024-09-04   |
|  196 | [quetzalcoatl-relays.org](w/family/a5fff0523301e058a091331f564d2eed0abad225902f0a96fa9ef6f6a11d66c8)                                              |        0.06 |      0.15 |       0.01 |         8 | 2021-06-17   |
|  197 | [A85182BA](w/family/b45f1285ea0d34decadaa7899891bf2e04df6df2f3e9f0875e030124d2a3498e)                                                             |        0.06 |      0    |       0.1  |         2 | 2023-01-18   |
|  198 | [07F0E652](w/relay/07F0E652E4CCB0A0F1E88D0046ECB322E6318C86)                                                                                      |        0.06 |      0    |       0.1  |         1 | 2022-04-15   |
|  199 | [email:mickymousecontact sektorblue.com ciissversi](w/relay/46DB04323499DD535956531DF2BF7B03EB2AB15D)                                             |        0.06 |      0    |       0.1  |         1 | 2021-12-04   |
|  200 | [email:jlvtrim at dropbears dot cc ciissversion:2](w/relay/408F374F131B45D7D63DBCB00E62F76B647943D9)                                              |        0.06 |      0    |       0.1  |         1 | 2022-02-12   |
|  201 | [email: itsvanbobaby AT torbewachen DOT xyz](w/relay/B9F69F144DF5BE2FD92DDBF9E67C659ECC5E539B)                                                    |        0.06 |      0    |       0.1  |         1 | 2022-08-01   |
|  202 | [:- spicyavo @ binaryvault . net](w/relay/6CBA90E31188A65E2B6AC1EE8412E8DE571ECAD6)                                                               |        0.06 |      0    |       0.1  |         1 | 2022-08-01   |
|  203 | [xplato1 &lt;at proton.me&gt;](w/relay/740148698671E67BA62AC941BBB74E874E0F579E)                                                                  |        0.06 |      0    |       0.1  |         1 | 2024-10-22   |
|  204 | [katawaredoki.net](w/family/84e02e2bba32c27c5bbd692aa3a7ba0a0b3f6c3cebbd47c7ee25e5463d3e67b4)                                                     |        0.06 |      0.01 |       0.09 |         4 | 2019-02-18   |
|  205 | [relay@lotusmassage123.com](w/relay/16E5E5C19F1C0F3FF3326E4D281F647D58730A8B)                                                                     |        0.06 |      0    |       0.1  |         1 | 2024-05-29   |
|  206 | [you&x27;re assumin&x27; imma human](w/relay/4E98AA295B7171996D18DD1F6A19F64AB4036B4A)                                                            |        0.06 |      0    |       0.1  |         1 | 2024-11-03   |
|  207 | [bogioa90 dot gmail.com](w/family/cad2b77fcf8a9b9a6a00b2fa8c6a00e646d3ab508db8d170dd8ef3b511ce35e7)                                               |        0.06 |      0    |       0.1  |         2 | 2024-08-12   |
|  208 | [5BE7317D](w/relay/5BE7317D29F26E5A3D96F0E7F8653B870E657C6C)                                                                                      |        0.06 |      0    |       0.1  |         1 | 2024-11-01   |
|  209 | [nuketheworld email:boom tntrelays.xyz ciissversio](w/relay/5FAE28CF4D1C520341EE104BF72516F4308B9485)                                             |        0.06 |      0    |       0.1  |         1 | 2021-11-14   |
|  210 | [7B8E2AC6](w/relay/7B8E2AC6B8CF87D8F2930725CF8122B657D84357)                                                                                      |        0.06 |      0    |       0.1  |         1 | 2024-01-21   |
|  211 | [Sophie &lt;tor AT 999eagle DOT moe&gt;](w/relay/FC1E441E097BA36930AA2F615EFB325AF76D2595)                                                        |        0.06 |      0    |       0.1  |         1 | 2020-06-22   |
|  212 | [email:bill-torrelays boughton.eu ciissversion:2](w/family/59d1019e3e5b2bd3ccf03549b6a0631d6d8d622a933ad15e808ea59d5dac9869)                      |        0.06 |      0    |       0.1  |         2 | 2019-02-18   |
|  213 | [GaliNightsbridge &lt;admin@GaliNightsbridge.net&gt;](w/relay/9211C28F875BD179EA4F865A2444C441DFF75840)                                           |        0.06 |      0    |       0.1  |         1 | 2024-01-21   |
|  214 | [1D24826A](w/family/cd22c3b6de05fbb921b1c7663cc9702e34736168259e232d70dc7a535736c197)                                                             |        0.06 |      0    |       0.08 |         3 | 2024-03-15   |
|  215 | [email:contact c0der3d.xyz abuse:contact AT c0der3](w/relay/05C32C5EE14454E0C4CD81DAE0F3DC32F729DA4B)                                             |        0.06 |      0    |       0.1  |         1 | 2021-11-19   |
|  216 | [email:freeassange foxxynodes.com ciisversion:2 bt](w/relay/BA13324719485DC3B5FF258C21603287F1AFFD06)                                             |        0.06 |      0    |       0.1  |         1 | 2021-11-14   |
|  217 | [vader@ciphermail.xyz](w/relay/77A3ADC5D455778B53C2803761916DFB7DA0A790)                                                                          |        0.06 |      0    |       0.1  |         1 | 2021-11-24   |
|  218 | [0xD2BDDAAEA71726EBF8FD20FF02435989068F7B6B Karin S](w/family/750991f1e141514377249f40bf08f26b076a6a2b8d6726506d9244a3a6ecb349)                   |        0.06 |      0    |       0    |         3 | 2023-05-04   |
|  219 | [mRtjR4JX6pgJ@protonmail.ch](w/family/1e9f438b85e868280f306c6b7bdcdb859fb09daece29933b0180aeed23a2e329)                                           |        0.06 |      0    |       0.01 |         3 | 2022-03-24   |
|  220 | [pupokin at gmx de](w/relay/68D2ABD936233A569E2B46D6228816149A16B4FA)                                                                             |        0.06 |      0    |       0.1  |         1 | 2019-02-18   |
|  221 | [email:d3fc0n c0der3d.xyz ciisversion:2 xmr:49bZRY](w/relay/916DC3199F639168CD20AEC4D45969268E807699)                                             |        0.06 |      0    |       0.1  |         1 | 2021-11-14   |
|  222 | [email:masterchief@sektorblue.com](w/relay/99EC64FE9EF0E0ECEC3E125A2327C2779C1E7947)                                                              |        0.06 |      0    |       0.1  |         1 | 2021-11-24   |
|  223 | [remote VIA uq dot ci](w/family/225f5fbfcad81f559275bdc7460fd4690651f62bb3a6ff931c2db1ca5787a72a)                                                 |        0.06 |      0.09 |       0.04 |         2 | 2024-12-19   |
|  224 | [tor-exit@mxmla.de](w/family/abc7318e423a5c1ef731e383b14e9886c3e56ac456e653cb232e4e8a8c338e6e)                                                    |        0.06 |      0.15 |       0.01 |         2 | 2024-11-06   |
|  225 | [bensraspirelayde@gmail.com](w/family/d417c72939b7b45bc7de9bb2482fbee49d7e1effcda72f31925b589394c3405a)                                           |        0.06 |      0    |       0.1  |         3 | 2024-01-22   |
|  226 | [Linus Nordberg 4096R/23291265 &lt;linustor@nordberg.](w/family/9f3c73eff64ae5153a545dd123315efceed2f6c4b5e59f5774091ab47ecf6f00)                 |        0.05 |      0    |       0.1  |         3 | 2019-02-18   |
|  227 | [email:citadel5 ciphermail.xyz zec:zs1nkw34ffgwxt9](w/relay/1F2EB70268CE9E18CE864D44D793E2091F3CE72C)                                             |        0.05 |      0    |       0.1  |         1 | 2021-11-24   |
|  228 | [/fabi/hererra/ gmx . com fabiana](w/relay/26BC5109EE3495F4655D133BBE0A77FE1608D9A7)                                                              |        0.05 |      0    |       0.1  |         1 | 2024-01-21   |
|  229 | [goodserver@why.com](w/relay/57B5A1DD96B06F8813A6F269F75A2057DB7E71D0)                                                                            |        0.05 |      0    |       0.1  |         1 | 2024-11-06   |
|  230 | [Best cheap vapes vape@citrinio.net](w/relay/C80B8274FCE2FF2F7E2079D1C397F685DEFA0793)                                                            |        0.05 |      0    |       0.1  |         1 | 2024-01-21   |
|  231 | [FUCK THE NSA Donate: 4AyALFfn3DQ6VSNaTzZMCgAicZy](w/relay/ADEA3D5609FCEC1EF2F4426C49313EB82DFE3E6B)                                              |        0.05 |      0    |       0.1  |         1 | 2022-03-04   |
|  232 | [email: vivaukrainecontact AT proton DOT me ciisver](w/relay/ECA08EAF2D28CA54BD487EE464182F5895DE1688)                                            |        0.05 |      0    |       0.1  |         1 | 2025-01-02   |
|  233 | [flashl1ght77 at pm dot me](w/family/35f85cdf0dd53b361b6ddaf823828a64db676b30a4ef6096588783e1f9fa65c2)                                            |        0.05 |      0    |       0.1  |         5 | 2022-10-10   |
|  234 | [Relay Admin Contact - mail@discretematch.cc](w/relay/340704679F46C155094816B34FF6BE491C0AA16E)                                                   |        0.05 |      0    |       0.1  |         1 | 2024-01-22   |
|  235 | [email:minionrelay@protonmail.com ciissversion:2](w/relay/38F732DD349A2E59078434651162A2F4201934A5)                                               |        0.05 |      0    |       0.1  |         1 | 2021-11-14   |
|  236 | [Martin; &lt;martinlt wafflehaus org&gt;](w/relay/4B7F4885DC18018C0B870DD7D8415E265099C187)                                                       |        0.05 |      0    |       0.1  |         1 | 2022-11-29   |
|  237 | [s dot aint667 at proton dot me](w/family/94277fb3eb03ada00f8c15c6b656ac66407a2840dfe12859b65eabe19ba02ba5)                                       |        0.05 |      0    |       0.09 |         4 | 2022-06-22   |
|  238 | [Yuki Ibuki &lt;yukiibuki090 at proton dot me&gt;](w/relay/2E289A14B649F500C194BD56DEE28F0A0D75533C)                                              |        0.05 |      0    |       0.09 |         1 | 2024-09-07   |
|  239 | [email: cs4nders AT proton DOT me](w/relay/71016548832DD26E1BA0D3216D75F3A77679062A)                                                              |        0.05 |      0    |       0.09 |         1 | 2025-01-06   |
|  240 | [Contact me at: blazedwizard@rapidmail&lt;.&gt;cc](w/relay/FF353F5D011E69ECDA10A57B46D06BC7B3FEB196)                                              |        0.05 |      0    |       0.09 |         1 | 2021-12-04   |
|  241 | [tor @ public-files dot de - BTC: 3JVUpva3XdTzNyTVH](w/family/eb405561e787b4ac8ab1978accaf1c35c208012d99eb580a3a6fe90e3e0cf6e7)                   |        0.05 |      0    |       0.09 |         2 | 2019-02-18   |
|  242 | [csheats@tutanota.com](w/family/d56ed6d53a15c2911dfe3eaa6dfb847557db8462c55ad246217568fbea806673)                                                 |        0.05 |      0.14 |       0.01 |         3 | 2022-10-25   |
|  243 | [toradmin at night-site dot org](w/relay/1C0736CF3744A3B87C2D2269B8BD3388C7E60552)                                                                |        0.05 |      0    |       0.09 |         1 | 2019-02-18   |
|  244 | [mail: contactmail at s1rocco.org](w/relay/7C781344302E21A6A954D7D794255CFD294D50EE)                                                              |        0.05 |      0    |       0.09 |         1 | 2024-05-24   |
|  245 | [darkened@proton.me](w/relay/7A8DF16033A55D4A7CD6D33A0963416A3E3065B1)                                                                            |        0.05 |      0    |       0.09 |         1 | 2025-01-03   |
|  246 | [AE68ACD0](w/relay/AE68ACD0266C414CDED4338D10BCDF17081563BC)                                                                                      |        0.05 |      0    |       0.09 |         1 | 2024-10-28   |
|  247 | [e: &lt;r3lay&gt;&lt;@torrelaymail.net&gt;](w/relay/8AB172C11996EC969EF5B42B7CB8ADDD07455AA4)                                                     |        0.05 |      0    |       0.09 |         1 | 2024-05-28   |
|  248 | [email:spacetex tutanota.com ciissversion:2 btc:14](w/relay/AF2B014CBE98D2E66B288323B47F2E8DDDD9904E)                                             |        0.05 |      0    |       0.09 |         1 | 2021-11-14   |
|  249 | [BEC5DA93](w/relay/BEC5DA93729F8ACA043228F057058A90C327AAA3)                                                                                      |        0.05 |      0    |       0.09 |         1 | 2023-03-05   |
|  250 | [3258B4E7](w/relay/3258B4E7215304549B41F3541DF45D5EE106534D)                                                                                      |        0.05 |      0    |       0.09 |         1 | 2024-11-24   |
|  251 | [email:fatdave moltencore.org ciissversion:2](w/relay/6E1CEDC61F3707C549B88FB9380E4A750621FCB8)                                                   |        0.05 |      0    |       0.09 |         1 | 2021-11-14   |
|  252 | [C3DFB7BD](w/relay/C3DFB7BD40B072EB6D46578F1BE021FDD9D60713)                                                                                      |        0.05 |      0    |       0.09 |         1 | 2024-12-30   |
|  253 | [email:Quetzalcoatl relays proton.me url:https://q](w/family/704fcecb4e2a2073adb8c1a35dd152ddbc6b83f29351f65fbcabff44cfb4fe08)                    |        0.05 |      0.13 |       0.01 |         8 | 2024-08-29   |
|  254 | [tor@birdeck.com](w/family/e3f8304b35df82b45c2a08ba5bc5879b50261949c886cc852ee0470a70aa3d9f)                                                      |        0.05 |      0.09 |       0.04 |         2 | 2024-07-27   |
|  255 | [tor-relay@t13pr.net](w/family/83d48613f45d2400f50ffa44b8e05ee37bf7fb357f8f7d263defcb3d6069b35b)                                                  |        0.05 |      0    |       0.09 |         2 | 2024-01-26   |
|  256 | [AA763073](w/family/3e697b6c77bf8ae63d4a2b160fbd8e9e53d92511e104293d382f8d4cbab4404a)                                                             |        0.05 |      0    |       0.09 |         3 | 2019-02-18   |
|  257 | [B58D 2CC8 1269 1D74 EDA8 44E2 C2F1 43CF E49F 7671](w/relay/362FA049325802519090C86BC43FC3C6ACBF5613)                                             |        0.05 |      0    |       0.09 |         1 | 2024-11-25   |
|  258 | [58A2A0E8](w/relay/58A2A0E849E9E3692F7B136223507E93CB099150)                                                                                      |        0.05 |      0    |       0.09 |         1 | 2022-07-12   |
|  259 | [66DCBBB9](w/relay/66DCBBB971CA555F86BB2B1D17C00C1828368736)                                                                                      |        0.05 |      0    |       0.09 |         1 | 2024-01-21   |
|  260 | [Logforme &lt;m7527 AT abc dot se&gt;](w/relay/8F6A78B1EA917F2BF221E87D14361C050A70CCC3)                                                          |        0.05 |      0    |       0.09 |         1 | 2021-03-19   |
|  261 | [pikz at tuta dot io](w/relay/E130296683B896A117CE5DA531A5645644178734)                                                                           |        0.05 |      0    |       0.09 |         1 | 2019-08-17   |
|  262 | [rofl.cat](w/family/2d51a6fc83984e03f6d2f50a9e7c939245fef2749377ad459f7fb922811abfb3)                                                             |        0.05 |      0    |       0.09 |         6 | 2019-02-18   |
|  263 | [Matthias Schmidt &lt;tor@vegms.de&gt;](w/relay/8DB706C9B7ABA89F08FCE919DE18DAC63266EC8D)                                                         |        0.05 |      0.13 |       0.01 |         1 | 2024-01-21   |
|  264 | [549FA4E3](w/relay/549FA4E30CD098742052B13CEECCF621ECE0E9D3)                                                                                      |        0.05 |      0    |       0.09 |         1 | 2022-04-03   |
|  265 | [F1542050](w/family/a0eb30b954d5f327fb6c2bf2007832bd6ec517a674ae48acfe7cf5599ed81f2e)                                                             |        0.05 |      0    |       0.04 |         2 | 2024-10-06   |
|  266 | [ceebee &lt;@&gt; chunguswire &lt;dot&gt; me](w/relay/1EFBACCD28A07FD6AD7AA6F1293177D71397E918)                                                   |        0.05 |      0    |       0.09 |         1 | 2022-08-01   |
|  267 | [65562EE2](w/relay/65562EE28CB698A451D29452F282A8F6EABD1865)                                                                                      |        0.05 |      0    |       0.09 |         1 | 2024-01-21   |
|  268 | [fiad@schloop.win](w/relay/7B842FB48CFF19898C8336A11CAA3F425C90F9B5)                                                                              |        0.05 |      0    |       0.09 |         1 | 2024-01-22   |
|  269 | [Yorrick &lt;yorrickh AT mail.ee&gt;](w/relay/90333CD7DF2601BE73557753DEE9B4C8444B5E4A)                                                           |        0.05 |      0    |       0.09 |         1 | 2022-05-03   |
|  270 | [nomore4thelast@protonmail.com](w/relay/A33AAA7E3F46C9AF19B4395641C167F48D3E608E)                                                                 |        0.05 |      0    |       0    |         1 | 2024-10-21   |
|  271 | [Fields of Nephilim Save my Soul newagenephilim@pm](w/relay/C09B0B689E4CF3997C45BAC02543C8433AFFB4A6)                                             |        0.05 |      0    |       0.09 |         1 | 2024-12-29   |
|  272 | [bofh@domain.tldr](w/relay/C56E98E934EDB5EEFA9322D5D4818E09325F7A80)                                                                              |        0.05 |      0    |       0.09 |         1 | 2022-09-20   |
|  273 | [noc@as204750.net](w/relay/A0B4BD14D86B8D1D77AED742BF8381764B624295)                                                                              |        0.05 |      0.16 |       0    |         1 | 2024-09-22   |
|  274 | [Nurtic-Vibe &lt;nurtic-vibe AT grmml DOT eu&gt;](w/family/04fa141793cdc93016b08a3ac6f13a2b20a9dab35a7f1b16081109b8e85d7848)                      |        0.05 |      0    |       0.09 |         2 | 2018-10-03   |
|  275 | [knight AT RELAYNAMEWITHOUTNUMBER DOOOT nett](w/relay/A03E52ED1DE8FDD4FF00C142012D907E3E5568C4)                                                   |        0.05 |      0    |       0.08 |         1 | 2024-06-11   |
|  276 | [xonumi.com](w/family/d80b813986a1394c58cdf4001c4f33a00a164951a1088fc353f9b6b76343ce13)                                                           |        0.05 |      0    |       0.08 |         3 | 2024-01-22   |
|  277 | [miwtor@web.de](w/relay/00F1F247B391B84CB6C221720BCBFC0DFDB91117)                                                                                 |        0.05 |      0    |       0.08 |         1 | 2020-09-29   |
|  278 | [89EEEFA5](w/relay/89EEEFA5880FA551586091524654BDE14792A812)                                                                                      |        0.05 |      0    |       0.08 |         1 | 2023-07-21   |
|  279 | [Beanbag &lt;bbag-bbag at pm . me&gt;](w/relay/A208C66E3BAF32B70920EB6AF8081F7CFA5DB1D1)                                                          |        0.05 |      0    |       0.08 |         1 | 2025-01-04   |
|  280 | [email:privacyboys@tutanota.com hoster:atomicnetwor](w/family/c1a4e0d4144899fdb5be10d58c15215a01ba0f1692aa5e5b5ab00a937afe42bd)                   |        0.05 |      0.12 |       0.01 |         4 | 2023-07-08   |
|  281 | [email:tor memcpy.io url:http://memcpy.io proof:ur](w/family/2d54489f1aa175b8f8a68e9a98538bb7353f388cf3fbaf1a620efc966d3aa71b)                    |        0.05 |      0    |       0.08 |         2 | 2021-12-24   |
|  282 | [Sponsored by https://tor.foundation](w/family/ebbcb59ceb9c642bec7b5e7b48c77c048c2a6303deb4633aafaba557beaf0260)                                  |        0.05 |      0    |       0.08 |         2 | 2024-07-22   |
|  283 | [www.schmeling-ol.de](w/family/b6afa470211e3d6c2b68393447456fd8731f6b38c4561d0408e8ac4a06cf503e)                                                  |        0.05 |      0    |       0.08 |         2 | 2019-09-16   |
|  284 | [9CD25E71](w/family/1fe88672ba09a424ee0db9d3c55b8d3eed1e6849807b679d4064faf6133170db)                                                             |        0.05 |      0    |       0.08 |         2 | 2024-01-22   |
|  285 | [Stan &lt;favorite0ne@proton.me&gt;](w/family/1cde88e9b09e46b048a9790a8173153428eccf12b0bb70f5e6179e6f68fde6ff)                                   |        0.05 |      0.12 |       0.01 |         3 | 2024-08-02   |
|  286 | [tor at kyrasec.nl](w/relay/28E1F5E0A2DB270868A879DF749809CAB56296D5)                                                                             |        0.05 |      0    |       0.08 |         1 | 2024-06-03   |
|  287 | [friend of tor @privatemail.com&gt;](w/relay/36F7F3BCC3847FEE902F460E6011A5627437F138)                                                            |        0.05 |      0    |       0.08 |         1 | 2024-01-21   |
|  288 | [Gold Diggers &lt;digginggoldtorrelay@proton.me&gt;](w/relay/4CF204F66452C89712B9CF513A213C1F03D8F706)                                            |        0.05 |      0    |       0.08 |         1 | 2024-12-24   |
|  289 | [5C426791](w/relay/5C426791CB47BDDDD97A71EB2EFC4CCC84DEB299)                                                                                      |        0.05 |      0    |       0.08 |         1 | 2023-01-28   |
|  290 | [Jim Bite Me thisssuckss at proton mail dot com](w/relay/5C8CC5659757F690C9B5B9BB4A4302E8397818BF)                                                |        0.05 |      0    |       0.08 |         1 | 2024-12-23   |
|  291 | [606ECD67](w/relay/606ECD67567ED6C84CA379BD4E7B6EB70C47FA47)                                                                                      |        0.05 |      0    |       0.08 |         1 | 2023-06-29   |
|  292 | [&lt;private&gt;](w/relay/AEA5C9C1791B36DA7E751723FEB66B0F511E4FC8)                                                                               |        0.05 |      0    |       0.08 |         1 | 2024-03-11   |
|  293 | [AF37B951](w/relay/AF37B951F76D2BB577366FA059D1B1913DD74D41)                                                                                      |        0.05 |      0    |       0.08 |         1 | 2024-11-05   |
|  294 | [your@e-mail](w/relay/E829677740C7E86F80B226024386C97167B2606A)                                                                                   |        0.05 |      0    |       0    |         1 | 2024-06-20   |
|  295 | [0CDCFB0B](w/family/61b41755504eb95bee127f23e38f430ea8ceced0a155f1ec184db801d786521b)                                                             |        0.05 |      0    |       0.08 |         2 | 2015-04-12   |
|  296 | [911](w/relay/38F848796D85A1705E4922DF8726E3FB3464807B)                                                                                           |        0.05 |      0    |       0.08 |         1 | 2024-03-04   |
|  297 | [TorInAS200462&lt;AmyCrossed AT tutanota dot com&gt;](w/relay/60AEEA23A85B83A407312B560A60482A501A6B89)                                           |        0.05 |      0    |       0.08 |         1 | 2021-06-27   |
|  298 | [7997C3FC](w/relay/7997C3FC88B02A2C6FEF96C5F5B5C50DD7DA2E2C)                                                                                      |        0.05 |      0    |       0.08 |         1 | 2020-08-01   |
|  299 | [7F302F0A](w/relay/7F302F0AACC76835768AF068849CA07D1CC38C5E)                                                                                      |        0.05 |      0    |       0.08 |         1 | 2020-09-10   |
|  300 | [Tuxifan &lt;tuxifan @ posteo . de&gt;](w/relay/A67891856C914E998E82D97A4CCC17381AC4E4FE)                                                         |        0.05 |      0    |       0.08 |         1 | 2024-02-05   |
|  301 | [B369F97F](w/relay/B369F97F3A75CCDCC219B3B7823370010614E956)                                                                                      |        0.05 |      0    |       0.08 |         1 | 2024-11-14   |
|  302 | [1E03D81C](w/relay/1E03D81C9744DE0E3C9DE6E6FBDF1DF9DAEA5AFC)                                                                                      |        0.04 |      0    |       0.08 |         1 | 2024-09-29   |
|  303 | [Gaius Sorjonen &lt;sorjonen AT tuta dot io&gt;](w/relay/36BF4C04D566C50BDFBF891C15D1DF0341C93685)                                                |        0.04 |      0    |       0.08 |         1 | 2024-07-21   |
|  304 | [44DC2366](w/relay/44DC23661E05DEFD94398936D9334987ABCB6E5E)                                                                                      |        0.04 |      0    |       0.08 |         1 | 2019-02-18   |
|  305 | [9A39B0B7](w/relay/9A39B0B75709DD747F5D94A7F24C6BFD80BC587B)                                                                                      |        0.04 |      0    |       0.08 |         1 | 2022-04-23   |
|  306 | [torinfo.unveiling972@passinbox.com](w/relay/D20D10318971A46FD6952D8702B44A9976CC9120)                                                            |        0.04 |      0    |       0    |         1 | 2025-01-04   |
|  307 | [none@none](w/relay/F1CC14C298442FAFF00762BA4339ECBED1AC0F92)                                                                                     |        0.04 |      0    |       0.08 |         1 | 2023-03-09   |
|  308 | [opsfi-mail protonmail com](w/family/3540e7dd418c1b6a6600bcc3b872134bdbd325dfdaf9e155314c081ab1f93ee7)                                            |        0.04 |      0    |       0.08 |         2 | 2024-01-21   |
|  309 | [tor@wurzelmann.at](w/family/60dba7e1cd8ac26c7383d1f18a97a4bfe14198b905265405ba40d70ed1304030)                                                    |        0.04 |      0    |       0.08 |         3 | 2024-08-21   |
|  310 | [348944DB](w/relay/348944DB6A0194FCE0161E400CE778CE0DBE47EA)                                                                                      |        0.04 |      0    |       0.08 |         1 | 2024-01-21   |
|  311 | [553652FB](w/relay/553652FBACFDB28098FDFB020F8F4998FF47DE8E)                                                                                      |        0.04 |      0    |       0.08 |         1 | 2024-01-22   |
|  312 | [Animate@proton.me](w/relay/58907DFC4C11B798A5A7C1149C96F4352F82F662)                                                                             |        0.04 |      0    |       0.08 |         1 | 2025-01-06   |
|  313 | [yout@e-mail](w/relay/A9D3E8EB8AD3DE09519AF5C3652E1545E560D5CB)                                                                                   |        0.04 |      0    |       0.08 |         1 | 2024-06-28   |
|  314 | [email:blueeyeswhitedragon kluismail com ciissver](w/relay/DF6F7908E7FDEEE5DE6DD9C92F7C9DFB20B0CE2A)                                              |        0.04 |      0    |       0.08 |         1 | 2024-01-29   |
|  315 | [your@e-mail](w/relay/B4F1193BECADD10F7EC08DB02C7672FB717987A4)                                                                                   |        0.04 |      0.11 |       0.01 |         1 | 2024-10-11   |
|  316 | [@zandermeer](w/relay/502B0D0D85D056ED7503796F6C28A9731AD5D000)                                                                                   |        0.04 |      0    |       0.08 |         1 | 2024-04-01   |
|  317 | [9A1C9EDB](w/relay/9A1C9EDB9397233138032449B0415E7941DDFC2F)                                                                                      |        0.04 |      0    |       0.08 |         1 | 2024-01-21   |
|  318 | [3490583454676@gmail.com](w/relay/F0D8DC4427780A97A996888E8C4F2819142BEDBB)                                                                       |        0.04 |      0    |       0.08 |         1 | 2025-01-14   |
|  319 | [xonumi.com](w/family/39af9e8d5a5a86273742feeaa5b21df80f5d384d35cc08032ea22169d736affa)                                                           |        0.04 |      0    |       0.08 |         2 | 2024-01-15   |
|  320 | [Mike Wille &lt;tor@mw.gd&gt; pgp: 1D53B2FF846754E7ABC7B](w/family/97275094477eb80bab7d148db032f4cbb23601203e6a9d757f003e1557ecc066)              |        0.04 |      0    |       0.05 |         3 | 2022-11-29   |
|  321 | [tor-relay-contact &lt;at&gt; digitalsquid &lt;dot&gt; co &lt;dot&gt;](w/family/e10d665eff7b1de34fa8efb08d7e8884690164ee48f6373ff15cd6572b54a1c3) |        0.04 |      0    |       0.05 |         5 | 2020-04-03   |
|  322 | [sabotage.net](w/relay/74C0C2705DB1192C03F19F7CD1BB234843B1A81F)                                                                                  |        0.04 |      0.11 |       0.01 |         1 | 2019-02-18   |
|  323 | [Stanislaw Halik &lt;sthalik@misaki.pl&gt;](w/relay/0B7BC0BF2C1186C1C6C23742141373B173DA0DA6)                                                     |        0.04 |      0    |       0.08 |         1 | 2023-11-23   |
|  324 | [torbert then an at and dignonet here a dot org](w/relay/91A147D0792B437BA5DF386B8D84F74D58A0ACC5)                                                |        0.04 |      0    |       0.08 |         1 | 2023-04-02   |
|  325 | [EB68C39C35BC73E97C267CF4087D607D91E0B52C admin &lt;mo](w/family/4b140412d8235a5cc856ceef554c2b0c21d96cc9713ce22e504a4e30fe67143b)                |        0.04 |      0    |       0.07 |         5 | 2023-08-22   |
|  326 | [1079E628](w/relay/1079E628FC6B0025656AC024F2D9975C441498CD)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2019-03-05   |
|  327 | [27B7D6C0](w/relay/27B7D6C06F30BD7A3B3BF8334A414513952BF738)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-07-21   |
|  328 | [9B81565C](w/relay/9B81565CE9970C205D1CFF2656171608D8603CDE)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-04-04   |
|  329 | [&lt;x6c656e696e sektorblue.com&gt;](w/relay/C4BDBFD1049EE1D4F6977C42485F94CD5F97BA92)                                                            |        0.04 |      0    |       0.07 |         1 | 2021-11-24   |
|  330 | [pikachu.systems](w/family/01e79b07890dc183449856bc9202b48de5d81a1360699555534af1ccb41e91fa)                                                      |        0.04 |      0    |       0.07 |         2 | 2021-12-22   |
|  331 | [Kutas Pierdolony &lt; tor.mooned586 A7 silomails , c0](w/family/e3cf93aaf41d79c37acee7cc37c789e68fcae134867523d00d2de2e23d8153f4)                |        0.04 |      0    |       0.07 |         3 | 2024-01-22   |
|  332 | [1D851C4B](w/family/c8540c25eb333c4f35e0d30d7146995729fb26a8265be498a73a7f036f917f4e)                                                             |        0.04 |      0    |       0.07 |         2 | 2023-04-04   |
|  333 | [raltullou@posteo.org](w/family/77543e1d6a6c99610f4aa2069634122ccd6bffebb38c725890a64c74f013a256)                                                 |        0.04 |      0    |       0.07 |         2 | 2017-02-13   |
|  334 | [27AD21AE](w/relay/27AD21AE45CC2DA5CE701925F23E30B5F2CE88C7)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-06-23   |
|  335 | [51407211](w/relay/51407211A947E4D5B670848340EB6C17BD1F600D)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-01-31   |
|  336 | [Pump my rump rumpypumpee at nospam protonmail.com](w/relay/A5B23CF462DA919BDD9717331A27206791689B87)                                             |        0.04 |      0    |       0.07 |         1 | 2024-12-30   |
|  337 | [celtiq.sec A.T. proton D.O.T. me](w/relay/B6F6A56C5DB1CFB18692695923B3E429758C9A3A)                                                              |        0.04 |      0    |       0.07 |         1 | 2023-02-07   |
|  338 | [Calypso Strausive mail: calypsos96@protonmail.com](w/relay/C9A13ECA8B56D4641B0339FE62A8482640BDDE26)                                             |        0.04 |      0    |       0.07 |         1 | 2024-12-28   |
|  339 | [CA0BA8FE](w/relay/CA0BA8FE9207FCF31701D7D3EE3BFBEFA7BB14C5)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-05-06   |
|  340 | [D870744F](w/relay/D870744F618F20F3A63592B4F9B0BB919FC1BED0)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-10-28   |
|  341 | [hostmaster@lauchyt.de](w/family/ec53d9d66a18566fb6da200627a5d6e3eaaae64322d0e11667e1d237b74a9e9e)                                                |        0.04 |      0    |       0.07 |         2 | 2023-03-27   |
|  342 | [giannoug AT-gmail DOt- com](w/family/077fece1fb36eb666ed2c1d82135c9024641c52742e132389166751cbe9cb2cc)                                           |        0.04 |      0    |       0.07 |         3 | 2019-02-18   |
|  343 | [vidarekinci@protonmail.com](w/relay/1F2FC2214D63A90926D0A6837896F84A16F4DB60)                                                                    |        0.04 |      0    |       0.07 |         1 | 2022-10-10   |
|  344 | [4134DA29](w/relay/4134DA299E17ED8F6F5AC6642EF1054BC3C133D3)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-11-08   |
|  345 | [Ali &lt;AlleyAllator@protonmail.com&gt;](w/relay/8B62F79629C8D4754651801BCF3EC0E255F1E0EE)                                                       |        0.04 |      0    |       0.07 |         1 | 2024-12-20   |
|  346 | [Vasil Kolev &lt;tor@ludost.net&gt;](w/relay/9E4CC64C4F94C359D43C5BA09094323FDBEFD975)                                                            |        0.04 |      0    |       0.07 |         1 | 2019-02-18   |
|  347 | [DAB09C9C](w/relay/DAB09C9C6118A8FD61F91C1186B2CF84A1467B3B)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-04-04   |
|  348 | [DAF25DF4](w/relay/DAF25DF4AD0452B958923AA9D77C54F1A5473ACD)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-01-22   |
|  349 | [E00DFD54](w/relay/E00DFD54DC165D5452FBD3530D30186DAD016A0C)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2019-02-18   |
|  350 | [tor-operator@xor.sc](w/relay/CBCC85F335E20705F791CFC8685951C90E24134D)                                                                           |        0.04 |      0.11 |       0.01 |         1 | 2022-08-21   |
|  351 | [email: tor at b0rken dot de](w/relay/013ABAED8F4CDB677BE0B5212E4B2583B86035EE)                                                                   |        0.04 |      0    |       0.07 |         1 | 2021-08-30   |
|  352 | [abuse at sign zwiebelmett dot xyz](w/relay/046F2D59A85FAE693676A87533717C57436261C2)                                                             |        0.04 |      0    |       0.07 |         1 | 2019-09-29   |
|  353 | [tor-relay@littleroot.de](w/relay/3797C9C124615A03EB45DB7945859F97ADFAC10F)                                                                       |        0.04 |      0    |       0.07 |         1 | 2024-06-02   |
|  354 | [levitate@proton.me](w/relay/899E99BF99101B3C183BE9AF9CB5A7BE92F9FC4E)                                                                            |        0.04 |      0    |       0.07 |         1 | 2024-12-05   |
|  355 | [flev @ kpnmail . nl](w/relay/94F16DA2BDDBA092954FF8EC29F9234A69949403)                                                                           |        0.04 |      0    |       0.07 |         1 | 2019-02-18   |
|  356 | [AA0D90C8](w/relay/AA0D90C85200A0A64CBC58AB4D6AA0058530BCE4)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-04-05   |
|  357 | [50shadesofblue85@gmail.com](w/family/a4d071c2de3637704814571897e0be9f9f37bcc4c693302d970c16c95f704144)                                           |        0.04 |      0    |       0.07 |         8 | 2024-08-30   |
|  358 | [your@e-mail](w/relay/72409582B43695A8A75EE323D0402086292688A6)                                                                                   |        0.04 |      0.1  |       0.01 |         1 | 2024-09-02   |
|  359 | [0xAAF5E25904F58A0F52BE1DA5BECFF25F495915B7 Absturz](w/relay/2A82DD0F42F479F2F55006D3C7AA052A84071ECB)                                            |        0.04 |      0    |       0.07 |         1 | 2024-01-21   |
|  360 | [Patrice Mail: patricericebluejay@protonmail.com](w/relay/B8F0736B96819C88A1AED46D5965FA18610694B5)                                               |        0.04 |      0    |       0.07 |         1 | 2025-01-10   |
|  361 | [easybird &lt;easybird.relay@proton.me&gt;](w/relay/6FE30A2A59E9A2E84723CF05E3C5051BB42175D3)                                                     |        0.04 |      0    |       0.07 |         1 | 2024-06-08   |
|  362 | [info@niklasl.com](w/relay/97E4BAB582717350E6FF6160899FA9B665C834E3)                                                                              |        0.04 |      0    |       0.07 |         1 | 2022-09-30   |
|  363 | [&lt;olafuringvason@posteo.is&gt;](w/relay/A9FAB6E0396C7B07ECEB39EE71288A08F7443AB7)                                                              |        0.04 |      0    |       0.07 |         1 | 2024-02-25   |
|  364 | [A5CAF012](w/relay/A5CAF012A4A940914DC441746B9342A6EC116417)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-03-01   |
|  365 | [maffaypeter847@gmail.com](w/relay/D9ADC85ABCD68A903908FE42FF7CA2D9F56AA32F)                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-11-27   |
|  366 | [FC87BA11](w/relay/FC87BA11F0364DBF5E5B9846F4C82132792F758C)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-01-22   |
|  367 | [xor.st &lt;tor@xor.st&gt;](w/relay/2ACF25EDCB5CAECF2F2AB2A5F9EB1E7600CD8B0D)                                                                     |        0.04 |      0.1  |       0.01 |         1 | 2024-07-04   |
|  368 | [17C2FBA1](w/relay/17C2FBA1F1AAB637E92247D060A734FD6786433B)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-01-22   |
|  369 | [379AD084](w/relay/379AD084786C17EC2D53C2B0420A330A3838E174)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-11-01   |
|  370 | [WilliDieEnte &lt;tor AT ente dot dev&gt;](w/relay/575B47977496E830DF5334F1A2266F16E028CB4B)                                                      |        0.04 |      0    |       0.07 |         1 | 2024-12-04   |
|  371 | [0x4471de61 Senf &lt;tor AT senf dot space&gt;](w/family/7be60b207a5080771d922285e1c050dbfceed84b24f89993b19f29eb6a81bc89)                        |        0.04 |      0    |       0.07 |         3 | 2022-12-29   |
|  372 | [tor-relay-admin@carlos1001.com](w/family/cbce76aa7036390374a9cb68eab4137b14a29d71e4348275ff8e1befe34e149d)                                       |        0.04 |      0.09 |       0.01 |         4 | 2021-05-18   |
|  373 | [tor@gweifinder.mozmail.com](w/family/a2c4823df2c76f86f9cb79d053061e98adbbd8eb5d637478a9f6ee3fdf72e5ad)                                           |        0.04 |      0    |       0.04 |        12 | 2023-12-13   |
|  374 | [Attest@proton.me](w/relay/015AB136B11A949009A160747296B21B9FA21D69)                                                                              |        0.04 |      0    |       0.07 |         1 | 2025-01-06   |
|  375 | [This is a university project contact me at jt0981](w/relay/07D8ECD7305722EE37FA0A408BC0D2034B9BE07A)                                             |        0.04 |      0    |       0.07 |         1 | 2025-01-05   |
|  376 | [09F9CD95](w/relay/09F9CD95B472256DFDFF666A0CFD82A3F3CE3514)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-02-10   |
|  377 | [114555F8](w/relay/114555F8664D317BB9616C02810A8A078049EAE3)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-01-23   |
|  378 | [1D6528AA](w/relay/1D6528AA190F17B2C055CBD042D672778A265661)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-06-09   |
|  379 | [IP-Eend &lt;tor AT ip-eend dot nl&gt;](w/relay/5FA794BF301AF35E4AED185E939CBA9D2CFC2360)                                                         |        0.04 |      0    |       0.07 |         1 | 2024-05-23   |
|  380 | [693F0A23](w/relay/693F0A23AB32726570F79857D92997A5125EC2D2)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2024-11-01   |
|  381 | [rng29a@wintermute.info](w/relay/8E7ACAD878BBD61097C0E0D557160F5D59BCE5CA)                                                                        |        0.04 |      0    |       0.07 |         1 | 2020-08-21   |
|  382 | [B16BFE5C](w/relay/B16BFE5C5DD2F76EAB72E3FD41A062706912B0F2)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2022-08-21   |
|  383 | [&lt;private&gt;](w/relay/D7C218579374ED6525E12362A0B2A3DAEB0B5CEC)                                                                               |        0.04 |      0    |       0.07 |         1 | 2024-03-21   |
|  384 | [hiwi &lt;hiwi AT nurfuerspam dot de&gt;](w/family/d2a2ed1e1d4b15d5d24bad7f2ca21fd2807f76cc743ccc2da261129283533acd)                              |        0.04 |      0    |       0.07 |         2 | 2024-11-27   |
|  385 | [Tor Admin &lt;toradmin AT veilsoftheonion DOT eu&gt;](w/family/5a85a0b18e18d13799109bbfb7325bdce3b17ea732564c4891cd2ebd3e05fa3d)                 |        0.04 |      0    |       0.07 |         2 | 2019-02-18   |
|  386 | [Sven Reissmann &lt;abuse at rz.hs-fulda.de&gt;](w/relay/E70906B974DF23A6858B06FED589DC3696781F00)                                                |        0.04 |      0.12 |       0    |         1 | 2024-01-21   |
|  387 | [z9kx21zk855s@protonmail.com](w/family/d302854ffd3517cc7576ce0f2d3fc9bb9d36f4d7815bbce142b3ad36d2cf00c8)                                          |        0.04 |      0.1  |       0.01 |         2 | 2023-06-13   |
|  388 | [email:hotpwkr jltn xyz Donate here:17zPicHTVE7GP](w/relay/5F3B05B9A5575E614337AFA84DF04F526CD14C1B)                                              |        0.04 |      0    |       0.07 |         1 | 2022-11-29   |
|  389 | [florentin.rochet@unamur.be](w/relay/BDD1649638E5BCA3303F89BAA27C06DE13ACFB24)                                                                    |        0.04 |      0    |       0.07 |         1 | 2024-07-09   |
|  390 | [DB603D15](w/relay/DB603D15336F59DBF6421B3BCBE786D54CE3FED3)                                                                                      |        0.04 |      0    |       0.07 |         1 | 2023-04-18   |
|  391 | [info@syndicateguys.com](w/family/146ce69c201710c56e7ada04fca862df4953fe8e52ed49d99c60e30688b398d0)                                               |        0.04 |      0.09 |       0    |         7 | 2024-01-20   |
|  392 | [tor a web7seas dot com](w/family/0b525e02eebe28c6333d7c86466b939eff3bebdb366f07bb37d78a0c029964ca)                                               |        0.04 |      0    |       0.06 |         2 | 2019-09-26   |
|  393 | [371C00BF](w/relay/371C00BF5F71AC45FBD5FE74504A6D2408BAD5E0)                                                                                      |        0.04 |      0    |       0.06 |         1 | 2023-05-10   |
|  394 | [474EA76A](w/relay/474EA76AC6B5BA6656560A2C1465C2A299751AD2)                                                                                      |        0.04 |      0    |       0.06 |         1 | 2023-07-11   |
|  395 | [6E5F1BE3](w/relay/6E5F1BE327BFA07D4A6E9D930315E906A4C641DB)                                                                                      |        0.04 |      0    |       0.06 |         1 | 2023-02-17   |
|  396 | [7DC499EA](w/relay/7DC499EA72BF553D3CBD1B149167EAA04FD37AA0)                                                                                      |        0.04 |      0    |       0.06 |         1 | 2023-02-17   |
|  397 | [tor at bgp dot rodeo](w/relay/923F05FE883DBC89BF111F391A882168010D165A)                                                                          |        0.04 |      0    |       0.06 |         1 | 2023-02-07   |
|  398 | [4096R/701269C611CA9526 OpenNetworX Tor Operator &lt;t](w/family/36ddbb7c51c33710fec21cbc6fddd2d7483d1f71adac97567bf4015a9bcc1e98)                |        0.04 |      0    |       0.06 |         3 | 2019-02-18   |
|  399 | [Paco Caliente &lt;p4co.c4liente AT protonmail dot com](w/relay/C237392DC121DF50C64C707C3FB95055E68B00CA)                                         |        0.04 |      0    |       0.06 |         1 | 2021-08-26   |
|  400 | [email:wwallace@tntrelays.xyz zec:zs1tlt8aqleaxy46r](w/relay/E04861C32098EF38D6BB2AEFEC81095953FEF0ED)                                            |        0.04 |      0    |       0.06 |         1 | 2022-11-29   |
|  401 | [no@thank.you](w/relay/EE9FFFB8FC1B120275BDDAFBC0BCBD98C8E7D532)                                                                                  |        0.04 |      0    |       0.06 |         1 | 2023-04-30   |
|  402 | [bund &lt;at-&gt; posteo dot&gt;de &lt;&gt; tor-relay.co](w/relay/F12C6E3002C96064A4C0B14CA277690E195D7074)                                       |        0.04 |      0    |       0.06 |         1 | 2023-08-18   |
|  403 | [tor@ioexplo.it](w/family/ef0ee00843beb195beea96be95fbd5bfb109291c5cb4809a6f463267b6498cd1)                                                       |        0.04 |      0    |       0.06 |         6 | 2024-12-23   |
|  404 | [maxzrbn AT protonmail DOT com](w/family/b02865586c455fecc750dc75ac9cdfd02795ec56f5d92f5c107cd849a8532c26)                                        |        0.04 |      0.1  |       0    |         5 | 2024-04-14   |
|  405 | [shadowroute01.oncoming659@passinbox.com](w/family/84b3937bb26440e405f3d52eab4ddf78e66498c428146794d6fa8c05d5ffc1d2)                              |        0.04 |      0    |       0    |         4 | 2024-05-19   |
|  406 | [Rotate-13 gbeznfgre@ubehf-vg.qr](w/relay/0C3D5E19E3C75B505C8ACD26F89DCA2DF970553E)                                                               |        0.04 |      0    |       0.06 |         1 | 2016-08-04   |
|  407 | [1261042B](w/relay/1261042B1775BBACE38DC6C4BCAE87A78B1CDF06)                                                                                      |        0.04 |      0    |       0.06 |         1 | 2024-06-03   |
|  408 | [7BB8A837](w/relay/7BB8A83721012EA9BEC56C219F933A61D4599659)                                                                                      |        0.04 |      0    |       0    |         1 | 2025-01-01   |
|  409 | [81EBAD67](w/relay/81EBAD67553A9039B75B96625F305BCA53910159)                                                                                      |        0.04 |      0    |       0.06 |         1 | 2024-10-06   |
|  410 | [8329D57A](w/family/952fe25504b11b921a02a502662fbb13e1bd29afdb9abf77c3346a02282c6b12)                                                             |        0.04 |      0    |       0.06 |         2 | 2024-05-23   |
|  411 | [8E3700E5](w/relay/8E3700E561E8E080564648601093AC9570080D8D)                                                                                      |        0.04 |      0    |       0.06 |         1 | 2023-05-10   |
|  412 | [bl4ckpr1sm@proton.me](w/relay/C1DDD8DB3C8AE88548E6ECE16C043E24D40D6FD8)                                                                          |        0.04 |      0    |       0.06 |         1 | 2024-10-14   |
|  413 | [Random Person &lt;mangolover at tutamail-com&gt;](w/relay/E36DDC844F5E441733CC0133A6A347BF89D8588A)                                              |        0.04 |      0    |       0.06 |         1 | 2024-05-05   |
|  414 | [email:hmenscerepig pm.me pgp:0c063fab0d477c7978bb](w/relay/E25BE2C3C2A1BF12FB262C73A485A582662A88A8)                                             |        0.04 |      0    |       0    |         1 | 2024-12-13   |
|  415 | [D643B486](w/relay/D643B4869F56026CC92B529727B3BF11F2ADB940)                                                                                      |        0.04 |      0    |       0.06 |         1 | 2024-09-21   |
|  416 | [jets843@privatemail.com](w/family/7024a68bf944969260c25e761b44112e643f0bb81e873761c6c72d32f1296616)                                              |        0.04 |      0.1  |       0.01 |         6 | 2022-08-11   |
|  417 | [email:validbutanonymaddress protonmail.com abuse:](w/family/7cb59ae64a2b5272263e415e08097ee1ee1e421df69a49bd4aa8cb31451bf5a1)                    |        0.04 |      0    |       0.06 |         2 | 2023-07-15   |
|  418 | [0D6CD875](w/relay/0D6CD875B60B762F4F65F8685BD0E39F9886340F)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-03-13   |
|  419 | [2A5F2AD5](w/relay/2A5F2AD5AC3A7A79BA24E26F837D35A56B334002)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-04-08   |
|  420 | [1FE6D59B](w/relay/1FE6D59BC44493017A8CDE25DF300D08BA80CCDD)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-03-23   |
|  421 | [human@kobar.de](w/relay/33E621678DA5F8E2895B3359E64F3C2DCB8494C8)                                                                                |        0.03 |      0    |       0    |         1 | 2024-11-06   |
|  422 | [tor-relay@simofamily.org](w/relay/53AD3B560F118E2D0B2433DD4F41775D13A7C7BD)                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-01-22   |
|  423 | [7B78F4D8](w/relay/7B78F4D80FDF06B2CAF510377577BBB04CB11695)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-11-12   |
|  424 | [0xBF06118DF3B3B2EA327BB8111460B586646E180D Kevin K](w/relay/938588DFA0CA1702C4BFEF88886918C944D494A6)                                            |        0.03 |      0    |       0    |         1 | 2024-05-15   |
|  425 | [Hosting-OS.de &lt;tor-relay@hosting-os.de&gt;](w/relay/E30BEF97249443897AA051E0A64310673FF63548)                                                 |        0.03 |      0    |       0    |         1 | 2022-03-24   |
|  426 | [DE915B27](w/relay/DE915B27AF0453595540924D28B8BA74D1276D31)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-01-22   |
|  427 | [torrelay fokaia AT manchester DOT gr](w/family/ef72b9be9bf9f745ff54fb9333a2f0d953c0696d6889471b9f93d5cd0a2d0974)                                 |        0.03 |      0    |       0.06 |         2 | 2022-03-14   |
|  428 | [germancraft.net](w/family/b936d9937824188d43bfb5748fa25a2e1dfbbfc1ce1f15079ab5bbbe70ed041a)                                                      |        0.03 |      0    |       0.02 |        12 | 2019-02-18   |
|  429 | [liiberated1@proton.me](w/family/5915014f96cd465111e3414b92a710e907094225013de22dd5f13215b14e9e2e)                                                |        0.03 |      0    |       0.06 |         2 | 2022-08-11   |
|  430 | [TorAdmin &lt;toradmin AT tanascius dot com&gt;](w/family/bf0b8be7cc1a07c9e6ae836a74a18b9afc7953a1ff88f31e839fc863962c0c5f)                       |        0.03 |      0    |       0.06 |         2 | 2019-12-05   |
|  431 | [John Doe johndoe@anon.local](w/relay/51646B520852370793AAA332CEFD5F4BFAA8C46B)                                                                   |        0.03 |      0.11 |       0    |         1 | 2024-01-21   |
|  432 | [sabotage.net](w/relay/678B3A694071537AD62723BDA96C6CF1358AE67A)                                                                                  |        0.03 |      0.09 |       0.01 |         1 | 2024-01-22   |
|  433 | [$ CONTACT GPG FINGERPRINT $ CONTACT NAME $ CONTA](w/relay/92630E3353B8E5D1D124FF36B95651CACD17C6F8)                                              |        0.03 |      0    |       0.06 |         1 | 2025-01-09   |
|  434 | [t.starlit144@passfwd.com](w/relay/D2A2E8F9CF83FBFF86C29612902F644AE9CB62DC)                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-05-23   |
|  435 | [tor@0x800.cz](w/relay/E09E1A570E7266E9DED42714F27D3D945D9B4EF4)                                                                                  |        0.03 |      0    |       0    |         1 | 2024-08-29   |
|  436 | [email:torrelay limoneneis.de url:limoneneis.de pr](w/family/6d5b6eb5700b69b828b46a3796b7a88c2e66d20962120e6352aeff763d2781aa)                    |        0.03 |      0    |       0    |         3 | 2025-01-03   |
|  437 | [37C1D665](w/family/b8a32185e809dc16ad286bdad519cc3527682d7aa524181485752e34682b3c95)                                                             |        0.03 |      0    |       0.06 |         2 | 2019-02-18   |
|  438 | [portaler-typ.0c@icloud.com](w/relay/A47C8E0D64E733EDC8CB4409BDE07DB3C0ED28A8)                                                                    |        0.03 |      0.11 |       0    |         1 | 2022-08-31   |
|  439 | [D0BEAF48](w/relay/D0BEAF489E339783A0146DA7575241A2E7F52C45)                                                                                      |        0.03 |      0.09 |       0    |         1 | 2025-01-08   |
|  440 | [c0der@freenode.cc](w/relay/02351FC88D0BF06F6CDE5452656641E6119DBD7E)                                                                             |        0.03 |      0    |       0.06 |         1 | 2021-11-12   |
|  441 | [dianaclip@proton.me](w/relay/0811AB09B32DA37DEB6EC17FB18F11E1842A2C0A)                                                                           |        0.03 |      0    |       0    |         1 | 2024-11-10   |
|  442 | [37A5E87E](w/relay/37A5E87EBD0B99B09650B32C8F3E085CF83A6EA7)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-05-01   |
|  443 | [zorc.xyz](w/relay/4CEAFCE5841C0DAE30164B4F59452F7F4D818A67)                                                                                      |        0.03 |      0    |       0    |         1 | 2021-01-28   |
|  444 | [samam &lt; at &gt; protonmail.com](w/relay/54DE63F4587058B79152A75A0238D7F7A0279215)                                                             |        0.03 |      0    |       0.06 |         1 | 2019-02-18   |
|  445 | [60C24AFF](w/relay/60C24AFF465D2E7FB6E9375E243F894E2939DF27)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-06-23   |
|  446 | [BA46824B](w/relay/BA46824BA757FCCC0FB4FDC0A52DC348BD84FBA6)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-08-16   |
|  447 | [8921CB0E](w/relay/8921CB0ECEA669EEF8A2FD20537D58A676F47228)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-04-24   |
|  448 | [rocking@proton.me](w/relay/8B48D839E679221267F1C33E22688C34501C56B1)                                                                             |        0.03 |      0    |       0.06 |         1 | 2024-12-13   |
|  449 | [CDD66C79](w/relay/CDD66C79A1BBE7DA53C6A40E7B604FEE07E9BAD8)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-03-15   |
|  450 | [theprivacyhaven@proton.me](w/relay/F57C29781F6AEEF2718ED37DF792218BDFC996B3)                                                                     |        0.03 |      0    |       0.06 |         1 | 2024-12-31   |
|  451 | [IT &lt;tor AT informatik dot uni-bremen dot de&gt;](w/relay/F1CD870D7A8FA364E459ABA70B1737D40B0B4BB3)                                            |        0.03 |      0    |       0.06 |         1 | 2022-04-03   |
|  452 | [0AFD832F](w/relay/0AFD832F09B6C2C9E0FE99E78B29E2ED325B0E54)                                                                                      |        0.03 |      0.09 |       0    |         1 | 2024-03-13   |
|  453 | [sabotage.net](w/relay/82E2708957A41EDA0819EE1C5FFC3E2DC38B9FE9)                                                                                  |        0.03 |      0.09 |       0    |         1 | 2024-01-22   |
|  454 | [email:contactrelay freenode.cc ciissversion:2 xmr](w/relay/0439AB73BB2B8730FCB15B18252928FC0C2EDF91)                                             |        0.03 |      0    |       0.06 |         1 | 2021-11-14   |
|  455 | [tor at ensayon dot com](w/relay/3ADA8CCC38AF196639ECF7FC7BF2215434F0C64D)                                                                        |        0.03 |      0    |       0.06 |         1 | 2024-10-09   |
|  456 | [tor at pingless dot com](w/relay/4F35B3EC9077B58D08129423CB9B1825EDB6FDCB)                                                                       |        0.03 |      0    |       0.06 |         1 | 2022-01-03   |
|  457 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/47F62C33607CD953ED026A63C67542ED424811A4)                                             |        0.03 |      0    |       0.06 |         1 | 2024-01-22   |
|  458 | [tortor AT mailbox dot org](w/relay/7C7862D39221B9C6785AA20A31430944D4BD54DE)                                                                     |        0.03 |      0    |       0.06 |         1 | 2024-05-10   |
|  459 | [76D58DE9](w/relay/76D58DE9BF46B35984FC45BB0BAE361A66968ABF)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-05-04   |
|  460 | [8A5EFB7B](w/relay/8A5EFB7BF172104441B5C5F5A047D92D9C70BA37)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-01-21   |
|  461 | [0x59205995C95D108C Sylvain Rager &lt;sylvain at reg](w/relay/BD4C647508162F59CB44E4DFC1C2B2B8A9387CCA)                                           |        0.03 |      0    |       0.06 |         1 | 2019-02-18   |
|  462 | [E42DEAC2](w/relay/E42DEAC28AB38BD89312FB92DA1B5D0CDC09386C)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-05-11   |
|  463 | [email johnsmith4675884798@proton.me](w/relay/D15D9A1BD6297C55E73A8AB2E63260EB62C95C4E)                                                           |        0.03 |      0    |       0.06 |         1 | 2024-12-31   |
|  464 | [Relay by H and the team. Contact us at: buzzteam A](w/relay/F50755D5018C23F6CD115F23C95CCB2DC8B608B1)                                            |        0.03 |      0    |       0.06 |         1 | 2022-08-01   |
|  465 | [tor@schr.at](w/relay/ED134C125AA560DDE5BADEBC228495BFDC226CF8)                                                                                   |        0.03 |      0    |       0.06 |         1 | 2024-05-24   |
|  466 | [secutor secure-bits.org](w/family/91eae0b270158b0c37b7b465db1c3cd17420eb7ef5d146699d0fea240743871d)                                              |        0.03 |      0    |       0.06 |         2 | 2024-01-22   |
|  467 | [Critical Cat &lt;tor@critical.cat&gt;](w/relay/2DCF5236122F31C9271FDDE79DB49397ABC05984)                                                         |        0.03 |      0    |       0.06 |         1 | 2024-01-22   |
|  468 | [mail: admin tjdev.de](w/family/ad0821c91771a0ff34723be3b502a74a3477944dc1c5e9515d62446d809c9d16)                                                 |        0.03 |      0    |       0.06 |         2 | 2022-09-10   |
|  469 | [mib at mib dot dev](w/relay/67AF1BD7BF90CC4EF1BDA1E9EA87F29E4C03EDFA)                                                                            |        0.03 |      0    |       0.06 |         1 | 2024-01-26   |
|  470 | [none](w/relay/7BD1E46FD753FBA0BEA36E569575FBDF4C5B877E)                                                                                          |        0.03 |      0    |       0.06 |         1 | 2024-01-22   |
|  471 | [71986901](w/relay/71986901178D81CBFD56484308B301D873E0760C)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-01-22   |
|  472 | [739AE4DE](w/relay/739AE4DE6FF2FB2500585E12FCE78FA593FA4AC6)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-07-19   |
|  473 | [tor.start100@gmail.com](w/relay/73A1E0B31A34C00013A0A13928877091143346FB)                                                                        |        0.03 |      0    |       0    |         1 | 2024-01-22   |
|  474 | [8D1272C0](w/relay/8D1272C0D099500E3AD69774D699BB857AFDF397)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-08-29   |
|  475 | [tor at cyberbunker dot biz](w/relay/8DC39E4999796372A449229C8BFDFBDD87605101)                                                                    |        0.03 |      0    |       0.06 |         1 | 2023-07-03   |
|  476 | [BE062843](w/relay/BE06284371FD903154A683D6C501FF1978C1FA1E)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-07-25   |
|  477 | [backupcloud7700@securemail.com](w/relay/E220E9B540E6E1563FCC795DE1B6BED49029EA50)                                                                |        0.03 |      0    |       0    |         1 | 2025-01-13   |
|  478 | [Tor admin &lt;tor AT schellingstrasse dot de&gt;](w/relay/DC7E7D9AB7AD52F03B856E6DC278E9D92BF19B33)                                              |        0.03 |      0    |       0.06 |         1 | 2020-08-21   |
|  479 | [Witam kontakt:jan AT hidemymail.xyz](w/relay/F72AF9F63CD443B2CC7FEB8552EC588EF1992F0A)                                                           |        0.03 |      0    |       0.06 |         1 | 2022-11-29   |
|  480 | [tor dot relay dot edc /at/ danwin1210 dot de](w/family/2552c7ec89fe1bf2c763dfd1ae441fbe5708dbcea6a4b6999d431364e60e2e43)                         |        0.03 |      0    |       0.05 |         6 | 2021-03-19   |
|  481 | [mk17hg@brocku.ca](w/family/7342317f7d56b2bfbf442396f4fe069f5879e4adb1a5b47b8661ca2ef5fed96c)                                                     |        0.03 |      0    |       0.06 |         8 | 2023-05-27   |
|  482 | [orenom@tutanota.com](w/family/28df2d50d5648a4404a54621b51ed20f27ef58e2f17cb259622e7c5984e6e90b)                                                  |        0.03 |      0    |       0    |         4 | 2020-07-12   |
|  483 | [tornode2022@protonmail.com](w/family/0ba85393b2eb642b4690663a6876dfd2c83e8bb26d7060b339a3441c76ca60ae)                                           |        0.03 |      0.1  |       0    |         6 | 2023-02-17   |
|  484 | [tor-exit-1.allium.dev](w/family/273870e0e7e5969842469e42d16711e0711f142a033b9573ef7a58a99d2755c5)                                                |        0.03 |      0.08 |       0    |         2 | 2022-08-21   |
|  485 | [ramin dot schreur at mail dot com](w/relay/7265075D62051D8125661309062B92AE136BB216)                                                             |        0.03 |      0.08 |       0    |         1 | 2022-04-03   |
|  486 | [a-n-o-n-y-m-e.net](w/relay/E1D7AEBD5218953FB8558056E13B25125CBE2B48)                                                                             |        0.03 |      0.08 |       0    |         1 | 2023-06-09   |
|  487 | [someonesneighbor1@protonmail.com](w/relay/D698261BC1B4A80E24BD050909552C7FE9464CD2)                                                              |        0.03 |      0.08 |       0    |         1 | 2022-05-03   |
|  488 | [galtland.network](w/relay/133D3D8F3B7220A314BAF02A42A566E230234638)                                                                              |        0.03 |      0    |       0.06 |         1 | 2022-06-27   |
|  489 | [38316AF9](w/relay/38316AF9D28F99A451C8789BE21C363ADD0F6846)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-05-12   |
|  490 | [arli@arli21.me](w/relay/64BCBA882D45CE42B56226564435EA0D364A7281)                                                                                |        0.03 |      0    |       0    |         1 | 2024-09-15   |
|  491 | [6154EEEE](w/relay/6154EEEE65A71AAF6B6CA33059D5E351C3B57D9B)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-06-09   |
|  492 | [pinkpurpleorange@proton.me](w/relay/6E3EDE76585F0B9BC2EFF89591D3073471BFD857)                                                                    |        0.03 |      0    |       0.06 |         1 | 2024-11-24   |
|  493 | [1024D/0x49360B3B1DFBA164 Bernhard M. Wiedemann &lt;to](w/relay/BEEE1C835E2954E74A407CDFFA124F00C2F2505B)                                         |        0.03 |      0    |       0.06 |         1 | 2021-03-09   |
|  494 | [DC073284](w/relay/DC073284BAA719D8ECC6ED22E7CCDE9919A06547)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-10-29   |
|  495 | [contact this relay operator at one2345ive &x27;@&x27; prot](w/relay/DF47C5938C23DE8F54DBF3DCE18DAE170AE40EF7)                                    |        0.03 |      0    |       0.06 |         1 | 2025-01-07   |
|  496 | [586D9093](w/relay/586D90935DF5C0F11DE8475B5A8D294F812A33C2)                                                                                      |        0.03 |      0.08 |       0    |         1 | 2025-01-05   |
|  497 | [torservers.net](w/relay/59267EC3DC757CF850DA0F5AF03AB5E69C75FEB7)                                                                                |        0.03 |      0.08 |       0    |         1 | 2023-01-08   |
|  498 | [sabotage.net](w/relay/9928E342EF92F2411D8D68ADC18F6D2B5367171D)                                                                                  |        0.03 |      0.08 |       0    |         1 | 2024-01-18   |
|  499 | [Randy Random &lt;postmaster@zocer.net&gt;](w/relay/062F73860BAAE602B63299373B97F085A6417A78)                                                     |        0.03 |      0    |       0.06 |         1 | 2024-09-22   |
|  500 | [0E83A834](w/relay/0E83A8347254C0572CF2A93D1D34674AC19798A8)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-12-01   |
|  501 | [0CAA2E90](w/relay/0CAA2E9044A86B11915C413B5A0911DF29E9A1AC)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-03-17   |
|  502 | [Eridanus &lt;tor AT 5ir dot de&gt;](w/relay/10A5EFCCD2FB9C1A4AC20FB779A5DB11B58957A7)                                                            |        0.03 |      0    |       0.06 |         1 | 2020-04-14   |
|  503 | [&lt;torrelayrunner AT protonmail DOT com&gt;](w/relay/246490C9408834587E96A68A05BEF039F284185A)                                                  |        0.03 |      0    |       0.06 |         1 | 2024-03-12   |
|  504 | [landshrimp at kluismail dot com](w/relay/9BD6765086E8F4B15D17F166F41911494ED78BDE)                                                               |        0.03 |      0    |       0.06 |         1 | 2022-03-04   |
|  505 | [zsXDYnpE6P at protonmail dot com](w/relay/9D2A5BC019A14D6F4BE1E61CC5E02EB381C810D9)                                                              |        0.03 |      0    |       0.06 |         1 | 2024-01-22   |
|  506 | [A9F8CA97](w/relay/A9F8CA97F0DD5F05F368B150CB10ECAB77581FAC)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2023-06-27   |
|  507 | [D1B228DE](w/relay/D1B228DE5DEF2F8087AEBED4E2115EC5840ACC25)                                                                                      |        0.03 |      0    |       0    |         1 | 2024-12-07   |
|  508 | [Vasil Kolev &lt;tor@ludost.net&gt;](w/relay/D8EA105E79803FB0040A8C2A676D93DAEA2CFFF0)                                                            |        0.03 |      0    |       0.06 |         1 | 2019-06-08   |
|  509 | [EDDD1EE1](w/relay/EDDD1EE1E5EF2C35C70C8FED5A52EF46E08597AF)                                                                                      |        0.03 |      0    |       0.06 |         1 | 2024-08-28   |
|  510 | [Kavin &lt;kavin-tor AT protonmail dot com&gt;](w/family/a87df169b6b7344121d6079c493700e072767d1b9bf7af0f6582790524bbda44)                        |        0.03 |      0    |       0.05 |         3 | 2023-01-18   |
|  511 | [evansaike consultant com](w/family/ed6ad1b40b96aac74a4f6d8d9013b61ab4a93211c7bdb74d3e4bf6ddd08a016e)                                             |        0.03 |      0.04 |       0.03 |         2 | 2022-07-22   |
|  512 | [Lilly Schramm &lt;lilly tor@trans.ceo&gt;](w/relay/469FB12BF25E0EA9ED889D0FE8BDC0E5AB2CD74C)                                                     |        0.03 |      0    |       0.05 |         1 | 2024-02-05   |
|  513 | [45EDDBE3](w/relay/45EDDBE30450D5E7D83D8AD2B8FFF0755E773500)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-10-23   |
|  514 | [email:ynp4bj airmail.cc ciissversion:2](w/relay/5B7A7720F84441F7BABE6C6CE8347C56DC4D6569)                                                        |        0.03 |      0    |       0.05 |         1 | 2024-08-14   |
|  515 | [58AA3EE7](w/relay/58AA3EE7E0830B92DBBB6C62A299A0A644BA31D5)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-04-05   |
|  516 | [dianaclip@proton.me](w/relay/5A2D7CA212CFEA07B70A527BE03E8C7B5CDFB718)                                                                           |        0.03 |      0    |       0    |         1 | 2024-11-10   |
|  517 | [6C333B5B](w/relay/6C333B5BDBA3DFE7A782E40CB970C271ABFED119)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2019-02-18   |
|  518 | [Sponsored by https://tor.foundation](w/relay/C5D1649E5FE05F3B75F2C2AE901783BEF41E6856)                                                           |        0.03 |      0    |       0.05 |         1 | 2024-08-30   |
|  519 | [platypus-tor-node/at/proton/dot/me](w/relay/D7B3558020235C1F374EEC8BDE1468E195411E3A)                                                            |        0.03 |      0    |       0.05 |         1 | 2021-05-08   |
|  520 | [kolektiv@nolog.cz](w/relay/F4FBFB2773FAB87E3708BEFA0B1BEE64FD52E579)                                                                             |        0.03 |      0    |       0.05 |         1 | 2024-12-28   |
|  521 | [athenarelay at protonmail dot com](w/family/39928412a46ad9d32002631d68f470cf79f1a5feaec059082975cd19d1a61453)                                    |        0.03 |      0.07 |       0.01 |         5 | 2019-07-05   |
|  522 | [dhnet.torcontact@gmail.com](w/family/26e6d077612c6c4d5929ff854710fcd98db11d17df91c7b2bd7ba58a32cb6434)                                           |        0.03 |      0.05 |       0.02 |         3 | 2022-09-09   |
|  523 | [torservers.net](w/relay/A1A78BE5F0A6698301913D08DDB76535D5E6D2AA)                                                                                |        0.03 |      0.08 |       0    |         1 | 2023-01-08   |
|  524 | [community.torproject.8pqny@passmail.net](w/relay/0B4190C676FAAD34EB2DCB9A288939476CEBCF32)                                                       |        0.03 |      0    |       0.05 |         1 | 2024-05-10   |
|  525 | [tesseract.dk](w/family/231fd42ddce3272c50ca33d8262032cd4397aa597abd086fe5bd6a1e037ff777)                                                         |        0.03 |      0    |       0.05 |         2 | 2020-05-13   |
|  526 | [2CD23D10](w/relay/2CD23D10948D1C6039977852274F700278B39EE8)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2023-05-06   |
|  527 | [1FB9CCBE](w/relay/1FB9CCBE02CF10978EAB16943973AC5C548FA243)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2022-08-11   |
|  528 | [31588E6B](w/relay/31588E6B91E26E54C32CA0F44A2016A92E1CC479)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-08-28   |
|  529 | [kzjaaqwfnabb protonmail com](w/relay/403D9E1DDD8E66FA8081DEAE17C94B2D1D1F6164)                                                                   |        0.03 |      0    |       0.05 |         1 | 2021-04-28   |
|  530 | [51221964](w/relay/512219649B647564779A016C054ADCF1D08D48EF)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-08-07   |
|  531 | [tor@home.arpa](w/relay/BA197EE81F7461776ED5F57270611FC02072E0D2)                                                                                 |        0.03 |      0    |       0.05 |         1 | 2024-10-14   |
|  532 | [C789BEC2](w/relay/C789BEC2E9D1562020A7E089742D8B379029523B)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-05-23   |
|  533 | [kontakt@hopfen.space](w/relay/7C80E6E91AF12DA27C15F6EA099E73499D613C18)                                                                          |        0.03 |      0    |       0.05 |         1 | 2022-05-13   |
|  534 | [0x1E7523CA911AC822 Markus Witt &lt;markus.witt@rwth-a](w/relay/76D2EBA82BBCCA3DF9F254A9A8372A10A26F3D14)                                         |        0.03 |      0    |       0.05 |         1 | 2019-04-29   |
|  535 | [Heartfire &lt;heartfire AT heartfire DOT me&gt;](w/family/946af3ad8b968b994f543c22bb519cada2de5d16479b71e6a21e89db3c9bf54e)                      |        0.03 |      0    |       0.05 |         3 | 2024-12-31   |
|  536 | [8B4ECB75](w/relay/8B4ECB759D13BF6778ACAA52D666EB2A3E7D2EED)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2020-11-09   |
|  537 | [Gunnis Va &lt;gv.anonym AT gmail dot com&gt;](w/relay/911B1FE9A2462D1739C1CC5E8FCA12900E72FAED)                                                  |        0.03 |      0    |       0.05 |         1 | 2024-11-28   |
|  538 | [8F9CD937](w/relay/8F9CD937D0177BE8AC9E27D18604F93216DFA6A9)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2022-05-03   |
|  539 | [94629572](w/relay/94629572C5FE987B006677296276F8AFD804E7D9)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-04-15   |
|  540 | [torrocks at- mailbox&lt;dot=&gt;org](w/relay/A4F11D693FAB6E949B2B7C18153C3F7989896007)                                                           |        0.03 |      0    |       0.05 |         1 | 2024-05-20   |
|  541 | [xyz.1328.tech](w/relay/BE2803357A0DCA205C24A3D318E45053C401EA4D)                                                                                 |        0.03 |      0    |       0.05 |         1 | 2024-11-29   |
|  542 | [Zufaellige Person vorname nachname@mail2tor.com](w/relay/D97D3472E23D8CA4DC0BD2ECAE6E82AE5DDF3341)                                               |        0.03 |      0    |       0.05 |         1 | 2024-01-22   |
|  543 | [E3D851EB](w/relay/E3D851EB58CD692D626D408390C451BB2CF30AD8)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-08-26   |
|  544 | [tor.gabrielg.es](w/relay/E47C30CE2E397CCDAF0EDE93739789367907DA1A)                                                                               |        0.03 |      0    |       0.05 |         1 | 2021-05-18   |
|  545 | [0x88888888 Ole Tange &lt;ole@tange.dk&gt;](w/relay/E20F4ADCA4C9F011C8F17073F1119367A4560856)                                                     |        0.03 |      0    |       0.05 |         1 | 2024-06-16   |
|  546 | [CB19C930](w/relay/CB19C930356F4F321CC87E063EBDE473674F2F97)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2023-03-29   |
|  547 | [dsasgfds-posteo net](w/relay/D2F05648A73CB0CBA7D254D8D12BB3181408FBAE)                                                                           |        0.03 |      0    |       0.05 |         1 | 2025-01-11   |
|  548 | [email:micrasoft at jltn . xyz ciisversion:2 confmg](w/relay/EA670AB58CD5E1D5DCAB571D100EA1D36D72CA28)                                            |        0.03 |      0    |       0.05 |         1 | 2024-03-15   |
|  549 | [relaymijn a t gmail d o t com](w/family/f9fd8fb7724cd5e9495799696a9a8442109382d18ce5359d285e6e2e6975588b)                                        |        0.03 |      0    |       0.05 |         2 | 2024-11-21   |
|  550 | [cvjoint73@protonmail.com](w/family/f9095e0709c28c7c351f9099082ccc3e47cc3141375a0587026d1ee6941edb2c)                                             |        0.03 |      0.1  |       0    |         2 | 2022-04-03   |
|  551 | [email:Quetzalcoatl relays proton.me url:https://q](w/family/825a40e0353edc3a905ac274e0016604e6dc65e86e6b5f33c460c2bd0f4d7e3e)                    |        0.03 |      0.08 |       0    |         7 | 2024-12-16   |
|  552 | [limited0ne@gmx.com](w/family/047b8fb47601f6ad3bf0856f2c9f2eff07bedc8f42967f3160e2f1e88e5f838b)                                                   |        0.03 |      0    |       0.05 |         3 | 2022-08-21   |
|  553 | [mentor@palokaj.co](w/relay/23899620429B1B0E726AC927EF86BEBDE10F1D0C)                                                                             |        0.03 |      0.08 |       0    |         1 | 2023-07-27   |
|  554 | [NotMyMomsAdmin &lt;NotMyMomsTorRelay AT schaefer minu](w/relay/2D8768E3EA8B974ADB69F7FA8140DBEAFC14C8F0)                                         |        0.03 |      0    |       0.05 |         1 | 2021-12-14   |
|  555 | [theres-no-email-for@bots.com](w/relay/45959A38ACAF2ECFB488A3C69D0C04F42438AB9D)                                                                  |        0.03 |      0    |       0.05 |         1 | 2024-04-14   |
|  556 | [tor-relay@steinmann.help](w/relay/6BD3A16B0A0CFE6493F9C7B4228CFB192468F38A)                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-04-13   |
|  557 | [email:snowball at rapidmail.cc](w/relay/90BCBF737079BB5047CB2AEAE49FBC1BA91B5EDB)                                                                |        0.03 |      0    |       0.05 |         1 | 2021-12-04   |
|  558 | [foo@example.com](w/relay/A4A80D167176EE3F26390847A0498EF7E2CC9BDB)                                                                               |        0.03 |      0    |       0    |         1 | 2024-10-05   |
|  559 | [B1FE4BE9](w/relay/B1FE4BE9DD33376DADC22D271803097E1AE8B35E)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2023-02-21   |
|  560 | [werger.ufer@tutanota.com](w/relay/BC7BBFBBF4AE5469405591D28BF3EF8071B0F32E)                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-01-21   |
|  561 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/B66BDA3E822EEC458DA530A97062362DFE771491)                                             |        0.03 |      0    |       0.05 |         1 | 2023-08-02   |
|  562 | [branux dot sarls at proton dot me](w/relay/C43F0E1F1E7504400DBE6BB7D40EBB4F153CB112)                                                             |        0.03 |      0    |       0    |         1 | 2024-08-24   |
|  563 | [Mr.Weasel ferretfet@proton.me](w/relay/CDCCB6E228E9BC0898713BD026CBA47E3C57B87D)                                                                 |        0.03 |      0    |       0.05 |         1 | 2024-04-03   |
|  564 | [ezyn.de](w/family/8459182e128af26901ec8d0cb70ebd17081c9c9ebed31958290d42575e9d31e6)                                                              |        0.03 |      0    |       0.05 |         3 | 2021-10-05   |
|  565 | [02C7A07B](w/relay/02C7A07B1214AA338A705EFCCA409D700F757201)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2023-03-01   |
|  566 | [bbb@gmail.com](w/relay/6B3FB0717F7C4983EE9920B120E21229A9FFFB32)                                                                                 |        0.03 |      0    |       0    |         1 | 2024-12-30   |
|  567 | [holonet.sh](w/relay/A8FB73D917B7C2B851A358729359E13EBA5978FA)                                                                                    |        0.03 |      0    |       0.05 |         1 | 2022-04-23   |
|  568 | [DC4EB02B](w/relay/DC4EB02B37F1F7D499303F41986EE4F7ACE2A090)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-12-31   |
|  569 | [E6D32265](w/relay/E6D32265F08C3CE616365B5D5FFAF64C63AEB6DC)                                                                                      |        0.03 |      0    |       0    |         1 | 2024-01-22   |
|  570 | [admin@caspervk.net](w/family/a3ef1f9ae6d38e7651876a19438279f1ae36e6e689cb9b1c75a87edf855c4b87)                                                   |        0.03 |      0.07 |       0    |         4 | 2023-08-06   |
|  571 | [PMG the world@is.yours](w/family/85494ea665dc97b86d959e139278ec17355da025eab2eb00c6ee160f578a8221)                                               |        0.03 |      0    |       0.04 |         2 | 2022-10-30   |
|  572 | [2CE9BE1F](w/relay/2CE9BE1FC88B9D0FA03F387C9E4F000B5D4B2AE9)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2019-05-09   |
|  573 | [252957C9](w/relay/252957C95C1E0B9C0A72F7ED4716BA1FFF24BF2F)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-08-28   |
|  574 | [0xFFFFFFFF observatory123 &lt;observatory123 AT proto](w/relay/45431BF8AB66C673942C1E344BB520625CE5F817)                                         |        0.03 |      0    |       0.05 |         1 | 2024-08-14   |
|  575 | [&lt;tor-contactREMOVEME AT t4cc0.re&gt; GPG: 0x3AFF3AB49](w/relay/5C8B811887778DCF705F3D39F19E40A21889451F)                                      |        0.03 |      0    |       0.05 |         1 | 2019-02-18   |
|  576 | [torspam at timanttikuutio . eu](w/relay/5E0D5B2B4C1AACE479607E84EC1BCE988910AB46)                                                                |        0.03 |      0    |       0.05 |         1 | 2021-05-08   |
|  577 | [keiferdodderblyyatgmaildodder dot com](w/relay/79E3B585803DE805CCBC00C1EF36B1E74372861D)                                                         |        0.03 |      0    |       0.05 |         1 | 2024-02-03   |
|  578 | [atomcats dot tor dot relay at gmail dot com tor-re](w/relay/9AB93B5422149E5DFF4BE6A3814E2F6D9648DB6A)                                            |        0.03 |      0    |       0.05 |         1 | 2019-02-18   |
|  579 | [Lennart Oldenburg &lt;lennart.oldenburg@esat.kuleuven](w/relay/ACC874AD6D4D3AC308CB6C044620A159A1123196)                                         |        0.03 |      0    |       0.05 |         1 | 2019-02-18   |
|  580 | [&lt;TGSwissNET abcATabc gmail abc abc com&gt;](w/relay/CFE52F8C180D13D0D730C818774EA502FF2073B4)                                                 |        0.03 |      0    |       0.05 |         1 | 2023-06-23   |
|  581 | [fuckedop@proton.me](w/relay/D6D677014A583E6F783A03F523A6C5DC2F6347D1)                                                                            |        0.03 |      0    |       0.05 |         1 | 2022-05-03   |
|  582 | [0A8FB5E2](w/family/b647f4616cf340a8a3d6eb196cff59e9fd02ab6b8a7b3642f09c7cebcaa43c0b)                                                             |        0.03 |      0    |       0.05 |         2 | 2022-10-27   |
|  583 | [tor@righttoprivacy.net](w/family/962533ecd3b3fbcd4f9518a69e77a3bf640417a8f06c9d61fe8f596f597b56c2)                                               |        0.03 |      0    |       0.05 |         2 | 2024-01-22   |
|  584 | [torrelay@hayzy.com](w/relay/07895E6DE9B3CBCB74B6CCF1ABB14BF112FF36F7)                                                                            |        0.03 |      0    |       0.05 |         1 | 2024-07-13   |
|  585 | [tor@netsecops.blog](w/relay/1355DA12ADB2C0B2C18006FE1E65F3253D35FF61)                                                                            |        0.03 |      0    |       0.05 |         1 | 2024-12-11   |
|  586 | [sakiratijja@proton.me](w/relay/20C97B1A358B8CFFD65F4FFF141E626218AB8CD4)                                                                         |        0.03 |      0    |       0.05 |         1 | 2025-01-11   |
|  587 | [24893333](w/relay/24893333D304C74CCDD11D99090C0471DCFED589)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2022-11-29   |
|  588 | [Sponsored by https://tor.foundation](w/relay/32BBFBD2CA50E34E145425090C56CF5C01852E78)                                                           |        0.03 |      0    |       0.05 |         1 | 2024-07-27   |
|  589 | [35BC0F0D](w/relay/35BC0F0DF661D06677DF301138772EA83B171C91)                                                                                      |        0.03 |      0    |       0    |         1 | 2024-09-07   |
|  590 | [froschw403@gmail.com](w/relay/393DB610A19F0C0BF32D603B20D732407C45019D)                                                                          |        0.03 |      0    |       0.05 |         1 | 2024-11-27   |
|  591 | [&lt;code9n at pm dot me&gt;](w/relay/41D4F82AB54AE5C5FB8D3CD24B4FC84350EFEF03)                                                                   |        0.03 |      0    |       0.05 |         1 | 2022-12-19   |
|  592 | [phoenitydawn tor admin &lt;tor@phoenitydawn.de&gt; - 1KW](w/relay/3E53D3979DB07EFD736661C934A1DED14127B684)                                      |        0.03 |      0    |       0.05 |         1 | 2019-02-18   |
|  593 | [&lt;&gt;money4peace&lt;&gt; @proton.me](w/relay/483239AC4B75CFA6CB8AB8C8EF1C26AB847F645C)                                                        |        0.03 |      0    |       0    |         1 | 2024-07-29   |
|  594 | [&lt;domi.0815@gmail.com&gt;](w/relay/6B0D4904A57D5A5B0F2EDFB6D3B04153F17D189E)                                                                   |        0.03 |      0    |       0.05 |         1 | 2022-11-29   |
|  595 | [C6C2F339](w/relay/C6C2F339836E2A1EFF64B9DAFCB00C1A0D48D5C7)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2022-07-02   |
|  596 | [71A1DA0D](w/relay/71A1DA0D554EC4107DD6ED7303D38DC9A9F8B241)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-06-05   |
|  597 | [Encode:UTF-8 &lt;&lt; gorrionne87 @ proton . me &gt;&gt;](w/relay/D74914027D56E2B7D431056F0C8B880FF2D8B07A)                                      |        0.03 |      0    |       0.05 |         1 | 2025-01-12   |
|  598 | [dianaclip@proton.me](w/relay/D46727B79075DC49AF70C28A8F8C4BC4701EEE22)                                                                           |        0.03 |      0    |       0    |         1 | 2024-11-10   |
|  599 | [techno stigma 0c at icloud dot com](w/relay/FB14847494E1889A7FDA79BC5DEB3A88FB830842)                                                            |        0.03 |      0    |       0    |         1 | 2024-01-30   |
|  600 | [contact at ng1x dot xyz](w/family/357cbb50496f703d9cfc2508cbf5eefb53c07d176a47181222cff7aef42cb292)                                              |        0.03 |      0    |       0.05 |         2 | 2022-06-02   |
|  601 | [relayA6Bkjm@gmail.com](w/relay/A398E05824C1CF432FE1DD241FF4F3462625F712)                                                                         |        0.03 |      0.09 |       0    |         1 | 2025-01-17   |
|  602 | [relay@hackster.anonaddy.com](w/relay/F635A9CD6163BD4B7B3BDC32CE0FE7B3340BC5DD)                                                                   |        0.03 |      0.09 |       0    |         1 | 2023-02-21   |
|  603 | [46F9FB94](w/relay/46F9FB943917858F618F2648595DEACD931D4400)                                                                                      |        0.03 |      0.07 |       0    |         1 | 2024-02-07   |
|  604 | [tor-NLfreedom@protonmail.com](w/relay/AF8DB275960279B87F098B16CC9C78092E118DB3)                                                                  |        0.03 |      0.07 |       0    |         1 | 2022-03-04   |
|  605 | [2B172EBC](w/relay/2B172EBC296D605A1AE72387139A0D5E5A717A76)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2024-10-22   |
|  606 | [12CE2632](w/relay/12CE2632ADF8FA59656836DFBFE0FFBDEE071F79)                                                                                      |        0.03 |      0    |       0.05 |         1 | 2023-02-09   |
|  607 | [eandy@gmx.de](w/relay/4FA68EF9F7C1096C87B172D152E5B39513BFD45C)                                                                                  |        0.03 |      0    |       0.05 |         1 | 2024-12-23   |
|  608 | [Rhys RE &lt;me at sign rhysre dot net&gt;](w/relay/484F666C491BCDE22B45E0E19D1CEA5ACC5A9611)                                                     |        0.03 |      0    |       0.05 |         1 | 2019-02-18   |
|  609 | [dir act at systemli.org](w/family/32914de500078d3949e64e9114fcbb1160af95a82c313d8fd97c1a68e44f51e7)                                              |        0.03 |      0    |       0.05 |         2 | 2023-04-18   |
|  610 | [@jbrps 0x588F6C31 &lt;jonas@rz-k.de&gt;](w/relay/CDAEBA458F6129776643751934076A51D851C348)                                                       |        0.03 |      0    |       0.05 |         1 | 2019-02-18   |
|  611 | [CryptoCactus Tor AT proton dot me](w/family/4de2e3f648a4de3af16e3315dbaec8d24ca44caa9853d46f7a52bd449593a434)                                    |        0.03 |      0    |       0.05 |         2 | 2024-01-28   |
|  612 | [tor at 0x3d dot lu - 1x3dG3utS7FDrTtJutnR3zuCo4Z8f](w/family/56774e0c7b15fe839d53b6e8f5e3d120ffa810abf918b16765a6e51aa9eeffb5)                   |        0.03 |      0    |       0.05 |         2 | 2019-02-18   |
|  613 | [35872480](w/family/8ad6b7122e0867bd32a5ae01bd8f7dd02aae06135ca13c5d4f51d1e0a28f3bc6)                                                             |        0.03 |      0    |       0    |         2 | 2024-09-22   |
|  614 | [alxu.ca](w/family/4875ffbca3f8bc4a4e8ee5585f555fb7ec8e810ccdb69548aae13ec80072813a)                                                              |        0.02 |      0    |       0.05 |         3 | 2019-02-18   |
|  615 | [obfuscation.oxofrmbl@mein.gmx](w/family/7a6ff48eec6035ca1e7b3468fbaa7067b1a3148ee516b9ffac457959a39aad8d)                                        |        0.02 |      0    |       0.05 |         2 | 2021-04-18   |
|  616 | [www.triplebit.org](w/family/c7f53433d59fcc2d8c960c7250e9d2ec605d088d76675165cba2029f69e410dc)                                                    |        0.02 |      0    |       0.03 |        20 | 2024-10-07   |
|  617 | [babysharkdootdoot@proton.me](w/relay/B8F50C7C673B72845001FD8D2EE6FD179F56D162)                                                                   |        0.02 |      0.07 |       0    |         1 | 2024-01-22   |
|  618 | [sabotage.net](w/relay/F9D235DA3EE3C5568A063DDDBC2A89890F71E708)                                                                                  |        0.02 |      0.07 |       0    |         1 | 2022-12-09   |
|  619 | [Burgwallbronn.xyz@proton.me](w/relay/29A793A4762382FC78F283E6664EF9C42E74B1D2)                                                                   |        0.02 |      0    |       0.05 |         1 | 2024-09-21   |
|  620 | [darmstadt@fridaysforfuture.de](w/relay/2FDB1719E6A5E6110F93CE3AC5E841F9B3A2B726)                                                                 |        0.02 |      0    |       0.05 |         1 | 2024-12-29   |
|  621 | [Mike Hertzog /Huthog@poortorrelayer.info](w/relay/7179F808E6817142EB2FD67B5AA21DFBC7876907)                                                      |        0.02 |      0    |       0.05 |         1 | 2024-01-22   |
|  622 | [www.rince.de](w/relay/D16A75E422664448F8A7E7D536D359D512B91256)                                                                                  |        0.02 |      0    |       0.05 |         1 | 2020-08-21   |
|  623 | [Gloria Mundi &lt;tor AT gloria-mundi DOT eu&gt;](w/relay/EFCFDBD8B78FE3D6336DBCBA1330E37B5A353709)                                               |        0.02 |      0    |       0.05 |         1 | 2023-07-21   |
|  624 | [your@e-mail](w/relay/F033EBDEF6A65B5423FBEA9576705DAFA1FBFFD9)                                                                                   |        0.02 |      0    |       0    |         1 | 2024-01-22   |
|  625 | [&lt;BrightEi AT proton dot me&gt;](w/family/a6292942de0377e5cf0a5f328097227b89e132131a27f1e8eb267357aae3346d)                                    |        0.02 |      0    |       0.04 |         2 | 2024-08-05   |
|  626 | [f46edmin@linuxmail.org](w/family/3ea7a11a6bdf49ba121a7992d8da6fb1f0d4361f007b91c38d1c06e4d5ec066a)                                               |        0.02 |      0.06 |       0.01 |         4 | 2022-04-13   |
|  627 | [2EC83D2B](w/family/b004551c57b9227d2a3543e51ce0801a440a26c59d3a2e2f9bc88ac135c0c979)                                                             |        0.02 |      0    |       0.04 |         4 | 2021-11-14   |
|  628 | [worldofmatthew.com](w/relay/259078C74CB230969A6AFCD8535C0B35AECFF868)                                                                            |        0.02 |      0.07 |       0    |         1 | 2020-08-31   |
|  629 | [email:bigcastle8127@airmail.cc ciissversion:2](w/relay/0C36AE99B744E32088C9ED23D7A31F8D23AE1A58)                                                 |        0.02 |      0    |       0.04 |         1 | 2022-12-06   |
|  630 | [2EB3C230](w/relay/2EB3C230180694A1E848001E20F36F76A2287039)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  631 | [3A005D00](w/relay/3A005D00D38E8F1CB88B47E023EF8F1E3788E550)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-10   |
|  632 | [4938A9B5](w/relay/4938A9B50436B901B355F5FD1D9D16805A4E41F8)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2023-08-02   |
|  633 | [tor@mail.flo-the.dev](w/relay/5B11EA82ED4DFAD156AFB6ACF306CE0E710AEDF8)                                                                          |        0.02 |      0    |       0.04 |         1 | 2024-01-21   |
|  634 | [ipunchsharks@protonmail.com](w/relay/75FE5236E67FFA4A44C1152C35EAB36360E4D7DF)                                                                   |        0.02 |      0    |       0.04 |         1 | 2019-06-08   |
|  635 | [zwiebelchentor@gmx.de](w/relay/85378A302B63676FA600E00BD4B3491053381BD7)                                                                         |        0.02 |      0    |       0.04 |         1 | 2024-01-22   |
|  636 | [88CFB26F](w/relay/88CFB26F0CB7A5506A171DA32C4E19152F464964)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2025-01-04   |
|  637 | [contact@itsebyte.org](w/relay/89F0A5E334622D2D30DA5F3DDEBB7F07AD555157)                                                                          |        0.02 |      0    |       0.04 |         1 | 2025-01-05   |
|  638 | [B4C39AD4](w/relay/B4C39AD461B21AA48DB4FB371B001D91A3043C0C)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2022-01-13   |
|  639 | [BE24D2F6](w/relay/BE24D2F644CF03F6BF3F4F18082383F2F4AF2034)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-13   |
|  640 | [luis.carilla1@gmail.com](w/relay/D41AFC78224578E5C5B3C26C2E55778037A52C5B)                                                                       |        0.02 |      0    |       0.04 |         1 | 2024-10-23   |
|  641 | [DFE3C36A](w/relay/DFE3C36A8D3DE61BFA0AF0E8DEC056458D46E2F3)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-11-02   |
|  642 | [F3FD38F2](w/relay/F3FD38F2D9646A3D72484D15585D9A0E9836AC1E)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-02-08   |
|  643 | [abuse@priv.city](w/family/d2c78960c2f6caf78f360d9c86a4d82b97541fcc1fe5db8bf440e69ad66564d7)                                                      |        0.02 |      0    |       0    |         3 | 2025-01-19   |
|  644 | [katerinazamurieva1996964j3cy@mail.ua](w/relay/069DE6996E15B35B99BFAB40DA170C662140AECA)                                                          |        0.02 |      0    |       0.04 |         1 | 2025-01-09   |
|  645 | [030B59F0](w/relay/030B59F0D25752E6C2332E3F7B14746EE6B16D16)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2023-09-17   |
|  646 | [2AD82F39](w/relay/2AD82F3964D325B3FE2FF74E980FB006374EF190)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-03-20   |
|  647 | [1884B98A](w/relay/1884B98A6817CEA48AD28311E7E9AC220B05533B)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-11-07   |
|  648 | [miraty.niv.re](w/relay/40FA09C151C3893B7018DEF55A9854BC9768B82C)                                                                                 |        0.02 |      0    |       0.04 |         1 | 2022-05-03   |
|  649 | [438F3EA4](w/relay/438F3EA4C9FB0DB63F5377A3271AB5435FAD7E04)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  650 | [edita@danwin1210.de](w/relay/64948AE6A45666B48445A83F4C6C19D3D22B3B3B)                                                                           |        0.02 |      0    |       0.04 |         1 | 2022-11-19   |
|  651 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/C746FE39C3592C470ADD8965A0FCBF5DC7EFF091)                                             |        0.02 |      0    |       0.04 |         1 | 2023-08-02   |
|  652 | [Random Person &lt;ettore dot bertani AT gmail dot com](w/relay/FF9475B400CF84900C3074BCE5ADFCCFE1CB9943)                                         |        0.02 |      0    |       0.04 |         1 | 2024-12-19   |
|  653 | [&lt;greenonion AT mailfreude dot de&gt;](w/relay/FFB4BF2AE896CA8E7B3C419855346415D743E889)                                                       |        0.02 |      0    |       0.04 |         1 | 2024-12-30   |
|  654 | [CBD42010](w/relay/CBD420106E46C1EECDB5A02B4CE12CFF1A38B9EB)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2023-08-08   |
|  655 | [GnuPG: 0x6DCEBB9F](w/relay/FD79B7F9230858B48E75F389661840C702511078)                                                                             |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  656 | [admin at hivemind dot biz](w/family/39be2a64ae2774331260849ca62b9b1cd41c215476be7b680a845ad1f3ae7290)                                            |        0.02 |      0    |       0.04 |         2 | 2022-07-22   |
|  657 | [relaytor at yahoo dot com](w/family/a162faf1b3ad9f3b38d1d1f4802e20504267c9a2e5f38ac7ea70ea237dcb6505)                                            |        0.02 |      0.06 |       0    |        12 | 2021-11-04   |
|  658 | [postmaster@lepenet.link](w/family/d0c975b341c0bd219ecf00a4e6e7b767651c945931fd98919b403952999c126b)                                              |        0.02 |      0    |       0.04 |         6 | 2024-02-23   |
|  659 | [EMAIL IS /kiddailey GMX com/](w/relay/94A1C04DB810A7E9B7BB62A8643CB4D9BDC9E7F2)                                                                  |        0.02 |      0.08 |       0    |         1 | 2024-01-30   |
|  660 | [belldaddy@tuta.io](w/family/059aec8a300d47973d585ac1d5401692cfbf77c43fc209269d31a1ab366e9068)                                                    |        0.02 |      0.07 |       0    |         2 | 2024-03-10   |
|  661 | [greorod1206@gmail.com](w/relay/83394E5B57988EFAD5102F1AF0E19E6FFCF8842A)                                                                         |        0.02 |      0.06 |       0    |         1 | 2023-06-03   |
|  662 | [staaf@protonmaildotch](w/relay/CE9ED7FB244F80F6310A6DC399F904C202FD8068)                                                                         |        0.02 |      0.06 |       0    |         1 | 2023-08-14   |
|  663 | [moehre-hostingtor@riseup.net](w/relay/61C52DFC090FD1B1AA0C1F431DC535249C311EB9)                                                                  |        0.02 |      0    |       0.04 |         1 | 2024-01-22   |
|  664 | [Naville Admin &lt;tor-admin naville.com&gt;](w/relay/7E1DBB55DE5CF3E6BD44B9526C9020022A5674A1)                                                   |        0.02 |      0    |       0.04 |         1 | 2024-12-19   |
|  665 | [8C5E2A69](w/relay/8C5E2A6935A8BE1E76CE12E777C157BEACE06F07)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-12-03   |
|  666 | [janiTORX5 &lt;at&gt; protonmail &lt;dot&gt; ch](w/relay/99C7F100EEBA27677715D0318A71D36366B804B1)                                                |        0.02 |      0    |       0.04 |         1 | 2025-01-06   |
|  667 | [I dont have an email to contact me on yet :](w/relay/A8E0BBA351D0A1159BED88CCD405D5AA4DF4EAF7)                                                   |        0.02 |      0    |       0.04 |         1 | 2024-01-21   |
|  668 | [CE602C5F](w/relay/CE602C5FDC13C4745EBE8A9D18BC166DEE5E5743)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-06-06   |
|  669 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/F69E79681EE8C7E56904926AE870C89C04560A4F)                                             |        0.02 |      0    |       0.04 |         1 | 2023-08-02   |
|  670 | [4311DB6F](w/family/6ad08318c9efeff5bb920155bd92670025a24b01d67ca56404acea63160ab3c3)                                                             |        0.02 |      0    |       0.04 |         2 | 2022-02-02   |
|  671 | [email:tor jonas-budde.de ciissversion:2](w/relay/1F65C60F1AFE81BDA6C2AE4D8B6CE2F12A983766)                                                       |        0.02 |      0    |       0.04 |         1 | 2025-01-05   |
|  672 | [pitivierglisse@gmail.com](w/relay/24494F0C553D13D1F46BE783DDE1572D7F0850BA)                                                                      |        0.02 |      0    |       0.04 |         1 | 2023-08-22   |
|  673 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/24D6B6B9591A07CCF43B35D559468B19F44DED6A)                                             |        0.02 |      0    |       0.04 |         1 | 2023-08-02   |
|  674 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/3B175AF473519C959975F39D8127845405F71CCF)                                             |        0.02 |      0    |       0.04 |         1 | 2023-08-02   |
|  675 | [48215EE6](w/relay/48215EE661083D8BA38E39B455AB93BE5228E274)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-10-16   |
|  676 | [Sponsored by https://tor.foundation](w/relay/58F3A320CD73CFE23398B4FAA213E8BA3779C5E7)                                                           |        0.02 |      0    |       0.04 |         1 | 2024-07-28   |
|  677 | [aliceblack48@proton.me](w/relay/6799A31C8C923D15FAC2BDBBB4F75F2D429075C7)                                                                        |        0.02 |      0    |       0    |         1 | 2025-01-17   |
|  678 | [7737A403](w/relay/7737A40305131AD8B5E60CFB9126E4BBE1ED7F76)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  679 | [torrelay@k2x.dev](w/relay/9B50C711511968EA8D9429F89FE4CF711417A0A9)                                                                              |        0.02 |      0    |       0    |         1 | 2024-11-11   |
|  680 | [banshee@proton.me](w/relay/98DFFD0922024C86C8AD3CF7C2B4B489550F7DAA)                                                                             |        0.02 |      0    |       0.04 |         1 | 2025-01-04   |
|  681 | [relay@stateofduality.de](w/relay/AC633C90E126E0BCA96F14ECE5D222B586FA0D56)                                                                       |        0.02 |      0    |       0.04 |         1 | 2019-10-06   |
|  682 | [B50A9826](w/relay/B50A98267A63713F37319D895EA1151C4B27BE4D)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  683 | [B5924BC1](w/relay/B5924BC1B2B39835E5A7D225736E62D4358D5870)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-10   |
|  684 | [zd316@cam.ac.uk](w/relay/B06552737CDA0E1EF84CF56ACB7491FDB81554FC)                                                                               |        0.02 |      0    |       0.04 |         1 | 2024-12-24   |
|  685 | [admin &lt;tor DASH 3xg0k33m AT dzp DOT nz&gt;](w/relay/BF50E09EED25B82861CF95E1AAA42DCFEF53E5D1)                                                 |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  686 | [E84FB379](w/relay/E84FB379C8D394660A2A34886049C948D3024189)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-01-21   |
|  687 | [chaotorum&lt;ASCII64&gt;onionmail&lt;ASCII46&gt;org](w/relay/DCB0BB5DF6D7CE6467DD82193EB4A8581A0F0645)                                           |        0.02 |      0    |       0.04 |         1 | 2021-08-06   |
|  688 | [0x88888888 Ole Tange &lt;ole@tange.dk&gt;](w/relay/F5582460A049E13A1E91AE5E0A4531FAAA1831E6)                                                     |        0.02 |      0    |       0.04 |         1 | 2024-07-29   |
|  689 | [AB8C1662](w/relay/AB8C1662485B50947725A0221E09638B46304FD8)                                                                                      |        0.02 |      0.07 |       0    |         1 | 2025-01-07   |
|  690 | [42C56C1B](w/relay/42C56C1BE2E5EE9EF1E10522A6AFC113F1D0E458)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-01-22   |
|  691 | [jens@reinemuth.pt](w/relay/410DA7387625D410089DEF6FFD1B88AE86671AA6)                                                                             |        0.02 |      0    |       0.04 |         1 | 2024-12-25   |
|  692 | [tor-contact@kher.nl](w/family/e0d49ec251ccfe2fdd0fe1a62f9f3b8b3c4255f89fae22563996ef4286f0bbbf)                                                  |        0.02 |      0    |       0.04 |         2 | 2019-06-08   |
|  693 | [colincogle.name](w/relay/498CDD3BF9DE59A5678E8488FEA450E1876242A5)                                                                               |        0.02 |      0    |       0.04 |         1 | 2022-03-14   |
|  694 | [4ADB08AF](w/relay/4ADB08AFCF04657E0A0288AA230EEB74A96B1CEE)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-01-21   |
|  695 | [5790B62A](w/relay/5790B62AD6C79A1092B30993A8F0F7F23A969FD6)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2020-04-23   |
|  696 | [nice try](w/relay/6007EF215FA156F200B634CC83BD76BB2D563DAA)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2022-10-20   |
|  697 | [tor@worldofmail.com](w/relay/737BF8424F0F4457FCAB53F9282088992C7E104E)                                                                           |        0.02 |      0    |       0.04 |         1 | 2024-10-13   |
|  698 | [86150EB3](w/relay/86150EB357A619A75B871AB9313625E808A6D9D4)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-10   |
|  699 | [8EF390A0](w/relay/8EF390A0CAA31F6AD7A5E2BE7976F33476A245EC)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2023-07-21   |
|  700 | [9B5B3B5B](w/relay/9B5B3B5BC953E8BE5058072310FDD0F631FD868E)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2020-09-10   |
|  701 | [ContactInfo email:knight AT germancraft dot net ur](w/relay/9D9F9FCDE5B200695353E0A29BC1872A1F43D648)                                            |        0.02 |      0    |       0.04 |         1 | 2024-04-11   |
|  702 | [bach.laminar-6e@icloud.com](w/relay/A40253888E9F6FE27EDFE5E8540EAFAF9E6A6B40)                                                                    |        0.02 |      0    |       0.04 |         1 | 2024-12-30   |
|  703 | [r3y7dvprknzsjnwgaufs@tutanota.de](w/relay/BAEE9F1327B726939E6C05550D23850018344390)                                                              |        0.02 |      0    |       0.04 |         1 | 2024-01-22   |
|  704 | [0xF40E25B8FB8FC3F2204ABFBBA9DE100CAF6305D0 Kilobug](w/relay/C308657FD420D95E5FD89C140D3C79B76C4C3D2C)                                            |        0.02 |      0    |       0.04 |         1 | 2024-11-17   |
|  705 | [wakako &lt;at&gt; rod &lt;dot&gt; ac](w/relay/E6161DD961CBB382B59EFA78252BC2827C469265)                                                          |        0.02 |      0    |       0.04 |         1 | 2021-02-17   |
|  706 | [support@vpsfree.org](w/relay/F7B024DB02C601185C202E26DFFD2AD525C16A36)                                                                           |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  707 | [torrelay at kieran dot de](w/family/6be1737d25dca6e8e42377c9a683ed600935abf8517b0c147972272e071577e4)                                            |        0.02 |      0    |       0.04 |         3 | 2019-01-31   |
|  708 | [Tor-Admins &lt;toooor AT all DOT de&gt;](w/relay/4B170476D09459328438F3E68ED19516C9F75A80)                                                       |        0.02 |      0.06 |       0    |         1 | 2019-02-28   |
|  709 | [dev.null@kryptonit.org](w/relay/14E722D088B68CCA306AE7834D564BD6F294BF23)                                                                        |        0.02 |      0    |       0.04 |         1 | 2024-09-29   |
|  710 | [25502A58](w/relay/25502A58CE78E0D11427540D0FAE3ADD079276EA)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2025-01-06   |
|  711 | [Nils Peterson &gt; ax3l.v0ss at gmail dot com](w/relay/1FF0E521C5B2085760EF3A50D6AE40036A440F8D)                                                 |        0.02 |      0    |       0    |         1 | 2022-01-03   |
|  712 | [2702323C](w/relay/2702323CEB6DE132008AF69618645C01130CD69E)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-10-16   |
|  713 | [43219E6F](w/relay/43219E6FC5B68A2E96317BE36A86193FBEAA063F)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-10-23   |
|  714 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/5B4BA9941C7045C5CAF8D6E748764BB6FEB93360)                                             |        0.02 |      0    |       0.04 |         1 | 2024-03-04   |
|  715 | [tor@opensource-it.org](w/relay/6F1A5F8E0A53CEF9632B2DC52DB1D5FF00D15409)                                                                         |        0.02 |      0    |       0.04 |         1 | 2024-08-22   |
|  716 | [. . .](w/relay/923DE89BAD9206721D2B1D60AC7E987097EDF070)                                                                                         |        0.02 |      0    |       0.04 |         1 | 2024-11-23   |
|  717 | [email: admin@xoa.se](w/relay/92A01038972F368200B03DC0D194B217BA441D55)                                                                           |        0.02 |      0    |       0.04 |         1 | 2022-05-13   |
|  718 | [93EF6977](w/relay/93EF69770D372DC7FE6AE8B1CA51F6C3E99F8482)                                                                                      |        0.02 |      0    |       0    |         1 | 2025-01-14   |
|  719 | [AABD320B](w/relay/AABD320BF803A8F59654789CC1FDD39F73A9506C)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-01-22   |
|  720 | [Sponsored by https://tor.foundation](w/relay/C57132A0E436DDA078980A6C2FE0BB9147FD0A40)                                                           |        0.02 |      0    |       0.04 |         1 | 2024-07-28   |
|  721 | [D0D99CCA](w/relay/D0D99CCA36B406F813CB7E5CA17CEE58FBDE88C9)                                                                                      |        0.02 |      0    |       0    |         1 | 2022-07-02   |
|  722 | [CF70F884](w/relay/CF70F8845167E65067B4279DA684AEF308585553)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-11-18   |
|  723 | [arpagic1@mail.com](w/family/abd7a80286ee040a5619a2f1d33a8d54df31ada7f6b9ac29e3406236a7ef854e)                                                    |        0.02 |      0    |       0.04 |         2 | 2024-11-15   |
|  724 | [E039FEF5](w/relay/E039FEF5CC8F0AF731AAC7B0FC1DBA63B33372DA)                                                                                      |        0.02 |      0    |       0    |         1 | 2022-11-29   |
|  725 | [tor@eti-net.de](w/relay/F32467BB64F3B5A954B9008202C4768BB02CB9E8)                                                                                |        0.02 |      0    |       0.04 |         1 | 2024-12-25   |
|  726 | [Our Tor relay: Because sometimes the longest detou](w/relay/FB4236B1D2C3C7FEA15C86583E808CC294EA8831)                                            |        0.02 |      0    |       0.04 |         1 | 2024-10-12   |
|  727 | [recipe-acl@mit.edu](w/family/d3966715436d6eaad2123016a93fa2f14f4d8fc7404de66e72a6a62183ce6e3e)                                                   |        0.02 |      0.02 |       0.02 |         5 | 2023-03-01   |
|  728 | [&lt;trly1 AT proton dot me&gt;](w/family/231bdc505004c0d52fc9ff4c74ef5e5b5ad8bb052aecf8e5403a3a17a158e948)                                       |        0.02 |      0    |       0.04 |         3 | 2019-02-18   |
|  729 | [Ka0a &lt;kAl3id0sc0p3@proton.me&gt;](w/family/620dffedbdb0ac4bf8b039508e634d99defd6da39f197eb3787a6a9e6865d18c)                                  |        0.02 |      0    |       0.04 |         2 | 2022-11-09   |
|  730 | [turtlecute @ horsefucker . org](w/family/ce2ca158c08fb842d083f6f5590ed1efa997c946f3bfb48b1e32f739c56238f3)                                       |        0.02 |      0.03 |       0    |         4 | 2022-10-10   |
|  731 | [Nomad, Digital &lt;digitalnomad34@protonmail.com&gt;](w/relay/03216E9498B9688056F68E6F590FC206E9F40771)                                          |        0.02 |      0.06 |       0    |         1 | 2025-01-02   |
|  732 | [hot.taco.relay@protonmail.com](w/relay/B8E18CA62C1B7F6D077BAF2F92548ECA9E2DA0CA)                                                                 |        0.02 |      0.06 |       0    |         1 | 2024-04-03   |
|  733 | [contact@radical-privacy.com](w/relay/0939A7FBB544A75FAF3887254BCBC6E3B4CEB4C4)                                                                   |        0.02 |      0    |       0.04 |         1 | 2024-11-14   |
|  734 | [2E593E0E](w/relay/2E593E0EC59788020C7A4429BB93F2F825E47A21)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-09-17   |
|  735 | [friedhaintor posteo.de](w/relay/55B885EFEA16C1EE9C6D65E2BAEBDD68AA968533)                                                                        |        0.02 |      0    |       0.04 |         1 | 2024-09-01   |
|  736 | [John Doe &lt;tor AT zeroxninety dot net&gt;](w/relay/5B041A38A473BAA1BF877091DC8F8ED63F63312D)                                                   |        0.02 |      0    |       0    |         1 | 2024-01-30   |
|  737 | [PUFF PUFF puuffdaaddy &lt;@&gt;protonmail.ch&lt;.&gt;me](w/relay/5C4FE03A9A6053319D70C5B6D8939D5F5419CE4A)                                       |        0.02 |      0    |       0.04 |         1 | 2025-01-08   |
|  738 | [adm AT&gt;&gt;tmrx.cc](w/relay/6A8D2C69C94A3DF3A80CC4153041DA81DC30A52C)                                                                         |        0.02 |      0    |       0.04 |         1 | 2024-01-22   |
|  739 | [6E0063AD](w/relay/6E0063ADCEE6389FB03361BF3B96442168D494A5)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-10   |
|  740 | [76A4FAD9](w/relay/76A4FAD913B837CBAC6C5A4AC9E0A29A8805D860)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-11-29   |
|  741 | [littlehoster.denote399@passinbox.com](w/relay/933D284804EED001280FE6BBF49C4D592171DF4B)                                                          |        0.02 |      0    |       0.04 |         1 | 2024-04-23   |
|  742 | [Leon &lt;Leon AT platinumhost dot io&gt;](w/relay/9808D762C79C15C59C68F08693F1650D377E8735)                                                      |        0.02 |      0    |       0.04 |         1 | 2023-04-12   |
|  743 | [darmstadt@fridaysforfuture.de](w/relay/DD068520C3C34EA4223DBD82A111E5AADC419EB7)                                                                 |        0.02 |      0    |       0.04 |         1 | 2024-12-31   |
|  744 | [DE928327](w/relay/DE9283278C50DCBA64F421A7E487BEF80F910870)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-17   |
|  745 | [FAB3FE2A](w/relay/FAB3FE2A1A13FFEE20B68FF879FFA0301B67AAFA)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-08-09   |
|  746 | [Patator &lt;cmVsYXktb3BlcmF0b3JAYXNjaWlhbmRodXRjaC5iZ](w/family/23270fbf5bebcd7069a3c5558486921b3dc042ccf05052aaef482ae8d5149665)                |        0.02 |      0    |       0.02 |         3 | 2021-10-05   |
|  747 | [tor.skankhunt42.pw](w/family/e65e843467a5f8d4cfea5b152891285a383293d9f8e9aa4866d22d46936067d7)                                                   |        0.02 |      0    |       0.04 |         2 | 2023-05-12   |
|  748 | [tor at ewigschlau dot de tor-relay.co](w/family/a43c87382e243315154be39265156803f9e1526948a9156ca3f8dc40b4f311ec)                                |        0.02 |      0    |       0.01 |         2 | 2020-07-02   |
|  749 | [zcarba@gmx.com](w/relay/CBB6074B15FF8BF9DF77FD4D083D6C585373E647)                                                                                |        0.02 |      0.07 |       0    |         1 | 2024-12-22   |
|  750 | [Effi.org &lt;tor AT effi dot org&gt;](w/family/725a367c290d2590645ff637b94e3eed17544f6a2c8631abdd98e71f7ecb385e)                                 |        0.02 |      0.05 |       0    |         2 | 2018-11-13   |
|  751 | [Bartosz Waszak &lt;waszi@httpx.pl&gt;](w/relay/132395E199674BC4E65EA90DA0150D51D12B8221)                                                         |        0.02 |      0.05 |       0    |         1 | 2022-03-04   |
|  752 | [&lt;statusquo@mailbox.org&gt;](w/relay/7D4389DC3BA69BECAB418D11E5E6B999014A70F7)                                                                 |        0.02 |      0.05 |       0    |         1 | 2024-05-03   |
|  753 | [scofflaw@mailfence.com](w/relay/77D85A7CE40DA25AEDB73AA2D8762C547BE287F2)                                                                        |        0.02 |      0.05 |       0    |         1 | 2024-11-05   |
|  754 | [O n i on Ra s pb e rry Sou p@prot o n ma](w/relay/3CEA56B817455E13C4B063E7D3E7726C286F7C9B)                                                      |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  755 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/0C741818F254073AF5A3D9F6F31D2A69CEC610EF)                                             |        0.02 |      0    |       0.04 |         1 | 2023-08-07   |
|  756 | [none](w/relay/14BE32AAACB9E7F0BCAFADC15986D787B1325BB6)                                                                                          |        0.02 |      0    |       0.04 |         1 | 2022-11-03   |
|  757 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/25D7CC3FA3599230CB985F2B6DEAE4D72526CE15)                                             |        0.02 |      0    |       0.04 |         1 | 2023-08-02   |
|  758 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/3158BE2413AC6A8F0BC3EC343BB056F6D24F2E53)                                             |        0.02 |      0    |       0.04 |         1 | 2023-08-02   |
|  759 | [40508842](w/relay/405088427ADA54F81B245FB6E6AF237521F5D3E7)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2023-03-29   |
|  760 | [4EE694A4](w/relay/4EE694A4556BFA6CDF220CD4C820B6C60E806160)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-11-20   |
|  761 | [54476788](w/relay/54476788A1AA7C348F20390DFC52ACA1352F4C57)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2022-11-19   |
|  762 | [PostGuard@gentlemansclub.de](w/relay/615D541946672D02F31995A48A89A526C7EC3524)                                                                   |        0.02 |      0    |       0.04 |         1 | 2021-05-08   |
|  763 | [nm1zujww at duck.com](w/relay/69811E0A90529A196ED44C10F3820E21807AD8D0)                                                                          |        0.02 |      0    |       0    |         1 | 2024-01-22   |
|  764 | [caldetas &lt;tor AT caldetas dot com&gt;](w/relay/B95F76EB1428A26901415FA46152B9536E764C8D)                                                      |        0.02 |      0    |       0    |         1 | 2024-02-22   |
|  765 | [tor AT ravidwivedi dot in](w/relay/772D509772071D3082BAAF1C781C8F917013F3CB)                                                                     |        0.02 |      0    |       0.04 |         1 | 2022-01-03   |
|  766 | [80D36C43](w/relay/80D36C43CC9226D106B99011DE4AD154447E15E6)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2025-01-12   |
|  767 | [None](w/relay/CFE72C8AFD1838F93D9F0E4A2D58FD87787C816F)                                                                                          |        0.02 |      0    |       0.04 |         1 | 2024-10-16   |
|  768 | [DC0B2CF7](w/relay/DC0B2CF7EFBE640DF3D1615EB8FE50E82FB53B45)                                                                                      |        0.02 |      0    |       0.04 |         1 | 2024-11-01   |
|  769 | [&lt;1ea7deadbeef AT posteo dot net&gt;](w/relay/F475E5987E44A2B7B143A2BEE3F8128EEFD7E5A3)                                                        |        0.02 |      0    |       0.04 |         1 | 2019-02-18   |
|  770 | [F1060E9E](w/relay/F1060E9E4386EF2497AF8A38AAB4DFEB026D4621)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-13   |
|  771 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/FA979DCF3A132D3AC796BDFA0C3B64EF76269CCB)                                             |        0.02 |      0    |       0.04 |         1 | 2023-08-08   |
|  772 | [Digineo GmbH &lt;tor AT digineo dot de&gt;](w/relay/B49649340BAABF74E9CA5D5014E45155382E0A13)                                                    |        0.02 |      0.05 |       0    |         1 | 2024-05-23   |
|  773 | [kol3v14@protonmail.com](w/relay/228931BDF59854D7EDD98C58B38D27A1678BE75E)                                                                        |        0.02 |      0    |       0.03 |         1 | 2024-02-10   |
|  774 | [327EEC1C](w/relay/327EEC1C3496BED6056DE756A3FD5AC4A69F84D9)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-11-18   |
|  775 | [7E1A01BA167E8023A6B68BE8A05D811694AE4D8E Felix Aur](w/relay/35F5A0B2F017FD09F7EBF33A565A53D8EB2C9272)                                            |        0.02 |      0    |       0.03 |         1 | 2022-01-03   |
|  776 | [PrivateCitizen &lt;pr1vat3citizen AT proton dot me&gt;](w/relay/42CE7A41076A8DF29C5306E431CDF5715850E7CC)                                        |        0.02 |      0    |       0    |         1 | 2023-05-06   |
|  777 | [Tor-Admins &lt;toooor AT all DOT de&gt;](w/relay/3E90247F6488DEA0554D2084F15897830FFE668F)                                                       |        0.02 |      0    |       0.03 |         1 | 2024-02-22   |
|  778 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/403A004838B6477887B8CE7E51393CF0DC34EC2E)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  779 | [5B62E424](w/relay/5B62E4243211E74432D3E38E5A74C373DAEA2C34)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-01-22   |
|  780 | [5AC2115B](w/relay/5AC2115B2C6E5A2382484EAEE5D9C7E9C229807A)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-10-27   |
|  781 | [6B7CEA7C](w/relay/6B7CEA7C2097CAB85E250634053ABD3754481446)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-01-22   |
|  782 | [YW1hdGV1cmRvZWRlbCBhdCBnbWFpbCBkb3QgY29tCg==](w/relay/83A83106CF70808C479B73D9141B03B7042F4605)                                                  |        0.02 |      0    |       0    |         1 | 2024-09-19   |
|  783 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/A944DB7EC17BCD578E696D75C72D04757B2A6D02)                                             |        0.02 |      0    |       0    |         1 | 2023-08-02   |
|  784 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/ABBD3528CFC27E15AF4C18F19BC08BBCA16DEAB5)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  785 | [raphael@gonku.de](w/relay/ADEDEE0DF9BBDF1C6373A24FB47C66C7430912AB)                                                                              |        0.02 |      0    |       0.03 |         1 | 2024-09-19   |
|  786 | [None](w/relay/AFDD93E5CB45BC671590F5B9E2136890C8012A5A)                                                                                          |        0.02 |      0    |       0    |         1 | 2022-10-30   |
|  787 | [CCACC399](w/relay/CCACC39911230FC95A00A859CBC3E94AD54B52A4)                                                                                      |        0.02 |      0    |       0    |         1 | 2022-11-09   |
|  788 | [tor-operator@maxwellfarrior.tech](w/relay/D53B7EFD1D481EB2550D03CF822B7E17D058261F)                                                              |        0.02 |      0    |       0.03 |         1 | 2024-04-13   |
|  789 | [tor@rkn.life](w/relay/F4A4D78F16E9A0353AD5BBEF4632C7022E20FB20)                                                                                  |        0.02 |      0    |       0.03 |         1 | 2019-02-18   |
|  790 | [relay at vonderste dot in](w/family/4058b43dd6074005ef8ef66fd0b5a1e49b31fcc462c4514c3935b9fedf8ee22b)                                            |        0.02 |      0    |       0.03 |         2 | 2024-08-28   |
|  791 | [mikael datanerd.se](w/relay/7AFFC971486FEADE7583170A616EA97DECA11190)                                                                            |        0.02 |      0.05 |       0    |         1 | 2024-10-19   |
|  792 | [008269B0](w/relay/008269B0D282617EBE0BB995461C78D77B7525F6)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-11-23   |
|  793 | [relay@bgrshell.eu](w/relay/01E388EF92B569074D8FA86CC9D442E829F6E885)                                                                             |        0.02 |      0    |       0.03 |         1 | 2024-11-23   |
|  794 | [none](w/relay/08650593B6FC2CF72B9655541F0A0503729CA1E9)                                                                                          |        0.02 |      0    |       0    |         1 | 2023-09-04   |
|  795 | [torrelay.IllidanStormrage@proton.me](w/relay/124B3FF6C0E0C619FFEDDE8ECF226FE9A9BA3B1E)                                                           |        0.02 |      0    |       0.03 |         1 | 2025-01-11   |
|  796 | [2144EC31](w/relay/2144EC311E714F30648F2B62546E2CA28FDBD36B)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-01-21   |
|  797 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/2EB3EC47737C98ABC24D274AFD5C9AD39DB75D7E)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  798 | [Thomas Steen Rasmussen / Tykling &lt;thomas@gibfest.d](w/relay/38CC95A8CE92A591D4A5779359BEFFBA13FA1B88)                                         |        0.02 |      0    |       0    |         1 | 2019-02-18   |
|  799 | [47D55C9B](w/relay/47D55C9BD170C948961EF1B6C5D1AEB4CF8F7D06)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-12-08   |
|  800 | [81FA8CD8](w/relay/81FA8CD8D863067C09C47E48EBC01B51CC69C4B4)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-04   |
|  801 | [Random Person nobody@tor.org](w/relay/8FDAFC439E2D09659A3EC0D723B9C3761EE5596D)                                                                  |        0.02 |      0    |       0.03 |         1 | 2024-02-15   |
|  802 | [A0026D48](w/relay/A0026D48DABBA1E8B0B644D92EC7098B41FCDF18)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-11-15   |
|  803 | [Tor Admin &lt;sysadmin AT waltoninstitute dot ie&gt;](w/relay/AF6BFD101C0DB57576C767E48A7CFDD75090672A)                                          |        0.02 |      0    |       0.03 |         1 | 2024-04-13   |
|  804 | [Random Person nobody@tor.org](w/relay/BBA4AC0A7CC698E97926AF69CE9A58AC26523CF9)                                                                  |        0.02 |      0    |       0.03 |         1 | 2024-02-15   |
|  805 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/BD7899597E826C9154F0C35264B5AD17E0B3B7E7)                                             |        0.02 |      0    |       0    |         1 | 2024-01-31   |
|  806 | [C270F5E0](w/relay/C270F5E09A05E528E1AF13257754A3460130CDA0)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-10-22   |
|  807 | [EA9E042A](w/relay/EA9E042A05E851076A657639CD0C84D8DA86A76F)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-01-21   |
|  808 | [F7D5CD0A](w/relay/F7D5CD0A533444BFCBE66E1640D563CF9DD58A1A)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-10-22   |
|  809 | [mewtwowho at proton.me](w/family/21c6a68720f51e00c522b330de6f697546773762d02a3a2ce8adf65e15985dde)                                               |        0.02 |      0.06 |       0    |         2 | 2024-12-30   |
|  810 | [name is Blaze --- blazeready@Mail.com](w/family/947a6df30c23c6b66753dae9d0af9deb7359ad72e98709fb339ad9e5447fb6ba)                                |        0.02 |      0.05 |       0    |         2 | 2024-01-21   |
|  811 | [billy819@mail.com](w/relay/0F938542D1C783D3DC0CB78CA53877290D9FB211)                                                                             |        0.02 |      0.06 |       0    |         1 | 2022-10-21   |
|  812 | [&lt;tor AT busybear DOT se&gt;](w/relay/7BE9E2EF2BB41BB662D9A3CD68289B9E3DBF8A08)                                                                |        0.02 |      0.05 |       0    |         1 | 2019-02-18   |
|  813 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/0CE59DBA1A9A747A428C711892AC093BBA34C38E)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-07   |
|  814 | [2659ACAA](w/relay/2659ACAA140B6845E38F189B4080817B9819EB9A)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2019-02-18   |
|  815 | [28655D30](w/relay/28655D3058B0BAE840B0DB48DC078C1F773D1291)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-01-22   |
|  816 | [LS &lt;rarity discard300 at simplelogin dot com&gt;](w/family/c373bd870ce7d2b6c3f76c1c4d54ea705d08147c288a04c2e79e08a3b5238b40)                  |        0.02 |      0    |       0.03 |         2 | 2024-10-13   |
|  817 | [54F5431B](w/relay/54F5431B6FB0AE5DF5BDF62C2F823915EBC1DAB9)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-11-19   |
|  818 | [sebastianboegl.de](w/relay/58ED9C9C35E433EE58764D62892B4FFD518A3CD0)                                                                             |        0.02 |      0    |       0.03 |         1 | 2019-02-18   |
|  819 | [5F41E480](w/relay/5F41E480383BC357A74228DA4CC580002841B50D)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-25   |
|  820 | [incognitorelay@proton.me](w/relay/995F99C63FCDE873B34CA1D6D97FF064BD8987A9)                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-01-21   |
|  821 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/A9D620A341A7AE2F6118D1C711AC2518C2CA8A99)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  822 | [0xDAC4CCB6722FF7E5 Alexander Bhm &lt;alexander.boehm](w/relay/C07DCA0B231BE0554AB4D574AC057C7572BD6EF0)                                          |        0.02 |      0    |       0.03 |         1 | 2022-07-02   |
|  823 | [relay@nici.gay](w/relay/BE05C5913FB4E70DCAFCB71E83FD926739E3B7FA)                                                                                |        0.02 |      0    |       0.03 |         1 | 2024-08-18   |
|  824 | [D8187484](w/relay/D818748485D5F6EFD560615A98FD04D70B4C75D5)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-01-22   |
|  825 | [D83E421D](w/relay/D83E421D70BCF946391D87230B3602F2BCF98F74)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-11   |
|  826 | [&lt;roger fillipo&gt; rodger.fillipo@mail.com](w/relay/D8A2D0080B0C73E1DC0EC9F33B497F64E5FB3F52)                                                 |        0.02 |      0    |       0.03 |         1 | 2019-02-18   |
|  827 | [tor@etwas42.de](w/relay/F5FA4A58DAA2339985D96CF55BC8B23207709FA3)                                                                                |        0.02 |      0    |       0    |         1 | 2025-01-16   |
|  828 | [EC16F2B1](w/relay/EC16F2B1D13F65836FD2B7856995828D18F32CC0)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2022-02-22   |
|  829 | [F2899981](w/relay/F2899981E3A601A7B2DDC7DDE02C248069704D9F)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2019-11-25   |
|  830 | [solitude at montanti dot us](w/family/4aef7901b55152e33447804d2a85b6f5db2e36d0c60ba660e70275bc5ee39321)                                          |        0.02 |      0    |       0    |         8 | 2022-05-03   |
|  831 | [darreng@posteo.net](w/relay/2483EFC5532F81C08CA48B15FA7F9AFAB3D2B041)                                                                            |        0.02 |      0.06 |       0    |         1 | 2024-09-01   |
|  832 | [WSSH - &lt;wssh at gmx dot com&gt;](w/relay/98CDDAF76419C5DBCBCF512D87E3F99BA5F22770)                                                            |        0.02 |      0.06 |       0    |         1 | 2021-12-04   |
|  833 | [hole1@gmx.com](w/relay/D47EE2158B8410670208016497C0BB27AA704630)                                                                                 |        0.02 |      0.06 |       0    |         1 | 2024-01-22   |
|  834 | [a-n-o-n-y-m-e.net](w/relay/C54BBA45D25E64037CAA107C3699F327D9934A67)                                                                             |        0.02 |      0.05 |       0    |         1 | 2024-05-07   |
|  835 | [0xFFFFFFFF Random Person &lt;nobody AT example dot co](w/relay/06E72526BBE040C51C5ADFBAA07ADD9AEB5E1FA1)                                         |        0.02 |      0    |       0.03 |         1 | 2016-02-03   |
|  836 | [0x31384448 Ole Rydahl Had a cat named Dobbo &lt;ole](w/relay/06353ACB9E2AC4D61F53DF152B6C0B5E946CA8AB)                                           |        0.02 |      0    |       0.03 |         1 | 2024-03-27   |
|  837 | [Xavier Bettel](w/relay/3BBF9D98C7D058D7C2E60F6BA5BD574CB4F3FE26)                                                                                 |        0.02 |      0    |       0.03 |         1 | 2019-02-18   |
|  838 | [1806.one &lt;1806 AT firemail dot cc&gt;](w/relay/090975875D1BBE53F6FF2ADCA8BA41C97DBB3E59)                                                      |        0.02 |      0    |       0.03 |         1 | 2022-06-15   |
|  839 | [tor.yhkki@slmail.me](w/family/d5cbd1cf546a8e0766b599e0c85eab9e734f7d659b039fa13a85efbd78765f50)                                                  |        0.02 |      0    |       0.03 |         2 | 2022-03-04   |
|  840 | [pKD9jZ19N1LiTvsjOF3 at ttutanota com](w/relay/37DDF1906EE3DB96130A717EA54667C64DAC78DF)                                                          |        0.02 |      0    |       0.03 |         1 | 2019-03-30   |
|  841 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/46B716F602EB0AF7BD5BC1CED5A9737FD8D46BF9)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  842 | [mail: torrelay &lt;at&gt; maciej.cloud](w/relay/3DA05FF92861FB0A0901C65E1C041C72C0D1CAE3)                                                        |        0.02 |      0    |       0.03 |         1 | 2023-04-06   |
|  843 | [5B6DAB15](w/relay/5B6DAB1516F3312E7F3E8DACFAABC732A5DF67CC)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2022-08-21   |
|  844 | [7A2A00CF](w/relay/7A2A00CF527CFA8B4493609CD9DB2E6480CF3443)                                                                                      |        0.02 |      0    |       0    |         1 | 2024-12-25   |
|  845 | [elude acid850@simplelogin.com](w/relay/9F7EBBD54748452E7FC926977B75F2462FA69BDD)                                                                 |        0.02 |      0    |       0.03 |         1 | 2024-10-22   |
|  846 | [83832@tec.link38.eu](w/relay/B41645F0A6EFB5416F35CFE022C7AD45FD374D35)                                                                           |        0.02 |      0    |       0.03 |         1 | 2022-06-12   |
|  847 | [4096R/1EE96C8A375D94EC46E1F93F12CD89085C726CB4 Jan](w/family/a7d768eebe382a6922ffad83f5375f6ff01836f8b07686155a63f8ea32abc3ea)                   |        0.02 |      0    |       0.03 |         2 | 2019-02-18   |
|  848 | [Patrich Stanley Nerdalert78@privatemail.com](w/relay/E1DA0F90454AED535ACE9B415F78C1A1359E29A1)                                                   |        0.02 |      0    |       0.03 |         1 | 2024-05-31   |
|  849 | [your@e-mail](w/relay/ECD0ED07D56146BE8782450E919AEAC63A76DBC2)                                                                                   |        0.02 |      0    |       0    |         1 | 2024-09-26   |
|  850 | [F11F59BB](w/relay/F11F59BB31E4624AFFC7D2AC55D4CD4D91FF9658)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-11-19   |
|  851 | [Resistance Change Freedom](w/family/1ce19397b939014bc9e4e622565f1f42b1e45413f84f143ddb4199ecd9ff2e75)                                            |        0.02 |      0.04 |       0    |         4 | 2019-02-18   |
|  852 | [noc@as210630.net](w/family/ae873d10502be5fc88dbe7f89e590ff9a8f66b8263fbb6c5d71c3e0ad9cab8be)                                                     |        0.02 |      0.05 |       0    |         3 | 2025-01-10   |
|  853 | [7B06C796](w/family/86684d643f042b43d901933a6dc9455e38948cc47943c634ad8e647e3c9ae64f)                                                             |        0.02 |      0    |       0.03 |         3 | 2024-03-12   |
|  854 | [0xE12ECD2E Nicola Ferralis &lt;feranick AT hotmail do](w/family/6ddee272a699a684bbe2efe5d5e036d84123eb50c13ca1c5b0a1858800107879)                |        0.02 |      0    |       0.02 |         3 | 2019-02-18   |
|  855 | [MarkN.Hebb@gmail.com](w/family/9510119674064ecf6c8e6cf0d8889e7fcb12382b99e2fcbac381ae3c1cc95921)                                                 |        0.02 |      0    |       0.03 |         2 | 2019-02-18   |
|  856 | [torproject at telekobold dot de](w/family/f8e11a86d4d0214dfce95697767fc1185d52928c330499bb5286e6ad45ae5491)                                      |        0.02 |      0    |       0    |         2 | 2022-11-19   |
|  857 | [Dev Null &lt;root@dev.null&gt;](w/relay/1F9F37C4EBD9E450AD61E745D49CEC05030D52BC)                                                                |        0.02 |      0.06 |       0    |         1 | 2024-09-30   |
|  858 | [torcornholio at gmail.com](w/relay/45F4FE80352C1B30AAFA8FF8F5E5715F1A98F3AC)                                                                     |        0.02 |      0.06 |       0    |         1 | 2023-07-07   |
|  859 | [peoplesliberation@proton.me](w/relay/14AE2154A26F1D42C3C3BEDC10D05FDD9F8545BB)                                                                   |        0.02 |      0.05 |       0    |         1 | 2023-07-06   |
|  860 | [David Kabo &lt;mytorrealy@proton.me&gt;](w/relay/26F5D0F28B756CDB8FEF0081C8F0A26FCEB5F943)                                                       |        0.02 |      0.05 |       0    |         1 | 2025-01-16   |
|  861 | [NoxDaFox nox32 at hotmail dot com](w/relay/3BA2A8C1BE4FD6CCEBBCE4689B66372A0519E0C8)                                                             |        0.02 |      0    |       0.03 |         1 | 2021-02-17   |
|  862 | [relay@enitg.no](w/relay/2800AA717730344F5D6BA282B27CCE64E90F1D13)                                                                                |        0.02 |      0    |       0.03 |         1 | 2024-09-18   |
|  863 | [63B53D61](w/relay/63B53D6186A18BA34B5749C193E92ADFB9395035)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2023-05-28   |
|  864 | [5D15E37B](w/relay/5D15E37B9CE27E3A7A15B93AA1670FCB27D4C0AB)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2022-06-12   |
|  865 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/67DFE854D957701C87F6852B853AF83EE8E0AE34)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  866 | [7DBD27A6](w/relay/7DBD27A6D352722BD3C44FA18202428A33FDD9D0)                                                                                      |        0.02 |      0    |       0.03 |         1 | 2024-02-16   |
|  867 | [tor@pathos-ii.ddnss.de](w/relay/6E7AA0C558D8814B1919F919D56245FA3D367EA0)                                                                        |        0.02 |      0    |       0    |         1 | 2024-02-20   |
|  868 | [Tor &lt;tor AT hasselba dot ch&gt;](w/family/9ef4409b1036ceacf608b269c0c2049c1f60c104e520ba0856ba7d38f5d041f4)                                   |        0.02 |      0    |       0.03 |         2 | 2024-09-04   |
|  869 | [59FDAC19FBC4E692652F3EB0C7B7552BDF21283B Smith &lt;qt](w/relay/767E444E1FA1DA75F3B77479DB5AE2FA3FFF75CC)                                         |        0.02 |      0    |       0.03 |         1 | 2019-02-18   |
|  870 | [umnacquitypowa@proton.me](w/relay/9301CDCBCE6E606FC2A571AC822D095364EE4A52)                                                                      |        0.02 |      0    |       0    |         1 | 2024-02-06   |
|  871 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/83721D5AE526BBF18C19C969B166EB5A559E36A2)                                             |        0.02 |      0    |       0    |         1 | 2023-08-02   |
|  872 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/95D150A7C45BCE9675843E2971209C5663834847)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  873 | [stu-junk at outlook com](w/relay/9837112DA1503CCAA3980CF49D9FAD6F4DEA4096)                                                                       |        0.02 |      0    |       0    |         1 | 2024-09-02   |
|  874 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/B0543A3DF8D402F53998E03CFE1B35845DB27D9D)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  875 | [tor at alo dot is tor-relay.co](w/relay/B13C2C569F3FD0C530B7D96E5FF7933DF7A0E834)                                                                |        0.02 |      0    |       0.03 |         1 | 2019-12-25   |
|  876 | [mandalorian.outpost.222@yandex DOT com](w/relay/DAC825BBF05D678ABDEA1C3086E8D99CF0BBF112)                                                        |        0.02 |      0    |       0.03 |         1 | 2024-01-29   |
|  877 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/B7DAA55B216C9405C6BFCBBC185371C27BD3AD59)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  878 | [Jugger Relay jugger-relay@protonmail.com](w/relay/D1C60F9BCF2DBA07A775978F66C9927D3A9490BB)                                                      |        0.02 |      0    |       0.03 |         1 | 2020-01-04   |
|  879 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/D855DE28F6524DD0D326027D35531F922E315B0F)                                             |        0.02 |      0    |       0.03 |         1 | 2023-08-02   |
|  880 | [5h098y32 at duck.com](w/relay/E5A935F6A91F39FE184DF2D143869894897E05B7)                                                                          |        0.02 |      0    |       0.03 |         1 | 2023-06-21   |
|  881 | [LongLiveTheOnion &lt;longlivetheonion /AT mailbox /do](w/relay/FCA08FA15437EDB22D37B114E21F04F97E231DCE)                                         |        0.02 |      0    |       0.03 |         1 | 2024-10-27   |
|  882 | [vmo7nzzu at anonaddy dot me](w/family/0e2f77a32377b2f0067679e908caacf5629eafa641ced11548db47cd71ee4f72)                                          |        0.02 |      0    |       0.03 |         7 | 2022-11-09   |
|  883 | [tor@dst.ca](w/family/2c887eb8eb33ad3b044075689e3e767b1b26a28665ae7de7d20e4e0ee7602894)                                                           |        0.01 |      0    |       0.03 |         4 | 2019-02-18   |
|  884 | [Svea Hosting &lt;info@svea.net&gt;](w/relay/10B689D11CDCB8EB74BF394880508C975058C608)                                                            |        0.01 |      0.04 |       0    |         1 | 2020-07-28   |
|  885 | [50E23506](w/relay/50E23506E5DC8576EB4E8F60751644364A3E13CE)                                                                                      |        0.01 |      0.04 |       0    |         1 | 2021-09-25   |
|  886 | [judas priest doamin here](w/relay/7F0541B21603F5D4A17A75C5326CEBC37E8E9D74)                                                                      |        0.01 |      0.04 |       0    |         1 | 2024-09-01   |
|  887 | [mikael datanerd.se](w/relay/B5410AF840A3DA3DCDA1EEC093167311CEB432EF)                                                                            |        0.01 |      0.04 |       0    |         1 | 2024-12-07   |
|  888 | [admin@tmtime.dev](w/relay/07978C40962990BC40D57A664393E7B7429942DE)                                                                              |        0.01 |      0    |       0    |         1 | 2025-01-05   |
|  889 | [12D5CABC](w/relay/12D5CABC9A021D94D5869A2692B3CD173DB97263)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2023-01-26   |
|  890 | [1A9B7E5F](w/relay/1A9B7E5FC08FFD349E73EF8FDF9098D71D5C5B62)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-12-17   |
|  891 | [random zandoli &lt;zandoli@riseup.net&gt;](w/relay/219671E56FE6D40F8E355E272FCD05EE23C00AC8)                                                     |        0.01 |      0    |       0.03 |         1 | 2024-01-21   |
|  892 | [ralph.ratz@recons.de](w/relay/2F051BD0124C65C8E617DC8B7EE508D0AF11AFC9)                                                                          |        0.01 |      0    |       0.03 |         1 | 2024-05-03   |
|  893 | [307DF18E](w/relay/307DF18E52874C08881D2A5238DA0CC02BF761CA)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-08-19   |
|  894 | [Andsec Team &lt;security AT andsec dot ch&gt;](w/relay/5282981DFCF46D5A1CBE40FDF3DDF9968E29A320)                                                 |        0.01 |      0    |       0.03 |         1 | 2024-10-27   |
|  895 | [dev.null@kryptonit.org](w/relay/68835C57C58F39A9DD22D9444BFE925FBBDC8195)                                                                        |        0.01 |      0    |       0.03 |         1 | 2024-09-29   |
|  896 | [706F54AC](w/relay/706F54AC939A65DBE31D01E2682BF2145E38A269)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-01-22   |
|  897 | [74574575](w/relay/74574575E4C839AEF11AF6A944A855D425FB5280)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2022-10-10   |
|  898 | [8470EAB3](w/relay/8470EAB36524CA781989E15F04CA6B8F52326554)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-01-22   |
|  899 | [abuse-from-tor@polo-uniar.it](w/relay/8BB55A3AFBB7E5D9EB83215DEC8F219E68DF9B6D)                                                                  |        0.01 |      0    |       0.03 |         1 | 2022-04-03   |
|  900 | [voqelfrei &lt;tor voqel AT pm me&gt; pgp:8018FA5B9E760EF](w/relay/8EA364B3BE31A4D365BE535C5C1B80C3664EFA3A)                                      |        0.01 |      0    |       0.03 |         1 | 2024-04-02   |
|  901 | [Random Person nobody@tor.org](w/relay/8FD386BF70C5EBA82804A3FD2438BC07B45D0714)                                                                  |        0.01 |      0    |       0.03 |         1 | 2024-02-15   |
|  902 | [A233051F](w/relay/A233051F685BAC0A1EDF9F7BADFC13C639EA8E17)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-03-25   |
|  903 | [dev.null@kryptonit.org](w/relay/A5CD2AD2A3091BCA98B347077127959E6ADB8155)                                                                        |        0.01 |      0    |       0.03 |         1 | 2024-09-29   |
|  904 | [admin@cynosure.red](w/relay/A6B53A7E077D4708C8CF8703CA21257D62414AD9)                                                                            |        0.01 |      0    |       0.03 |         1 | 2024-10-24   |
|  905 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/E13B9BD1B368E72C896041136CC2C3986B05C026)                                             |        0.01 |      0    |       0.03 |         1 | 2023-08-02   |
|  906 | [dev.null@kryptonit.org](w/relay/D811B00286CC34E3AEEB1CD8D588681455C2325C)                                                                        |        0.01 |      0    |       0.03 |         1 | 2024-09-29   |
|  907 | [thegoonfather@duck.com](w/relay/E10448CAABC270543AB6A10FF13C18C85D9B90C8)                                                                        |        0.01 |      0    |       0    |         1 | 2024-05-29   |
|  908 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/ECE6033BCA05BC3A593AF9DF2C5CC12D88C7E14A)                                             |        0.01 |      0    |       0.03 |         1 | 2023-08-02   |
|  909 | [ED861855](w/relay/ED861855C655E373547D4C4E86A35C5A313FA497)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-08-20   |
|  910 | [w3da5mxwr@relay.firefox.com](w/family/d15de2f4c1be1def9c072f898477588a3a9122f524c970cdac88d36d4f68b10b)                                          |        0.01 |      0    |       0.03 |         3 | 2023-02-07   |
|  911 | [CanisAlpha aa tt PROTON MAIL o COM](w/family/1165dfeece1d389f678cc4d061aa1ed8ecfa6a0a88ab1cf3bd862ae210dfa912)                                   |        0.01 |      0    |       0.03 |         3 | 2022-03-24   |
|  912 | [Vulnix &lt;tor-contact AT vulnix dot net&gt;](w/relay/F319E2C484E2DE9001E6485F25064562D7EA8C6A)                                                  |        0.01 |      0.04 |       0    |         1 | 2025-01-05   |
|  913 | [0BB33B60](w/relay/0BB33B60FAED4D8094E73243849BCAF2F2313177)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2025-01-06   |
|  914 | [Scott Maxwell tor-contact-2024-netcup-medium-arm](w/relay/1BB90EC57A20D2CC36ACFA8E2E729A7772F39DEF)                                              |        0.01 |      0    |       0.03 |         1 | 2024-04-05   |
|  915 | [298EC333](w/relay/298EC3331E104E9E84313B10B2DF0746594EED47)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-01-22   |
|  916 | [nicoleiocana.com](w/relay/21C9D9F1633246269DEB84A79495E85C07E8466D)                                                                              |        0.01 |      0    |       0.03 |         1 | 2020-09-20   |
|  917 | [2BDC19C9](w/relay/2BDC19C98DB0DE0E8B97D339AB6E3D9E3CC7B36D)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-19   |
|  918 | [liara.rviin@slmail.me](w/relay/24F465980178B37DC2D5F908713B7FA4B4E43BAA)                                                                         |        0.01 |      0    |       0.03 |         1 | 2024-11-16   |
|  919 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/33382F0CDA84B56BCB2D337B3781450FED849FED)                                             |        0.01 |      0    |       0.03 |         1 | 2023-08-02   |
|  920 | [5746FE4B](w/relay/5746FE4B8D868FE07816DB846DFFBCCEF235AD16)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-01-22   |
|  921 | [denis@serverleih.de](w/relay/5E5D44A8CF9AB5E4C3B10822D42FF10B3CDE0497)                                                                           |        0.01 |      0    |       0    |         1 | 2022-12-19   |
|  922 | [61050750](w/relay/61050750B002143D23CA5D586105408E08C15236)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-12-16   |
|  923 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/C6AABFDBC60356D8AAF268E44C2978117924A887)                                             |        0.01 |      0    |       0.03 |         1 | 2023-08-02   |
|  924 | [66EEF68A](w/relay/66EEF68A3307E63D59CE34969A710F1FA697DE83)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-10-11   |
|  925 | [admin &lt;raging relay@protonmail.com&gt;](w/relay/7451225CBA6B689530738AF26E5B9CA2B051827E)                                                     |        0.01 |      0    |       0    |         1 | 2024-02-01   |
|  926 | [83AF86A9](w/relay/83AF86A91559D6BD097661D4A459BBDA5248A2F2)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-11-05   |
|  927 | [8B09 DE4C E20B AD74 EF9A 11C4 F668 C57D 79DC 827E](w/relay/91BAB54C6923454F4E5EDC59313C45002B238665)                                             |        0.01 |      0    |       0.03 |         1 | 2020-08-31   |
|  928 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/9EDE6EC99AE77678CD113BFFFC4303CD20A5111F)                                             |        0.01 |      0    |       0.03 |         1 | 2023-08-02   |
|  929 | [galois &quot;d a s h&quot; onion &quot;a t&quot; protonmail &quot;d o t&quot; co](w/relay/A170153BF63A9D2E2FBCA3FCD867286AC3B80CEA)              |        0.01 |      0    |       0.03 |         1 | 2021-08-06   |
|  930 | [0x5c3732f4942cffc4 Roland van Ipenburg &lt;ipenburg@x](w/relay/A480D8C9F9B1112E47C24E33DAC0419CAF1A821A)                                         |        0.01 |      0    |       0.03 |         1 | 2019-12-05   |
|  931 | [systemli &lt;t o r - e x i t .AT. s y s t e m l i DOT](w/relay/ACEA5C60E4D37D9770246E81C19DB1C3F3CD1A8F)                                         |        0.01 |      0    |       0.03 |         1 | 2023-07-27   |
|  932 | [I thought you GNU](w/relay/BE0ABF48A57031C9AFBC49B1F18D9B62B411E5E0)                                                                             |        0.01 |      0    |       0.03 |         1 | 2024-01-19   |
|  933 | [email:tormaster nerdreich.de btc:1Ma9whLg6U5HDBUP](w/relay/BE2B68B8B88BFC353302360D58ACF9BD9BA98024)                                             |        0.01 |      0    |       0    |         1 | 2021-12-14   |
|  934 | [C1F93754](w/relay/C1F9375437CAA5C5BF1AA4C8E78107BF61883FD5)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-01-21   |
|  935 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/C361B532AD3BBBCF020654151E5F23320D8F8812)                                             |        0.01 |      0    |       0.03 |         1 | 2023-08-02   |
|  936 | [5h098y32 at duck . com](w/relay/CD2A63AA540A39B2E3772C7B4E4EB2B82140E8B0)                                                                        |        0.01 |      0    |       0.03 |         1 | 2024-02-04   |
|  937 | [EB806B20](w/relay/EB806B20BA699736EE317165323FEEC655A480E6)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2022-09-20   |
|  938 | [tornode@emailfucker.club](w/relay/F022431FC705A7642AE25C8DEAB40109736A0EA6)                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-12-30   |
|  939 | [tor-operator at infosecproject dot org](w/relay/FA85D84F61DCC9E5FAAC177808226A2EDC32B89B)                                                        |        0.01 |      0    |       0.03 |         1 | 2024-03-24   |
|  940 | [none](w/family/16faf099921a0d55d301748d269f9dc1c9068108023f9d99e3e8e02924f1753e)                                                                 |        0.01 |      0.04 |       0    |         2 | 2024-02-01   |
|  941 | [contact@cypher.re](w/relay/010D853EA9DC7BEAA3BF9B1910D0AF6439C43CAC)                                                                             |        0.01 |      0.04 |       0    |         1 | 2024-11-17   |
|  942 | [a-n-o-n-y-m-e.net](w/relay/3B5B6351330FA96EF3527A1BBB3F389C2310E8E6)                                                                             |        0.01 |      0.04 |       0    |         1 | 2024-05-05   |
|  943 | [a-n-o-n-y-m-e.net](w/relay/90705D63956EDD5904D173F1998F421C5FC5B6FC)                                                                             |        0.01 |      0.04 |       0    |         1 | 2024-05-30   |
|  944 | [4096R/34650013 La Quadrature du Net &lt;tor@laquadrat](w/relay/D71B1CA1C9DC7E8CA64158E106AD770A21160FEE)                                         |        0.01 |      0.04 |       0    |         1 | 2019-02-18   |
|  945 | [YoyoYankee &lt;american AT protonmail dot com&gt;](w/relay/F745D5A34A289EF0C88544D0DC400B21120F5E81)                                             |        0.01 |      0.04 |       0    |         1 | 2024-07-21   |
|  946 | [dharma-initiative-tor-network e-mail-symbol proton](w/relay/013AD81926572519EBCB7048E78462B5E9F1319D)                                            |        0.01 |      0    |       0    |         1 | 2023-08-16   |
|  947 | [04DFE047](w/relay/04DFE047ACDF7A6620ACA782FAFC5EF1AE7F4754)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2019-04-17   |
|  948 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/0ABA99986CC96F80A273E3F08856137A72DEF31F)                                             |        0.01 |      0    |       0.03 |         1 | 2023-08-07   |
|  949 | [AntsySeptum@proton.me](w/relay/09505AFA25D17A3EC5D909CB66E8F1F786498422)                                                                         |        0.01 |      0    |       0.03 |         1 | 2024-11-05   |
|  950 | [235A96D6](w/relay/235A96D6C1489B504E4DCB35C21C9DCCA01E4758)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2021-07-07   |
|  951 | [&lt;tor-relay@ceskar.xyz&gt; s7xwcb5vpszox5a -----BEGIN](w/relay/53136799CC1E2DFE0F5D279D79DDE4F51EE9AF0C)                                       |        0.01 |      0    |       0.03 |         1 | 2023-03-11   |
|  952 | [53D47235](w/relay/53D4723566DE710BAB029840404466F3EDB24D49)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2025-01-06   |
|  953 | [tor822196@gmail.com](w/relay/5A13D8FD24A229360DE96328C756C69F5FC2AA37)                                                                           |        0.01 |      0    |       0.03 |         1 | 2024-02-06   |
|  954 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/60BC2D373119A9C0B5ED9EA81BD099AC5CC45795)                                             |        0.01 |      0    |       0    |         1 | 2024-03-04   |
|  955 | [6F4C45A1](w/relay/6F4C45A1D3EA0EA4B464DA37891460AEDA26ADDF)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-06-20   |
|  956 | [precambrien &lt;precambrien AT cestcool dot net&gt;](w/relay/8D5392A1FE568211EF62CCAF257DAE584AA5CDA5)                                           |        0.01 |      0    |       0.03 |         1 | 2022-06-02   |
|  957 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/881CC97BF7BA6B2A150931CEBD9F2A2DA5434D0A)                                             |        0.01 |      0    |       0.03 |         1 | 2023-08-02   |
|  958 | [m4j843@gmail.com](w/relay/C5EFF0D9868DFB917032293FC883F7679821D245)                                                                              |        0.01 |      0    |       0.03 |         1 | 2024-02-16   |
|  959 | [CD55FF8B](w/relay/CD55FF8B16A8011EF545A600761C4CA59DC170D8)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2024-03-09   |
|  960 | [CF9BEB3E](w/relay/CF9BEB3E3554C5C343024641A91CC9AE6B849882)                                                                                      |        0.01 |      0    |       0.03 |         1 | 2022-08-31   |
|  961 | [fulloffaith -SPAM-CUTTOFF- @gmx.com](w/relay/3E26373D9F491C3C11FAE484E2A705611D019C02)                                                           |        0.01 |      0.04 |       0    |         1 | 2024-01-22   |
|  962 | [favorite0ne @proton.me](w/relay/56E9E80B813A69AA6B72E4B464A7154142EC45F6)                                                                        |        0.01 |      0.04 |       0    |         1 | 2024-01-21   |
|  963 | [email:abuse-zuluu at protonmail dot com url:http:/](w/relay/C09DFF947C9ED5C479B371C3BCAE7FF7D573F98C)                                            |        0.01 |      0.04 |       0    |         1 | 2023-08-20   |
|  964 | [carbon1958@protonmail.com](w/family/a4a5a4cec52408dfe964717026d24a6b6a19c2c30a3eb60273d4e4711b726bd4)                                            |        0.01 |      0.02 |       0    |         2 | 2024-03-08   |
|  965 | [nomore4thelast@protonmail.com](w/relay/0499CE73E4A26B3C94A519EBEAA06ACF9D325BC5)                                                                 |        0.01 |      0    |       0.02 |         1 | 2024-10-21   |
|  966 | [abuse@srstubes.com](w/relay/0F4DE55998EB3A301ED7B8F66E6244493F63F727)                                                                            |        0.01 |      0    |       0.02 |         1 | 2025-01-13   |
|  967 | [214323BD](w/relay/214323BD34E15A3F6E8818E3ADC6F055E4C3A136)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-01-22   |
|  968 | [beat me marvinfreehudred@proton.me](w/relay/5F3981B8E05F5594740B4CC56E8C958403A42C76)                                                            |        0.01 |      0    |       0    |         1 | 2024-01-22   |
|  969 | [5F65CD87](w/relay/5F65CD878EB0ACDA81882C8105B374588383D63A)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-28   |
|  970 | [torstenrelay@protonmail.com](w/relay/873C5AC9DCFBA2C852EB1EF4DB08EAAB472DB31B)                                                                   |        0.01 |      0    |       0    |         1 | 2020-10-30   |
|  971 | [karsgoesbeepATlilbroDOTca](w/relay/9FFEE8F76A0067B3D7D21FE0F48AB0122AC80BA7)                                                                     |        0.01 |      0    |       0    |         1 | 2024-12-27   |
|  972 | [9E2A4B1A](w/relay/9E2A4B1AE7771002DB0CC9A0E7A067AC22E5A121)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2021-02-17   |
|  973 | [Amsterdam, NL &lt;everybodyswatching@netherlands.nl&gt;](w/relay/A6E4B97CA238DE7E8998D410FB6D2DED07B53509)                                       |        0.01 |      0    |       0.02 |         1 | 2023-01-28   |
|  974 | [AAA7DA4D](w/relay/AAA7DA4D258D055780F4EE496D1154238DF75E04)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-12-23   |
|  975 | [shadowlynx@example.com](w/relay/AE19F2B7D024EDA73084556467E28A32D4EEA98A)                                                                        |        0.01 |      0    |       0.02 |         1 | 2025-01-15   |
|  976 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/B1F1CDE96E9DC0AB68F833C0370F7F0F43E29F70)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
|  977 | [BF935943](w/relay/BF93594384A02DE7689C4FD821E2638DA2CD4792)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2022-05-23   |
|  978 | [dev.null@kryptonit.org](w/relay/DA79CD34C3B82190CCF063D98254A7A278D94915)                                                                        |        0.01 |      0    |       0.02 |         1 | 2024-10-17   |
|  979 | [bftorirelay@gmail.com](w/relay/C30D848B3D8F3E5F4F8A80E6DF69692FE0611D5E)                                                                         |        0.01 |      0    |       0.02 |         1 | 2024-01-22   |
|  980 | [tor at praseodyme dot net](w/relay/E3724FCBE37167609B29FFFC310141F337701467)                                                                     |        0.01 |      0    |       0.02 |         1 | 2021-01-18   |
|  981 | [5B2B8D57736C5CB2E561FB4613517D5C7BD72B14 Mattias C](w/relay/D10EA75DAC14FDD41612695036AA29631D279C06)                                            |        0.01 |      0    |       0    |         1 | 2024-02-02   |
|  982 | [FFD52CFC](w/relay/FFD52CFC177BC5164DF786409B1FF956085A3A42)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-05-17   |
|  983 | [nomore4thelast@protonmail.com](w/relay/F60D7573896AE71E11A0B764396D4E79EC36A7C5)                                                                 |        0.01 |      0    |       0.02 |         1 | 2024-10-21   |
|  984 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/ED12CB22CB33C1433CDCD4C5D77AA20E61F3AECE)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
|  985 | [vstyx@tuta.io](w/relay/EF3BC00F2A5BBC0198A9C29F337973AB85416292)                                                                                 |        0.01 |      0    |       0.02 |         1 | 2024-12-31   |
|  986 | [FB3838E0](w/relay/FB3838E0FEE218EE47B3D4F1F264AB9F0E12C9DB)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2025-01-15   |
|  987 | [CD8A6568](w/family/f8cb589037ae47b484da0303d715a15a143309c7fb413839757424d0fd16bfeb)                                                             |        0.01 |      0    |       0.02 |         2 | 2024-01-21   |
|  988 | [potlatch protonmail com](w/family/f4abf23e26d49a1628b4523d07c8ba70cafeb0afd21c0213d9d5d60213ed4de2)                                              |        0.01 |      0.02 |       0.01 |         5 | 2019-02-18   |
|  989 | [Dan &lt; xiaoqic at cs dot princeton dot edu &gt;](w/family/230b1dbf20821f89ae34989085e8b04f4da40586e1093f4e8ac927aa685c1fb0)                    |        0.01 |      0    |       0.02 |         9 | 2021-06-27   |
|  990 | [quetzalcoatl-relays.org](w/family/93395e779985d1f01b989ce655dd6ff615ceadf02bb0bb81006aaa9a167ed0d0)                                              |        0.01 |      0.04 |       0    |         8 | 2023-07-03   |
|  991 | [01900B2C](w/family/7268e84dd074df9d37c85a0bba99f048350ea3594942425bc829b538e1c54e90)                                                             |        0.01 |      0    |       0.02 |         4 | 2023-11-02   |
|  992 | [noc =at= schokomil.ch](w/family/e556776e550b89f47af1a1f9add7435c31de85b2da36065caddfd5c2fb65529e)                                                |        0.01 |      0    |       0.02 |         2 | 2019-02-18   |
|  993 | [B8CE7258](w/relay/B8CE72588C2314C6513BF4B3817856A4EB314F6D)                                                                                      |        0.01 |      0.04 |       0    |         1 | 2024-08-28   |
|  994 | [-nighrydr88-privatemail-com-](w/relay/6F278A2CFF7C5C90E7BCDC8A8B148E914C79C284)                                                                  |        0.01 |      0.04 |       0    |         1 | 2024-02-19   |
|  995 | [the dude ------------------@----------------------](w/relay/E1C5E4857CD8E918FA03B1E15F1076D0A235B075)                                            |        0.01 |      0.04 |       0    |         1 | 2024-02-16   |
|  996 | [Privacy Is @ Human Right Two](w/relay/D53C431C0C194310553C2C780B5733BF223B1078)                                                                  |        0.01 |      0.04 |       0    |         1 | 2025-01-06   |
|  997 | [00FF9083](w/relay/00FF9083A2736D7E13C2ED8F51A2365BDC1F5C0E)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-11-20   |
|  998 | [145C1A48](w/relay/145C1A48FA9D246080535BC24CA4BCCE9EFFBA5F)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-10   |
|  999 | [&lt;tor-relay@ceskar.xyz&gt; s7xwcb5vpszox5a -----BEGIN](w/relay/2D69E1B3FE267639A237E37A847BD0A5A67972F9)                                       |        0.01 |      0    |       0.02 |         1 | 2024-11-30   |
| 1000 | [Heliodex &lt;heli@odex.cf&gt;](w/relay/3F97583420BD8443DD63A425B107F54C65E3CE0D)                                                                 |        0.01 |      0    |       0    |         1 | 2024-01-21   |
| 1001 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/52FB884DC2B0825EA9D162365BEEFB6D916648EE)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
| 1002 | [cerca at swiss-enigma dot ch](w/relay/530BC13FE24D7C4849E16D459631B5A6538DEB11)                                                                  |        0.01 |      0    |       0.02 |         1 | 2023-08-12   |
| 1003 | [torkowo@testowo.pl](w/relay/54A29E2BBE66F472813D9A937A103F37966205C7)                                                                            |        0.01 |      0    |       0.02 |         1 | 2024-04-06   |
| 1004 | [5B987FF9](w/relay/5B987FF9139F3A6FB433C4D079E15DA1FE9D6B85)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-08-25   |
| 1005 | [629301C0](w/relay/629301C063FC047171C8A0F1520A9D7CF60308EC)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-05-16   |
| 1006 | [idontcheckmyemailanyways](w/relay/724B0F6B4D12E3A0E5AEA0EB9FC1D2410C165001)                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-01-22   |
| 1007 | [d4b4ughv4@mozmail.com](w/relay/82128406F5CD1D5761BE1C86F6D30784483B46EA)                                                                         |        0.01 |      0    |       0    |         1 | 2025-01-16   |
| 1008 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/C30EB051B7838234794CCD3F309123AA0A1FC968)                                             |        0.01 |      0    |       0.02 |         1 | 2024-01-31   |
| 1009 | [Nobody pudzian-relay at protonmail.com](w/relay/C5E0FF684FA437B905F53AEE45749DAB1868D5D1)                                                        |        0.01 |      0    |       0.02 |         1 | 2022-02-02   |
| 1010 | [url:https://ricsi.priv.at proof:uri-rsa ciissversi](w/relay/FF86A59E35A2CF7F2744DA768DFBE90860868676)                                            |        0.01 |      0    |       0.02 |         1 | 2022-01-13   |
| 1011 | [FDA67317](w/relay/FDA673176CE83EEB3DD24414A5AD7B411D9165BC)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2022-09-20   |
| 1012 | [frei.raum Technikkollektiv &lt;roland.k AT disroot DO](w/family/6eb4e863c875c944fd902a6d0e3e9b8fc4d5e36f89de53804bf428182d574dbf)                |        0.01 |      0.04 |       0    |         2 | 2019-09-16   |
| 1013 | [&lt;gigi.marian.kent@gmail.com&gt;](w/family/db45d92aeda386138b18f2efdef9b1650cc3b692625c72e9969c4c79b88baae4)                                   |        0.01 |      0    |       0.02 |         2 | 2023-11-20   |
| 1014 | [nsa special projects directorate](w/family/0ecfcace5187c1ab460b9dcf8764119896c7ca113efb1c2a9bdd41f3d331926f)                                     |        0.01 |      0    |       0.02 |         5 | 2020-09-20   |
| 1015 | [quetzalcoatl-relays.org](w/family/27acefdf1fbded4b9aa8ba7f51dc2cb58c7f087f8e4224690664149886e9f0fb)                                              |        0.01 |      0.04 |       0    |         8 | 2023-06-03   |
| 1016 | [iraqizachy@privatemail.com](w/family/365243014e03b2fc5e505a6032813acc81a27f5900e39e91aba88d84df53ac8e)                                           |        0.01 |      0    |       0.02 |         3 | 2024-06-10   |
| 1017 | [relayfwy0Oo@gmail.com](w/relay/681EE8E76A96980BAC18EFE622E965FF709C30C0)                                                                         |        0.01 |      0.04 |       0    |         1 | 2024-12-13   |
| 1018 | [your friendly tor relay operator/ Ulie Dein / Comm](w/relay/5EF4629DB729712EF7FECBA74533BBF06704E00D)                                            |        0.01 |      0.03 |       0    |         1 | 2024-02-24   |
| 1019 | [fritohlays@fastmail.com](w/relay/7FE7D3A5B11CCA6D2BC37F83B5674CF28F4B2FAD)                                                                       |        0.01 |      0.03 |       0    |         1 | 2024-01-22   |
| 1020 | [987CFC56](w/relay/987CFC56FD7BE2B940B91D087C88F82386453663)                                                                                      |        0.01 |      0.03 |       0    |         1 | 2022-05-23   |
| 1021 | [NO SOLICITING ////// jimbo263 ///// @fastmail.com](w/relay/BFF8AE91EA09B2207432CA4C60E449F3516E7C3D)                                             |        0.01 |      0.03 |       0    |         1 | 2024-03-15   |
| 1022 | [C4ECFD56](w/relay/C4ECFD56A447F7F32907683873A28287EA3A1E06)                                                                                      |        0.01 |      0.03 |       0    |         1 | 2024-02-19   |
| 1023 | [The Yeti &lt;yeti AT shokk DOT de&gt;](w/relay/0D45D7CEFF9405A8FDC919F138BD9D7FCA1AB103)                                                         |        0.01 |      0    |       0.02 |         1 | 2024-12-07   |
| 1024 | [TengoKawana &lt;tengokawana AT protonmail dot com&gt;](w/relay/0DB28B5D5F467F00270750231D2C0F8129811599)                                         |        0.01 |      0    |       0    |         1 | 2023-07-02   |
| 1025 | [skirtsandcats@proton.me](w/relay/1A32F188D32DF01890A5EEF4F47243704E593BE6)                                                                       |        0.01 |      0    |       0.02 |         1 | 2024-06-25   |
| 1026 | [1B9534D7](w/relay/1B9534D70C954C139697EDD8C1DD42499657F816)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-14   |
| 1027 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/1F8C8467BD430D36B9538D8D62F74176A048FE20)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
| 1028 | [cpgs2v97c@mozmail.com](w/relay/37118A947888D3556F2D7CC8D2A53A354ADD459D)                                                                         |        0.01 |      0    |       0.02 |         1 | 2024-04-25   |
| 1029 | [not.a@real.email](w/relay/3F477C00E1E1635052EE496A5E337FA7212C6DB1)                                                                              |        0.01 |      0    |       0.02 |         1 | 2024-12-06   |
| 1030 | [405B635B](w/relay/405B635B7026B28DA52E0062F67470DA28AABC45)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-01-22   |
| 1031 | [tor@jednota.party](w/relay/5D31D09B6B92E2E960A6F654671A308772DDFD99)                                                                             |        0.01 |      0    |       0.02 |         1 | 2025-01-15   |
| 1032 | [5DC40F53](w/relay/5DC40F5357EDF4809A9010828172072C95A73514)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1033 | [donrichys@riseup.net](w/relay/627823120E3BFC03271EB3B2BC0AFF1627D14D95)                                                                          |        0.01 |      0    |       0.02 |         1 | 2023-05-06   |
| 1034 | [Damn these things are expensive &lt;3 tordel-network](w/relay/715590A1E1654B897C6EAC7699CC9A7CA9EF00AB)                                          |        0.01 |      0    |       0    |         1 | 2021-08-26   |
| 1035 | [72C480E8](w/relay/72C480E844BE33AAD027C5DB0D9CEE2AF67C574B)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-05-29   |
| 1036 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/9FAAA5937029C10F612809176DD62EA48917F70C)                                             |        0.01 |      0    |       0.02 |         1 | 2024-03-04   |
| 1037 | [TorRelay.TacticalAtom@gmail.com](w/relay/95A0105031078B387F03596EF6D9FB96B7C99221)                                                               |        0.01 |      0    |       0.02 |         1 | 2022-12-09   |
| 1038 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/A44A9974AAEAF814534C2F773D87093C733E417D)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-08   |
| 1039 | [AE4EB5F6](w/relay/AE4EB5F6F34B0E424AA024D102771D35F954D9F4)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-01-21   |
| 1040 | [&lt;roger fillipo&gt; rodger.fillipo@mail.com](w/relay/C5BF27560E4B007365FBA96D32F9E74614218C8E)                                                 |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1041 | [CFE937F5](w/relay/CFE937F5809DEE2C2916A6C54A59CCA5BC5D702A)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2019-03-30   |
| 1042 | [CD75B876](w/relay/CD75B8768320BB26A52F2B73078271B0D882CC17)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-10-26   |
| 1043 | [D1E30157](w/relay/D1E30157F356215EF91AA23A2F7317080CAE4C55)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-09-25   |
| 1044 | [email: bigul AT tutanota DOT com](w/relay/E88DEBDCBD86A71249B4F5EAF30A5E51E3F90B25)                                                              |        0.01 |      0    |       0.02 |         1 | 2024-04-10   |
| 1045 | [E9BE2D99](w/relay/E9BE2D996C5255DFABBAA4E086E5A4BDC192E4AF)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-11-11   |
| 1046 | [rotor-tor@pm.me](w/relay/DC984437C7560BD4FDBCE0E0C4CD8DB50510AFC9)                                                                               |        0.01 |      0    |       0.02 |         1 | 2024-05-05   |
| 1047 | [E11657B9](w/relay/E11657B991DD4FAF4589C2440D7472A5F63BC04E)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-10   |
| 1048 | [ebn &gt; at &gt; protonmail &lt; . &lt; com](w/relay/F11EA3F9F00E95F19261DA93D667944C4F9CB5FC)                                                   |        0.01 |      0    |       0    |         1 | 2024-08-06   |
| 1049 | [chimagamer01@gmail.com](w/family/b75f67e335a55654afc0a8ad8c06e7032867778d72bccef542eda5d5ec574830)                                               |        0.01 |      0    |       0.01 |         3 | 2024-04-19   |
| 1050 | [&lt;dmpmmservice --at-- gmail . -com-&gt;](w/family/127d69e9c902bd87025522b535f8072b8de297c5633b16df6290f4bb60017ac5)                            |        0.01 |      0    |       0    |         6 | 2024-09-15   |
| 1051 | [463A4B44](w/family/875c7938398ab01dd55807a08755839d1e8458ef837c5a37042d2e3c117329f9)                                                             |        0.01 |      0    |       0.02 |         2 | 2022-08-21   |
| 1052 | [th3wanderlust proton me](w/relay/431C23492DE6169E6A5ACEB9B24033D58428C116)                                                                       |        0.01 |      0.04 |       0    |         1 | 2023-05-28   |
| 1053 | [&lt;nobody AT example dot com&gt;](w/relay/1137AB1F84EC2D52DFB1915717F14FF1A10EB392)                                                             |        0.01 |      0.03 |       0    |         1 | 2018-11-22   |
| 1054 | [411361FD](w/relay/411361FDBEE704CEE86BF599257E117BC1F7063B)                                                                                      |        0.01 |      0.03 |       0    |         1 | 2024-08-15   |
| 1055 | [fuentescielo@cock.li](w/relay/5AC002A3FE3FFCF0FCC66A75FCFFC1F4B3786BDD)                                                                          |        0.01 |      0.03 |       0    |         1 | 2024-04-16   |
| 1056 | [00C7825A](w/relay/00C7825A1A6FC87DBF9BA0BC83FD60BAA3869136)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-21   |
| 1057 | [037B6C60](w/relay/037B6C60DAD4DF32FDA29BF458D5C8C816AA8F3E)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2019-08-22   |
| 1058 | [freeasinbeer@techie.com](w/relay/1B54D213A5D7E936281D303129D3FB1D5CE64EBA)                                                                       |        0.01 |      0    |       0.02 |         1 | 2024-07-15   |
| 1059 | [tor@dnet.ovh](w/relay/2A5746BFF32A363CD3AAD05196C0F10E7143BBB6)                                                                                  |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1060 | [31D270A3](w/relay/31D270A38505D4BFBBCABF717E9FB4BCA6DDF2FF)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2019-11-05   |
| 1061 | [4BD4407A](w/relay/4BD4407A2EE0F3CB801BD13E813190CFD6E31B6C)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-12-21   |
| 1062 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/63C51065F45A363727FC069D536AC4F576455DD9)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
| 1063 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/668F90D9ECBD73993DDDB6C084B2BD36E97291DF)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
| 1064 | [6DB10460](w/relay/6DB104609C610EF2E1600003DD83821506E2545D)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2022-10-20   |
| 1065 | [tankf33der@disroot.org](w/relay/95CEC8854A6FB514142A7317CFB12B0AD794223C)                                                                        |        0.01 |      0    |       0.02 |         1 | 2024-04-15   |
| 1066 | [tor@garrenhax.se](w/relay/9DA5284A51021A711ECAA677C81E5408222B9F2A)                                                                              |        0.01 |      0    |       0.02 |         1 | 2020-02-13   |
| 1067 | [ADEC41CA](w/relay/ADEC41CA0EAB7E4D39FD49EF586BE78CACD3110A)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-07-31   |
| 1068 | [Paris, FR &lt;parisofficial@france.fr&gt;](w/relay/AF24B19E4DB5187AB7C278AE1A1E96D02FA9BCAC)                                                     |        0.01 |      0    |       0    |         1 | 2024-02-17   |
| 1069 | [your@e-mail](w/relay/BDDCE5082D7C317AE35C8C8AF538D07DBFA0D458)                                                                                   |        0.01 |      0    |       0    |         1 | 2024-09-26   |
| 1070 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/E42A20F2DED13F8A22145811133C7E3F63B10607)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
| 1071 | [email:foxwells riseup.net](w/relay/E4B0CAD11B5487C46293759A3D4B74484CF93509)                                                                     |        0.01 |      0    |       0.02 |         1 | 2022-09-10   |
| 1072 | [CFE7762C](w/relay/CFE7762C702EF4F790DCD2892368A63254F73750)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-14   |
| 1073 | [D206EE22](w/relay/D206EE22AA1AAF9890F6A04B281E774EF91FE6B3)                                                                                      |        0.01 |      0    |       0    |         1 | 2022-07-02   |
| 1074 | [torrelaysaregreat@gmail.com xmr:84czj1u2Q4dJ7bzf41](w/relay/F54250A898FFD6CBB195CA62105AB62FA49B82AA)                                            |        0.01 |      0    |       0.02 |         1 | 2024-10-05   |
| 1075 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/F11D6B9BE67E65A79B8613834A28D77789AA2D82)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
| 1076 | [tor AT ppdlv DOT net](w/family/8acbaa6e715b0d71c7658f5f7d844ca3c111e2f6cdc6e9340353c7802995ac14)                                                 |        0.01 |      0    |       0    |         2 | 2024-10-20   |
| 1077 | [io-tor@twormtwo.com](w/family/d8f2c2f6baa98366462514857802009026b80869f728b8cf8eb9acbfe240cf2f)                                                  |        0.01 |      0    |       0.02 |         2 | 2024-07-17   |
| 1078 | [torrelay@brave.com](w/family/e573e347ba6a012904ebbacc11ca9df9f2b0499a07580250f865e57cd835605e)                                                   |        0.01 |      0    |       0.02 |         6 | 2019-02-18   |
| 1079 | [squarebrain--@cocaine--.ninja--](w/family/4d841d22ee3428816ab28fcb237a2f1f913de3648e5c2025e1673690b43ef81c)                                      |        0.01 |      0    |       0.02 |         2 | 2024-03-16   |
| 1080 | [gleebear@proton.me](w/family/cdd3fc6a9b3c2f0bb0182ed668f0d2fdb28bbd59477e1924785393fd58ce066e)                                                   |        0.01 |      0.03 |       0    |         2 | 2022-12-09   |
| 1081 | [nashepro at proton dot me](w/relay/936AAC50D69C9A3E3B37BA258156547F000C8D9D)                                                                     |        0.01 |      0.04 |       0    |         1 | 2024-06-28   |
| 1082 | [abuse at miner dot dk see https://www.miner.dk](w/relay/248A96B2A88A3EAB14699B9096CE6ABF77D0606A)                                                |        0.01 |      0.03 |       0    |         1 | 2020-07-02   |
| 1083 | [&lt; onion-exit @ /stagingdomain- dot -name&gt;](w/relay/5AA6370205AA611CED967BDB4D8EBCB9D5DB57A9)                                               |        0.01 |      0.03 |       0    |         1 | 2021-06-27   |
| 1084 | [no-spam@example.com](w/relay/6C8FAF1A64CF7D4B956FC20FB94F8D1F94D18FFE)                                                                           |        0.01 |      0.03 |       0    |         1 | 2025-01-15   |
| 1085 | [8F16229D](w/relay/8F16229D5425774DCA566D7737596178153DB838)                                                                                      |        0.01 |      0.03 |       0    |         1 | 2020-04-03   |
| 1086 | [h0tch0c @caramail.fr](w/relay/A6CD7CA239580522C4B6ED93AFB9A058B275AD9E)                                                                          |        0.01 |      0.03 |       0    |         1 | 2023-07-29   |
| 1087 | [BAF223E9](w/relay/BAF223E9DF62D3261F1675C6CFC4E5D50F15FA57)                                                                                      |        0.01 |      0.03 |       0    |         1 | 2020-02-13   |
| 1088 | [CC3113E6](w/relay/CC3113E6D50D2CC7A1CAC94624DD2D6C0021F56F)                                                                                      |        0.01 |      0.03 |       0    |         1 | 2021-03-29   |
| 1089 | [01FF9C85](w/relay/01FF9C8571D1C09FA8D2ACCE727D5530FEC10038)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2020-01-05   |
| 1090 | [Tor P. &lt;torp ARROBA sol 42 PUNTO com&gt;](w/relay/30BFB9E2ED011EA4434109DF3A4C9480B7D2F68B)                                                   |        0.01 |      0    |       0.02 |         1 | 2023-06-03   |
| 1091 | [breakingbread0@proton.me](w/relay/43548D125655E5312C41AA348D2A71467855115C)                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-04-01   |
| 1092 | [contact@plop.ovh](w/family/ad3c4f5fc836372681620a08ed9b9648d5db703ab63159c110767ce6c9dfaf4e)                                                     |        0.01 |      0    |       0.02 |         2 | 2024-01-22   |
| 1093 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/637525EC6102BEB7BBAC0BCADE55DD16FB0437E3)                                             |        0.01 |      0    |       0    |         1 | 2024-01-21   |
| 1094 | [84.pilnik.tempery@icloud.com](w/relay/627B9F40572FB2B409FBEECEED2FC8D044C03DB7)                                                                  |        0.01 |      0    |       0    |         1 | 2024-12-23   |
| 1095 | [Canadian Amateur Radio Operator c/s VA1DER &lt; nameo](w/relay/6DDDDA309535A1376AE404303B63A25225B62FA4)                                         |        0.01 |      0    |       0.02 |         1 | 2024-11-15   |
| 1096 | [tor@eti-net.de](w/relay/71188A034FDAE18DDD0022C5A6BE19A993EB02D2)                                                                                |        0.01 |      0    |       0.02 |         1 | 2024-02-09   |
| 1097 | [823D33ED](w/relay/823D33ED9D54AD1505DD5634695A1DCD8E98ABC5)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-15   |
| 1098 | [97B11832](w/relay/97B118325F445584FF91A6E3BF98C01C32C6693B)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-12-19   |
| 1099 | [pokherchip@mail.com](w/relay/A2E327922875FF477B982200D30759B9A223BA3C)                                                                           |        0.01 |      0    |       0.02 |         1 | 2024-11-04   |
| 1100 | [BD59E773](w/relay/BD59E773639F1AFC856F7688A74430E1E27D6921)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-11-11   |
| 1101 | [SysCom &lt;syscom =at= snt.utwente.nl&gt;](w/relay/D08660B6D70B6249A57D89BB7A8F2EA2C952BD35)                                                     |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1102 | [sere04versed@icloud.com](w/relay/CE4C88B2CA700655AC0CC98F093973EA86CAEE4D)                                                                       |        0.01 |      0    |       0.02 |         1 | 2024-01-22   |
| 1103 | [Jan Weiher &lt;jan buksy de&gt;](w/relay/F4F605AA21C4633CCB5B8DBBC1CEEE5C590C6DCE)                                                               |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1104 | [F2F8309E](w/relay/F2F8309E8F9B2D816AFB639C86CC2929DEC9459A)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2021-09-25   |
| 1105 | [F723641A](w/relay/F723641AC2E1822939F30ABB00FB1908E1605C31)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-02   |
| 1106 | [noc@0x7c0.com](w/family/568289c40df335fe3b7195e1c0e950a5626b982b2ad0672880a5844a0bfc61ed)                                                        |        0.01 |      0.03 |       0    |         4 | 2024-07-26   |
| 1107 | [vlad at vlads dot me](w/family/b4223ce9db1b75b18bcbf75c4eb10dae3b979fb907939ec31092719fce9fafae)                                                 |        0.01 |      0    |       0.02 |         2 | 2019-02-18   |
| 1108 | [0FAD8CE4](w/family/1bbcbb1269e2fb8e54bf1601c65f419ef2d09297e74aaefc57467b234880de49)                                                             |        0.01 |      0    |       0.02 |         2 | 2024-03-19   |
| 1109 | [097D8390](w/family/82a1ccf33d3c08abb525f50b0e04f9383724dad0affda45d922eec10dfa5ea73)                                                             |        0.01 |      0    |       0.02 |         2 | 2022-01-23   |
| 1110 | [phillw.net](w/family/4077dd8ff68ab5d3fcd78730f6515d2de78333db2d84dce0211a5946ebf9edbd)                                                           |        0.01 |      0    |       0.02 |         2 | 2019-02-18   |
| 1111 | [tor@cabaal.net](w/family/8210ac24820845df5be55d74fccf9f7a252e83e5ad77d2abd58b3bc8663599e1)                                                       |        0.01 |      0    |       0.02 |         3 | 2023-10-27   |
| 1112 | [someone &lt; tor27 AT nurfuerspam DOT de &gt;](w/family/1a6189b2f3110133f00358f663aa3438a4c2d43d4f7cc6136ea1b98be5666d9a)                        |        0.01 |      0    |       0    |         3 | 2023-06-09   |
| 1113 | [avaet1iriejai9duv6aj at gmail dot com tor-relay.c](w/family/e462549470381e0ecaa69b2a0188ef5cf07ecfd7870d7877a6f37e5768f0e8a0)                    |        0.01 |      0    |       0.02 |         4 | 2019-09-01   |
| 1114 | [gutter.duckdns.org](w/family/3004368a2c821cfa6724147f4871ab3cd7c97fb651ea532ac1c7da42ea0160f8)                                                   |        0.01 |      0    |       0.01 |         7 | 2021-12-04   |
| 1115 | [Clara &lt;3 &lt;clara at zergflag dot fr&gt;](w/family/9764ae674104e4529fb78fe72f455f755efc55434bd90ff5a88a1a7e88f9a170)                         |        0.01 |      0    |       0.02 |         2 | 2024-01-22   |
| 1116 | [a-n-o-n-y-m-e.net](w/relay/36E4BEA3E092D05DC25F4CD29A9A5C7D9D0C7571)                                                                             |        0.01 |      0.03 |       0    |         1 | 2024-06-11   |
| 1117 | [laladee@posteo.net](w/relay/9DBD92C848EEC352D542FBAC89DE2439271F699B)                                                                            |        0.01 |      0.03 |       0    |         1 | 2024-12-04   |
| 1118 | [fos-admin snokado@gmx.de](w/relay/075D50331B95190A7EC58FC9C570A34761196003)                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-01-22   |
| 1119 | [0F7CA1AC](w/relay/0F7CA1ACC93EFA2F5034F299302894D7823BA56F)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-12-28   |
| 1120 | [176EC378](w/relay/176EC37891794DC7001398A4591FA7F1A77C499D)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-07-27   |
| 1121 | [1CD86E55](w/relay/1CD86E55B4A707863105AB108A99F307C11892BA)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-02-19   |
| 1122 | [&lt;tamanegi AT rainside dot sk&gt;](w/relay/21310F48066A4CAADEB2BFD324F0B38F8E1448D6)                                                           |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1123 | [i-am-freman-@-privatemail dot com](w/relay/41F0FC3181C674F99FD1505E6240AEE060B263AF)                                                             |        0.01 |      0    |       0    |         1 | 2024-03-30   |
| 1124 | [493A4023](w/relay/493A402320BA0F4EE453D0098FAE8452723B2EB8)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2023-03-23   |
| 1125 | [Cryptobot7 &lt;cryptobot7 AT protonmail dot com&gt;](w/relay/4A32D9D9C0E29275A0584503275658139E844BFF)                                           |        0.01 |      0    |       0.02 |         1 | 2023-08-08   |
| 1126 | [John](w/relay/6C1B288D873C75A696EB70E9FF713B786D37D192)                                                                                          |        0.01 |      0    |       0.02 |         1 | 2022-01-13   |
| 1127 | [614656D1](w/relay/614656D126EC3434046476DB6FD631B71124DAB4)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2022-05-23   |
| 1128 | [FollowMyWay@mail.ru](w/relay/652CC2F03EEDFF84E5F61EF8CD19D3D97DB5E7EF)                                                                           |        0.01 |      0    |       0.02 |         1 | 2024-06-26   |
| 1129 | [cookieandtea@cocaine.ninja](w/relay/B8F8E84576DE8CC6CDE136D2374F9385A2AFFAD0)                                                                    |        0.01 |      0    |       0.02 |         1 | 2024-10-30   |
| 1130 | [tor at txwx.de](w/relay/C7FF606D59C7F6BECA8A341D3CF11B423F382D5D)                                                                                |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1131 | [6D6B24A5](w/relay/6D6B24A5A3288D62BCB146F4421B6C097443FFB6)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-11-20   |
| 1132 | [abuse@spnet.net](w/relay/7794F060BA3F2F60443A6BC35261F6687B150C2C)                                                                               |        0.01 |      0    |       0    |         1 | 2023-01-18   |
| 1133 | [75BFDE08](w/relay/75BFDE081BEEAF99D35B1DC86DD8A7463B1B9DD5)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-12-25   |
| 1134 | [7913C398](w/relay/7913C398EFEDC700D08125162FD1977CB5720D26)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-10-14   |
| 1135 | [community.torproject.grief119@passmail.net](w/relay/92B2DA65043D06118A2E4BBEFF87A877C5CF2310)                                                    |        0.01 |      0    |       0.02 |         1 | 2024-08-16   |
| 1136 | [876C7CE4](w/relay/876C7CE43774366250D3E768E690DAB9D4B5D5A3)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1137 | [888D2CB4](w/relay/888D2CB4F8E26F22D86B60C779A94994CBAE56B3)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-12-18   |
| 1138 | [Anfrage@fastner.dev](w/relay/9098B2E4ED5DD1CE20D91663DE90386BC717C619)                                                                           |        0.01 |      0    |       0    |         1 | 2024-12-11   |
| 1139 | [email@dvdznf.xyz](w/relay/96428042D3D729B5EA8EA0D41957DACA19B5F633)                                                                              |        0.01 |      0    |       0.02 |         1 | 2023-04-16   |
| 1140 | [ADC19D08](w/relay/ADC19D080D18C8C7C1157D2F434B4AD626F9C19F)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-05-14   |
| 1141 | [abuse@srstubes.com](w/relay/B142A470CF4FD7519E3F89D8FE0E7D5C966A219B)                                                                            |        0.01 |      0    |       0.02 |         1 | 2025-01-13   |
| 1142 | [&lt;romeooscarkilo AT pm DOT me&gt;](w/relay/BBC0CD384B1B756786B678D0B5F56A629CDC0654)                                                           |        0.01 |      0    |       0    |         1 | 2025-01-19   |
| 1143 | [TheStaticTurtle &lt;tor-relay@thestaticturtle.fr&gt;](w/relay/DDDA625FF6C1F1F4554281C2D6DC3FBAD092CB5F)                                          |        0.01 |      0    |       0.02 |         1 | 2020-01-24   |
| 1144 | [DE8E0958](w/relay/DE8E0958DE6209F99B6248EE39E7C583C5532E6B)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-12-28   |
| 1145 | [nicetrynono@gmail.com](w/relay/FBD40937C6E1523CA717036FC4FD5ECC832A93B7)                                                                         |        0.01 |      0    |       0.02 |         1 | 2022-01-13   |
| 1146 | [abuse@srstubes.com](w/relay/FD3517DFFC281F1430EBB6A62520595A8FF7B378)                                                                            |        0.01 |      0    |       0.02 |         1 | 2025-01-13   |
| 1147 | [c4tdr0ut at duck dot com](w/family/f766ea854f9eecc4c2feef27a4767dfed5addbf205278cc9f9211b11ab547456)                                             |        0.01 |      0    |       0.02 |         2 | 2025-01-03   |
| 1148 | [7be58bbb-2028-4549-923c-93325619a0f1@anonaddy.me](w/family/588ab26502807550c11d60951958a6fcf1070439c5c436a6fb9fe873d4690b35)                     |        0.01 |      0.03 |       0    |         2 | 2024-11-10   |
| 1149 | [yumpy&lt;at&gt;fastmail&lt;.&gt;net](w/family/0816458e9ae0c4d79b32e3a0ec888b66a854d6d2c78a9f3cdaa1c12794949bed)                                  |        0.01 |      0.03 |       0    |         2 | 2024-01-22   |
| 1150 | [kai.sx](w/family/8d23dc68384094e8f7f05f521cb149d7d59bc753078c6f217fdf2c6310203328)                                                               |        0.01 |      0    |       0.02 |         2 | 2019-02-18   |
| 1151 | [cub-due0k@icloud.com](w/family/940d17cb445a89a7b2edc0b3b8b4166ee0928dce20cbd70b1276e589c4cbf6d0)                                                 |        0.01 |      0    |       0    |         2 | 2024-10-25   |
| 1152 | [kszczot.pl](w/family/f53b8123c17f4043a0e0b9354f99994b49aea176dc1681adfbe3b69b65ede466)                                                           |        0.01 |      0    |       0.01 |         3 | 2024-10-30   |
| 1153 | [&lt; pokefamily AT tutanota dot com&gt;](w/family/77da984d569105cc09ef760f66b3b5aa9953dd308d776a2f389dcfc850093a4e)                              |        0.01 |      0    |       0.02 |         2 | 2022-03-04   |
| 1154 | [Fiete &lt;m DOT buechner AT gmail DOT com&gt;](w/family/12b18bb0368d85d316954e2260b4d67635604d46bc850231585bd614c10b4d72)                        |        0.01 |      0    |       0.02 |         2 | 2021-12-24   |
| 1155 | [tor102 &lt;tor102 AT ip-connect dot info&gt;](w/family/2ef4ee4e3a75dea8060b708c48cac3587c489e9581033fc395d9d73846da5d05)                         |        0.01 |      0    |       0.02 |         4 | 2023-03-15   |
| 1156 | [234B06E4](w/family/2067ac44334d9463a02e5ea6be12d1e8e577e9730e0f300a4a71717d151d4320)                                                             |        0.01 |      0    |       0.02 |         3 | 2022-04-13   |
| 1157 | [quetzalcoatl-relays.org](w/relay/31AB04A3080091FECCAFD6B02B3D46BE9DB82FE5)                                                                       |        0.01 |      0.03 |       0    |         1 | 2020-12-29   |
| 1158 | [Admin &lt;tor.uncharted624@passmail.net&gt;](w/relay/6796C85E7E1D547CAEC9D5CED6DE9068187288C6)                                                   |        0.01 |      0.03 |       0    |         1 | 2024-01-21   |
| 1159 | [01B8F18C](w/relay/01B8F18C11CE2877E8190FA2C81808CD087515C0)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2022-02-05   |
| 1160 | [EF201A39 &lt;nat@makarevitch.org&gt;](w/relay/03BD56B5072FB07D2B4D79E2FB04366D415EF3EC)                                                          |        0.01 |      0    |       0.02 |         1 | 2021-08-21   |
| 1161 | [chaz@chaz6.com](w/relay/02A0D8DDF4DA4E601C1C66143BB0C8A0F2F3C857)                                                                                |        0.01 |      0    |       0.02 |         1 | 2023-10-28   |
| 1162 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/211AD97025CCC8BF59C4BC557B9D95088EE0634B)                                             |        0.01 |      0    |       0.02 |         1 | 2023-08-02   |
| 1163 | [264E8CA3](w/relay/264E8CA388F3D00081CD7E91D6C4272C048B6AF9)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2022-03-14   |
| 1164 | [Random Person nobody@tor.org](w/relay/34BA623496287D2E4D3224FF33ED1C6435A73363)                                                                  |        0.01 |      0    |       0.02 |         1 | 2023-01-28   |
| 1165 | [hacksax-osald.0c at icloud.com](w/relay/3DFC91005FC1DD4CC6623F25955EB496E66E969A)                                                                |        0.01 |      0    |       0    |         1 | 2023-01-28   |
| 1166 | [&lt;tor@blicky.net&gt;](w/relay/49DC222A7494AEF8E7DBF2E3CAABF23504C77B64)                                                                        |        0.01 |      0    |       0.02 |         1 | 2019-02-18   |
| 1167 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/57588D86F91240BC3D6BA891BDFAF52AF5F6A438)                                             |        0.01 |      0    |       0.02 |         1 | 2024-03-04   |
| 1168 | [54EE5C1E](w/relay/54EE5C1EBB76502CE9C92775FDCB7BC6FE8D6F40)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2022-10-30   |
| 1169 | [CryingOnion-relay@protonmail.com](w/relay/5A9B2EC4C652EC4FF72C8C673937BE27B3486666)                                                              |        0.01 |      0    |       0.02 |         1 | 2020-10-10   |
| 1170 | [6DABEE3D](w/relay/6DABEE3D82CA3D299EB7573397BC333E6D37DC1F)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-12-21   |
| 1171 | [6E8A208C](w/relay/6E8A208CA020FC4114904EFA294E26614E7D865E)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2025-01-08   |
| 1172 | [783EAC35](w/relay/783EAC35329BB398CB4EEF28DDFA74E219878BE4)                                                                                      |        0.01 |      0    |       0    |         1 | 2025-01-15   |
| 1173 | [bosslike589 at gmail dot com](w/relay/92988EFE7676BA402296B63AE254968E7AA91980)                                                                  |        0.01 |      0    |       0.02 |         1 | 2022-12-29   |
| 1174 | [0xF1ADC390 Random Tor Node Operator &lt;tor at unterd](w/relay/A508096AA0C899F4E6ECD1D9C35037B89008BCBA)                                         |        0.01 |      0    |       0.02 |         1 | 2023-02-17   |
| 1175 | [tor@operapia.org](w/relay/AD97106BA2C903AC2A2A222FEBBB4E645AF6E9AD)                                                                              |        0.01 |      0    |       0.02 |         1 | 2024-01-22   |
| 1176 | [CBFC5270](w/relay/CBFC5270C0C5110CD3DC5DF366358D1A4266943D)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-12-19   |
| 1177 | [tor-relay-claire@shoryuken.me](w/relay/D747A27C631B1C90BE76388BC5AF5FA389D30DCE)                                                                 |        0.01 |      0    |       0    |         1 | 2024-02-19   |
| 1178 | [support at keybouh dot dev](w/relay/E6060F09E8007FC7CFAC7BC24477F9D878B247DD)                                                                    |        0.01 |      0    |       0.02 |         1 | 2020-11-29   |
| 1179 | [toreatsonions@proton.me](w/relay/EDA5E5C0C655BFD4B4410E1612A4D13F398502C9)                                                                       |        0.01 |      0    |       0.02 |         1 | 2024-11-18   |
| 1180 | [atyourservice@morke.org](w/relay/EFE27FE4AC60A4904BE00647C9B53F1841C93040)                                                                       |        0.01 |      0    |       0    |         1 | 2023-03-10   |
| 1181 | [cyberbits.eu](w/relay/F836446663F1EB816F13708955F105D0B2F5C8E0)                                                                                  |        0.01 |      0    |       0.02 |         1 | 2020-07-22   |
| 1182 | [email: jabber-relay at boatmail.cc confmgmt:ansibl](w/family/1e70da2a32be1bfc8c939a9a1048330e8f9e5515b90b64a0909b8777cd2bbb94)                   |        0.01 |      0    |       0    |         2 | 2025-01-19   |
| 1183 | [tor101 &lt;tor101 AT ip-connect dot info&gt;](w/family/cb754f1046ce391646e82bf5d4d557a61d5b1b934128ace92c8fe288d5349bfa)                         |        0.01 |      0    |       0.02 |         4 | 2024-01-22   |
| 1184 | [&lt;tor at snehankekre dot com&gt;](w/family/bbffb31668dd5277c8f486b3cd4cf071a7b7dc190337f21862deec2780280566)                                   |        0.01 |      0    |       0.02 |         2 | 2021-12-14   |
| 1185 | [1FCCC3FB](w/family/ec0dc7e81269ddb642dd0d82282c5cf1f115ddba9c9841b1b921ee26b29eb2e2)                                                             |        0.01 |      0    |       0.02 |         4 | 2024-03-05   |
| 1186 | [nx42.de](w/family/c176fbd3e9e3fa786fb9f52e6b7db0c6a9a82c63f957aa6c6ab9c1d883cb5d8c)                                                              |        0.01 |      0    |       0.02 |         2 | 2019-02-18   |
| 1187 | [0xA178459DC4EC1DA3 Ryan Omasta &lt;abuse dash tor AT](w/family/fbd3b01cff05f3d1ec9dd788094c1db151c482ed2433e04143c451f7e0728149)                 |        0.01 |      0.02 |       0    |         3 | 2024-12-21   |
| 1188 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/003A08F1ADC002D24979C68AA5A33369C04D9C7F)                                             |        0.01 |      0.03 |       0    |         1 | 2023-11-09   |
| 1189 | [&lt;developing ATT keemail dott me&gt;](w/relay/127F6358F68FFB7E437DBA51D6D4DAC47B9F78A7)                                                        |        0.01 |      0.03 |       0    |         1 | 2021-05-26   |
| 1190 | [cl1ps.geamy at protonmail dot com](w/relay/6465578393CD74400E68E8A9F09B5375C1BB5C24)                                                             |        0.01 |      0.03 |       0    |         1 | 2025-01-16   |
| 1191 | [Tor &lt;tor@plutex.de&gt;](w/relay/EF9C4611FAA7C21155A8BA2A721DDC3D27816035)                                                                     |        0.01 |      0.03 |       0    |         1 | 2019-02-18   |
| 1192 | [bc1q8jtc0jnvwxw5h4724v04xc3hvnq28s8wme2686 &lt;tor AT](w/relay/02B2152129686AE0BE05F3D1460591DD71C4BB15)                                         |        0.01 |      0    |       0.02 |         1 | 2022-11-28   |
| 1193 | [stephan dot schmidt at skynet-london dot co dot uk](w/relay/2A9617210F42738F14D0CFE0AF9C50E7CBB355FC)                                            |        0.01 |      0    |       0    |         1 | 2025-01-02   |
| 1194 | [0AF3293D](w/relay/0AF3293D2AE809C9EEE6F13B7C9306BB07651C71)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-05   |
| 1195 | [137DD636](w/relay/137DD6369FCCA88677286A910F173A84B48A73AE)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2023-12-15   |
| 1196 | [1324B4C0](w/relay/1324B4C0E741D5786DFD2106F9F71734CAA331F8)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-11-27   |
| 1197 | [isodiapher /at/ movim / eu xmpp ad9c85ac 5aded](w/relay/1814DBD5E7E1839CA3F43847683A08F3BF3D5C91)                                                |        0.01 |      0    |       0.02 |         1 | 2023-03-25   |
| 1198 | [24C312C6](w/relay/24C312C65675E80CFC729E04600D0D9DD27379F4)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2021-01-08   |
| 1199 | [tor AT r-36 D0T net](w/relay/30ABFEA883B663C22D35B7467F13476304B40581)                                                                           |        0.01 |      0    |       0    |         1 | 2024-03-01   |
| 1200 | [5h098y32 at duck . com](w/relay/4F510004DAA88E84F60AD991A6A733FF8615CE38)                                                                        |        0.01 |      0    |       0.02 |         1 | 2023-06-21   |
| 1201 | [tor 1 AT online DOT de](w/relay/525EE34C1A7B89AB9DF585246DE30E32702913F5)                                                                        |        0.01 |      0    |       0.02 |         1 | 2020-01-14   |
| 1202 | [Person of good will &lt;nobody - example com](w/relay/4BCAA064723358D133BE9B45EF8436D32BC993E3)                                                  |        0.01 |      0    |       0.02 |         1 | 2024-02-01   |
| 1203 | [deeznodes@protonmail.com](w/relay/55804F9D37F7B27BD0426B3CB06C64B4D0F95546)                                                                      |        0.01 |      0    |       0    |         1 | 2020-02-23   |
| 1204 | [5DCCC86A](w/relay/5DCCC86AE64A8BFC5F81FFBF2D0C7765B1C7C500)                                                                                      |        0.01 |      0    |       0.02 |         1 | 2024-12-02   |
| 1205 | [Kevin &lt;tor AT kberanek dot com&gt;](w/relay/66C102FA5DDF48C9EEEB048C1630933B66C50ECC)                                                         |        0.01 |      0    |       0.02 |         1 | 2020-05-13   |
| 1206 | [machinepfftround4 at protonmail dot com](w/relay/C72B272FD1C5304DF1C0865A4F4F6AA6C1B87FA3)                                                       |        0.01 |      0    |       0.02 |         1 | 2024-06-09   |
| 1207 | [javier.a javi5@gmx.com](w/relay/87DBC90DDA72B9751B021A237D5A173D06F7A409)                                                                        |        0.01 |      0    |       0.02 |         1 | 2024-01-22   |
| 1208 | [nomore4thelast@protonmail.com](w/relay/91BB8F6C9FB9C607A553D4DDE32FA4DE96EE2F75)                                                                 |        0.01 |      0    |       0.02 |         1 | 2024-10-21   |
| 1209 | [tor relai@hyter.online](w/relay/A4F26D0C77C25FC31BBD376AC1B8A8FB0598908F)                                                                        |        0.01 |      0    |       0    |         1 | 2024-04-08   |
| 1210 | [Mi Gibtsdonet &lt;nobody AT example dot com&gt;](w/relay/C93A07D6BDAC150FC437441B6BA331A036E8182D)                                               |        0.01 |      0    |       0.02 |         1 | 2025-01-15   |
| 1211 | [relais06@mailbox.org](w/relay/CAA2BB7232F98457D3B4D2D2EAE62C1460C37651)                                                                          |        0.01 |      0    |       0.02 |         1 | 2024-12-21   |
| 1212 | [torproject.org.masculine802@passmail.net](w/relay/FE05FEFAE7AED4F3D05C3A308999EA2113EC3383)                                                      |        0.01 |      0    |       0.02 |         1 | 2024-08-27   |
| 1213 | [einSehrNetterHoster](w/relay/FF8B7CAD5F508972509D79F933FB24D2F524AB75)                                                                           |        0.01 |      0    |       0.02 |         1 | 2022-01-13   |
| 1214 | [Tessier-Ashpool-Tech-Support protonmail com](w/relay/CBD05C5E1EC91AD648B2BE16EC909024F2F096B0)                                                   |        0.01 |      0    |       0.02 |         1 | 2020-12-09   |
| 1215 | [hydra@cock.lu](w/relay/D1CA03021AAF1A8FFE615906661E56A895695B93)                                                                                 |        0.01 |      0    |       0.02 |         1 | 2024-02-04   |
| 1216 | [gooserider42 at proton dot me](w/family/550ea16149dd4003d6fb227d611f7ce05adc20dce0ef77b603d0f70e6966f094)                                        |        0.01 |      0    |       0.01 |         2 | 2022-08-01   |
| 1217 | [316DE45E](w/family/75ab7b94bdeda930e7e3e9e40281951e0984a1a0e6a12f8692cc52ee3eb1dedf)                                                             |        0.01 |      0    |       0.01 |         2 | 2019-02-18   |
| 1218 | [Mr. Leviathan &lt; tor-relay @ lvthn D.O.T win &gt;](w/family/1ef2159034806c4dd12f05eb2daa5db930cb0396c24e1ca354eb031c8d24af93)                  |        0.01 |      0    |       0.02 |         3 | 2022-04-23   |
| 1219 | [teitel.net](w/family/0c8dbd3e2711faa5e704ffd38cb72f4fe72f22cb7f5795170f35d60178eac38f)                                                           |        0.01 |      0.02 |       0    |         2 | 2019-12-25   |
| 1220 | [nermal@tutanota.de](w/family/ccb3bb5cfd48a2de515a3c499d2b497a3edec4a98741d264ccf69de95f58bcfe)                                                   |        0.01 |      0    |       0    |         2 | 2024-10-15   |
| 1221 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/F5A1575131F8EE7F41D72532592FA6A784821C4F)                                             |        0.01 |      0.03 |       0    |         1 | 2024-01-22   |
| 1222 | [supermp3man@protonmail.com](w/relay/EE72F8544BC46F6FFCDB47CCDB954E5AC642756C)                                                                    |        0.01 |      0.03 |       0    |         1 | 2022-04-23   |
| 1223 | [&lt;DONTPANIC&gt; &lt;gmx.co.uk&gt;](w/relay/0932F9009DCF32EC60FD52F975318D3F6E8E59F9)                                                           |        0.01 |      0.02 |       0    |         1 | 2023-12-02   |
| 1224 | [a-n-o-n-y-m-e.net](w/relay/25FC41154DCB2CAE3ABD74A8DFCD5B90D2CFFD57)                                                                             |        0.01 |      0.02 |       0    |         1 | 2024-01-30   |
| 1225 | [pazcthy@mail.com](w/relay/4B61EC04E1797D8688475BD24EDA450914497D84)                                                                              |        0.01 |      0.02 |       0    |         1 | 2023-07-31   |
| 1226 | [art4096 proton mail](w/relay/825365C44650897970F158574AF29D42A33DE541)                                                                           |        0.01 |      0.02 |       0    |         1 | 2022-09-30   |
| 1227 | [DONT SPAM DONT SPY legalizeprivacy protonmail com](w/relay/A92D83E8F98941335076FFA47660BB87EB0AF2E2)                                             |        0.01 |      0.02 |       0    |         1 | 2023-05-24   |
| 1228 | [matrixrevolution@mail2tor.com](w/relay/AAA9D692D1B3BE6788C7E86EA6ABEE3AB17C8289)                                                                 |        0.01 |      0.02 |       0    |         1 | 2024-11-10   |
| 1229 | [ben &lt;AT&gt; uq.ci](w/relay/15CD2C302869242498AFEB2369C0E95882DFCB6A)                                                                          |        0.01 |      0    |       0.01 |         1 | 2025-01-08   |
| 1230 | [0E20E3BF](w/relay/0E20E3BFB1BDC3422E568403E37C00249D9BA901)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2023-09-13   |
| 1231 | [187F555B](w/relay/187F555BA1549E7493DD946181277CC303B0B79F)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-11-18   |
| 1232 | [morrrgoth@proton.me](w/relay/1BBAA8F23B56535430AB888190BE1007D33EAA9F)                                                                           |        0.01 |      0    |       0    |         1 | 2024-09-12   |
| 1233 | [Stechus Kaktus &lt;stechuskaktus1337@protonmail.com&gt;](w/relay/1F4078E841EC74C92C88D69B296A8E2EAA2349AA)                                       |        0.01 |      0    |       0.01 |         1 | 2023-07-29   |
| 1234 | [&lt;ben tor at graef . in&gt;](w/relay/3004A0135AE7E42F3D1475838F76EFF9BE46294A)                                                                 |        0.01 |      0    |       0.01 |         1 | 2024-12-13   |
| 1235 | [tor-node-admin@protonmail.com](w/relay/31E3072BE2D7FEC5707F09C351612FE2B7AE48D5)                                                                 |        0.01 |      0    |       0.01 |         1 | 2022-01-23   |
| 1236 | [email:admin selea.se proof:uri-rsa abuse:abuse](w/relay/419C756F1150ACD57C1A19783AB682FD3CE56E24)                                                |        0.01 |      0    |       0.01 |         1 | 2025-01-09   |
| 1237 | [4322D045](w/relay/4322D045F0C55D270FCA8CF4845149DED8BB7833)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-12-21   |
| 1238 | [44FB31D0](w/relay/44FB31D0A2E567E2D52AC92C6BCDA59D03F5B44F)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2021-07-27   |
| 1239 | [tor@schweren.dev](w/relay/4953D65C802860DED172D788B9660BC29DF92235)                                                                              |        0.01 |      0    |       0.01 |         1 | 2024-01-22   |
| 1240 | [nospam@gmail.com](w/relay/582E9FDCFB6B6573A9EC0EF9F560C4A0245997E7)                                                                              |        0.01 |      0    |       0.01 |         1 | 2024-03-23   |
| 1241 | [athalis.de](w/relay/584FAA0033A52C4A7091C3D3FDF70A2EFF6C739D)                                                                                    |        0.01 |      0    |       0.01 |         1 | 2020-10-30   |
| 1242 | [67CDF7A4](w/relay/67CDF7A4D06E98E55AAE595BBEBF38E64C4CCBF3)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1243 | [6E402A41](w/relay/6E402A413395D0E8794817C3C50C2B1F7DBF1B0E)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-01-22   |
| 1244 | [7D06BF2C](w/relay/7D06BF2C460DFAFF2181677558C3BC644A139999)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-01-29   |
| 1245 | [7009E23E](w/relay/7009E23ED3BA23216E7C22F7AA20A84DE937B8ED)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-07-26   |
| 1246 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/856E3A14EC2CAD7412C9A6E8FC0C3FDFD075E8F5)                                             |        0.01 |      0    |       0.01 |         1 | 2024-01-31   |
| 1247 | [tor-admin &lt;tor@mnesys.org&gt;](w/relay/86D924EDE1498B4E1DD08D2260F3E9FE454012E1)                                                              |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1248 | [Leader &lt;leader AT free-hack dot com&gt;](w/relay/88D6A3C0FC28EAE6B9AD0BA1082223C03C1B32FA)                                                    |        0.01 |      0    |       0.01 |         1 | 2021-10-05   |
| 1249 | [Ns27bdd25e@ro.ru](w/relay/9FFE57C231BF3D7CCB15F79FFE1B908EC3700404)                                                                              |        0.01 |      0    |       0.01 |         1 | 2024-08-29   |
| 1250 | [A151005A](w/relay/A151005A71B878158266576DCAE6D82EE5CBCDBC)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2022-11-09   |
| 1251 | [antiglowiemachine9000@proton.me](w/relay/AA80B523EB781CF470CA5A91427200620FFD4281)                                                               |        0.01 |      0    |       0.01 |         1 | 2024-02-18   |
| 1252 | [Relay Admin &lt;privacheese AT proton.me&gt;](w/relay/A4DB56034A3FEABAFB2CF516BE5D1D4C1A1D6AE8)                                                  |        0.01 |      0    |       0.01 |         1 | 2024-09-06   |
| 1253 | [0x641814BB9C9F44AE tor@nicolasmueller.eu](w/relay/AAFFA68AB61238F9044B6ECBA62E25264113EB88)                                                      |        0.01 |      0    |       0.01 |         1 | 2020-04-23   |
| 1254 | [My Tor Node &lt;mytornode@xn--y9a.net&gt;](w/relay/B54BC0EB7CF821FE2B9A6D7116BEE75217FCEE3C)                                                     |        0.01 |      0    |       0.01 |         1 | 2022-05-03   |
| 1255 | [Ali Gatorr &lt;Ali DOT Gatorr AT free DOT fr&gt;](w/relay/ACBF3D504CFF3D74D1991AFDF6AC070606232B10)                                              |        0.01 |      0    |       0.01 |         1 | 2020-04-23   |
| 1256 | [C42C51EF](w/relay/C42C51EFC275C45EF94CF810E02BA737FD99F7FA)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2023-05-16   |
| 1257 | [tor AT r-36 D0T net](w/relay/E41C0F451207B4D1C623A12AE56AF2BCC0064BB0)                                                                           |        0.01 |      0    |       0    |         1 | 2024-03-01   |
| 1258 | [CB44E8ED](w/relay/CB44E8ED1FAB648275C39756EB1758060C43BCA4)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-01-22   |
| 1259 | [cleshawnlamontegue@gmail.com](w/relay/CD478DBDF96F456C386E2BE52670E76A815EDBF3)                                                                  |        0.01 |      0    |       0.01 |         1 | 2024-07-13   |
| 1260 | [CD5CF125](w/relay/CD5CF125FED4BE5DA5F259F75AF3D4DD182C54D0)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2019-06-28   |
| 1261 | [D5A2B3AE](w/relay/D5A2B3AE1E8047017A0BBC7209FD624DB84D47CE)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2019-04-29   |
| 1262 | [dmitri @bk.ru](w/relay/D3E07F606B1CA18FE85F02C061414ABF8482271C)                                                                                 |        0.01 |      0    |       0    |         1 | 2024-03-01   |
| 1263 | [tor@schabernax.de](w/relay/EB1FC45FDE95E4ECFFFCBDA2E61BB26BC2A7723A)                                                                             |        0.01 |      0    |       0    |         1 | 2024-12-21   |
| 1264 | [F4650430](w/relay/F4650430F42F198A101E9FC884338D4C62EAC457)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-11-20   |
| 1265 | [abuse@srstubes.com](w/relay/F7CC37F98E25E75EBC97BFD4FA7955053A0370BC)                                                                            |        0.01 |      0    |       0.01 |         1 | 2025-01-06   |
| 1266 | [Julie &x27;Dirty Needles&x27; Kerr calledmeawhore@inmyown](w/relay/F897862DBE9B188EAA5A11ED3795867DC66DA1B3)                                     |        0.01 |      0    |       0    |         1 | 2024-03-17   |
| 1267 | [subtype@protonmail.com](w/family/f77dc921d86415554392d8770fdf80dfd618b63798ba5e28a02cc69ff992925c)                                               |        0.01 |      0.02 |       0    |         2 | 2019-10-16   |
| 1268 | [tor-relay@ahnlak.com](w/family/8d747f8663ef67f1100adf6e03e40145332b4d7140ca5c61611145db2444505f)                                                 |        0.01 |      0    |       0    |         6 | 2024-06-06   |
| 1269 | [Steven Murdoch &lt;ephemer-tor-admin@cl.cam.ac.uk&gt;](w/family/f7d97a091fa8a93a612c5f49aa22604ece2a1858b17f65054f4fd57a5e7d6e76)                |        0.01 |      0    |       0.01 |         2 | 2019-02-18   |
| 1270 | [FlashTor at e.mail DOT de](w/family/cf6885c388d90be2f6cb872d8ad5c3ab8f74b000ff684400f69584b909b446ac)                                            |        0.01 |      0    |       0.01 |         8 | 2019-02-18   |
| 1271 | [24523E7B](w/family/3d20a4d0aa4deff1e7c1b29fa00220b6d74663fedc8c28f482c7714681e1d159)                                                             |        0.01 |      0    |       0.01 |         2 | 2021-03-29   |
| 1272 | [hnlexit@bsideshawaii.org](w/family/2e38d9c0bc47fc019d86071bf72fcb809a5df81a1165dc48981ea9fd6770170c)                                             |        0.01 |      0.02 |       0    |         9 | 2024-01-22   |
| 1273 | [2062C6FE](w/family/8c4195c72febc40a717a2c35cae7ed022eb19c945285aae27993477f5a0131e9)                                                             |        0.01 |      0    |       0.01 |         2 | 2021-09-05   |
| 1274 | [&lt;sunshinecowboy56 AT protonmail dot com&gt;](w/family/d4520d9f440bda18174735694989f30764f2f9bd44350b7c908ea1e2ee8a3412)                       |        0.01 |      0.02 |       0    |         4 | 2024-01-22   |
| 1275 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/05EA20BE14D0AC4F3D69DECF20F15A2E28353C0A)                                             |        0.01 |      0.03 |       0    |         1 | 2023-09-06   |
| 1276 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/3D1D69A2A1254BD52A938D68C1AD4FBD31F1852A)                                             |        0.01 |      0.03 |       0    |         1 | 2024-01-14   |
| 1277 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/0B041A1650BD8989F9187AE553C9DB41783F114B)                                             |        0.01 |      0.03 |       0    |         1 | 2023-11-09   |
| 1278 | [email:schroedingers cat riseup.net pgp:4A74E1B840](w/relay/114F6F2A3A6E8AB9AC2BD54B8C5A204C1CA5942B)                                             |        0.01 |      0.03 |       0    |         1 | 2019-04-13   |
| 1279 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/CD92DB6464DDE96E1FDB2381B7DB92D2D31CC8B9)                                             |        0.01 |      0.03 |       0    |         1 | 2024-01-22   |
| 1280 | [tor at d-ku dot de - 0x86d7bbcc54cbb356](w/relay/467D7417FFA611BC20227FE347494CE5F61218FB)                                                       |        0.01 |      0.02 |       0    |         1 | 2019-10-26   |
| 1281 | [emeraldonion.org](w/relay/481313B7E49931D893B9DD4898AE6218C3172D99)                                                                              |        0.01 |      0.02 |       0    |         1 | 2024-07-26   |
| 1282 | [postmaster@km30701-02.keymachine.de](w/relay/4A3B874F0187F2CF0DA3C8F76063B070F9F7A14F)                                                           |        0.01 |      0.02 |       0    |         1 | 2024-10-07   |
| 1283 | [bf two zero nine @mailbox.org](w/relay/58B81035FC28AACA8F0E85E46C8EBAD7FCFA8404)                                                                 |        0.01 |      0.02 |       0    |         1 | 2024-01-22   |
| 1284 | [620562B7](w/relay/620562B7EA252030D579134EDC5045BA83C5F10D)                                                                                      |        0.01 |      0.02 |       0    |         1 | 2024-01-25   |
| 1285 | [MIYOP @tutanota.de](w/relay/9EE1970E1AD558CF0F297537E32A449EB740CB9D)                                                                            |        0.01 |      0.02 |       0    |         1 | 2024-01-16   |
| 1286 | [B1B687C3](w/relay/B1B687C3C4EF46249D638DCE77DDC7AAA39F2996)                                                                                      |        0.01 |      0.02 |       0    |         1 | 2022-02-02   |
| 1287 | [francois &lt; tor AT zof.sh&gt;](w/relay/D9C55AC5549BF4940BE0ABBBE0E34CCC8D6D06E5)                                                               |        0.01 |      0.02 |       0    |         1 | 2021-05-18   |
| 1288 | [flowerstotheworld at proton dot me](w/relay/DAB938592E18820E54E50FE136171613125F4885)                                                            |        0.01 |      0.02 |       0    |         1 | 2025-01-14   |
| 1289 | [your@e-mail](w/relay/3CFA3F6B33AD08D42C20EADE313E43E79D97FCF5)                                                                                   |        0.01 |      0    |       0.01 |         1 | 2023-02-23   |
| 1290 | [0C9B3C68](w/relay/0C9B3C686421C5A8C20BAA0D7369CD929F43A174)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2013-10-21   |
| 1291 | [14080AF1](w/relay/14080AF1608D3099553AEBC58FBFB695D3314253)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-06-02   |
| 1292 | [4096R/1EC9B6F7 baloonasTORrelay &lt;baloona at baloon](w/relay/10D219897E4F2594AF1EC01C414C2E3754ABA5C8)                                         |        0.01 |      0    |       0.01 |         1 | 2021-01-30   |
| 1293 | [toroperator1776@protonmail.com](w/relay/1C7D71A2581DE79C5CFC4ED1FF75D5BE30F01BB7)                                                                |        0.01 |      0    |       0.01 |         1 | 2019-03-20   |
| 1294 | [2DFCA202](w/relay/2DFCA202F13A90F91A820B4C3321FC847E269484)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2022-06-02   |
| 1295 | [tor@eerie-indiana.uk](w/relay/2F7156F433D46BF41338068B3D48DE39877B3D0F)                                                                          |        0.01 |      0    |       0    |         1 | 2025-01-08   |
| 1296 | [42BF33B3](w/relay/42BF33B3CEBF6ED91A6A267818CC73D7E988F31F)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2020-12-29   |
| 1297 | [436F432D](w/relay/436F432DA1A497234471A0870555097957400091)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-11-18   |
| 1298 | [45418A62](w/relay/45418A624C233F1831797A7A5B5DDB083864594B)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2023-02-25   |
| 1299 | [Alessandro Greco &lt;alessandro DOT greco DOT 1 AT pr](w/relay/47B72187844C00AA5D524415E52E3BE81E63056B)                                         |        0.01 |      0    |       0.01 |         1 | 2024-02-02   |
| 1300 | [kybersenko@mailfence.com](w/relay/48763AFDDCA440443630E9D2041C7B5DD9DB1E6A)                                                                      |        0.01 |      0    |       0    |         1 | 2025-01-16   |
| 1301 | [507AD463](w/relay/507AD463D241926A857D600EA4C3D490D0917FD0)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-19   |
| 1302 | [relay runner8@riseup.net](w/relay/4B0E7A0210A75278C4058A6F947369EBF27791A3)                                                                      |        0.01 |      0    |       0    |         1 | 2023-01-18   |
| 1303 | [trnf AT posteo DOT pm](w/relay/5312D9D6076D15962AFC0E4A834E8F6B9EAA531D)                                                                         |        0.01 |      0    |       0.01 |         1 | 2025-01-06   |
| 1304 | [57D02580](w/relay/57D02580B8A9BE634B729F4D5BE429B61930BF1E)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-03-23   |
| 1305 | [mckillershappyplace@proton.me](w/relay/C68BF67E4C14E0850F6DC3A3202E70927B0256E3)                                                                 |        0.01 |      0    |       0    |         1 | 2024-01-22   |
| 1306 | [torrelaysaregreat@gmail.com xmr:84czj1u2Q4dJ7bzf41](w/relay/6FBA9F4455D25F096401DCEE6CB0D9A21F8DAABF)                                            |        0.01 |      0    |       0.01 |         1 | 2024-09-17   |
| 1307 | [72270EB5](w/relay/72270EB58EDEBE727AA29E67417628DBCE889FAE)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1308 | [Ragga Muffin &lt;contact AT raggamuffin dot org&gt;](w/relay/757F4A12701ACD73A5352054EA4F357CC4B44765)                                           |        0.01 |      0    |       0    |         1 | 2022-05-23   |
| 1309 | [81E8A4F5](w/relay/81E8A4F52F14178E840349FAF92C97AC998DB326)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-11-04   |
| 1310 | [gorlock@gmx.net](w/relay/79C674E6C1AC90687CCCF644D24C17AC1E535A3C)                                                                               |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1311 | [82798874](w/relay/827988742048E7FAA1AE88F3089EE8DCC1139D91)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-03-28   |
| 1312 | [chinquapin single underscore no spaces kype aatt s](w/relay/872108C52C52CC10217A351C883E991AEDF7C470)                                            |        0.01 |      0    |       0.01 |         1 | 2020-09-30   |
| 1313 | [f89g65f21@national.shitposting.agency](w/relay/87B3557F3E792217E2BC4E9923EACA4AEC5BA9C3)                                                         |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1314 | [9BA1289C](w/relay/9BA1289CDCFD907B8D40A8AB12F36BE620DD4085)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1315 | [95AA1C2E](w/relay/95AA1C2E49850B25AFF92E08E1F6C93AD1629C31)                                                                                      |        0.01 |      0    |       0    |         1 | 2022-07-02   |
| 1316 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/9AAB8E74CA1D88F1649B33B8C3CD58F3BF522663)                                             |        0.01 |      0    |       0.01 |         1 | 2024-03-04   |
| 1317 | [EMTY &lt;emty.pro AT proton&gt;](w/relay/9D7B2AE5779BA88FD25D828E2CFCBEAFF5C37951)                                                               |        0.01 |      0    |       0.01 |         1 | 2024-09-20   |
| 1318 | [trinity.fr.eu.org](w/relay/A8503903F97FF27F5D1C3CA38817329F581925E6)                                                                             |        0.01 |      0    |       0.01 |         1 | 2020-06-12   |
| 1319 | [BAD367BA](w/relay/BAD367BA226F2BA8A616F53C2DBDC2471B50DB70)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2025-01-03   |
| 1320 | [DAABB04E](w/relay/DAABB04E4E3336B336B2523D5448DA8B0A43BD7A)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-01-22   |
| 1321 | [A8F9764C rubefeli &lt;&quot;relay nickname&quot; AT pm.me&gt;](w/relay/C0E4C6914B7C008D550E739D80BF2C3F51C909B2)                                 |        0.01 |      0    |       0.01 |         1 | 2022-12-29   |
| 1322 | [tor-relay@vaw-valentin.de](w/relay/C2F3631B1386FD7BA5227B28783315CD52EB1526)                                                                     |        0.01 |      0    |       0.01 |         1 | 2024-10-12   |
| 1323 | [torrelay at vonkuenheim dot de](w/relay/E14B30A83FF80C576B2EC0F2C8A5F29D41B8DC8E)                                                                |        0.01 |      0    |       0.01 |         1 | 2019-03-20   |
| 1324 | [skynova7421@proton.me](w/relay/E1916EBFB69AB4D432EAF1D2FCB9F413704D3631)                                                                         |        0.01 |      0    |       0.01 |         1 | 2025-01-15   |
| 1325 | [aestetium@protonmail.com](w/relay/E1B8239725A8886B8662B7047DEDD9C6B0D8AE45)                                                                      |        0.01 |      0    |       0.01 |         1 | 2023-04-06   |
| 1326 | [C89976F4](w/relay/C89976F41351B3F0CDA25C385B41ED26A276579A)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2023-03-09   |
| 1327 | [TRFI&gt; torrelayfi gmail](w/relay/CD6E8C548704F4CE544CD71365D46F110518FBED)                                                                     |        0.01 |      0    |       0    |         1 | 2019-07-28   |
| 1328 | [tor AT r-36 D0T net](w/relay/CE71B81414D7E0C379B5882324B7222DA4B6863F)                                                                           |        0.01 |      0    |       0    |         1 | 2024-03-01   |
| 1329 | [jjaytehjetplane@gmail.com](w/relay/D2F4DAC5918BB082A5CFAC5275B29FAC9B399B2B)                                                                     |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1330 | [ChocolateIceCream Admin &lt;ChocolateIceCream.Admin@f](w/relay/DDDB2EE03597B584684DF08FB6981FE5EF1FFBB5)                                         |        0.01 |      0    |       0    |         1 | 2024-10-20   |
| 1331 | [E02A46C0](w/relay/E02A46C053ABE0A69E39268307C96228425BCE27)                                                                                      |        0.01 |      0    |       0    |         1 | 2024-11-22   |
| 1332 | [Tor Operator &lt;3a2f709c-777e-4c9d-9039-1661cc92e083](w/relay/EDB29CA8E8D01B019FEE9BD075BF0662926D87DC)                                         |        0.01 |      0    |       0.01 |         1 | 2025-01-05   |
| 1333 | [email:torproxy protonmail.com proof:uri-rsa abuse](w/relay/F98CE40031795D3704365019EA9F8AC56AE2994B)                                             |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1334 | [tor@53c70r.de](w/relay/FA561E534DDDE63830FA0B0A484235ED23BB27A3)                                                                                 |        0.01 |      0    |       0.01 |         1 | 2020-12-19   |
| 1335 | [aeon@oppai](w/relay/FA6BF9C6F15D6894A4A42F5DA5D54626F5ABA624)                                                                                    |        0.01 |      0    |       0    |         1 | 2024-06-10   |
| 1336 | [alissastranger003@firemail.de](w/family/41813acbe6e8c1a51a5c04bfe0018e2e59a05afcca5ce9e66f259dfbf496ae10)                                        |        0.01 |      0    |       0.01 |         2 | 2025-01-10   |
| 1337 | [wowgreenman proton](w/family/371a7cd7555138bc65a057012c58db941c7c09fa848ef57189b53d873bfa1cb2)                                                   |        0.01 |      0    |       0    |         2 | 2025-01-20   |
| 1338 | [jingojngo@gmail.com](w/family/d1de3a542de6090eb8734f1b76cc94fab5477b8f735eaf791a4dff05c1be0bcb)                                                  |        0.01 |      0    |       0    |         8 | 2022-06-22   |
| 1339 | [3FB88013](w/family/08bf087c7bd8ec4b9d68c864b5c87e2d9e1c3786eb0fdc08f7279a5458872c40)                                                             |        0.01 |      0    |       0.01 |         2 | 2024-01-28   |
| 1340 | [tor106 &lt;tor106 AT ip-connect dot info&gt;](w/family/59006a23ae59bc2c1c741eb365e9454c43d0cdca3d8fb862eee8cd6c3b293480)                         |        0.01 |      0    |       0.01 |         4 | 2024-01-22   |
| 1341 | [Random Person &lt;tor AT conti dash usa dot net&gt;](w/family/339768477452d31456c3ddb50acbbd9abf09d5a7785019be1056cb214c6807b4)                  |        0.01 |      0    |       0.01 |         2 | 2020-12-19   |
| 1342 | [letsdoit &lt;letsdoit@gmx-topmail.de&gt;](w/family/18249c31888b063b431f845a68db3a69bf0cbe4d6ad5f128cd455f7400d5d296)                             |        0.01 |      0    |       0.01 |         4 | 2021-03-19   |
| 1343 | [12961130](w/family/06fcf2a532049653542d5965c6686710fe12ca4bc2988e47ef43300085af7bf8)                                                             |        0.01 |      0    |       0.01 |         2 | 2022-04-18   |
| 1344 | [8EED46FF](w/family/5eab3ce14318f2ce3234cc1d12b21ec6743bd70b7fbd7d626d71c83ff72569bc)                                                             |        0.01 |      0    |       0.01 |         2 | 2024-03-19   |
| 1345 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/22CDC8DE6BE8A6E6ED4A9FADF66740B8F1A29DE0)                                             |        0.01 |      0.03 |       0    |         1 | 2024-01-22   |
| 1346 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/5AB3131D0B48E66C6770FB8E7BBA991D4A4F7D59)                                             |        0.01 |      0.03 |       0    |         1 | 2024-01-22   |
| 1347 | [url:relayon.org proof:uri-rsa abuse:abuse relayon](w/relay/C028378B070FC72B2AB9E5C93F6E292D841B9EAC)                                             |        0.01 |      0.03 |       0    |         1 | 2024-01-21   |
| 1348 | [0xD5792C4C8C6F8DE8377949D1F48380B2EC8F9449 Tor Ope](w/relay/2A36005A811C8B420F380D67C4A9D630655F0900)                                            |        0.01 |      0.02 |       0    |         1 | 2019-02-18   |
| 1349 | [emeraldonion.org](w/relay/686486E748AA8C360A57E81E4ED915479740AF61)                                                                              |        0.01 |      0.02 |       0    |         1 | 2024-07-26   |
| 1350 | [a-n-o-n-y-m-e.net](w/relay/6F6CE59AC456500E505D82AF09ADFC583022DB87)                                                                             |        0.01 |      0.02 |       0    |         1 | 2024-01-22   |
| 1351 | [&lt;c4t2816 at protonmail . ch&gt;](w/relay/90668E0C9E0E46E017D7D8FB842A2D23E9004E84)                                                            |        0.01 |      0.02 |       0    |         1 | 2023-06-29   |
| 1352 | [9C9B2A36](w/relay/9C9B2A363EA04E554D73CC8FBAC157EC81F41AEE)                                                                                      |        0.01 |      0.02 |       0    |         1 | 2023-06-09   |
| 1353 | [&lt; loik93 @ mail 2 &gt; dot co](w/relay/99317933558461828D54706B64752830448EA124)                                                              |        0.01 |      0.02 |       0    |         1 | 2024-12-30   |
| 1354 | [A7F8FBDC](w/relay/A7F8FBDCB5D91093E6AFCD6480D48A97A24A5B71)                                                                                      |        0.01 |      0.02 |       0    |         1 | 2024-03-16   |
| 1355 | [mbox: skylark host: protonmail dot com](w/relay/00240ECB2B535AA4C1E1874D744DFA6AF2E5E941)                                                        |        0.01 |      0    |       0.01 |         1 | 2020-08-28   |
| 1356 | [servicetor@nexticom.net](w/relay/00B57BF614F7ED3051073B5D4526FF0B23AF217B)                                                                       |        0.01 |      0    |       0.01 |         1 | 2019-11-22   |
| 1357 | [014BD096](w/relay/014BD09636373B78CC28BA70E36C7190E3DE236A)                                                                                      |        0.01 |      0    |       0    |         1 | 2019-07-22   |
| 1358 | [02264CEE](w/relay/02264CEE8E7D062A910747A7F5D13B16766076D6)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-03-11   |
| 1359 | [laser chef proton me](w/relay/3CADFF1E426C41699887B48EFEA375A81E888E3C)                                                                          |        0.01 |      0    |       0.01 |         1 | 2024-01-21   |
| 1360 | [katze@kunfoo.org](w/relay/09BFE6A362D2CE435C45F99B56171B6DA486D0F1)                                                                              |        0.01 |      0    |       0.01 |         1 | 2022-02-23   |
| 1361 | [0C4F1583](w/relay/0C4F1583423B58DE05BF8261429F05639FE2C5A3)                                                                                      |        0.01 |      0    |       0    |         1 | 2025-01-03   |
| 1362 | [bundesgebaermutter.ddnss.eu](w/relay/15841A96CA5C1171985A9565BF7CDDFE2BF8E91E)                                                                   |        0.01 |      0    |       0    |         1 | 2016-08-09   |
| 1363 | [13CE18FD](w/relay/13CE18FDA95C3F628B2D1772030C925B7F716BD7)                                                                                      |        0.01 |      0    |       0    |         1 | 2023-04-19   |
| 1364 | [Random Person &lt;my-tor-jitsi AT laryllian dot de&gt;](w/relay/11EA7F8A581D7BCD1F77ED5B7526A0B92B003A87)                                        |        0.01 |      0    |       0.01 |         1 | 2022-03-02   |
| 1365 | [limoneneis.de](w/relay/0E2F20AA0DBC87C255640E0F4F415B14694DF7A5)                                                                                 |        0.01 |      0    |       0.01 |         1 | 2022-01-26   |
| 1366 | [arpsel.ws](w/relay/1D1D23F156944855E0A5FE06E99DA408EED5AE6B)                                                                                     |        0.01 |      0    |       0.01 |         1 | 2023-06-21   |
| 1367 | [ps-tor-operators at listen.informatik.kit.edu](w/relay/2C164169C508C104985551D19D6F76652DC184A6)                                                 |        0.01 |      0    |       0.01 |         1 | 2023-08-02   |
| 1368 | [&lt;gamerik AT protonmail dot com&gt;](w/relay/2862BFB61695B5FEC6E66AC9EA60151570460D2E)                                                         |        0.01 |      0    |       0    |         1 | 2024-02-03   |
| 1369 | [jimbo263@fastmail.com](w/relay/35335AB58392102637D786641333C7D5DFAC9869)                                                                         |        0.01 |      0    |       0.01 |         1 | 2022-08-31   |
| 1370 | [ziplock &lt;ziplock@riseup.net&gt;](w/relay/38B6C305C159F03E56082F6D6B752516B1040008)                                                            |        0.01 |      0    |       0.01 |         1 | 2024-06-05   |
| 1371 | [4226020F](w/relay/4226020F016082390541440612B24C2228EE6E7B)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2024-02-18   |
| 1372 | [kleft &lt;kleft AT riseup dot net&gt;](w/relay/3F25A8A8070DCCEB7DC9567EED7AA993EEA580B1)                                                         |        0.01 |      0    |       0.01 |         1 | 2024-03-03   |
| 1373 | [Martin Kroell &lt;martin at kroell dot net&gt;](w/relay/44DF1007B545B4D8057F279025EBB33CF99BE227)                                                |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1374 | [Arjen &lt;2cc54472a9@sinenomine.email&gt;](w/relay/4E8FCF9D0C137BE95052B1A98DD317F5F9DB74A9)                                                     |        0.01 |      0    |       0    |         1 | 2022-08-21   |
| 1375 | [hawk at swiss-enigma dot ch](w/relay/5495F0435963D526BFD303120D0BEC72363842F6)                                                                   |        0.01 |      0    |       0.01 |         1 | 2022-09-20   |
| 1376 | [&lt;sinstranger@proton.me&gt;](w/relay/6B16F05645346F795DA66668E2F45DB04F240351)                                                                 |        0.01 |      0    |       0.01 |         1 | 2024-11-20   |
| 1377 | [Random Person &lt;pitime2038 AT gmail dot com&gt;](w/relay/675EB5F943842126CB34B805F6BDC888B81F8E70)                                             |        0.01 |      0    |       0.01 |         1 | 2024-04-17   |
| 1378 | [vstor@foldr.org](w/relay/6CD04D67F68F65C3C872DA0C8C367B7DB09EC895)                                                                               |        0.01 |      0    |       0.01 |         1 | 2022-10-30   |
| 1379 | [admin@mnlab.xyz](w/relay/6D5DA44B6648612D9CDFF8B69D640D86EFA38203)                                                                               |        0.01 |      0    |       0.01 |         1 | 2021-12-24   |
| 1380 | [solitvde@proton.me](w/relay/6DEAB610DCE74BF8F95568F9C6616C5442B6B62E)                                                                            |        0.01 |      0    |       0    |         1 | 2024-09-06   |
| 1381 | [T0rNode555Nose koq@protonmail.com](w/relay/7712A1AC21D4B96E2773F4C8F97962E304EC7628)                                                             |        0.01 |      0    |       0.01 |         1 | 2021-09-05   |
| 1382 | [postmaster@yolovision-inc.com](w/relay/831AA2AD749BB28CEC9F75A744F36D0621E4751D)                                                                 |        0.01 |      0    |       0.01 |         1 | 2024-01-21   |
| 1383 | [your@email.com](w/relay/B45A9DDE16C7B8234C68AE02F4BFDB18CAB9C029)                                                                                |        0.01 |      0    |       0.01 |         1 | 2024-06-30   |
| 1384 | [AB62ED1A](w/relay/AB62ED1A87A54F4193FCEEC587CB991399FADFBD)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2023-03-03   |
| 1385 | [AFEAF3A9](w/relay/AFEAF3A9E0DB1D837BE8FF1983BA0C65A3E71D73)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2022-07-12   |
| 1386 | [Admin &lt;causes.beretta0c@icloud.com&gt;](w/relay/DA3FD24EDEA501C7133307CA73E991AC5B1D76BF)                                                     |        0.01 |      0    |       0.01 |         1 | 2024-06-16   |
| 1387 | [Web Master &lt;tor AT torieshavefuckedthe dot uk&gt;](w/relay/C18757E0193FE45E25E85B62CBC4E22A72FBF879)                                          |        0.01 |      0    |       0    |         1 | 2024-03-02   |
| 1388 | [tor relay.7razv@aleeas.com](w/relay/C29621EBA9B52A1C26FA2059D45FB925EF4A6F18)                                                                    |        0.01 |      0    |       0.01 |         1 | 2024-07-21   |
| 1389 | [Decio &lt;decio@decio.eu&gt;](w/relay/E459E02374D0385D2E2515CBBE707EA208966BCF)                                                                  |        0.01 |      0    |       0.01 |         1 | 2019-02-18   |
| 1390 | [4b02f3f8327468277442dd4765d8494b5f453a64 Admin &lt;ad](w/relay/FF929A01FB58B8988E9AD7A75DE8C414486A82EB)                                         |        0.01 |      0    |       0.01 |         1 | 2021-06-27   |
| 1391 | [tor-relay38493016504204532@proton.me](w/relay/D7E1846EBE9B4F2E3359B3768035C9184E8F470D)                                                          |        0.01 |      0    |       0.01 |         1 | 2024-12-27   |
| 1392 | [phantomwave at protonmail dot com](w/relay/E7A3DA42BCA86430F089DD32C3FDA33534E76F19)                                                             |        0.01 |      0    |       0.01 |         1 | 2021-06-27   |
| 1393 | [John Doe &lt;webmaster aT krypta d0t net&gt;](w/relay/E612306325AE03F0C82C290ACAFB8C724A8B5B91)                                                  |        0.01 |      0    |       0.01 |         1 | 2021-02-07   |
| 1394 | [Tor Contact Radboud CS &lt;tor-relay@cs.ru.nl&gt;](w/relay/F4F18711CD684B6BBE8DFDF5F6F1043D43BDD7E3)                                             |        0.01 |      0    |       0.01 |         1 | 2024-02-12   |
| 1395 | [F05114B2](w/relay/F05114B22E66D08581B5936C646F62649485D879)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2023-04-02   |
| 1396 | [F318BE2B](w/relay/F318BE2B5B5BB72F3140FE37A337FC8F233C977C)                                                                                      |        0.01 |      0    |       0.01 |         1 | 2025-01-10   |

<div class="datatable-end"></div>

## Autonomous Systems by CW Fraction

<div class="datatable-begin"></div>

|     | AS Name                                                                                                                                                                             |   CW Fraction(%) |   Guard(%) |   Exit(%) |   #Relays |
|----:|:------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------:|-----------:|----------:|----------:|
|   0 | [Hetzner Online GmbH](w/as_number/AS24940) [H](https://bgp.he.net/AS24940) [R](https://stat.ripe.net/AS24940)                                                                       |            10.74 |      16.63 |      0    |       372 |
|   1 | [Stiftung Erneuerbare Freiheit](w/as_number/AS60729) [H](https://bgp.he.net/AS60729) [R](https://stat.ripe.net/AS60729)                                                             |            10.35 |       4.25 |     23.04 |       389 |
|   2 | [OVH SAS](w/as_number/AS16276) [H](https://bgp.he.net/AS16276) [R](https://stat.ripe.net/AS16276)                                                                                   |             8.42 |      13.15 |      1.24 |       520 |
|   3 | [SURF B.V.](w/as_number/AS1101) [H](https://bgp.he.net/AS1101) [R](https://stat.ripe.net/AS1101)                                                                                    |             7.9  |       1.77 |     20.41 |       290 |
|   4 | [1337 Services GmbH](w/as_number/AS210558) [H](https://bgp.he.net/AS210558) [R](https://stat.ripe.net/AS210558)                                                                     |             4.82 |       3.41 |      8.03 |       464 |
|   5 | [netcup GmbH](w/as_number/AS197540) [H](https://bgp.he.net/AS197540) [R](https://stat.ripe.net/AS197540)                                                                            |             4.73 |       6.1  |      2.1  |       293 |
|   6 | [IONOS SE](w/as_number/AS8560) [H](https://bgp.he.net/AS8560) [R](https://stat.ripe.net/AS8560)                                                                                     |             3.32 |       4.9  |      0    |       206 |
|   7 | [Foundation for Applied Privacy](w/as_number/AS208323) [H](https://bgp.he.net/AS208323) [R](https://stat.ripe.net/AS208323)                                                         |             2.56 |       0    |      7.68 |       104 |
|   8 | [FranTech Solutions](w/as_number/AS53667) [H](https://bgp.he.net/AS53667) [R](https://stat.ripe.net/AS53667)                                                                        |             1.88 |       0.82 |      3.81 |       206 |
|   9 | [SCALEWAY S.A.S.](w/as_number/AS12876) [H](https://bgp.he.net/AS12876) [R](https://stat.ripe.net/AS12876)                                                                           |             1.75 |       2.78 |      0.15 |        85 |
|  10 | [F3 Netze e.V.](w/as_number/AS205100) [H](https://bgp.he.net/AS205100) [R](https://stat.ripe.net/AS205100)                                                                          |             1.75 |       0.45 |      4.36 |        24 |
|  11 | [Berdiev Ruslan Mukhabatovich](w/as_number/AS214576) [H](https://bgp.he.net/AS214576) [R](https://stat.ripe.net/AS214576)                                                           |             1.7  |       0.74 |      3.59 |        80 |
|  12 | [QuxLabs AB](w/as_number/AS214503) [H](https://bgp.he.net/AS214503) [R](https://stat.ripe.net/AS214503)                                                                             |             1.04 |       0.19 |      2.74 |        80 |
|  13 | [The Infrastructure Group B.V.](w/as_number/AS60404) [H](https://bgp.he.net/AS60404) [R](https://stat.ripe.net/AS60404)                                                             |             0.95 |       0.27 |      2.14 |        60 |
|  14 | [EVANZO e-commerce GmbH](w/as_number/AS42730) [H](https://bgp.he.net/AS42730) [R](https://stat.ripe.net/AS42730)                                                                    |             0.94 |       1.48 |      0    |        36 |
|  15 | [ColocationX Ltd.](w/as_number/AS208046) [H](https://bgp.he.net/AS208046) [R](https://stat.ripe.net/AS208046)                                                                       |             0.94 |       1.12 |      0.69 |        42 |
|  16 | [WIIT AG](w/as_number/AS24961) [H](https://bgp.he.net/AS24961) [R](https://stat.ripe.net/AS24961)                                                                                   |             0.76 |       1.26 |      0    |        35 |
|  17 | [FlokiNET ehf](w/as_number/AS200651) [H](https://bgp.he.net/AS200651) [R](https://stat.ripe.net/AS200651)                                                                           |             0.74 |       0.16 |      1.89 |        70 |
|  18 | [Init7 Switzerland Ltd.](w/as_number/AS13030) [H](https://bgp.he.net/AS13030) [R](https://stat.ripe.net/AS13030)                                                                    |             0.73 |       1.03 |      0    |        30 |
|  19 | [Swisscom Schweiz AG](w/as_number/AS3303) [H](https://bgp.he.net/AS3303) [R](https://stat.ripe.net/AS3303)                                                                          |             0.73 |       0.95 |      0    |        17 |
|  20 | [FEELB SARL](w/as_number/AS207992) [H](https://bgp.he.net/AS207992) [R](https://stat.ripe.net/AS207992)                                                                             |             0.71 |       0.9  |      0    |        48 |
|  21 | [M247 Europe SRL](w/as_number/AS9009) [H](https://bgp.he.net/AS9009) [R](https://stat.ripe.net/AS9009)                                                                              |             0.62 |       0.97 |      0.11 |        45 |
|  22 | [AEZA INTERNATIONAL LTD](w/as_number/AS210644) [H](https://bgp.he.net/AS210644) [R](https://stat.ripe.net/AS210644)                                                                 |             0.56 |       0.88 |      0.01 |        44 |
|  23 | [Oracle Corporation](w/as_number/AS31898) [H](https://bgp.he.net/AS31898) [R](https://stat.ripe.net/AS31898)                                                                        |             0.56 |       0.73 |      0    |       153 |
|  24 | [KeFF Networks Ltd](w/as_number/AS41281) [H](https://bgp.he.net/AS41281) [R](https://stat.ripe.net/AS41281)                                                                         |             0.49 |       0.12 |      1.23 |        26 |
|  25 | [B2 Net Solutions Inc.](w/as_number/AS55286) [H](https://bgp.he.net/AS55286) [R](https://stat.ripe.net/AS55286)                                                                     |             0.48 |       0.81 |      0    |        42 |
|  26 | [Contabo GmbH](w/as_number/AS51167) [H](https://bgp.he.net/AS51167) [R](https://stat.ripe.net/AS51167)                                                                              |             0.48 |       0.56 |      0.24 |        71 |
|  27 | [Foreningen for digitala fri- och rattigheter](w/as_number/AS198093) [H](https://bgp.he.net/AS198093) [R](https://stat.ripe.net/AS198093)                                           |             0.47 |       0.12 |      1.17 |        33 |
|  28 | [RWTH Aachen University](w/as_number/AS47610) [H](https://bgp.he.net/AS47610) [R](https://stat.ripe.net/AS47610)                                                                    |             0.45 |       0.77 |      0    |         9 |
|  29 | [GLOBAL CONNECTIVITY SOLUTIONS LLP](w/as_number/AS215540) [H](https://bgp.he.net/AS215540) [R](https://stat.ripe.net/AS215540)                                                      |             0.44 |       0.63 |      0.15 |        39 |
|  30 | [No ACK Group Holding AB](w/as_number/AS30893) [H](https://bgp.he.net/AS30893) [R](https://stat.ripe.net/AS30893)                                                                   |             0.44 |       0.11 |      1.11 |        26 |
|  31 | [default gateway UG haftungsbeschraenkt](w/as_number/AS206236) [H](https://bgp.he.net/AS206236) [R](https://stat.ripe.net/AS206236)                                                 |             0.43 |       0.74 |      0    |         8 |
|  32 | [WorldStream B.V.](w/as_number/AS49981) [H](https://bgp.he.net/AS49981) [R](https://stat.ripe.net/AS49981)                                                                          |             0.42 |       0.5  |      0    |        17 |
|  33 | [dataforest GmbH](w/as_number/AS58212) [H](https://bgp.he.net/AS58212) [R](https://stat.ripe.net/AS58212)                                                                           |             0.4  |       0.69 |      0    |         7 |
|  34 | [LeaseWeb Netherlands B.V.](w/as_number/AS60781) [H](https://bgp.he.net/AS60781) [R](https://stat.ripe.net/AS60781)                                                                 |             0.38 |       0.49 |      0.21 |        24 |
|  35 | [Ferdinand Zink trading as Tube-Hosting](w/as_number/AS49581) [H](https://bgp.he.net/AS49581) [R](https://stat.ripe.net/AS49581)                                                    |             0.37 |       0.64 |      0    |         6 |
|  36 | [ZONER a.s.](w/as_number/AS34222) [H](https://bgp.he.net/AS34222) [R](https://stat.ripe.net/AS34222)                                                                                |             0.35 |       0.57 |      0    |        14 |
|  37 | [Private Layer INC](w/as_number/AS51852) [H](https://bgp.he.net/AS51852) [R](https://stat.ripe.net/AS51852)                                                                         |             0.33 |       0.2  |      0.48 |        35 |
|  38 | [KPN B.V.](w/as_number/AS1136) [H](https://bgp.he.net/AS1136) [R](https://stat.ripe.net/AS1136)                                                                                     |             0.32 |       0.5  |      0    |        16 |
|  39 | [Magna Capax Finland Oy](w/as_number/AS203003) [H](https://bgp.he.net/AS203003) [R](https://stat.ripe.net/AS203003)                                                                 |             0.32 |       0.38 |      0    |        23 |
|  40 | [MilkyWan Association](w/as_number/AS2027) [H](https://bgp.he.net/AS2027) [R](https://stat.ripe.net/AS2027)                                                                         |             0.32 |       0.19 |      0.61 |        10 |
|  41 | [Host Europe GmbH](w/as_number/AS21499) [H](https://bgp.he.net/AS21499) [R](https://stat.ripe.net/AS21499)                                                                          |             0.31 |       0.54 |      0    |         8 |
|  42 | [Leaseweb Deutschland GmbH](w/as_number/AS28753) [H](https://bgp.he.net/AS28753) [R](https://stat.ripe.net/AS28753)                                                                 |             0.31 |       0.37 |      0.16 |        17 |
|  43 | [NForce Entertainment B.V.](w/as_number/AS43350) [H](https://bgp.he.net/AS43350) [R](https://stat.ripe.net/AS43350)                                                                 |             0.31 |       0.24 |      0.48 |         5 |
|  44 | [South Park Networks LLC](w/as_number/AS214379) [H](https://bgp.he.net/AS214379) [R](https://stat.ripe.net/AS214379)                                                                |             0.29 |       0.5  |      0    |        12 |
|  45 | [Akamai Technologies, Inc.](w/as_number/AS63949) [H](https://bgp.he.net/AS63949) [R](https://stat.ripe.net/AS63949)                                                                 |             0.29 |       0.18 |      0.12 |       108 |
|  46 | [IELO-LIAZO SERVICES SAS](w/as_number/AS29075) [H](https://bgp.he.net/AS29075) [R](https://stat.ripe.net/AS29075)                                                                   |             0.26 |       0.06 |      0.64 |        16 |
|  47 | [Bahnhof AB](w/as_number/AS8473) [H](https://bgp.he.net/AS8473) [R](https://stat.ripe.net/AS8473)                                                                                   |             0.25 |       0.32 |      0.11 |        17 |
|  48 | [Strato GmbH](w/as_number/AS6724) [H](https://bgp.he.net/AS6724) [R](https://stat.ripe.net/AS6724)                                                                                  |             0.25 |       0.31 |      0    |        15 |
|  49 | [Coolhousing s.r.o.](w/as_number/AS35592) [H](https://bgp.he.net/AS35592) [R](https://stat.ripe.net/AS35592)                                                                        |             0.24 |       0.4  |      0.02 |        11 |
|  50 | [SOLLUTIUM EU Sp z.o.o.](w/as_number/AS43641) [H](https://bgp.he.net/AS43641) [R](https://stat.ripe.net/AS43641)                                                                    |             0.24 |       0.18 |      0.17 |        11 |
|  51 | [Forening for DotSrc](w/as_number/AS210731) [H](https://bgp.he.net/AS210731) [R](https://stat.ripe.net/AS210731)                                                                    |             0.24 |       0.06 |      0.62 |        11 |
|  52 | [Netwerkvereniging Coloclue](w/as_number/AS8283) [H](https://bgp.he.net/AS8283) [R](https://stat.ripe.net/AS8283)                                                                   |             0.23 |       0.26 |      0.18 |        16 |
|  53 | [HIVELOCITY, Inc.](w/as_number/AS29802) [H](https://bgp.he.net/AS29802) [R](https://stat.ripe.net/AS29802)                                                                          |             0.22 |       0.38 |      0    |        37 |
|  54 | [Gigahost AS](w/as_number/AS56655) [H](https://bgp.he.net/AS56655) [R](https://stat.ripe.net/AS56655)                                                                               |             0.22 |       0.38 |      0    |        10 |
|  55 | [Feral.io Ltd](w/as_number/AS200052) [H](https://bgp.he.net/AS200052) [R](https://stat.ripe.net/AS200052)                                                                           |             0.21 |       0.09 |      0    |         5 |
|  56 | [Universal Layer LLC](w/as_number/AS399532) [H](https://bgp.he.net/AS399532) [R](https://stat.ripe.net/AS399532)                                                                    |             0.21 |       0.05 |      0.53 |        30 |
|  57 | [TECHOFF SRV LIMITED](w/as_number/AS48090) [H](https://bgp.he.net/AS48090) [R](https://stat.ripe.net/AS48090)                                                                       |             0.21 |       0.05 |      0.52 |        17 |
|  58 | [Pfcloud UG](w/as_number/AS51396) [H](https://bgp.he.net/AS51396) [R](https://stat.ripe.net/AS51396)                                                                                |             0.2  |       0.29 |      0.09 |         9 |
|  59 | [STARK INDUSTRIES SOLUTIONS LTD](w/as_number/AS44477) [H](https://bgp.he.net/AS44477) [R](https://stat.ripe.net/AS44477)                                                            |             0.2  |       0.23 |      0    |        24 |
|  60 | [Free SAS](w/as_number/AS12322) [H](https://bgp.he.net/AS12322) [R](https://stat.ripe.net/AS12322)                                                                                  |             0.19 |       0.24 |      0    |        24 |
|  61 | [Deutsche Telekom AG](w/as_number/AS3320) [H](https://bgp.he.net/AS3320) [R](https://stat.ripe.net/AS3320)                                                                          |             0.19 |       0.18 |      0    |        82 |
|  62 | [UNMANAGED LTD](w/as_number/AS47890) [H](https://bgp.he.net/AS47890) [R](https://stat.ripe.net/AS47890)                                                                             |             0.19 |       0.05 |      0.49 |        24 |
|  63 | [SABOTAGE LLC](w/as_number/AS61125) [H](https://bgp.he.net/AS61125) [R](https://stat.ripe.net/AS61125)                                                                              |             0.18 |       0.04 |      0.46 |         6 |
|  64 | [Windcloud 4.0 GmbH](w/as_number/AS210226) [H](https://bgp.he.net/AS210226) [R](https://stat.ripe.net/AS210226)                                                                     |             0.17 |       0.29 |      0    |         8 |
|  65 | [Infomaniak Network SA](w/as_number/AS29222) [H](https://bgp.he.net/AS29222) [R](https://stat.ripe.net/AS29222)                                                                     |             0.17 |       0.29 |      0    |         7 |
|  66 | [Vodafone Czech Republic a.s.](w/as_number/AS16019) [H](https://bgp.he.net/AS16019) [R](https://stat.ripe.net/AS16019)                                                              |             0.17 |       0.18 |      0.06 |        20 |
|  67 | [G-Core Labs S.A.](w/as_number/AS202422) [H](https://bgp.he.net/AS202422) [R](https://stat.ripe.net/AS202422)                                                                       |             0.16 |       0.26 |      0    |        13 |
|  68 | [HostSlim B.V.](w/as_number/AS207083) [H](https://bgp.he.net/AS207083) [R](https://stat.ripe.net/AS207083)                                                                          |             0.16 |       0.23 |      0    |        12 |
|  69 | [velia.net Internetdienste GmbH](w/as_number/AS29066) [H](https://bgp.he.net/AS29066) [R](https://stat.ripe.net/AS29066)                                                            |             0.16 |       0.22 |      0    |         5 |
|  70 | [Verein zur Foerderung eines Deutschen Forschungsnetzes e.V.](w/as_number/AS680) [H](https://bgp.he.net/AS680) [R](https://stat.ripe.net/AS680)                                     |             0.16 |       0.2  |      0.12 |         8 |
|  71 | [DigitalOcean, LLC](w/as_number/AS14061) [H](https://bgp.he.net/AS14061) [R](https://stat.ripe.net/AS14061)                                                                         |             0.16 |       0.2  |      0    |        99 |
|  72 | [WEDOS Internet, a.s.](w/as_number/AS197019) [H](https://bgp.he.net/AS197019) [R](https://stat.ripe.net/AS197019)                                                                   |             0.16 |       0.07 |      0.26 |        19 |
|  73 | [Epinatura LLC](w/as_number/AS207656) [H](https://bgp.he.net/AS207656) [R](https://stat.ripe.net/AS207656)                                                                          |             0.16 |       0.06 |      0.2  |        22 |
|  74 | [Obehosting AB](w/as_number/AS42675) [H](https://bgp.he.net/AS42675) [R](https://stat.ripe.net/AS42675)                                                                             |             0.15 |       0.26 |      0    |        11 |
|  75 | [Datasource AG](w/as_number/AS51395) [H](https://bgp.he.net/AS51395) [R](https://stat.ripe.net/AS51395)                                                                             |             0.15 |       0.26 |      0    |         6 |
|  76 | [SURF B.V.](w/as_number/AS1103) [H](https://bgp.he.net/AS1103) [R](https://stat.ripe.net/AS1103)                                                                                    |             0.15 |       0.25 |      0    |         3 |
|  77 | [ALEXHOST SRL](w/as_number/AS200019) [H](https://bgp.he.net/AS200019) [R](https://stat.ripe.net/AS200019)                                                                           |             0.15 |       0.23 |      0    |        32 |
|  78 | [MEVSPACE sp. z o.o.](w/as_number/AS201814) [H](https://bgp.he.net/AS201814) [R](https://stat.ripe.net/AS201814)                                                                    |             0.14 |       0.25 |      0    |         9 |
|  79 | [The Constant Company, LLC](w/as_number/AS20473) [H](https://bgp.he.net/AS20473) [R](https://stat.ripe.net/AS20473)                                                                 |             0.14 |       0.1  |      0    |        60 |
|  80 | [GTHost](w/as_number/AS63023) [H](https://bgp.he.net/AS63023) [R](https://stat.ripe.net/AS63023)                                                                                    |             0.13 |       0.23 |      0    |         9 |
|  81 | [Keyweb AG](w/as_number/AS31103) [H](https://bgp.he.net/AS31103) [R](https://stat.ripe.net/AS31103)                                                                                 |             0.13 |       0.13 |      0.14 |        19 |
|  82 | [Seflow s.r.l.](w/as_number/AS49367) [H](https://bgp.he.net/AS49367) [R](https://stat.ripe.net/AS49367)                                                                             |             0.12 |       0.21 |      0    |         6 |
|  83 | [Odido Netherlands B.V.](w/as_number/AS50266) [H](https://bgp.he.net/AS50266) [R](https://stat.ripe.net/AS50266)                                                                    |             0.12 |       0.21 |      0    |         4 |
|  84 | [IP Volume inc](w/as_number/AS202425) [H](https://bgp.he.net/AS202425) [R](https://stat.ripe.net/AS202425)                                                                          |             0.12 |       0.15 |      0.09 |         4 |
|  85 | [Florian Kolb](w/as_number/AS58087) [H](https://bgp.he.net/AS58087) [R](https://stat.ripe.net/AS58087)                                                                              |             0.12 |       0.1  |      0.16 |         5 |
|  86 | [Internet Magnate Pty Ltd](w/as_number/AS214209) [H](https://bgp.he.net/AS214209) [R](https://stat.ripe.net/AS214209)                                                               |             0.12 |       0.09 |      0.02 |        25 |
|  87 | [The Calyx Institue](w/as_number/AS4224) [H](https://bgp.he.net/AS4224) [R](https://stat.ripe.net/AS4224)                                                                           |             0.12 |       0.03 |      0.31 |        19 |
|  88 | [Fredrik Holmqvist](w/as_number/AS33837) [H](https://bgp.he.net/AS33837) [R](https://stat.ripe.net/AS33837)                                                                         |             0.12 |       0.03 |      0.3  |        10 |
|  89 | [Maximilian Jacobsen](w/as_number/AS206075) [H](https://bgp.he.net/AS206075) [R](https://stat.ripe.net/AS206075)                                                                    |             0.12 |       0.01 |      0.15 |         6 |
|  90 | [Vetenskapsradet / SUNET](w/as_number/AS1653) [H](https://bgp.he.net/AS1653) [R](https://stat.ripe.net/AS1653)                                                                      |             0.11 |       0.2  |      0    |         5 |
|  91 | [SIA VEESP](w/as_number/AS43317) [H](https://bgp.he.net/AS43317) [R](https://stat.ripe.net/AS43317)                                                                                 |             0.11 |       0.19 |      0    |        13 |
|  92 | [Lennart Seitz trading as &quot;ETH-Services&quot;](w/as_number/AS200462) [H](https://bgp.he.net/AS200462) [R](https://stat.ripe.net/AS200462)                                      |             0.11 |       0.19 |      0    |         5 |
|  93 | [Julian Achter](w/as_number/AS215898) [H](https://bgp.he.net/AS215898) [R](https://stat.ripe.net/AS215898)                                                                          |             0.11 |       0.14 |      0.1  |         7 |
|  94 | [ServerAstra Kft.](w/as_number/AS56322) [H](https://bgp.he.net/AS56322) [R](https://stat.ripe.net/AS56322)                                                                          |             0.11 |       0.14 |      0.02 |        10 |
|  95 | [MAXKO d.o.o.](w/as_number/AS211619) [H](https://bgp.he.net/AS211619) [R](https://stat.ripe.net/AS211619)                                                                           |             0.11 |       0.06 |      0.21 |        13 |
|  96 | [hosttech GmbH](w/as_number/AS207143) [H](https://bgp.he.net/AS207143) [R](https://stat.ripe.net/AS207143)                                                                          |             0.1  |       0.18 |      0    |         4 |
|  97 | [24fire GmbH](w/as_number/AS216063) [H](https://bgp.he.net/AS216063) [R](https://stat.ripe.net/AS216063)                                                                            |             0.1  |       0.18 |      0    |         3 |
|  98 | [Telia Company AB](w/as_number/AS3301) [H](https://bgp.he.net/AS3301) [R](https://stat.ripe.net/AS3301)                                                                             |             0.1  |       0.17 |      0    |        11 |
|  99 | [UAB Cherry Servers](w/as_number/AS16125) [H](https://bgp.he.net/AS16125) [R](https://stat.ripe.net/AS16125)                                                                        |             0.1  |       0.17 |      0    |         6 |
| 100 | [Norlys Digital A/S](w/as_number/AS39642) [H](https://bgp.he.net/AS39642) [R](https://stat.ripe.net/AS39642)                                                                        |             0.1  |       0.17 |      0    |         5 |
| 101 | [Forskningsnettet - Danish network for Research and Education](w/as_number/AS1835) [H](https://bgp.he.net/AS1835) [R](https://stat.ripe.net/AS1835)                                 |             0.1  |       0.17 |      0    |         2 |
| 102 | [Scalaxy B.V.](w/as_number/AS58061) [H](https://bgp.he.net/AS58061) [R](https://stat.ripe.net/AS58061)                                                                              |             0.1  |       0.15 |      0.06 |         3 |
| 103 | [Tom Gewiese](w/as_number/AS215365) [H](https://bgp.he.net/AS215365) [R](https://stat.ripe.net/AS215365)                                                                            |             0.1  |       0.14 |      0    |         4 |
| 104 | [ANEXIA Internetdienstleistungs GmbH](w/as_number/AS42473) [H](https://bgp.he.net/AS42473) [R](https://stat.ripe.net/AS42473)                                                       |             0.1  |       0.12 |      0    |         8 |
| 105 | [1984 ehf](w/as_number/AS44925) [H](https://bgp.he.net/AS44925) [R](https://stat.ripe.net/AS44925)                                                                                  |             0.1  |       0.08 |      0.15 |        26 |
| 106 | [Lowhosting services of Davide Gennari](w/as_number/AS212508) [H](https://bgp.he.net/AS212508) [R](https://stat.ripe.net/AS212508)                                                  |             0.1  |       0.04 |      0.21 |         8 |
| 107 | [MivoCloud SRL](w/as_number/AS39798) [H](https://bgp.he.net/AS39798) [R](https://stat.ripe.net/AS39798)                                                                             |             0.09 |       0.15 |      0    |        17 |
| 108 | [BrainStorm Network, Inc](w/as_number/AS136258) [H](https://bgp.he.net/AS136258) [R](https://stat.ripe.net/AS136258)                                                                |             0.09 |       0.14 |      0    |        49 |
| 109 | [HZ Hosting Ltd](w/as_number/AS59711) [H](https://bgp.he.net/AS59711) [R](https://stat.ripe.net/AS59711)                                                                            |             0.09 |       0.14 |      0    |        10 |
| 110 | [UAB &quot;Baltnetos komunikacijos&quot;](w/as_number/AS15440) [H](https://bgp.he.net/AS15440) [R](https://stat.ripe.net/AS15440)                                                   |             0.09 |       0.12 |      0    |        14 |
| 111 | [Verizon Business](w/as_number/AS701) [H](https://bgp.he.net/AS701) [R](https://stat.ripe.net/AS701)                                                                                |             0.09 |       0.11 |      0    |        47 |
| 112 | [MASSIVEGRID LTD](w/as_number/AS49683) [H](https://bgp.he.net/AS49683) [R](https://stat.ripe.net/AS49683)                                                                           |             0.09 |       0.1  |      0    |        14 |
| 113 | [WAIcore Ltd](w/as_number/AS213887) [H](https://bgp.he.net/AS213887) [R](https://stat.ripe.net/AS213887)                                                                            |             0.09 |       0.07 |      0    |         7 |
| 114 | [ESEVEN DevOps GmbH](w/as_number/AS48927) [H](https://bgp.he.net/AS48927) [R](https://stat.ripe.net/AS48927)                                                                        |             0.09 |       0.06 |      0    |         2 |
| 115 | [Trabia SRL](w/as_number/AS43289) [H](https://bgp.he.net/AS43289) [R](https://stat.ripe.net/AS43289)                                                                                |             0.09 |       0.03 |      0.18 |        14 |
| 116 | [SWITCH](w/as_number/AS559) [H](https://bgp.he.net/AS559) [R](https://stat.ripe.net/AS559)                                                                                          |             0.09 |       0.02 |      0.22 |         4 |
| 117 | [Verdina Ltd.](w/as_number/AS201133) [H](https://bgp.he.net/AS201133) [R](https://stat.ripe.net/AS201133)                                                                           |             0.08 |       0.15 |      0    |         5 |
| 118 | [Ikoula Net SAS](w/as_number/AS21409) [H](https://bgp.he.net/AS21409) [R](https://stat.ripe.net/AS21409)                                                                            |             0.08 |       0.14 |      0    |         9 |
| 119 | [IVER NORGE AS](w/as_number/AS49409) [H](https://bgp.he.net/AS49409) [R](https://stat.ripe.net/AS49409)                                                                             |             0.08 |       0.13 |      0    |         4 |
| 120 | [Civil association Init Lab](w/as_number/AS200533) [H](https://bgp.he.net/AS200533) [R](https://stat.ripe.net/AS200533)                                                             |             0.08 |       0.13 |      0    |         2 |
| 121 | [S.C. INFOTECH-GRUP S.R.L.](w/as_number/AS201670) [H](https://bgp.he.net/AS201670) [R](https://stat.ripe.net/AS201670)                                                              |             0.08 |       0.12 |      0.01 |        13 |
| 122 | [IP Connect Inc](w/as_number/AS213373) [H](https://bgp.he.net/AS213373) [R](https://stat.ripe.net/AS213373)                                                                         |             0.08 |       0.11 |      0.04 |         5 |
| 123 | [Oy Crea Nova Hosting Solution Ltd](w/as_number/AS51765) [H](https://bgp.he.net/AS51765) [R](https://stat.ripe.net/AS51765)                                                         |             0.08 |       0.1  |      0    |        20 |
| 124 | [IPAX GmbH](w/as_number/AS44133) [H](https://bgp.he.net/AS44133) [R](https://stat.ripe.net/AS44133)                                                                                 |             0.08 |       0.09 |      0    |         9 |
| 125 | [HostPapa](w/as_number/AS36352) [H](https://bgp.he.net/AS36352) [R](https://stat.ripe.net/AS36352)                                                                                  |             0.08 |       0.03 |      0.05 |        56 |
| 126 | [Association &quot;Gitoyen&quot;](w/as_number/AS20766) [H](https://bgp.he.net/AS20766) [R](https://stat.ripe.net/AS20766)                                                           |             0.08 |       0.02 |      0.2  |         5 |
| 127 | [SkyLink Data Center BV](w/as_number/AS44592) [H](https://bgp.he.net/AS44592) [R](https://stat.ripe.net/AS44592)                                                                    |             0.08 |       0.02 |      0.2  |         4 |
| 128 | [Zencurity ApS](w/as_number/AS57860) [H](https://bgp.he.net/AS57860) [R](https://stat.ripe.net/AS57860)                                                                             |             0.08 |       0.02 |      0.2  |         2 |
| 129 | [IncogNET LLC](w/as_number/AS210630) [H](https://bgp.he.net/AS210630) [R](https://stat.ripe.net/AS210630)                                                                           |             0.08 |       0    |      0.22 |        23 |
| 130 | [RoyaleHosting BV](w/as_number/AS212477) [H](https://bgp.he.net/AS212477) [R](https://stat.ripe.net/AS212477)                                                                       |             0.07 |       0.13 |      0    |         5 |
| 131 | [Telenor Norge AS](w/as_number/AS2119) [H](https://bgp.he.net/AS2119) [R](https://stat.ripe.net/AS2119)                                                                             |             0.07 |       0.12 |      0    |        12 |
| 132 | [BELNET](w/as_number/AS2611) [H](https://bgp.he.net/AS2611) [R](https://stat.ripe.net/AS2611)                                                                                       |             0.07 |       0.12 |      0    |         2 |
| 133 | [Michael Sebastian Schinzel trading as IP-Projects GmbH &amp; Co. KG](w/as_number/AS48314) [H](https://bgp.he.net/AS48314) [R](https://stat.ripe.net/AS48314)                       |             0.07 |       0.11 |      0    |        11 |
| 134 | [Tele2 Sverige AB](w/as_number/AS1257) [H](https://bgp.he.net/AS1257) [R](https://stat.ripe.net/AS1257)                                                                             |             0.07 |       0.11 |      0    |        11 |
| 135 | [Vodafone GmbH](w/as_number/AS3209) [H](https://bgp.he.net/AS3209) [R](https://stat.ripe.net/AS3209)                                                                                |             0.07 |       0.09 |      0    |        43 |
| 136 | [Advin Services LLC](w/as_number/AS206216) [H](https://bgp.he.net/AS206216) [R](https://stat.ripe.net/AS206216)                                                                     |             0.07 |       0.08 |      0.01 |         5 |
| 137 | [Zomro B.V.](w/as_number/AS204601) [H](https://bgp.he.net/AS204601) [R](https://stat.ripe.net/AS204601)                                                                             |             0.07 |       0.08 |      0    |         2 |
| 138 | [Host Sailor Ltd](w/as_number/AS60117) [H](https://bgp.he.net/AS60117) [R](https://stat.ripe.net/AS60117)                                                                           |             0.07 |       0.07 |      0    |         3 |
| 139 | [Atomic Networks LLC](w/as_number/AS399820) [H](https://bgp.he.net/AS399820) [R](https://stat.ripe.net/AS399820)                                                                    |             0.07 |       0.04 |      0.12 |         6 |
| 140 | [Orange S.A.](w/as_number/AS3215) [H](https://bgp.he.net/AS3215) [R](https://stat.ripe.net/AS3215)                                                                                  |             0.07 |       0.04 |      0    |        10 |
| 141 | [Datacamp Limited](w/as_number/AS212238) [H](https://bgp.he.net/AS212238) [R](https://stat.ripe.net/AS212238)                                                                       |             0.07 |       0.03 |      0.05 |         9 |
| 142 | [Privex Inc.](w/as_number/AS210083) [H](https://bgp.he.net/AS210083) [R](https://stat.ripe.net/AS210083)                                                                            |             0.07 |       0.02 |      0.18 |         4 |
| 143 | [Telecom Italia S.p.A.](w/as_number/AS3269) [H](https://bgp.he.net/AS3269) [R](https://stat.ripe.net/AS3269)                                                                        |             0.07 |       0.01 |      0    |        15 |
| 144 | [BlueVPS OU](w/as_number/AS62005) [H](https://bgp.he.net/AS62005) [R](https://stat.ripe.net/AS62005)                                                                                |             0.07 |       0    |      0.04 |        14 |
| 145 | [FAST GEO HOSTING S.R.L.](w/as_number/AS41111) [H](https://bgp.he.net/AS41111) [R](https://stat.ripe.net/AS41111)                                                                   |             0.07 |       0    |      0    |         3 |
| 146 | [Serious Tubes Networks](w/as_number/AS50066) [H](https://bgp.he.net/AS50066) [R](https://stat.ripe.net/AS50066)                                                                    |             0.06 |       0.11 |      0    |         5 |
| 147 | [Bouygues Telecom SA](w/as_number/AS5410) [H](https://bgp.he.net/AS5410) [R](https://stat.ripe.net/AS5410)                                                                          |             0.06 |       0.11 |      0    |         3 |
| 148 | [LIONLINK NETWORKS](w/as_number/AS54098) [H](https://bgp.he.net/AS54098) [R](https://stat.ripe.net/AS54098)                                                                         |             0.06 |       0.1  |      0    |        15 |
| 149 | [MEDIANET INVEST AE](w/as_number/AS200736) [H](https://bgp.he.net/AS200736) [R](https://stat.ripe.net/AS200736)                                                                     |             0.06 |       0.1  |      0    |        12 |
| 150 | [GREEN FLOID LLC](w/as_number/AS59729) [H](https://bgp.he.net/AS59729) [R](https://stat.ripe.net/AS59729)                                                                           |             0.06 |       0.1  |      0    |         8 |
| 151 | [UK Dedicated Servers Limited](w/as_number/AS42831) [H](https://bgp.he.net/AS42831) [R](https://stat.ripe.net/AS42831)                                                              |             0.06 |       0.1  |      0    |         3 |
| 152 | [Collin Schneeweiss trading as Unesty Company](w/as_number/AS211301) [H](https://bgp.he.net/AS211301) [R](https://stat.ripe.net/AS211301)                                           |             0.06 |       0.1  |      0    |         3 |
| 153 | [Fiberby ApS](w/as_number/AS42541) [H](https://bgp.he.net/AS42541) [R](https://stat.ripe.net/AS42541)                                                                               |             0.06 |       0.1  |      0    |         2 |
| 154 | [BornFiber Service Provider ApS](w/as_number/AS24800) [H](https://bgp.he.net/AS24800) [R](https://stat.ripe.net/AS24800)                                                            |             0.06 |       0.1  |      0    |         2 |
| 155 | [IWS NETWORKS LLC](w/as_number/AS199968) [H](https://bgp.he.net/AS199968) [R](https://stat.ripe.net/AS199968)                                                                       |             0.06 |       0.09 |      0.04 |         3 |
| 156 | [Sunrise GmbH](w/as_number/AS6730) [H](https://bgp.he.net/AS6730) [R](https://stat.ripe.net/AS6730)                                                                                 |             0.06 |       0.09 |      0    |         6 |
| 157 | [Cogent Communications](w/as_number/AS174) [H](https://bgp.he.net/AS174) [R](https://stat.ripe.net/AS174)                                                                           |             0.06 |       0.08 |      0.06 |        11 |
| 158 | [SKB Enterprise B.V.](w/as_number/AS64425) [H](https://bgp.he.net/AS64425) [R](https://stat.ripe.net/AS64425)                                                                       |             0.06 |       0.08 |      0    |         2 |
| 159 | [Neterra Ltd.](w/as_number/AS34224) [H](https://bgp.he.net/AS34224) [R](https://stat.ripe.net/AS34224)                                                                              |             0.06 |       0.05 |      0.08 |        14 |
| 160 | [IOMART CLOUD SERVICES LIMITED](w/as_number/AS20860) [H](https://bgp.he.net/AS20860) [R](https://stat.ripe.net/AS20860)                                                             |             0.06 |       0.05 |      0.08 |         3 |
| 161 | [EstNOC OY](w/as_number/AS206804) [H](https://bgp.he.net/AS206804) [R](https://stat.ripe.net/AS206804)                                                                              |             0.06 |       0.03 |      0.11 |         4 |
| 162 | [Aruba S.p.A.](w/as_number/AS31034) [H](https://bgp.he.net/AS31034) [R](https://stat.ripe.net/AS31034)                                                                              |             0.06 |       0.03 |      0    |         2 |
| 163 | [Tetaneutral.net Association declaree](w/as_number/AS197422) [H](https://bgp.he.net/AS197422) [R](https://stat.ripe.net/AS197422)                                                   |             0.06 |       0.01 |      0.17 |         4 |
| 164 | [Nine Internet Solutions AG](w/as_number/AS29691) [H](https://bgp.he.net/AS29691) [R](https://stat.ripe.net/AS29691)                                                                |             0.06 |       0.01 |      0.16 |         3 |
| 165 | [Amazon.com, Inc.](w/as_number/AS16509) [H](https://bgp.he.net/AS16509) [R](https://stat.ripe.net/AS16509)                                                                          |             0.06 |       0    |      0.15 |        23 |
| 166 | [Remote Admin Sp. Z o.o.](w/as_number/AS212663) [H](https://bgp.he.net/AS212663) [R](https://stat.ripe.net/AS212663)                                                                |             0.05 |       0.1  |      0    |         5 |
| 167 | [HOSTKEY B.V.](w/as_number/AS57043) [H](https://bgp.he.net/AS57043) [R](https://stat.ripe.net/AS57043)                                                                              |             0.05 |       0.1  |      0    |         3 |
| 168 | [Freedom Internet BV](w/as_number/AS206238) [H](https://bgp.he.net/AS206238) [R](https://stat.ripe.net/AS206238)                                                                    |             0.05 |       0.09 |      0    |        17 |
| 169 | [TELEFONICA DE ESPANA S.A.U.](w/as_number/AS3352) [H](https://bgp.he.net/AS3352) [R](https://stat.ripe.net/AS3352)                                                                  |             0.05 |       0.09 |      0    |         6 |
| 170 | [Universitaet Stuttgart](w/as_number/AS553) [H](https://bgp.he.net/AS553) [R](https://stat.ripe.net/AS553)                                                                          |             0.05 |       0.09 |      0    |         2 |
| 171 | [Teleservice Bredband Skane AB](w/as_number/AS34244) [H](https://bgp.he.net/AS34244) [R](https://stat.ripe.net/AS34244)                                                             |             0.05 |       0.09 |      0    |         2 |
| 172 | [RCS &amp; RDS SA](w/as_number/AS8708) [H](https://bgp.he.net/AS8708) [R](https://stat.ripe.net/AS8708)                                                                             |             0.05 |       0.08 |      0    |        12 |
| 173 | [Leaseweb USA, Inc.](w/as_number/AS396362) [H](https://bgp.he.net/AS396362) [R](https://stat.ripe.net/AS396362)                                                                     |             0.05 |       0.08 |      0    |         9 |
| 174 | [ISPpro Internet KG](w/as_number/AS35366) [H](https://bgp.he.net/AS35366) [R](https://stat.ripe.net/AS35366)                                                                        |             0.05 |       0.08 |      0    |         8 |
| 175 | [level66.network UG haftungsbeschraenkt](w/as_number/AS56381) [H](https://bgp.he.net/AS56381) [R](https://stat.ripe.net/AS56381)                                                    |             0.05 |       0.08 |      0    |         1 |
| 176 | [AT&amp;T Services, Inc.](w/as_number/AS7018) [H](https://bgp.he.net/AS7018) [R](https://stat.ripe.net/AS7018)                                                                      |             0.05 |       0.07 |      0    |        53 |
| 177 | [Limestone Networks, Inc.](w/as_number/AS46475) [H](https://bgp.he.net/AS46475) [R](https://stat.ripe.net/AS46475)                                                                  |             0.05 |       0.07 |      0    |        26 |
| 178 | [Virtual Systems LLC](w/as_number/AS30860) [H](https://bgp.he.net/AS30860) [R](https://stat.ripe.net/AS30860)                                                                       |             0.05 |       0.06 |      0.04 |         8 |
| 179 | [Elisa Oyj](w/as_number/AS719) [H](https://bgp.he.net/AS719) [R](https://stat.ripe.net/AS719)                                                                                       |             0.05 |       0.06 |      0    |         4 |
| 180 | [23M GmbH](w/as_number/AS47447) [H](https://bgp.he.net/AS47447) [R](https://stat.ripe.net/AS47447)                                                                                  |             0.05 |       0.05 |      0.05 |         7 |
| 181 | [ReliableSite.Net LLC](w/as_number/AS23470) [H](https://bgp.he.net/AS23470) [R](https://stat.ripe.net/AS23470)                                                                      |             0.05 |       0.04 |      0.08 |        26 |
| 182 | [BARTOSZ WASZAK trading as HOSTEAM S.C. TOMASZ GROSZEWSKI BARTOSZ WASZAK LUKASZ GROSZEWSKI](w/as_number/AS51290) [H](https://bgp.he.net/AS51290) [R](https://stat.ripe.net/AS51290) |             0.05 |       0.03 |      0.1  |         3 |
| 183 | [Datasource AG](w/as_number/AS56803) [H](https://bgp.he.net/AS56803) [R](https://stat.ripe.net/AS56803)                                                                             |             0.05 |       0.01 |      0.14 |         2 |
| 184 | [wilhelm.tel GmbH](w/as_number/AS15943) [H](https://bgp.he.net/AS15943) [R](https://stat.ripe.net/AS15943)                                                                          |             0.05 |       0    |      0    |         6 |
| 185 | [Sapinet SAS](w/as_number/AS39421) [H](https://bgp.he.net/AS39421) [R](https://stat.ripe.net/AS39421)                                                                               |             0.05 |       0    |      0    |         2 |
| 186 | [Moustafa Mohamed Mohamed Ahmed Elghoubashi](w/as_number/AS214366) [H](https://bgp.he.net/AS214366) [R](https://stat.ripe.net/AS214366)                                             |             0.04 |       0.08 |      0    |        17 |
| 187 | [SECURED SERVERS LLC](w/as_number/AS19437) [H](https://bgp.he.net/AS19437) [R](https://stat.ripe.net/AS19437)                                                                       |             0.04 |       0.08 |      0    |         9 |
| 188 | [Pe3ny Net s.r.o.](w/as_number/AS48926) [H](https://bgp.he.net/AS48926) [R](https://stat.ripe.net/AS48926)                                                                          |             0.04 |       0.08 |      0    |         1 |
| 189 | [INEA sp. z o.o.](w/as_number/AS13110) [H](https://bgp.he.net/AS13110) [R](https://stat.ripe.net/AS13110)                                                                           |             0.04 |       0.08 |      0    |         1 |
| 190 | [Rica Web Services](w/as_number/AS26832) [H](https://bgp.he.net/AS26832) [R](https://stat.ripe.net/AS26832)                                                                         |             0.04 |       0.07 |      0    |        13 |
| 191 | [Sia Nano IT](w/as_number/AS43513) [H](https://bgp.he.net/AS43513) [R](https://stat.ripe.net/AS43513)                                                                               |             0.04 |       0.07 |      0    |         6 |
| 192 | [Marco Lingl trading as Cyberse GmbH &amp; Co. KG](w/as_number/AS208208) [H](https://bgp.he.net/AS208208) [R](https://stat.ripe.net/AS208208)                                       |             0.04 |       0.07 |      0    |         4 |
| 193 | [UK-2 Limited](w/as_number/AS13213) [H](https://bgp.he.net/AS13213) [R](https://stat.ripe.net/AS13213)                                                                              |             0.04 |       0.07 |      0    |         4 |
| 194 | [BAR Informatik AG](w/as_number/AS25353) [H](https://bgp.he.net/AS25353) [R](https://stat.ripe.net/AS25353)                                                                         |             0.04 |       0.07 |      0    |         1 |
| 195 | [SURF B.V.](w/as_number/AS1102) [H](https://bgp.he.net/AS1102) [R](https://stat.ripe.net/AS1102)                                                                                    |             0.04 |       0.07 |      0    |         1 |
| 196 | [National Infrastructures for Research and Technology S.A.](w/as_number/AS5408) [H](https://bgp.he.net/AS5408) [R](https://stat.ripe.net/AS5408)                                    |             0.04 |       0.06 |      0    |         6 |
| 197 | [EDIS GmbH](w/as_number/AS57169) [H](https://bgp.he.net/AS57169) [R](https://stat.ripe.net/AS57169)                                                                                 |             0.04 |       0.06 |      0    |         5 |
| 198 | [DIGI SPAIN TELECOM S.L.](w/as_number/AS57269) [H](https://bgp.he.net/AS57269) [R](https://stat.ripe.net/AS57269)                                                                   |             0.04 |       0.06 |      0    |         4 |
| 199 | [GamerHost s.r.o.](w/as_number/AS50338) [H](https://bgp.he.net/AS50338) [R](https://stat.ripe.net/AS50338)                                                                          |             0.04 |       0.06 |      0    |         1 |
| 200 | [Nick Bouwhuis](w/as_number/AS202585) [H](https://bgp.he.net/AS202585) [R](https://stat.ripe.net/AS202585)                                                                          |             0.04 |       0.06 |      0    |         1 |
| 201 | [GANDI SAS](w/as_number/AS29169) [H](https://bgp.he.net/AS29169) [R](https://stat.ripe.net/AS29169)                                                                                 |             0.04 |       0.05 |      0    |         4 |
| 202 | [Master Internet s.r.o.](w/as_number/AS24971) [H](https://bgp.he.net/AS24971) [R](https://stat.ripe.net/AS24971)                                                                    |             0.04 |       0.05 |      0    |         4 |
| 203 | [GLOBALCONNECT AS](w/as_number/AS2116) [H](https://bgp.he.net/AS2116) [R](https://stat.ripe.net/AS2116)                                                                             |             0.04 |       0.05 |      0    |         2 |
| 204 | [D-hosting die Rackspace &amp; Connectivity GmbH](w/as_number/AS44716) [H](https://bgp.he.net/AS44716) [R](https://stat.ripe.net/AS44716)                                           |             0.04 |       0.04 |      0.06 |         2 |
| 205 | [Psychz Networks](w/as_number/AS40676) [H](https://bgp.he.net/AS40676) [R](https://stat.ripe.net/AS40676)                                                                           |             0.04 |       0.04 |      0.02 |        23 |
| 206 | [GANDI SAS](w/as_number/AS203476) [H](https://bgp.he.net/AS203476) [R](https://stat.ripe.net/AS203476)                                                                              |             0.04 |       0.03 |      0.03 |         8 |
| 207 | [Orange Polska Spolka Akcyjna](w/as_number/AS5617) [H](https://bgp.he.net/AS5617) [R](https://stat.ripe.net/AS5617)                                                                 |             0.04 |       0.02 |      0    |        11 |
| 208 | [AQUILENET](w/as_number/AS198985) [H](https://bgp.he.net/AS198985) [R](https://stat.ripe.net/AS198985)                                                                              |             0.04 |       0.01 |      0.11 |         4 |
| 209 | [Datashield, Inc.](w/as_number/AS211720) [H](https://bgp.he.net/AS211720) [R](https://stat.ripe.net/AS211720)                                                                       |             0.04 |       0.01 |      0.11 |         1 |
| 210 | [NAV COMMUNICATIONS SRL](w/as_number/AS6718) [H](https://bgp.he.net/AS6718) [R](https://stat.ripe.net/AS6718)                                                                       |             0.04 |       0.01 |      0.1  |         6 |
| 211 | [Greenfiber Internet &amp; Dienste GmbH](w/as_number/AS213281) [H](https://bgp.he.net/AS213281) [R](https://stat.ripe.net/AS213281)                                                 |             0.04 |       0    |      0    |         1 |
| 212 | [Niagara Regional Broadband Networks Limited](w/as_number/AS53486) [H](https://bgp.he.net/AS53486) [R](https://stat.ripe.net/AS53486)                                               |             0.03 |       0.06 |      0    |         9 |
| 213 | [I-SERVERS LTD](w/as_number/AS209641) [H](https://bgp.he.net/AS209641) [R](https://stat.ripe.net/AS209641)                                                                          |             0.03 |       0.06 |      0    |         5 |
| 214 | [DNA Oyj](w/as_number/AS16086) [H](https://bgp.he.net/AS16086) [R](https://stat.ripe.net/AS16086)                                                                                   |             0.03 |       0.06 |      0    |         4 |
| 215 | [Greenhost BV](w/as_number/AS47172) [H](https://bgp.he.net/AS47172) [R](https://stat.ripe.net/AS47172)                                                                              |             0.03 |       0.06 |      0    |         3 |
| 216 | [IP Fiber Inc](w/as_number/AS204615) [H](https://bgp.he.net/AS204615) [R](https://stat.ripe.net/AS204615)                                                                           |             0.03 |       0.06 |      0    |         3 |
| 217 | [Globalhost d.o.o.](w/as_number/AS200698) [H](https://bgp.he.net/AS200698) [R](https://stat.ripe.net/AS200698)                                                                      |             0.03 |       0.06 |      0    |         3 |
| 218 | [Cloud Wall Ltd.](w/as_number/AS58294) [H](https://bgp.he.net/AS58294) [R](https://stat.ripe.net/AS58294)                                                                           |             0.03 |       0.06 |      0    |         2 |
| 219 | [FiberXpress BV](w/as_number/AS57717) [H](https://bgp.he.net/AS57717) [R](https://stat.ripe.net/AS57717)                                                                            |             0.03 |       0.06 |      0    |         1 |
| 220 | [Layer7 Networks GmbH](w/as_number/AS35042) [H](https://bgp.he.net/AS35042) [R](https://stat.ripe.net/AS35042)                                                                      |             0.03 |       0.06 |      0    |         1 |
| 221 | [NovoServe B.V.](w/as_number/AS24875) [H](https://bgp.he.net/AS24875) [R](https://stat.ripe.net/AS24875)                                                                            |             0.03 |       0.06 |      0    |         1 |
| 222 | [w1n ltd](w/as_number/AS42237) [H](https://bgp.he.net/AS42237) [R](https://stat.ripe.net/AS42237)                                                                                   |             0.03 |       0.05 |      0.02 |         7 |
| 223 | [Leaseweb USA, Inc.](w/as_number/AS30633) [H](https://bgp.he.net/AS30633) [R](https://stat.ripe.net/AS30633)                                                                        |             0.03 |       0.05 |      0    |         7 |
| 224 | [SERVERD SAS](w/as_number/AS62000) [H](https://bgp.he.net/AS62000) [R](https://stat.ripe.net/AS62000)                                                                               |             0.03 |       0.05 |      0    |         4 |
| 225 | [SIA RixHost](w/as_number/AS52048) [H](https://bgp.he.net/AS52048) [R](https://stat.ripe.net/AS52048)                                                                               |             0.03 |       0.05 |      0    |         4 |
| 226 | [Serverius Holding B.V.](w/as_number/AS50673) [H](https://bgp.he.net/AS50673) [R](https://stat.ripe.net/AS50673)                                                                    |             0.03 |       0.05 |      0    |         3 |
| 227 | [BOLIGNET-AARHUS F.M.B.A.](w/as_number/AS33796) [H](https://bgp.he.net/AS33796) [R](https://stat.ripe.net/AS33796)                                                                  |             0.03 |       0.05 |      0    |         2 |
| 228 | [Pavel Zizka](w/as_number/AS200918) [H](https://bgp.he.net/AS200918) [R](https://stat.ripe.net/AS200918)                                                                            |             0.03 |       0.05 |      0    |         2 |
| 229 | [Luxembourg Online S.A.](w/as_number/AS8632) [H](https://bgp.he.net/AS8632) [R](https://stat.ripe.net/AS8632)                                                                       |             0.03 |       0.05 |      0    |         1 |
| 230 | [VSHosting s.r.o.](w/as_number/AS43541) [H](https://bgp.he.net/AS43541) [R](https://stat.ripe.net/AS43541)                                                                          |             0.03 |       0.05 |      0    |         1 |
| 231 | [Dawico Deutschland GmbH](w/as_number/AS39614) [H](https://bgp.he.net/AS39614) [R](https://stat.ripe.net/AS39614)                                                                   |             0.03 |       0.05 |      0    |         1 |
| 232 | [WIIT AG](w/as_number/AS39519) [H](https://bgp.he.net/AS39519) [R](https://stat.ripe.net/AS39519)                                                                                   |             0.03 |       0.05 |      0    |         1 |
| 233 | [Nicklas Yli-Lantta](w/as_number/AS206125) [H](https://bgp.he.net/AS206125) [R](https://stat.ripe.net/AS206125)                                                                     |             0.03 |       0.05 |      0    |         1 |
| 234 | [Zettaplan AG](w/as_number/AS200713) [H](https://bgp.he.net/AS200713) [R](https://stat.ripe.net/AS200713)                                                                           |             0.03 |       0.05 |      0    |         1 |
| 235 | [British Telecommunications PLC](w/as_number/AS2856) [H](https://bgp.he.net/AS2856) [R](https://stat.ripe.net/AS2856)                                                               |             0.03 |       0.04 |      0    |        11 |
| 236 | [BL Networks](w/as_number/AS399629) [H](https://bgp.he.net/AS399629) [R](https://stat.ripe.net/AS399629)                                                                            |             0.03 |       0.04 |      0    |         5 |
| 237 | [Wojciech Czapkowicz](w/as_number/AS214481) [H](https://bgp.he.net/AS214481) [R](https://stat.ripe.net/AS214481)                                                                    |             0.03 |       0.04 |      0    |         2 |
| 238 | [HostRoyale Technologies Pvt Ltd](w/as_number/AS203020) [H](https://bgp.he.net/AS203020) [R](https://stat.ripe.net/AS203020)                                                        |             0.03 |       0.03 |      0.06 |         4 |
| 239 | [Contabo Asia Private Limited](w/as_number/AS141995) [H](https://bgp.he.net/AS141995) [R](https://stat.ripe.net/AS141995)                                                           |             0.03 |       0.03 |      0.01 |        15 |
| 240 | [Webglobe, s.r.o.](w/as_number/AS29134) [H](https://bgp.he.net/AS29134) [R](https://stat.ripe.net/AS29134)                                                                          |             0.03 |       0.02 |      0.06 |         5 |
| 241 | [GREEN FLOID LLC](w/as_number/AS15626) [H](https://bgp.he.net/AS15626) [R](https://stat.ripe.net/AS15626)                                                                           |             0.03 |       0.02 |      0.06 |         4 |
| 242 | [23VNet Kft.](w/as_number/AS30836) [H](https://bgp.he.net/AS30836) [R](https://stat.ripe.net/AS30836)                                                                               |             0.03 |       0.02 |      0.03 |         6 |
| 243 | [dogado GmbH](w/as_number/AS45012) [H](https://bgp.he.net/AS45012) [R](https://stat.ripe.net/AS45012)                                                                               |             0.03 |       0.01 |      0    |         2 |
| 244 | [DataWagon LLC](w/as_number/AS27176) [H](https://bgp.he.net/AS27176) [R](https://stat.ripe.net/AS27176)                                                                             |             0.03 |       0    |      0.08 |         9 |
| 245 | [Virtual Systems LLC](w/as_number/AS6698) [H](https://bgp.he.net/AS6698) [R](https://stat.ripe.net/AS6698)                                                                          |             0.03 |       0    |      0.08 |         2 |
| 246 | [Eurofiber France SAS](w/as_number/AS39405) [H](https://bgp.he.net/AS39405) [R](https://stat.ripe.net/AS39405)                                                                      |             0.03 |       0    |      0.08 |         2 |
| 247 | [Zen Internet Ltd](w/as_number/AS13037) [H](https://bgp.he.net/AS13037) [R](https://stat.ripe.net/AS13037)                                                                          |             0.03 |       0    |      0    |         4 |
| 248 | [Wien Energie GmbH](w/as_number/AS202616) [H](https://bgp.he.net/AS202616) [R](https://stat.ripe.net/AS202616)                                                                      |             0.03 |       0    |      0    |         2 |
| 249 | [Netversor GmbH](w/as_number/AS200081) [H](https://bgp.he.net/AS200081) [R](https://stat.ripe.net/AS200081)                                                                         |             0.03 |       0    |      0    |         2 |
| 250 | [Proximus Luxembourg S.A.](w/as_number/AS56665) [H](https://bgp.he.net/AS56665) [R](https://stat.ripe.net/AS56665)                                                                  |             0.03 |       0    |      0    |         1 |
| 251 | [SH.cz s.r.o.](w/as_number/AS39392) [H](https://bgp.he.net/AS39392) [R](https://stat.ripe.net/AS39392)                                                                              |             0.03 |       0    |      0    |         1 |
| 252 | [LLHOST INC. SRL](w/as_number/AS35277) [H](https://bgp.he.net/AS35277) [R](https://stat.ripe.net/AS35277)                                                                           |             0.02 |       0.05 |      0    |         3 |
| 253 | [Sharktech](w/as_number/AS46844) [H](https://bgp.he.net/AS46844) [R](https://stat.ripe.net/AS46844)                                                                                 |             0.02 |       0.04 |      0    |        18 |
| 254 | [Level 3 Parent, LLC](w/as_number/AS3356) [H](https://bgp.he.net/AS3356) [R](https://stat.ripe.net/AS3356)                                                                          |             0.02 |       0.04 |      0    |         9 |
| 255 | [DpkgSoft International Limited](w/as_number/AS215590) [H](https://bgp.he.net/AS215590) [R](https://stat.ripe.net/AS215590)                                                         |             0.02 |       0.04 |      0    |         4 |
| 256 | [Sia Nano IT](w/as_number/AS52173) [H](https://bgp.he.net/AS52173) [R](https://stat.ripe.net/AS52173)                                                                               |             0.02 |       0.04 |      0    |         3 |
| 257 | [Tele Asia Limited](w/as_number/AS133398) [H](https://bgp.he.net/AS133398) [R](https://stat.ripe.net/AS133398)                                                                      |             0.02 |       0.04 |      0    |         3 |
| 258 | [ORANGE ROMANIA COMMUNICATION S.A](w/as_number/AS9050) [H](https://bgp.he.net/AS9050) [R](https://stat.ripe.net/AS9050)                                                             |             0.02 |       0.04 |      0    |         2 |
| 259 | [Slovak Telekom, a.s.](w/as_number/AS6855) [H](https://bgp.he.net/AS6855) [R](https://stat.ripe.net/AS6855)                                                                         |             0.02 |       0.04 |      0    |         2 |
| 260 | [i3D.net B.V](w/as_number/AS49544) [H](https://bgp.he.net/AS49544) [R](https://stat.ripe.net/AS49544)                                                                               |             0.02 |       0.04 |      0    |         2 |
| 261 | [VNext AB](w/as_number/AS44176) [H](https://bgp.he.net/AS44176) [R](https://stat.ripe.net/AS44176)                                                                                  |             0.02 |       0.04 |      0    |         2 |
| 262 | [ATW Internet Kft.](w/as_number/AS41075) [H](https://bgp.he.net/AS41075) [R](https://stat.ripe.net/AS41075)                                                                         |             0.02 |       0.04 |      0    |         2 |
| 263 | [SURF B.V.](w/as_number/AS1133) [H](https://bgp.he.net/AS1133) [R](https://stat.ripe.net/AS1133)                                                                                    |             0.02 |       0.04 |      0    |         2 |
| 264 | [TimeWeb Ltd.](w/as_number/AS9123) [H](https://bgp.he.net/AS9123) [R](https://stat.ripe.net/AS9123)                                                                                 |             0.02 |       0.04 |      0    |         1 |
| 265 | [Saitis Network, N.Desir](w/as_number/AS6893) [H](https://bgp.he.net/AS6893) [R](https://stat.ripe.net/AS6893)                                                                      |             0.02 |       0.04 |      0    |         1 |
| 266 | [toob limited](w/as_number/AS60377) [H](https://bgp.he.net/AS60377) [R](https://stat.ripe.net/AS60377)                                                                              |             0.02 |       0.04 |      0    |         1 |
| 267 | [FIBIA P/S](w/as_number/AS44869) [H](https://bgp.he.net/AS44869) [R](https://stat.ripe.net/AS44869)                                                                                 |             0.02 |       0.04 |      0    |         1 |
| 268 | [NETPLANET GmbH](w/as_number/AS24953) [H](https://bgp.he.net/AS24953) [R](https://stat.ripe.net/AS24953)                                                                            |             0.02 |       0.04 |      0    |         1 |
| 269 | [HL komm Telekommunikations GmbH](w/as_number/AS16097) [H](https://bgp.he.net/AS16097) [R](https://stat.ripe.net/AS16097)                                                           |             0.02 |       0.04 |      0    |         1 |
| 270 | [Triplebit](w/as_number/AS401332) [H](https://bgp.he.net/AS401332) [R](https://stat.ripe.net/AS401332)                                                                              |             0.02 |       0.03 |      0    |        20 |
| 271 | [HostHatch, LLC](w/as_number/AS63473) [H](https://bgp.he.net/AS63473) [R](https://stat.ripe.net/AS63473)                                                                            |             0.02 |       0.03 |      0    |         7 |
| 272 | [JSC Selectel](w/as_number/AS49505) [H](https://bgp.he.net/AS49505) [R](https://stat.ripe.net/AS49505)                                                                              |             0.02 |       0.03 |      0    |         2 |
| 273 | [ZERGRUSH SRL](w/as_number/AS39622) [H](https://bgp.he.net/AS39622) [R](https://stat.ripe.net/AS39622)                                                                              |             0.02 |       0.03 |      0    |         2 |
| 274 | [TDC Holding A/S](w/as_number/AS3292) [H](https://bgp.he.net/AS3292) [R](https://stat.ripe.net/AS3292)                                                                              |             0.02 |       0.03 |      0    |         2 |
| 275 | [MARKAHOST TELEKOMUNIKASYON VE TICARET LIMITED SIRKETI](w/as_number/AS207279) [H](https://bgp.he.net/AS207279) [R](https://stat.ripe.net/AS207279)                                  |             0.02 |       0.03 |      0    |         2 |
| 276 | [NXT Initiative SAS](w/as_number/AS35426) [H](https://bgp.he.net/AS35426) [R](https://stat.ripe.net/AS35426)                                                                        |             0.02 |       0.03 |      0    |         1 |
| 277 | [Hostiserver Ltd](w/as_number/AS32338) [H](https://bgp.he.net/AS32338) [R](https://stat.ripe.net/AS32338)                                                                           |             0.02 |       0.03 |      0    |         1 |
| 278 | [NORDUnet](w/as_number/AS2603) [H](https://bgp.he.net/AS2603) [R](https://stat.ripe.net/AS2603)                                                                                     |             0.02 |       0.03 |      0    |         1 |
| 279 | [Alessandro Accorsi trading as Len Service SRL](w/as_number/AS215026) [H](https://bgp.he.net/AS215026) [R](https://stat.ripe.net/AS215026)                                          |             0.02 |       0.03 |      0    |         1 |
| 280 | [Jon Arve Vanvik](w/as_number/AS210152) [H](https://bgp.he.net/AS210152) [R](https://stat.ripe.net/AS210152)                                                                        |             0.02 |       0.03 |      0    |         1 |
| 281 | [SMARTNET LIMITED](w/as_number/AS203446) [H](https://bgp.he.net/AS203446) [R](https://stat.ripe.net/AS203446)                                                                       |             0.02 |       0.03 |      0    |         1 |
| 282 | [SkyPass Solutions Sp. z.o.o.](w/as_number/AS202520) [H](https://bgp.he.net/AS202520) [R](https://stat.ripe.net/AS202520)                                                           |             0.02 |       0.03 |      0    |         1 |
| 283 | [HEAnet CLG](w/as_number/AS1213) [H](https://bgp.he.net/AS1213) [R](https://stat.ripe.net/AS1213)                                                                                   |             0.02 |       0.03 |      0    |         1 |
| 284 | [Massachusetts Institute of Technology](w/as_number/AS396527) [H](https://bgp.he.net/AS396527) [R](https://stat.ripe.net/AS396527)                                                  |             0.02 |       0.02 |      0.02 |         5 |
| 285 | [VERIXI SA](w/as_number/AS6696) [H](https://bgp.he.net/AS6696) [R](https://stat.ripe.net/AS6696)                                                                                    |             0.02 |       0.02 |      0.02 |         3 |
| 286 | [Virgin Media Limited](w/as_number/AS5089) [H](https://bgp.he.net/AS5089) [R](https://stat.ripe.net/AS5089)                                                                         |             0.02 |       0.02 |      0    |        13 |
| 287 | [Baykov Ilya Sergeevich](w/as_number/AS41745) [H](https://bgp.he.net/AS41745) [R](https://stat.ripe.net/AS41745)                                                                    |             0.02 |       0.02 |      0    |         8 |
| 288 | [Melbikomas UAB](w/as_number/AS56630) [H](https://bgp.he.net/AS56630) [R](https://stat.ripe.net/AS56630)                                                                            |             0.02 |       0.02 |      0    |         7 |
| 289 | [ROCKHOSTER PRIVATE LIMITED](w/as_number/AS215381) [H](https://bgp.he.net/AS215381) [R](https://stat.ripe.net/AS215381)                                                             |             0.02 |       0.02 |      0    |         7 |
| 290 | [GREEN FLOID LLC](w/as_number/AS204957) [H](https://bgp.he.net/AS204957) [R](https://stat.ripe.net/AS204957)                                                                        |             0.02 |       0.02 |      0    |         6 |
| 291 | [SCALEWAY S.A.S.](w/as_number/AS29447) [H](https://bgp.he.net/AS29447) [R](https://stat.ripe.net/AS29447)                                                                           |             0.02 |       0.02 |      0    |         5 |
| 292 | [T-Mobile Czech Republic a.s.](w/as_number/AS13036) [H](https://bgp.he.net/AS13036) [R](https://stat.ripe.net/AS13036)                                                              |             0.02 |       0.02 |      0    |         4 |
| 293 | [Cyber Planet LLC](w/as_number/AS401104) [H](https://bgp.he.net/AS401104) [R](https://stat.ripe.net/AS401104)                                                                       |             0.02 |       0.01 |      0.05 |        11 |
| 294 | [FOP Kazakov Oleksandr Oleksandrovich](w/as_number/AS45045) [H](https://bgp.he.net/AS45045) [R](https://stat.ripe.net/AS45045)                                                      |             0.02 |       0.01 |      0.03 |         3 |
| 295 | [24 SHELLS](w/as_number/AS55081) [H](https://bgp.he.net/AS55081) [R](https://stat.ripe.net/AS55081)                                                                                 |             0.02 |       0.01 |      0    |        10 |
| 296 | [Techcrea Solutions SAS](w/as_number/AS197922) [H](https://bgp.he.net/AS197922) [R](https://stat.ripe.net/AS197922)                                                                 |             0.02 |       0.01 |      0    |         4 |
| 297 | [Emerald Onion](w/as_number/AS396507) [H](https://bgp.he.net/AS396507) [R](https://stat.ripe.net/AS396507)                                                                          |             0.02 |       0    |      0.07 |         3 |
| 298 | [INTERNATIONAL HOSTING SOLUTIONS LLP](w/as_number/AS213354) [H](https://bgp.he.net/AS213354) [R](https://stat.ripe.net/AS213354)                                                    |             0.02 |       0    |      0.05 |         2 |
| 299 | [Comcast Cable Communications, LLC](w/as_number/AS7922) [H](https://bgp.he.net/AS7922) [R](https://stat.ripe.net/AS7922)                                                            |             0.02 |       0    |      0    |        38 |
| 300 | [1&amp;1 Versatel Deutschland GmbH](w/as_number/AS8881) [H](https://bgp.he.net/AS8881) [R](https://stat.ripe.net/AS8881)                                                            |             0.02 |       0    |      0    |        19 |
| 301 | [A1 Bulgaria EAD](w/as_number/AS29580) [H](https://bgp.he.net/AS29580) [R](https://stat.ripe.net/AS29580)                                                                           |             0.02 |       0    |      0    |         5 |
| 302 | [Skhron OU](w/as_number/AS215467) [H](https://bgp.he.net/AS215467) [R](https://stat.ripe.net/AS215467)                                                                              |             0.02 |       0    |      0    |         3 |
| 303 | [DIGI Tavkozlesi es Szolgaltato Kft.](w/as_number/AS20845) [H](https://bgp.he.net/AS20845) [R](https://stat.ripe.net/AS20845)                                                       |             0.02 |       0    |      0    |         3 |
| 304 | [ElmoNet Oy](w/as_number/AS8829) [H](https://bgp.he.net/AS8829) [R](https://stat.ripe.net/AS8829)                                                                                   |             0.02 |       0    |      0    |         1 |
| 305 | [Leaseweb USA, Inc.](w/as_number/AS394380) [H](https://bgp.he.net/AS394380) [R](https://stat.ripe.net/AS394380)                                                                     |             0.01 |       0.03 |      0    |         7 |
| 306 | [Leaseweb USA, Inc.](w/as_number/AS393886) [H](https://bgp.he.net/AS393886) [R](https://stat.ripe.net/AS393886)                                                                     |             0.01 |       0.03 |      0    |         7 |
| 307 | [WIND TRE S.P.A.](w/as_number/AS1267) [H](https://bgp.he.net/AS1267) [R](https://stat.ripe.net/AS1267)                                                                              |             0.01 |       0.03 |      0    |         5 |
| 308 | [Turnkey Internet Inc.](w/as_number/AS40244) [H](https://bgp.he.net/AS40244) [R](https://stat.ripe.net/AS40244)                                                                     |             0.01 |       0.03 |      0    |         4 |
| 309 | [Digital Shape Technologies Inc.](w/as_number/AS33705) [H](https://bgp.he.net/AS33705) [R](https://stat.ripe.net/AS33705)                                                           |             0.01 |       0.03 |      0    |         4 |
| 310 | [Hohl IT e.U.](w/as_number/AS40994) [H](https://bgp.he.net/AS40994) [R](https://stat.ripe.net/AS40994)                                                                              |             0.01 |       0.03 |      0    |         2 |
| 311 | [Karlsruhe Institute of Technology](w/as_number/AS34878) [H](https://bgp.he.net/AS34878) [R](https://stat.ripe.net/AS34878)                                                         |             0.01 |       0.03 |      0    |         2 |
| 312 | [Oxide Group Limited](w/as_number/AS199654) [H](https://bgp.he.net/AS199654) [R](https://stat.ripe.net/AS199654)                                                                    |             0.01 |       0.03 |      0    |         2 |
| 313 | [C2NET s.r.o.](w/as_number/AS56456) [H](https://bgp.he.net/AS56456) [R](https://stat.ripe.net/AS56456)                                                                              |             0.01 |       0.03 |      0    |         1 |
| 314 | [S-NET Sp. z o.o.](w/as_number/AS42927) [H](https://bgp.he.net/AS42927) [R](https://stat.ripe.net/AS42927)                                                                          |             0.01 |       0.03 |      0    |         1 |
| 315 | [Aktsiaselts WaveCom](w/as_number/AS34702) [H](https://bgp.he.net/AS34702) [R](https://stat.ripe.net/AS34702)                                                                       |             0.01 |       0.03 |      0    |         1 |
| 316 | [Zdruzenie pouzivatelov Slovenskej akademickej datovej siete SANET](w/as_number/AS2607) [H](https://bgp.he.net/AS2607) [R](https://stat.ripe.net/AS2607)                            |             0.01 |       0.03 |      0    |         1 |
| 317 | [Digitale Partizipation e.V.](w/as_number/AS204911) [H](https://bgp.he.net/AS204911) [R](https://stat.ripe.net/AS204911)                                                            |             0.01 |       0.03 |      0    |         1 |
| 318 | [Internetmanufaktur Karlsruhe UG haftungsbeschraenkt](w/as_number/AS202539) [H](https://bgp.he.net/AS202539) [R](https://stat.ripe.net/AS202539)                                    |             0.01 |       0.03 |      0    |         1 |
| 319 | [Tamatiya EOOD](w/as_number/AS50360) [H](https://bgp.he.net/AS50360) [R](https://stat.ripe.net/AS50360)                                                                             |             0.01 |       0.02 |      0.01 |         6 |
| 320 | [Hurricane Electric LLC](w/as_number/AS6939) [H](https://bgp.he.net/AS6939) [R](https://stat.ripe.net/AS6939)                                                                       |             0.01 |       0.02 |      0    |         8 |
| 321 | [LLC Baxet](w/as_number/AS51659) [H](https://bgp.he.net/AS51659) [R](https://stat.ripe.net/AS51659)                                                                                 |             0.01 |       0.02 |      0    |         6 |
| 322 | [Oliver Horscht is trading as &quot;SYNLINQ&quot;](w/as_number/AS44486) [H](https://bgp.he.net/AS44486) [R](https://stat.ripe.net/AS44486)                                          |             0.01 |       0.02 |      0    |         6 |
| 323 | [Aixit GmbH](w/as_number/AS29551) [H](https://bgp.he.net/AS29551) [R](https://stat.ripe.net/AS29551)                                                                                |             0.01 |       0.02 |      0    |         5 |
| 324 | [GleSYS AB](w/as_number/AS42708) [H](https://bgp.he.net/AS42708) [R](https://stat.ripe.net/AS42708)                                                                                 |             0.01 |       0.02 |      0    |         4 |
| 325 | [VPS House Technology Group LLC](w/as_number/AS399122) [H](https://bgp.he.net/AS399122) [R](https://stat.ripe.net/AS399122)                                                         |             0.01 |       0.02 |      0    |         4 |
| 326 | [ITITAN HOSTING SOLUTIONS SRL](w/as_number/AS214062) [H](https://bgp.he.net/AS214062) [R](https://stat.ripe.net/AS214062)                                                           |             0.01 |       0.02 |      0    |         4 |
| 327 | [SIA VEESP](w/as_number/AS42532) [H](https://bgp.he.net/AS42532) [R](https://stat.ripe.net/AS42532)                                                                                 |             0.01 |       0.02 |      0    |         3 |
| 328 | [Voxility LLP](w/as_number/AS3223) [H](https://bgp.he.net/AS3223) [R](https://stat.ripe.net/AS3223)                                                                                 |             0.01 |       0.02 |      0    |         3 |
| 329 | [Baxet Group Inc.](w/as_number/AS26383) [H](https://bgp.he.net/AS26383) [R](https://stat.ripe.net/AS26383)                                                                          |             0.01 |       0.02 |      0    |         3 |
| 330 | [Andrei Tiberiu Holt](w/as_number/AS211462) [H](https://bgp.he.net/AS211462) [R](https://stat.ripe.net/AS211462)                                                                    |             0.01 |       0.02 |      0    |         3 |
| 331 | [Keminet SHPK](w/as_number/AS197706) [H](https://bgp.he.net/AS197706) [R](https://stat.ripe.net/AS197706)                                                                           |             0.01 |       0.02 |      0    |         3 |
| 332 | [Vivacom Bulgaria EAD](w/as_number/AS8866) [H](https://bgp.he.net/AS8866) [R](https://stat.ripe.net/AS8866)                                                                         |             0.01 |       0.02 |      0    |         2 |
| 333 | [GLOBALTELEHOST Corp.](w/as_number/AS62563) [H](https://bgp.he.net/AS62563) [R](https://stat.ripe.net/AS62563)                                                                      |             0.01 |       0.02 |      0    |         2 |
| 334 | [Belcloud LTD](w/as_number/AS44901) [H](https://bgp.he.net/AS44901) [R](https://stat.ripe.net/AS44901)                                                                              |             0.01 |       0.02 |      0    |         2 |
| 335 | [iFog GmbH](w/as_number/AS34927) [H](https://bgp.he.net/AS34927) [R](https://stat.ripe.net/AS34927)                                                                                 |             0.01 |       0.02 |      0    |         2 |
| 336 | [Telia Eesti AS](w/as_number/AS3249) [H](https://bgp.he.net/AS3249) [R](https://stat.ripe.net/AS3249)                                                                               |             0.01 |       0.02 |      0    |         2 |
| 337 | [Bredband2 AB](w/as_number/AS29518) [H](https://bgp.he.net/AS29518) [R](https://stat.ripe.net/AS29518)                                                                              |             0.01 |       0.02 |      0    |         2 |
| 338 | [H2NEXUS LTD](w/as_number/AS215730) [H](https://bgp.he.net/AS215730) [R](https://stat.ripe.net/AS215730)                                                                            |             0.01 |       0.02 |      0    |         2 |
| 339 | [UAB &quot;Interneto vizija&quot;](w/as_number/AS212531) [H](https://bgp.he.net/AS212531) [R](https://stat.ripe.net/AS212531)                                                       |             0.01 |       0.02 |      0    |         2 |
| 340 | [Community Fibre Limited](w/as_number/AS201838) [H](https://bgp.he.net/AS201838) [R](https://stat.ripe.net/AS201838)                                                                |             0.01 |       0.02 |      0    |         2 |
| 341 | [PlusServer GmbH](w/as_number/AS61157) [H](https://bgp.he.net/AS61157) [R](https://stat.ripe.net/AS61157)                                                                           |             0.01 |       0.02 |      0    |         1 |
| 342 | [Swisscom Schweiz AG](w/as_number/AS57370) [H](https://bgp.he.net/AS57370) [R](https://stat.ripe.net/AS57370)                                                                       |             0.01 |       0.02 |      0    |         1 |
| 343 | [Zemlyaniy Dmitro Leonidovich](w/as_number/AS47987) [H](https://bgp.he.net/AS47987) [R](https://stat.ripe.net/AS47987)                                                              |             0.01 |       0.02 |      0    |         1 |
| 344 | [Stadtwerke Woergl GmbH](w/as_number/AS34694) [H](https://bgp.he.net/AS34694) [R](https://stat.ripe.net/AS34694)                                                                    |             0.01 |       0.02 |      0    |         1 |
| 345 | [CD-Telematika a.s.](w/as_number/AS25512) [H](https://bgp.he.net/AS25512) [R](https://stat.ripe.net/AS25512)                                                                        |             0.01 |       0.02 |      0    |         1 |
| 346 | [Bastiaan Mathijs Brink](w/as_number/AS215248) [H](https://bgp.he.net/AS215248) [R](https://stat.ripe.net/AS215248)                                                                 |             0.01 |       0.02 |      0    |         1 |
| 347 | [03AI LTD](w/as_number/AS213725) [H](https://bgp.he.net/AS213725) [R](https://stat.ripe.net/AS213725)                                                                               |             0.01 |       0.02 |      0    |         1 |
| 348 | [GREEN FLOID LLC](w/as_number/AS21100) [H](https://bgp.he.net/AS21100) [R](https://stat.ripe.net/AS21100)                                                                           |             0.01 |       0.02 |      0    |         1 |
| 349 | [Felix Gassan](w/as_number/AS207252) [H](https://bgp.he.net/AS207252) [R](https://stat.ripe.net/AS207252)                                                                           |             0.01 |       0.02 |      0    |         1 |
| 350 | [Data Room, Inc](w/as_number/AS19624) [H](https://bgp.he.net/AS19624) [R](https://stat.ripe.net/AS19624)                                                                            |             0.01 |       0.02 |      0    |         1 |
| 351 | [Rainside s.r.o.](w/as_number/AS12508) [H](https://bgp.he.net/AS12508) [R](https://stat.ripe.net/AS12508)                                                                           |             0.01 |       0.02 |      0    |         1 |
| 352 | [2S Computers SRL](w/as_number/AS204471) [H](https://bgp.he.net/AS204471) [R](https://stat.ripe.net/AS204471)                                                                       |             0.01 |       0.01 |      0.03 |         2 |
| 353 | [netcup GmbH](w/as_number/AS214996) [H](https://bgp.he.net/AS214996) [R](https://stat.ripe.net/AS214996)                                                                            |             0.01 |       0.01 |      0.01 |         3 |
| 354 | [TELUS Communications Inc.](w/as_number/AS852) [H](https://bgp.he.net/AS852) [R](https://stat.ripe.net/AS852)                                                                       |             0.01 |       0.01 |      0    |        11 |
| 355 | [Google Fiber Inc.](w/as_number/AS16591) [H](https://bgp.he.net/AS16591) [R](https://stat.ripe.net/AS16591)                                                                         |             0.01 |       0.01 |      0    |        10 |
| 356 | [Cincinnati Bell Telephone Company LLC](w/as_number/AS6181) [H](https://bgp.he.net/AS6181) [R](https://stat.ripe.net/AS6181)                                                        |             0.01 |       0.01 |      0    |         6 |
| 357 | [FIRST SERVER LIMITED](w/as_number/AS205090) [H](https://bgp.he.net/AS205090) [R](https://stat.ripe.net/AS205090)                                                                   |             0.01 |       0.01 |      0    |         6 |
| 358 | [Vodafone Limited](w/as_number/AS5378) [H](https://bgp.he.net/AS5378) [R](https://stat.ripe.net/AS5378)                                                                             |             0.01 |       0.01 |      0    |         5 |
| 359 | [JSC Selectel](w/as_number/AS50340) [H](https://bgp.he.net/AS50340) [R](https://stat.ripe.net/AS50340)                                                                              |             0.01 |       0.01 |      0    |         4 |
| 360 | [Shinjiru Technology Sdn Bhd](w/as_number/AS45839) [H](https://bgp.he.net/AS45839) [R](https://stat.ripe.net/AS45839)                                                               |             0.01 |       0.01 |      0    |         4 |
| 361 | [EuroByte LLC](w/as_number/AS210079) [H](https://bgp.he.net/AS210079) [R](https://stat.ripe.net/AS210079)                                                                           |             0.01 |       0.01 |      0    |         4 |
| 362 | [Orange Espagne SA](w/as_number/AS12479) [H](https://bgp.he.net/AS12479) [R](https://stat.ripe.net/AS12479)                                                                         |             0.01 |       0.01 |      0    |         4 |
| 363 | [Informacines sistemos ir technologijos, UAB](w/as_number/AS61272) [H](https://bgp.he.net/AS61272) [R](https://stat.ripe.net/AS61272)                                               |             0.01 |       0.01 |      0    |         3 |
| 364 | [InMotion Hosting, Inc.](w/as_number/AS54641) [H](https://bgp.he.net/AS54641) [R](https://stat.ripe.net/AS54641)                                                                    |             0.01 |       0.01 |      0    |         3 |
| 365 | [Leaseweb Canada Inc.](w/as_number/AS32613) [H](https://bgp.he.net/AS32613) [R](https://stat.ripe.net/AS32613)                                                                      |             0.01 |       0.01 |      0    |         3 |
| 366 | [Cinzia Tocci trading as C1V](w/as_number/AS212271) [H](https://bgp.he.net/AS212271) [R](https://stat.ripe.net/AS212271)                                                            |             0.01 |       0.01 |      0    |         3 |
| 367 | [ENARTIA Single Member S.A.](w/as_number/AS199246) [H](https://bgp.he.net/AS199246) [R](https://stat.ripe.net/AS199246)                                                             |             0.01 |       0.01 |      0    |         3 |
| 368 | [Jisc Services Limited](w/as_number/AS786) [H](https://bgp.he.net/AS786) [R](https://stat.ripe.net/AS786)                                                                           |             0.01 |       0.01 |      0    |         2 |
| 369 | [UpCloud Ltd](w/as_number/AS202053) [H](https://bgp.he.net/AS202053) [R](https://stat.ripe.net/AS202053)                                                                            |             0.01 |       0.01 |      0    |         2 |
| 370 | [Telia Finland Oyj](w/as_number/AS1759) [H](https://bgp.he.net/AS1759) [R](https://stat.ripe.net/AS1759)                                                                            |             0.01 |       0.01 |      0    |         2 |
| 371 | [Bofiber AS](w/as_number/AS59720) [H](https://bgp.he.net/AS59720) [R](https://stat.ripe.net/AS59720)                                                                                |             0.01 |       0.01 |      0    |         1 |
| 372 | [Bredband2 Stockholms Stadsnaet AB](w/as_number/AS50821) [H](https://bgp.he.net/AS50821) [R](https://stat.ripe.net/AS50821)                                                         |             0.01 |       0.01 |      0    |         1 |
| 373 | [VPS4You Kft.](w/as_number/AS47325) [H](https://bgp.he.net/AS47325) [R](https://stat.ripe.net/AS47325)                                                                              |             0.01 |       0.01 |      0    |         1 |
| 374 | [Zzoomm plc](w/as_number/AS42611) [H](https://bgp.he.net/AS42611) [R](https://stat.ripe.net/AS42611)                                                                                |             0.01 |       0.01 |      0    |         1 |
| 375 | [Pirkan Opiskelija-asunnot Oy](w/as_number/AS39484) [H](https://bgp.he.net/AS39484) [R](https://stat.ripe.net/AS39484)                                                              |             0.01 |       0.01 |      0    |         1 |
| 376 | [Rychly drat, s.r.o.](w/as_number/AS202618) [H](https://bgp.he.net/AS202618) [R](https://stat.ripe.net/AS202618)                                                                    |             0.01 |       0.01 |      0    |         1 |
| 377 | [FIRST SERVER LIMITED](w/as_number/AS200740) [H](https://bgp.he.net/AS200740) [R](https://stat.ripe.net/AS200740)                                                                   |             0.01 |       0.01 |      0    |         1 |
| 378 | [GHOSTnet GmbH](w/as_number/AS12586) [H](https://bgp.he.net/AS12586) [R](https://stat.ripe.net/AS12586)                                                                             |             0.01 |       0.01 |      0    |         1 |
| 379 | [HeLi NET Telekommunikation GmbH &amp; Co.](w/as_number/AS12355) [H](https://bgp.he.net/AS12355) [R](https://stat.ripe.net/AS12355)                                                 |             0.01 |       0.01 |      0    |         1 |
| 380 | [Svea Hosting AB](w/as_number/AS41634) [H](https://bgp.he.net/AS41634) [R](https://stat.ripe.net/AS41634)                                                                           |             0.01 |       0    |      0.04 |         1 |
| 381 | [Octopuce s.a.r.l.](w/as_number/AS28855) [H](https://bgp.he.net/AS28855) [R](https://stat.ripe.net/AS28855)                                                                         |             0.01 |       0    |      0.04 |         1 |
| 382 | [0x7c0 Labs LLC](w/as_number/AS400861) [H](https://bgp.he.net/AS400861) [R](https://stat.ripe.net/AS400861)                                                                         |             0.01 |       0    |      0.03 |         4 |
| 383 | [&x27;&x27;IT FRUIT&x27;&x27; S.R.L.](w/as_number/AS56380) [H](https://bgp.he.net/AS56380) [R](https://stat.ripe.net/AS56380)                                                       |             0.01 |       0    |      0.03 |         2 |
| 384 | [Davide Silvetti trading as &x27;Association Osservatorio Nessuno ODV&x27;](w/as_number/AS214094) [H](https://bgp.he.net/AS214094) [R](https://stat.ripe.net/AS214094)              |             0.01 |       0    |      0.03 |         2 |
| 385 | [PLUTEX GmbH](w/as_number/AS49855) [H](https://bgp.he.net/AS49855) [R](https://stat.ripe.net/AS49855)                                                                               |             0.01 |       0    |      0.03 |         1 |
| 386 | [INVITE Systems SRL](w/as_number/AS44679) [H](https://bgp.he.net/AS44679) [R](https://stat.ripe.net/AS44679)                                                                        |             0.01 |       0    |      0.03 |         1 |
| 387 | [REEVO S.P.A.](w/as_number/AS3242) [H](https://bgp.he.net/AS3242) [R](https://stat.ripe.net/AS3242)                                                                                 |             0.01 |       0    |      0.03 |         1 |
| 388 | [Cinia Oy](w/as_number/AS20904) [H](https://bgp.he.net/AS20904) [R](https://stat.ripe.net/AS20904)                                                                                  |             0.01 |       0    |      0.03 |         1 |
| 389 | [Castlegem SRL](w/as_number/AS201308) [H](https://bgp.he.net/AS201308) [R](https://stat.ripe.net/AS201308)                                                                          |             0.01 |       0    |      0.03 |         1 |
| 390 | [Hawaiian Telcom Services Company, Inc.](w/as_number/AS36149) [H](https://bgp.he.net/AS36149) [R](https://stat.ripe.net/AS36149)                                                    |             0.01 |       0    |      0.02 |         8 |
| 391 | [Advania Island ehf](w/as_number/AS50613) [H](https://bgp.he.net/AS50613) [R](https://stat.ripe.net/AS50613)                                                                        |             0.01 |       0    |      0.02 |         4 |
| 392 | [ab stract ltd](w/as_number/AS39287) [H](https://bgp.he.net/AS39287) [R](https://stat.ripe.net/AS39287)                                                                             |             0.01 |       0    |      0.02 |         4 |
| 393 | [UAB Host Baltic](w/as_number/AS209605) [H](https://bgp.he.net/AS209605) [R](https://stat.ripe.net/AS209605)                                                                        |             0.01 |       0    |      0.02 |         2 |
| 394 | [TalkTalk Communications Limited](w/as_number/AS13285) [H](https://bgp.he.net/AS13285) [R](https://stat.ripe.net/AS13285)                                                           |             0.01 |       0    |      0    |         9 |
| 395 | [HOSTKEY B.V.](w/as_number/AS50867) [H](https://bgp.he.net/AS50867) [R](https://stat.ripe.net/AS50867)                                                                              |             0.01 |       0    |      0    |         6 |
| 396 | [M-net Telekommunikations GmbH](w/as_number/AS8767) [H](https://bgp.he.net/AS8767) [R](https://stat.ripe.net/AS8767)                                                                |             0.01 |       0    |      0    |         4 |
| 397 | [MAV Studios UK LTD](w/as_number/AS204755) [H](https://bgp.he.net/AS204755) [R](https://stat.ripe.net/AS204755)                                                                     |             0.01 |       0    |      0    |         4 |
| 398 | [Netia SA](w/as_number/AS12741) [H](https://bgp.he.net/AS12741) [R](https://stat.ripe.net/AS12741)                                                                                  |             0.01 |       0    |      0    |         4 |
| 399 | [Iway AG](w/as_number/AS8758) [H](https://bgp.he.net/AS8758) [R](https://stat.ripe.net/AS8758)                                                                                      |             0.01 |       0    |      0    |         3 |
| 400 | [Proximus NV](w/as_number/AS5432) [H](https://bgp.he.net/AS5432) [R](https://stat.ripe.net/AS5432)                                                                                  |             0.01 |       0    |      0    |         3 |
| 401 | [AVA HOST SRL](w/as_number/AS48753) [H](https://bgp.he.net/AS48753) [R](https://stat.ripe.net/AS48753)                                                                              |             0.01 |       0    |      0    |         3 |
| 402 | [comtrance service GmbH](w/as_number/AS41108) [H](https://bgp.he.net/AS41108) [R](https://stat.ripe.net/AS41108)                                                                    |             0.01 |       0    |      0    |         3 |
| 403 | [Societe Francaise Du Radiotelephone - SFR SA](w/as_number/AS15557) [H](https://bgp.he.net/AS15557) [R](https://stat.ripe.net/AS15557)                                              |             0.01 |       0    |      0    |         3 |
| 404 | [PE Denis Podolskii](w/as_number/AS61335) [H](https://bgp.he.net/AS61335) [R](https://stat.ripe.net/AS61335)                                                                        |             0.01 |       0    |      0    |         2 |
| 405 | [Taylan Gueler trading as Soliaweb](w/as_number/AS215987) [H](https://bgp.he.net/AS215987) [R](https://stat.ripe.net/AS215987)                                                      |             0.01 |       0    |      0    |         2 |
| 406 | [Patrik Lagerman](w/as_number/AS35100) [H](https://bgp.he.net/AS35100) [R](https://stat.ripe.net/AS35100)                                                                           |             0.01 |       0    |      0    |         1 |
| 407 | [Vladylsav Naumets](w/as_number/AS214196) [H](https://bgp.he.net/AS214196) [R](https://stat.ripe.net/AS214196)                                                                      |             0.01 |       0    |      0    |         1 |
| 408 | [F &amp; W Networks Ltd](w/as_number/AS207645) [H](https://bgp.he.net/AS207645) [R](https://stat.ripe.net/AS207645)                                                                 |             0.01 |       0    |      0    |         1 |
| 409 | [FIBRUS NETWORKS LTD](w/as_number/AS202282) [H](https://bgp.he.net/AS202282) [R](https://stat.ripe.net/AS202282)                                                                    |             0.01 |       0    |      0    |         1 |
| 410 | [Lars Jannick Volkers trading as Etheron Hosting](w/as_number/AS200223) [H](https://bgp.he.net/AS200223) [R](https://stat.ripe.net/AS200223)                                        |             0.01 |       0    |      0    |         1 |
| 411 | [htp GmbH](w/as_number/AS13045) [H](https://bgp.he.net/AS13045) [R](https://stat.ripe.net/AS13045)                                                                                  |             0.01 |       0    |      0    |         1 |
| 412 | [Telenet BV](w/as_number/AS6848) [H](https://bgp.he.net/AS6848) [R](https://stat.ripe.net/AS6848)                                                                                   |             0    |       0.01 |      0    |         5 |
| 413 | [Nocix, LLC](w/as_number/AS33387) [H](https://bgp.he.net/AS33387) [R](https://stat.ripe.net/AS33387)                                                                                |             0    |       0.01 |      0    |         5 |
| 414 | [New Dream Network, LLC](w/as_number/AS26347) [H](https://bgp.he.net/AS26347) [R](https://stat.ripe.net/AS26347)                                                                    |             0    |       0.01 |      0    |         5 |
| 415 | [British Telecommunications PLC](w/as_number/AS6871) [H](https://bgp.he.net/AS6871) [R](https://stat.ripe.net/AS6871)                                                               |             0    |       0.01 |      0    |         4 |
| 416 | [Dedicated.com](w/as_number/AS63018) [H](https://bgp.he.net/AS63018) [R](https://stat.ripe.net/AS63018)                                                                             |             0    |       0.01 |      0    |         4 |
| 417 | [Leaseweb USA, Inc.](w/as_number/AS395954) [H](https://bgp.he.net/AS395954) [R](https://stat.ripe.net/AS395954)                                                                     |             0    |       0.01 |      0    |         4 |
| 418 | [tzulo, inc.](w/as_number/AS11878) [H](https://bgp.he.net/AS11878) [R](https://stat.ripe.net/AS11878)                                                                               |             0    |       0.01 |      0    |         4 |
| 419 | [Adamo Telecom Iberia S.A.](w/as_number/AS35699) [H](https://bgp.he.net/AS35699) [R](https://stat.ripe.net/AS35699)                                                                 |             0    |       0.01 |      0    |         3 |
| 420 | [TENNET TELECOM SRL](w/as_number/AS33911) [H](https://bgp.he.net/AS33911) [R](https://stat.ripe.net/AS33911)                                                                        |             0    |       0.01 |      0    |         3 |
| 421 | [ALMOUROLTEC SERVICOS DE INFORMATICA E INTERNET LDA](w/as_number/AS24768) [H](https://bgp.he.net/AS24768) [R](https://stat.ripe.net/AS24768)                                        |             0    |       0.01 |      0    |         3 |
| 422 | [Odrex Software LLC](w/as_number/AS202223) [H](https://bgp.he.net/AS202223) [R](https://stat.ripe.net/AS202223)                                                                     |             0    |       0.01 |      0    |         3 |
| 423 | [Vodafone Portugal - Communicacoes Pessoais S.A.](w/as_number/AS12353) [H](https://bgp.he.net/AS12353) [R](https://stat.ripe.net/AS12353)                                           |             0    |       0.01 |      0    |         3 |
| 424 | [VSE NET GmbH](w/as_number/AS9063) [H](https://bgp.he.net/AS9063) [R](https://stat.ripe.net/AS9063)                                                                                 |             0    |       0.01 |      0    |         2 |
| 425 | [BSE Software GmbH](w/as_number/AS9044) [H](https://bgp.he.net/AS9044) [R](https://stat.ripe.net/AS9044)                                                                            |             0    |       0.01 |      0    |         2 |
| 426 | [POST Luxembourg](w/as_number/AS6661) [H](https://bgp.he.net/AS6661) [R](https://stat.ripe.net/AS6661)                                                                              |             0    |       0.01 |      0    |         2 |
| 427 | [PhoenixNAP LLC](w/as_number/AS11572) [H](https://bgp.he.net/AS11572) [R](https://stat.ripe.net/AS11572)                                                                            |             0    |       0.01 |      0    |         2 |
| 428 | [Alexander Wagberg trading as Wberg Networks](w/as_number/AS8873) [H](https://bgp.he.net/AS8873) [R](https://stat.ripe.net/AS8873)                                                  |             0    |       0.01 |      0    |         1 |
| 429 | [&quot;Bezeq&quot;- THE ISRAEL TELECOMMUNICATION CORP. LTD.](w/as_number/AS6810) [H](https://bgp.he.net/AS6810) [R](https://stat.ripe.net/AS6810)                                   |             0    |       0.01 |      0    |         1 |
| 430 | [eServer s.r.o.](w/as_number/AS61424) [H](https://bgp.he.net/AS61424) [R](https://stat.ripe.net/AS61424)                                                                            |             0    |       0.01 |      0    |         1 |
| 431 | [NEAS ENERGI TELEKOM AS](w/as_number/AS61275) [H](https://bgp.he.net/AS61275) [R](https://stat.ripe.net/AS61275)                                                                    |             0    |       0.01 |      0    |         1 |
| 432 | [Glattwerk AG](w/as_number/AS61174) [H](https://bgp.he.net/AS61174) [R](https://stat.ripe.net/AS61174)                                                                              |             0    |       0.01 |      0    |         1 |
| 433 | [Baytems Holdings Oy](w/as_number/AS60414) [H](https://bgp.he.net/AS60414) [R](https://stat.ripe.net/AS60414)                                                                       |             0    |       0.01 |      0    |         1 |
| 434 | [Hyperoptic Ltd](w/as_number/AS56478) [H](https://bgp.he.net/AS56478) [R](https://stat.ripe.net/AS56478)                                                                            |             0    |       0.01 |      0    |         1 |
| 435 | [Marek Bajerski trading as HITME.PL](w/as_number/AS50840) [H](https://bgp.he.net/AS50840) [R](https://stat.ripe.net/AS50840)                                                        |             0    |       0.01 |      0    |         1 |
| 436 | [Individual Entrepreneur Anton Levin](w/as_number/AS50053) [H](https://bgp.he.net/AS50053) [R](https://stat.ripe.net/AS50053)                                                       |             0    |       0.01 |      0    |         1 |
| 437 | [MK Netzdienste GmbH](w/as_number/AS43150) [H](https://bgp.he.net/AS43150) [R](https://stat.ripe.net/AS43150)                                                                       |             0    |       0.01 |      0    |         1 |
| 438 | [Three Fourteen SASU](w/as_number/AS42275) [H](https://bgp.he.net/AS42275) [R](https://stat.ripe.net/AS42275)                                                                       |             0    |       0.01 |      0    |         1 |
| 439 | [RGnet OU](w/as_number/AS3927) [H](https://bgp.he.net/AS3927) [R](https://stat.ripe.net/AS3927)                                                                                     |             0    |       0.01 |      0    |         1 |
| 440 | [LINZ STROM GAS WAERME GmbH fuer Energiedienstleistungen und Telekommunikation](w/as_number/AS35369) [H](https://bgp.he.net/AS35369) [R](https://stat.ripe.net/AS35369)             |             0    |       0.01 |      0    |         1 |
| 441 | [TOV &quot;Highload Systems&quot;](w/as_number/AS34259) [H](https://bgp.he.net/AS34259) [R](https://stat.ripe.net/AS34259)                                                          |             0    |       0.01 |      0    |         1 |
| 442 | [ProvDotNet LLC](w/as_number/AS3061) [H](https://bgp.he.net/AS3061) [R](https://stat.ripe.net/AS3061)                                                                               |             0    |       0.01 |      0    |         1 |
| 443 | [Agentia de Administrare a Retelei Nationale de Informatica pentru Educatie si Cercetare](w/as_number/AS2614) [H](https://bgp.he.net/AS2614) [R](https://stat.ripe.net/AS2614)      |             0    |       0.01 |      0    |         1 |
| 444 | [PHOTON SPARK SRL](w/as_number/AS216249) [H](https://bgp.he.net/AS216249) [R](https://stat.ripe.net/AS216249)                                                                       |             0    |       0.01 |      0    |         1 |
| 445 | [Intraserv Kamil Schild](w/as_number/AS211742) [H](https://bgp.he.net/AS211742) [R](https://stat.ripe.net/AS211742)                                                                 |             0    |       0.01 |      0    |         1 |
| 446 | [Box Broadband Limited](w/as_number/AS210874) [H](https://bgp.he.net/AS210874) [R](https://stat.ripe.net/AS210874)                                                                  |             0    |       0.01 |      0    |         1 |
| 447 | [Open Fiber S.P.A.](w/as_number/AS210218) [H](https://bgp.he.net/AS210218) [R](https://stat.ripe.net/AS210218)                                                                      |             0    |       0.01 |      0    |         1 |
| 448 | [NILSAT Ltd.](w/as_number/AS209696) [H](https://bgp.he.net/AS209696) [R](https://stat.ripe.net/AS209696)                                                                            |             0    |       0.01 |      0    |         1 |
| 449 | [Internetnord AB](w/as_number/AS206774) [H](https://bgp.he.net/AS206774) [R](https://stat.ripe.net/AS206774)                                                                        |             0    |       0.01 |      0    |         1 |
| 450 | [DevNet Oy](w/as_number/AS205449) [H](https://bgp.he.net/AS205449) [R](https://stat.ripe.net/AS205449)                                                                              |             0    |       0.01 |      0    |         1 |
| 451 | [Olivenet Network S.L.](w/as_number/AS201746) [H](https://bgp.he.net/AS201746) [R](https://stat.ripe.net/AS201746)                                                                  |             0    |       0.01 |      0    |         1 |
| 452 | [NT Group Systemy Informatyczne Sp. z o.o.](w/as_number/AS197448) [H](https://bgp.he.net/AS197448) [R](https://stat.ripe.net/AS197448)                                              |             0    |       0.01 |      0    |         1 |
| 453 | [IPHH Internet Port Hamburg GmbH](w/as_number/AS12731) [H](https://bgp.he.net/AS12731) [R](https://stat.ripe.net/AS12731)                                                           |             0    |       0.01 |      0    |         1 |
| 454 | [Visual Online S.A.](w/as_number/AS9008) [H](https://bgp.he.net/AS9008) [R](https://stat.ripe.net/AS9008)                                                                           |             0    |       0    |      0.02 |         1 |
| 455 | [DG-NET SA](w/as_number/AS57608) [H](https://bgp.he.net/AS57608) [R](https://stat.ripe.net/AS57608)                                                                                 |             0    |       0    |      0.02 |         1 |
| 456 | [VIPNET PRIM Ltd](w/as_number/AS45007) [H](https://bgp.he.net/AS45007) [R](https://stat.ripe.net/AS45007)                                                                           |             0    |       0    |      0.02 |         1 |
| 457 | [TNNet Oy](w/as_number/AS30798) [H](https://bgp.he.net/AS30798) [R](https://stat.ripe.net/AS30798)                                                                                  |             0    |       0    |      0.02 |         1 |
| 458 | [Host Africa Pty Ltd](w/as_number/AS328364) [H](https://bgp.he.net/AS328364) [R](https://stat.ripe.net/AS328364)                                                                    |             0    |       0    |      0.01 |        21 |
| 459 | [CLOUDLAYER8 LIMITED](w/as_number/AS197648) [H](https://bgp.he.net/AS197648) [R](https://stat.ripe.net/AS197648)                                                                    |             0    |       0    |      0.01 |         6 |
| 460 | [Internetport Sweden AB](w/as_number/AS49770) [H](https://bgp.he.net/AS49770) [R](https://stat.ripe.net/AS49770)                                                                    |             0    |       0    |      0.01 |         3 |
| 461 | [Nubes, LLC](w/as_number/AS40021) [H](https://bgp.he.net/AS40021) [R](https://stat.ripe.net/AS40021)                                                                                |             0    |       0    |      0.01 |         3 |
| 462 | [University of North Carolina at Chapel Hill](w/as_number/AS36850) [H](https://bgp.he.net/AS36850) [R](https://stat.ripe.net/AS36850)                                               |             0    |       0    |      0.01 |         3 |
| 463 | [Fork Networking, LLC](w/as_number/AS46841) [H](https://bgp.he.net/AS46841) [R](https://stat.ripe.net/AS46841)                                                                      |             0    |       0    |      0.01 |         2 |
| 464 | [Vivacom Bulgaria EAD](w/as_number/AS43205) [H](https://bgp.he.net/AS43205) [R](https://stat.ripe.net/AS43205)                                                                      |             0    |       0    |      0.01 |         2 |
| 465 | [University of Waterloo](w/as_number/AS12093) [H](https://bgp.he.net/AS12093) [R](https://stat.ripe.net/AS12093)                                                                    |             0    |       0    |      0.01 |         2 |
| 466 | [MODIRUM MDPAY OU](w/as_number/AS62248) [H](https://bgp.he.net/AS62248) [R](https://stat.ripe.net/AS62248)                                                                          |             0    |       0    |      0.01 |         1 |
| 467 | [QuickMeg Inc](w/as_number/AS54702) [H](https://bgp.he.net/AS54702) [R](https://stat.ripe.net/AS54702)                                                                              |             0    |       0    |      0.01 |         1 |
| 468 | [Blix Solutions AS](w/as_number/AS50304) [H](https://bgp.he.net/AS50304) [R](https://stat.ripe.net/AS50304)                                                                         |             0    |       0    |      0.01 |         1 |
| 469 | [Aqua Ray SAS](w/as_number/AS41653) [H](https://bgp.he.net/AS41653) [R](https://stat.ripe.net/AS41653)                                                                              |             0    |       0    |      0.01 |         1 |
| 470 | [University of Michigan](w/as_number/AS36375) [H](https://bgp.he.net/AS36375) [R](https://stat.ripe.net/AS36375)                                                                    |             0    |       0    |      0.01 |         1 |
| 471 | [Kantonsschule Zug](w/as_number/AS34288) [H](https://bgp.he.net/AS34288) [R](https://stat.ripe.net/AS34288)                                                                         |             0    |       0    |      0.01 |         1 |
| 472 | [Labitat](w/as_number/AS205235) [H](https://bgp.he.net/AS205235) [R](https://stat.ripe.net/AS205235)                                                                                |             0    |       0    |      0.01 |         1 |
| 473 | [Streams Telecommunicationsservices GmbH](w/as_number/AS13022) [H](https://bgp.he.net/AS13022) [R](https://stat.ripe.net/AS13022)                                                   |             0    |       0    |      0.01 |         1 |
| 474 | [University Linz](w/as_number/AS1205) [H](https://bgp.he.net/AS1205) [R](https://stat.ripe.net/AS1205)                                                                              |             0    |       0    |      0    |        50 |
| 475 | [Namecheap, Inc.](w/as_number/AS22612) [H](https://bgp.he.net/AS22612) [R](https://stat.ripe.net/AS22612)                                                                           |             0    |       0    |      0    |        18 |
| 476 | [Wideband Networks Pty Ltd](w/as_number/AS4764) [H](https://bgp.he.net/AS4764) [R](https://stat.ripe.net/AS4764)                                                                    |             0    |       0    |      0    |        14 |
| 477 | [Charter Communications](w/as_number/AS20115) [H](https://bgp.he.net/AS20115) [R](https://stat.ripe.net/AS20115)                                                                    |             0    |       0    |      0    |        12 |
| 478 | [Korea Telecom](w/as_number/AS4766) [H](https://bgp.he.net/AS4766) [R](https://stat.ripe.net/AS4766)                                                                                |             0    |       0    |      0    |        11 |
| 479 | [Gigabit Hosting Sdn Bhd](w/as_number/AS55720) [H](https://bgp.he.net/AS55720) [R](https://stat.ripe.net/AS55720)                                                                   |             0    |       0    |      0    |        10 |
| 480 | [CenturyLink Communications, LLC](w/as_number/AS209) [H](https://bgp.he.net/AS209) [R](https://stat.ripe.net/AS209)                                                                 |             0    |       0    |      0    |        10 |
| 481 | [prgmr.com, Inc.](w/as_number/AS47066) [H](https://bgp.he.net/AS47066) [R](https://stat.ripe.net/AS47066)                                                                           |             0    |       0    |      0    |         9 |
| 482 | [Chunghwa Telecom Co., Ltd.](w/as_number/AS3462) [H](https://bgp.he.net/AS3462) [R](https://stat.ripe.net/AS3462)                                                                   |             0    |       0    |      0    |         9 |
| 483 | [Telefonica Germany GmbH &amp; Co.OHG](w/as_number/AS6805) [H](https://bgp.he.net/AS6805) [R](https://stat.ripe.net/AS6805)                                                         |             0    |       0    |      0    |         8 |
| 484 | [Microsoft Corporation](w/as_number/AS8075) [H](https://bgp.he.net/AS8075) [R](https://stat.ripe.net/AS8075)                                                                        |             0    |       0    |      0    |         7 |
| 485 | [Bell Canada](w/as_number/AS577) [H](https://bgp.he.net/AS577) [R](https://stat.ripe.net/AS577)                                                                                     |             0    |       0    |      0    |         7 |
| 486 | [Aokigahara SRL](w/as_number/AS215659) [H](https://bgp.he.net/AS215659) [R](https://stat.ripe.net/AS215659)                                                                         |             0    |       0    |      0    |         7 |
| 487 | [Shaw Communications Inc.](w/as_number/AS6327) [H](https://bgp.he.net/AS6327) [R](https://stat.ripe.net/AS6327)                                                                     |             0    |       0    |      0    |         6 |
| 488 | [Frontier Communications of America, Inc.](w/as_number/AS5650) [H](https://bgp.he.net/AS5650) [R](https://stat.ripe.net/AS5650)                                                     |             0    |       0    |      0    |         6 |
| 489 | [SUPERLOOP AUSTRALIA PTY LTD](w/as_number/AS38195) [H](https://bgp.he.net/AS38195) [R](https://stat.ripe.net/AS38195)                                                               |             0    |       0    |      0    |         6 |
| 490 | [Vodafone Libertel B.V.](w/as_number/AS33915) [H](https://bgp.he.net/AS33915) [R](https://stat.ripe.net/AS33915)                                                                    |             0    |       0    |      0    |         6 |
| 491 | [ecotel communication ag](w/as_number/AS12312) [H](https://bgp.he.net/AS12312) [R](https://stat.ripe.net/AS12312)                                                                   |             0    |       0    |      0    |         6 |
| 492 | [Charter Communications Inc](w/as_number/AS10796) [H](https://bgp.he.net/AS10796) [R](https://stat.ripe.net/AS10796)                                                                |             0    |       0    |      0    |         6 |
| 493 | [TPG Internet Pty Ltd](w/as_number/AS7545) [H](https://bgp.he.net/AS7545) [R](https://stat.ripe.net/AS7545)                                                                         |             0    |       0    |      0    |         5 |
| 494 | [Cablevision Systems Corp.](w/as_number/AS6128) [H](https://bgp.he.net/AS6128) [R](https://stat.ripe.net/AS6128)                                                                    |             0    |       0    |      0    |         5 |
| 495 | [TekSavvy Solutions, Inc.](w/as_number/AS5645) [H](https://bgp.he.net/AS5645) [R](https://stat.ripe.net/AS5645)                                                                     |             0    |       0    |      0    |         5 |
| 496 | [SIA Tet](w/as_number/AS47570) [H](https://bgp.he.net/AS47570) [R](https://stat.ripe.net/AS47570)                                                                                   |             0    |       0    |      0    |         5 |
| 497 | [GoDaddy.com, LLC](w/as_number/AS398101) [H](https://bgp.he.net/AS398101) [R](https://stat.ripe.net/AS398101)                                                                       |             0    |       0    |      0    |         5 |
| 498 | [Cox Communications Inc.](w/as_number/AS22773) [H](https://bgp.he.net/AS22773) [R](https://stat.ripe.net/AS22773)                                                                   |             0    |       0    |      0    |         5 |
| 499 | [InMotion Hosting, Inc.](w/as_number/AS22611) [H](https://bgp.he.net/AS22611) [R](https://stat.ripe.net/AS22611)                                                                    |             0    |       0    |      0    |         5 |
| 500 | [GLOBAL INTERNET SOLUTIONS LLC](w/as_number/AS207713) [H](https://bgp.he.net/AS207713) [R](https://stat.ripe.net/AS207713)                                                          |             0    |       0    |      0    |         5 |
| 501 | [Wholesail networks LLC](w/as_number/AS20055) [H](https://bgp.he.net/AS20055) [R](https://stat.ripe.net/AS20055)                                                                    |             0    |       0    |      0    |         5 |
| 502 | [EN Technologies Pte Ltd](w/as_number/AS133210) [H](https://bgp.he.net/AS133210) [R](https://stat.ripe.net/AS133210)                                                                |             0    |       0    |      0    |         5 |
| 503 | [Fastweb SpA](w/as_number/AS12874) [H](https://bgp.he.net/AS12874) [R](https://stat.ripe.net/AS12874)                                                                               |             0    |       0    |      0    |         5 |
| 504 | [Two Degrees Mobile Limited](w/as_number/AS9790) [H](https://bgp.he.net/AS9790) [R](https://stat.ripe.net/AS9790)                                                                   |             0    |       0    |      0    |         4 |
| 505 | [Mailbox Internet Hizmetleri Ltd. Sti.](w/as_number/AS62425) [H](https://bgp.he.net/AS62425) [R](https://stat.ripe.net/AS62425)                                                     |             0    |       0    |      0    |         4 |
| 506 | [Zappie Host LLC](w/as_number/AS61138) [H](https://bgp.he.net/AS61138) [R](https://stat.ripe.net/AS61138)                                                                           |             0    |       0    |      0    |         4 |
| 507 | [Videotron Ltee](w/as_number/AS5769) [H](https://bgp.he.net/AS5769) [R](https://stat.ripe.net/AS5769)                                                                               |             0    |       0    |      0    |         4 |
| 508 | [Sky UK Limited](w/as_number/AS5607) [H](https://bgp.he.net/AS5607) [R](https://stat.ripe.net/AS5607)                                                                               |             0    |       0    |      0    |         4 |
| 509 | [Hostinger International Limited](w/as_number/AS47583) [H](https://bgp.he.net/AS47583) [R](https://stat.ripe.net/AS47583)                                                           |             0    |       0    |      0    |         4 |
| 510 | [Alibaba US Technology Co., Ltd.](w/as_number/AS45102) [H](https://bgp.he.net/AS45102) [R](https://stat.ripe.net/AS45102)                                                           |             0    |       0    |      0    |         4 |
| 511 | [Prentiss County Electric Power Association](w/as_number/AS398242) [H](https://bgp.he.net/AS398242) [R](https://stat.ripe.net/AS398242)                                             |             0    |       0    |      0    |         4 |
| 512 | [SingNet Pte Ltd](w/as_number/AS3758) [H](https://bgp.he.net/AS3758) [R](https://stat.ripe.net/AS3758)                                                                              |             0    |       0    |      0    |         4 |
| 513 | [MULTACOM CORPORATION](w/as_number/AS35916) [H](https://bgp.he.net/AS35916) [R](https://stat.ripe.net/AS35916)                                                                      |             0    |       0    |      0    |         4 |
| 514 | [Metronet](w/as_number/AS30600) [H](https://bgp.he.net/AS30600) [R](https://stat.ripe.net/AS30600)                                                                                  |             0    |       0    |      0    |         4 |
| 515 | [Lyse Tele AS](w/as_number/AS29695) [H](https://bgp.he.net/AS29695) [R](https://stat.ripe.net/AS29695)                                                                              |             0    |       0    |      0    |         4 |
| 516 | [Ultahost, Inc.](w/as_number/AS214036) [H](https://bgp.he.net/AS214036) [R](https://stat.ripe.net/AS214036)                                                                         |             0    |       0    |      0    |         4 |
| 517 | [PT Cloud Hosting Indonesia](w/as_number/AS136052) [H](https://bgp.he.net/AS136052) [R](https://stat.ripe.net/AS136052)                                                             |             0    |       0    |      0    |         4 |
| 518 | [Telstra Limited](w/as_number/AS1221) [H](https://bgp.he.net/AS1221) [R](https://stat.ripe.net/AS1221)                                                                              |             0    |       0    |      0    |         4 |
| 519 | [Charter Communications Inc](w/as_number/AS11427) [H](https://bgp.he.net/AS11427) [R](https://stat.ripe.net/AS11427)                                                                |             0    |       0    |      0    |         4 |
| 520 | [Charter Communications Inc](w/as_number/AS11426) [H](https://bgp.he.net/AS11426) [R](https://stat.ripe.net/AS11426)                                                                |             0    |       0    |      0    |         4 |
| 521 | [EDPNET Belgium BV](w/as_number/AS9031) [H](https://bgp.he.net/AS9031) [R](https://stat.ripe.net/AS9031)                                                                            |             0    |       0    |      0    |         3 |
| 522 | [T-Mobile Austria GmbH](w/as_number/AS8412) [H](https://bgp.he.net/AS8412) [R](https://stat.ripe.net/AS8412)                                                                        |             0    |       0    |      0    |         3 |
| 523 | [SAKURA internet // HOKKAIDO BACKBONE](w/as_number/AS7684) [H](https://bgp.he.net/AS7684) [R](https://stat.ripe.net/AS7684)                                                         |             0    |       0    |      0    |         3 |
| 524 | [GMO Internet INC.](w/as_number/AS7506) [H](https://bgp.he.net/AS7506) [R](https://stat.ripe.net/AS7506)                                                                            |             0    |       0    |      0    |         3 |
| 525 | [Leaseweb USA, Inc.](w/as_number/AS7203) [H](https://bgp.he.net/AS7203) [R](https://stat.ripe.net/AS7203)                                                                           |             0    |       0    |      0    |         3 |
| 526 | [Verizon Business](w/as_number/AS6167) [H](https://bgp.he.net/AS6167) [R](https://stat.ripe.net/AS6167)                                                                             |             0    |       0    |      0    |         3 |
| 527 | [Synapsis.io](w/as_number/AS6145) [H](https://bgp.he.net/AS6145) [R](https://stat.ripe.net/AS6145)                                                                                  |             0    |       0    |      0    |         3 |
| 528 | [LEASEWEB SINGAPORE PTE. LTD.](w/as_number/AS59253) [H](https://bgp.he.net/AS59253) [R](https://stat.ripe.net/AS59253)                                                              |             0    |       0    |      0    |         3 |
| 529 | [LLC Smart Ape](w/as_number/AS56694) [H](https://bgp.he.net/AS56694) [R](https://stat.ripe.net/AS56694)                                                                             |             0    |       0    |      0    |         3 |
| 530 | [Metrabyte Co.,Ltd](w/as_number/AS56067) [H](https://bgp.he.net/AS56067) [R](https://stat.ripe.net/AS56067)                                                                         |             0    |       0    |      0    |         3 |
| 531 | [Hostwinds LLC.](w/as_number/AS54290) [H](https://bgp.he.net/AS54290) [R](https://stat.ripe.net/AS54290)                                                                            |             0    |       0    |      0    |         3 |
| 532 | [Global Layer B.V.](w/as_number/AS49453) [H](https://bgp.he.net/AS49453) [R](https://stat.ripe.net/AS49453)                                                                         |             0    |       0    |      0    |         3 |
| 533 | [NTT Communications Corporation](w/as_number/AS4713) [H](https://bgp.he.net/AS4713) [R](https://stat.ripe.net/AS4713)                                                               |             0    |       0    |      0    |         3 |
| 534 | [Hostcenter](w/as_number/AS45382) [H](https://bgp.he.net/AS45382) [R](https://stat.ripe.net/AS45382)                                                                                |             0    |       0    |      0    |         3 |
| 535 | [Redoubt Networks](w/as_number/AS400304) [H](https://bgp.he.net/AS400304) [R](https://stat.ripe.net/AS400304)                                                                       |             0    |       0    |      0    |         3 |
| 536 | [Leaseweb USA, Inc.](w/as_number/AS396190) [H](https://bgp.he.net/AS396190) [R](https://stat.ripe.net/AS396190)                                                                     |             0    |       0    |      0    |         3 |
| 537 | [Signet B.V.](w/as_number/AS35470) [H](https://bgp.he.net/AS35470) [R](https://stat.ripe.net/AS35470)                                                                               |             0    |       0    |      0    |         3 |
| 538 | [WholeSale Internet, Inc.](w/as_number/AS32097) [H](https://bgp.he.net/AS32097) [R](https://stat.ripe.net/AS32097)                                                                  |             0    |       0    |      0    |         3 |
| 539 | [FDCservers.net](w/as_number/AS30058) [H](https://bgp.he.net/AS30058) [R](https://stat.ripe.net/AS30058)                                                                            |             0    |       0    |      0    |         3 |
| 540 | [FiberState, LLC](w/as_number/AS26042) [H](https://bgp.he.net/AS26042) [R](https://stat.ripe.net/AS26042)                                                                           |             0    |       0    |      0    |         3 |
| 541 | [Two Degrees Mobile Limited](w/as_number/AS23655) [H](https://bgp.he.net/AS23655) [R](https://stat.ripe.net/AS23655)                                                                |             0    |       0    |      0    |         3 |
| 542 | [SERV.HOST GROUP LTD](w/as_number/AS207957) [H](https://bgp.he.net/AS207957) [R](https://stat.ripe.net/AS207957)                                                                    |             0    |       0    |      0    |         3 |
| 543 | [Leaseweb USA, Inc.](w/as_number/AS19148) [H](https://bgp.he.net/AS19148) [R](https://stat.ripe.net/AS19148)                                                                        |             0    |       0    |      0    |         3 |
| 544 | [Fort Hays State University](w/as_number/AS18460) [H](https://bgp.he.net/AS18460) [R](https://stat.ripe.net/AS18460)                                                                |             0    |       0    |      0    |         3 |
| 545 | [TOTHOST SOLUTIONS AND TECHNOLOGIES COMPANY LIMITED](w/as_number/AS151873) [H](https://bgp.he.net/AS151873) [R](https://stat.ripe.net/AS151873)                                     |             0    |       0    |      0    |         3 |
| 546 | [Evoxt Enterprise](w/as_number/AS149440) [H](https://bgp.he.net/AS149440) [R](https://stat.ripe.net/AS149440)                                                                       |             0    |       0    |      0    |         3 |
| 547 | [NYI](w/as_number/AS11403) [H](https://bgp.he.net/AS11403) [R](https://stat.ripe.net/AS11403)                                                                                       |             0    |       0    |      0    |         3 |
| 548 | [SAKURA internet // EAST JAPAN BACKBONE](w/as_number/AS9370) [H](https://bgp.he.net/AS9370) [R](https://stat.ripe.net/AS9370)                                                       |             0    |       0    |      0    |         2 |
| 549 | [EWE TEL GmbH](w/as_number/AS9145) [H](https://bgp.he.net/AS9145) [R](https://stat.ripe.net/AS9145)                                                                                 |             0    |       0    |      0    |         2 |
| 550 | [TalkTalk Communications Limited](w/as_number/AS9105) [H](https://bgp.he.net/AS9105) [R](https://stat.ripe.net/AS9105)                                                              |             0    |       0    |      0    |         2 |
| 551 | [Jump Networks Ltd](w/as_number/AS8943) [H](https://bgp.he.net/AS8943) [R](https://stat.ripe.net/AS8943)                                                                            |             0    |       0    |      0    |         2 |
| 552 | [Melbikomas UAB](w/as_number/AS8849) [H](https://bgp.he.net/AS8849) [R](https://stat.ripe.net/AS8849)                                                                               |             0    |       0    |      0    |         2 |
| 553 | [Bell Canada](w/as_number/AS855) [H](https://bgp.he.net/AS855) [R](https://stat.ripe.net/AS855)                                                                                     |             0    |       0    |      0    |         2 |
| 554 | [INTERNET AG Global Network](w/as_number/AS8495) [H](https://bgp.he.net/AS8495) [R](https://stat.ripe.net/AS8495)                                                                   |             0    |       0    |      0    |         2 |
| 555 | [A1 Telekom Austria AG](w/as_number/AS8447) [H](https://bgp.he.net/AS8447) [R](https://stat.ripe.net/AS8447)                                                                        |             0    |       0    |      0    |         2 |
| 556 | [NetCologne Gesellschaft fur Telekommunikation mbH](w/as_number/AS8422) [H](https://bgp.he.net/AS8422) [R](https://stat.ripe.net/AS8422)                                            |             0    |       0    |      0    |         2 |
| 557 | [TELEKOM SRBIJA a.d.](w/as_number/AS8400) [H](https://bgp.he.net/AS8400) [R](https://stat.ripe.net/AS8400)                                                                          |             0    |       0    |      0    |         2 |
| 558 | [kabelplus GmbH](w/as_number/AS8339) [H](https://bgp.he.net/AS8339) [R](https://stat.ripe.net/AS8339)                                                                               |             0    |       0    |      0    |         2 |
| 559 | [Saskatchewan Telecommunications](w/as_number/AS803) [H](https://bgp.he.net/AS803) [R](https://stat.ripe.net/AS803)                                                                 |             0    |       0    |      0    |         2 |
| 560 | [Viettel Group](w/as_number/AS7552) [H](https://bgp.he.net/AS7552) [R](https://stat.ripe.net/AS7552)                                                                                |             0    |       0    |      0    |         2 |
| 561 | [Ote SA Hellenic Telecommunications Organisation](w/as_number/AS6799) [H](https://bgp.he.net/AS6799) [R](https://stat.ripe.net/AS6799)                                              |             0    |       0    |      0    |         2 |
| 562 | [Human-life Information Platforms Institute](w/as_number/AS63806) [H](https://bgp.he.net/AS63806) [R](https://stat.ripe.net/AS63806)                                                |             0    |       0    |      0    |         2 |
| 563 | [PURtel.com GmbH](w/as_number/AS62336) [H](https://bgp.he.net/AS62336) [R](https://stat.ripe.net/AS62336)                                                                           |             0    |       0    |      0    |         2 |
| 564 | [Clouvider Limited](w/as_number/AS62240) [H](https://bgp.he.net/AS62240) [R](https://stat.ripe.net/AS62240)                                                                         |             0    |       0    |      0    |         2 |
| 565 | [AKILE LTD](w/as_number/AS61112) [H](https://bgp.he.net/AS61112) [R](https://stat.ripe.net/AS61112)                                                                                 |             0    |       0    |      0    |         2 |
| 566 | [servinga GmbH](w/as_number/AS58329) [H](https://bgp.he.net/AS58329) [R](https://stat.ripe.net/AS58329)                                                                             |             0    |       0    |      0    |         2 |
| 567 | [Adman LLC](w/as_number/AS57494) [H](https://bgp.he.net/AS57494) [R](https://stat.ripe.net/AS57494)                                                                                 |             0    |       0    |      0    |         2 |
| 568 | [CGI GLOBAL LIMITED](w/as_number/AS56971) [H](https://bgp.he.net/AS56971) [R](https://stat.ripe.net/AS56971)                                                                        |             0    |       0    |      0    |         2 |
| 569 | [Digital Storage Company Limited](w/as_number/AS56153) [H](https://bgp.he.net/AS56153) [R](https://stat.ripe.net/AS56153)                                                           |             0    |       0    |      0    |         2 |
| 570 | [O2 Czech Republic, a.s.](w/as_number/AS5610) [H](https://bgp.he.net/AS5610) [R](https://stat.ripe.net/AS5610)                                                                      |             0    |       0    |      0    |         2 |
| 571 | [Magyar Telekom plc.](w/as_number/AS5483) [H](https://bgp.he.net/AS5483) [R](https://stat.ripe.net/AS5483)                                                                          |             0    |       0    |      0    |         2 |
| 572 | [Genesis Hosting Solutions, LLC](w/as_number/AS53914) [H](https://bgp.he.net/AS53914) [R](https://stat.ripe.net/AS53914)                                                            |             0    |       0    |      0    |         2 |
| 573 | [Tele Columbus AG](w/as_number/AS50436) [H](https://bgp.he.net/AS50436) [R](https://stat.ripe.net/AS50436)                                                                          |             0    |       0    |      0    |         2 |
| 574 | [Info Data Center Ltd.](w/as_number/AS48900) [H](https://bgp.he.net/AS48900) [R](https://stat.ripe.net/AS48900)                                                                     |             0    |       0    |      0    |         2 |
| 575 | [SingTel Optus Pty Ltd](w/as_number/AS4804) [H](https://bgp.he.net/AS4804) [R](https://stat.ripe.net/AS4804)                                                                        |             0    |       0    |      0    |         2 |
| 576 | [Spark New Zealand Trading Limited](w/as_number/AS4771) [H](https://bgp.he.net/AS4771) [R](https://stat.ripe.net/AS4771)                                                            |             0    |       0    |      0    |         2 |
| 577 | [ARDH GLOBAL INDONESIA, PT](w/as_number/AS45731) [H](https://bgp.he.net/AS45731) [R](https://stat.ripe.net/AS45731)                                                                 |             0    |       0    |      0    |         2 |
| 578 | [O.M.C. COMPUTERS &amp; COMMUNICATIONS LTD](w/as_number/AS44709) [H](https://bgp.he.net/AS44709) [R](https://stat.ripe.net/AS44709)                                                 |             0    |       0    |      0    |         2 |
| 579 | [Codehof LLC](w/as_number/AS400771) [H](https://bgp.he.net/AS400771) [R](https://stat.ripe.net/AS400771)                                                                            |             0    |       0    |      0    |         2 |
| 580 | [Microtronix ESolutions, LLC](w/as_number/AS400175) [H](https://bgp.he.net/AS400175) [R](https://stat.ripe.net/AS400175)                                                            |             0    |       0    |      0    |         2 |
| 581 | [Hostodo](w/as_number/AS399804) [H](https://bgp.he.net/AS399804) [R](https://stat.ripe.net/AS399804)                                                                                |             0    |       0    |      0    |         2 |
| 582 | [Snaju Development](w/as_number/AS399646) [H](https://bgp.he.net/AS399646) [R](https://stat.ripe.net/AS399646)                                                                      |             0    |       0    |      0    |         2 |
| 583 | [Lounea Palvelut Oy](w/as_number/AS39699) [H](https://bgp.he.net/AS39699) [R](https://stat.ripe.net/AS39699)                                                                        |             0    |       0    |      0    |         2 |
| 584 | [Latitude.sh](w/as_number/AS396356) [H](https://bgp.he.net/AS396356) [R](https://stat.ripe.net/AS396356)                                                                            |             0    |       0    |      0    |         2 |
| 585 | [Hub66, Inc](w/as_number/AS395510) [H](https://bgp.he.net/AS395510) [R](https://stat.ripe.net/AS395510)                                                                             |             0    |       0    |      0    |         2 |
| 586 | [GTT Communications Inc.](w/as_number/AS3257) [H](https://bgp.he.net/AS3257) [R](https://stat.ripe.net/AS3257)                                                                      |             0    |       0    |      0    |         2 |
| 587 | [MEO - SERVICOS DE COMUNICACOES E MULTIMEDIA S.A.](w/as_number/AS3243) [H](https://bgp.he.net/AS3243) [R](https://stat.ripe.net/AS3243)                                             |             0    |       0    |      0    |         2 |
| 588 | [xTom GmbH](w/as_number/AS3214) [H](https://bgp.he.net/AS3214) [R](https://stat.ripe.net/AS3214)                                                                                    |             0    |       0    |      0    |         2 |
| 589 | [Mediacom Communications Corp](w/as_number/AS30036) [H](https://bgp.he.net/AS30036) [R](https://stat.ripe.net/AS30036)                                                              |             0    |       0    |      0    |         2 |
| 590 | [National Institute of Informatics](w/as_number/AS2907) [H](https://bgp.he.net/AS2907) [R](https://stat.ripe.net/AS2907)                                                            |             0    |       0    |      0    |         2 |
| 591 | [Leaseweb USA, Inc.](w/as_number/AS27411) [H](https://bgp.he.net/AS27411) [R](https://stat.ripe.net/AS27411)                                                                        |             0    |       0    |      0    |         2 |
| 592 | [IT7 Networks Inc](w/as_number/AS25820) [H](https://bgp.he.net/AS25820) [R](https://stat.ripe.net/AS25820)                                                                          |             0    |       0    |      0    |         2 |
| 593 | [Zenlayer Inc](w/as_number/AS21859) [H](https://bgp.he.net/AS21859) [R](https://stat.ripe.net/AS21859)                                                                              |             0    |       0    |      0    |         2 |
| 594 | [HostingBazis Beteti Tarsasag](w/as_number/AS215904) [H](https://bgp.he.net/AS215904) [R](https://stat.ripe.net/AS215904)                                                           |             0    |       0    |      0    |         2 |
| 595 | [Bullet Group LTD](w/as_number/AS215762) [H](https://bgp.he.net/AS215762) [R](https://stat.ripe.net/AS215762)                                                                       |             0    |       0    |      0    |         2 |
| 596 | [Silent Connection Ltd.](w/as_number/AS215240) [H](https://bgp.he.net/AS215240) [R](https://stat.ripe.net/AS215240)                                                                 |             0    |       0    |      0    |         2 |
| 597 | [LLC IT Business](w/as_number/AS215116) [H](https://bgp.he.net/AS215116) [R](https://stat.ripe.net/AS215116)                                                                        |             0    |       0    |      0    |         2 |
| 598 | [Dominic Scholz trading as ITP-Solutions GmbH &amp; Co. KG](w/as_number/AS213250) [H](https://bgp.he.net/AS213250) [R](https://stat.ripe.net/AS213250)                              |             0    |       0    |      0    |         2 |
| 599 | [Hetzner Online GmbH](w/as_number/AS213230) [H](https://bgp.he.net/AS213230) [R](https://stat.ripe.net/AS213230)                                                                    |             0    |       0    |      0    |         2 |
| 600 | [Signet B.V.](w/as_number/AS20857) [H](https://bgp.he.net/AS20857) [R](https://stat.ripe.net/AS20857)                                                                               |             0    |       0    |      0    |         2 |
| 601 | [Amarutu Technology Ltd](w/as_number/AS206264) [H](https://bgp.he.net/AS206264) [R](https://stat.ripe.net/AS206264)                                                                 |             0    |       0    |      0    |         2 |
| 602 | [FIRST SERVER LIMITED](w/as_number/AS204997) [H](https://bgp.he.net/AS204997) [R](https://stat.ripe.net/AS204997)                                                                   |             0    |       0    |      0    |         2 |
| 603 | [Hiper A/S](w/as_number/AS203953) [H](https://bgp.he.net/AS203953) [R](https://stat.ripe.net/AS203953)                                                                              |             0    |       0    |      0    |         2 |
| 604 | [HJELM ENTERPRISES AB](w/as_number/AS199950) [H](https://bgp.he.net/AS199950) [R](https://stat.ripe.net/AS199950)                                                                   |             0    |       0    |      0    |         2 |
| 605 | [TechnoLux Ltd.](w/as_number/AS199173) [H](https://bgp.he.net/AS199173) [R](https://stat.ripe.net/AS199173)                                                                         |             0    |       0    |      0    |         2 |
| 606 | [Viewqwest Pte Ltd](w/as_number/AS18106) [H](https://bgp.he.net/AS18106) [R](https://stat.ripe.net/AS18106)                                                                         |             0    |       0    |      0    |         2 |
| 607 | [Quickline AG](w/as_number/AS15600) [H](https://bgp.he.net/AS15600) [R](https://stat.ripe.net/AS15600)                                                                              |             0    |       0    |      0    |         2 |
| 608 | [Telstra Limited](w/as_number/AS135887) [H](https://bgp.he.net/AS135887) [R](https://stat.ripe.net/AS135887)                                                                        |             0    |       0    |      0    |         2 |
| 609 | [Mammoth Media Pty Ltd](w/as_number/AS133159) [H](https://bgp.he.net/AS133159) [R](https://stat.ripe.net/AS133159)                                                                  |             0    |       0    |      0    |         2 |
| 610 | [Xserver Inc.](w/as_number/AS131965) [H](https://bgp.he.net/AS131965) [R](https://stat.ripe.net/AS131965)                                                                           |             0    |       0    |      0    |         2 |
| 611 | [Charter Communications Inc](w/as_number/AS11351) [H](https://bgp.he.net/AS11351) [R](https://stat.ripe.net/AS11351)                                                                |             0    |       0    |      0    |         2 |
| 612 | [SUPERLOOP AUSTRALIA PTY LTD](w/as_number/AS10143) [H](https://bgp.he.net/AS10143) [R](https://stat.ripe.net/AS10143)                                                               |             0    |       0    |      0    |         2 |
| 613 | [Carnegie Mellon University](w/as_number/AS9) [H](https://bgp.he.net/AS9) [R](https://stat.ripe.net/AS9)                                                                            |             0    |       0    |      0    |         1 |
| 614 | [Maxis Broadband Sdn Bhd](w/as_number/AS9534) [H](https://bgp.he.net/AS9534) [R](https://stat.ripe.net/AS9534)                                                                      |             0    |       0    |      0    |         1 |
| 615 | [HAONAN YANG TRADING AS AUGUST INTERNET](w/as_number/AS945) [H](https://bgp.he.net/AS945) [R](https://stat.ripe.net/AS945)                                                          |             0    |       0    |      0    |         1 |
| 616 | [VOCUS PTY LTD](w/as_number/AS9443) [H](https://bgp.he.net/AS9443) [R](https://stat.ripe.net/AS9443)                                                                                |             0    |       0    |      0    |         1 |
| 617 | [SAKURA internet // WEST JAPAN BACKBONE](w/as_number/AS9371) [H](https://bgp.he.net/AS9371) [R](https://stat.ripe.net/AS9371)                                                       |             0    |       0    |      0    |         1 |
| 618 | [SK Broadband Co Ltd](w/as_number/AS9318) [H](https://bgp.he.net/AS9318) [R](https://stat.ripe.net/AS9318)                                                                          |             0    |       0    |      0    |         1 |
| 619 | [Philippine Long Distance Telephone Co.](w/as_number/AS9299) [H](https://bgp.he.net/AS9299) [R](https://stat.ripe.net/AS9299)                                                       |             0    |       0    |      0    |         1 |
| 620 | [Hong Kong Broadband Network Ltd](w/as_number/AS9269) [H](https://bgp.he.net/AS9269) [R](https://stat.ripe.net/AS9269)                                                              |             0    |       0    |      0    |         1 |
| 621 | [Wobcom GmbH](w/as_number/AS9136) [H](https://bgp.he.net/AS9136) [R](https://stat.ripe.net/AS9136)                                                                                  |             0    |       0    |      0    |         1 |
| 622 | [DMIT Cloud Services](w/as_number/AS906) [H](https://bgp.he.net/AS906) [R](https://stat.ripe.net/AS906)                                                                             |             0    |       0    |      0    |         1 |
| 623 | [EWE TEL GmbH](w/as_number/AS9066) [H](https://bgp.he.net/AS9066) [R](https://stat.ripe.net/AS9066)                                                                                 |             0    |       0    |      0    |         1 |
| 624 | [Host Europe GmbH](w/as_number/AS8972) [H](https://bgp.he.net/AS8972) [R](https://stat.ripe.net/AS8972)                                                                             |             0    |       0    |      0    |         1 |
| 625 | [Orange Romania S.A.](w/as_number/AS8953) [H](https://bgp.he.net/AS8953) [R](https://stat.ripe.net/AS8953)                                                                          |             0    |       0    |      0    |         1 |
| 626 | [tal.de GmbH](w/as_number/AS8820) [H](https://bgp.he.net/AS8820) [R](https://stat.ripe.net/AS8820)                                                                                  |             0    |       0    |      0    |         1 |
| 627 | [A1 Bulgaria EAD](w/as_number/AS8717) [H](https://bgp.he.net/AS8717) [R](https://stat.ripe.net/AS8717)                                                                              |             0    |       0    |      0    |         1 |
| 628 | [dogado GmbH](w/as_number/AS8648) [H](https://bgp.he.net/AS8648) [R](https://stat.ripe.net/AS8648)                                                                                  |             0    |       0    |      0    |         1 |
| 629 | [Hutchison Drei Austria GmbH](w/as_number/AS8437) [H](https://bgp.he.net/AS8437) [R](https://stat.ripe.net/AS8437)                                                                  |             0    |       0    |      0    |         1 |
| 630 | [Zayo Infrastructure France SA](w/as_number/AS8218) [H](https://bgp.he.net/AS8218) [R](https://stat.ripe.net/AS8218)                                                                |             0    |       0    |      0    |         1 |
| 631 | [Cogeco Connexion Inc.](w/as_number/AS7992) [H](https://bgp.he.net/AS7992) [R](https://stat.ripe.net/AS7992)                                                                        |             0    |       0    |      0    |         1 |
| 632 | [Koumbit](w/as_number/AS7765) [H](https://bgp.he.net/AS7765) [R](https://stat.ripe.net/AS7765)                                                                                      |             0    |       0    |      0    |         1 |
| 633 | [Grande Communications Networks, LLC](w/as_number/AS7459) [H](https://bgp.he.net/AS7459) [R](https://stat.ripe.net/AS7459)                                                          |             0    |       0    |      0    |         1 |
| 634 | [Windstream Communications LLC](w/as_number/AS7029) [H](https://bgp.he.net/AS7029) [R](https://stat.ripe.net/AS7029)                                                                |             0    |       0    |      0    |         1 |
| 635 | [Liberty Global B.V.](w/as_number/AS6830) [H](https://bgp.he.net/AS6830) [R](https://stat.ripe.net/AS6830)                                                                          |             0    |       0    |      0    |         1 |
| 636 | [ANDORRA TELECOM, S.A.U.](w/as_number/AS6752) [H](https://bgp.he.net/AS6752) [R](https://stat.ripe.net/AS6752)                                                                      |             0    |       0    |      0    |         1 |
| 637 | [Breitband in Bayern GmbH](w/as_number/AS64396) [H](https://bgp.he.net/AS64396) [R](https://stat.ripe.net/AS64396)                                                                  |             0    |       0    |      0    |         1 |
| 638 | [UnReal Servers, LLC](w/as_number/AS64236) [H](https://bgp.he.net/AS64236) [R](https://stat.ripe.net/AS64236)                                                                       |             0    |       0    |      0    |         1 |
| 639 | [Vetta Online Ltd](w/as_number/AS64073) [H](https://bgp.he.net/AS64073) [R](https://stat.ripe.net/AS64073)                                                                          |             0    |       0    |      0    |         1 |
| 640 | [JMF Investment &amp; Technology PTY LTD](w/as_number/AS63997) [H](https://bgp.he.net/AS63997) [R](https://stat.ripe.net/AS63997)                                                   |             0    |       0    |      0    |         1 |
| 641 | [Ready Server Pte Ltd](w/as_number/AS63930) [H](https://bgp.he.net/AS63930) [R](https://stat.ripe.net/AS63930)                                                                      |             0    |       0    |      0    |         1 |
| 642 | [XMission, L.C.](w/as_number/AS6315) [H](https://bgp.he.net/AS6315) [R](https://stat.ripe.net/AS6315)                                                                               |             0    |       0    |      0    |         1 |
| 643 | [ANS ACADEMY LIMITED](w/as_number/AS61323) [H](https://bgp.he.net/AS61323) [R](https://stat.ripe.net/AS61323)                                                                       |             0    |       0    |      0    |         1 |
| 644 | [Akenes SA](w/as_number/AS61098) [H](https://bgp.he.net/AS61098) [R](https://stat.ripe.net/AS61098)                                                                                 |             0    |       0    |      0    |         1 |
| 645 | [Servereasy Srl](w/as_number/AS60798) [H](https://bgp.he.net/AS60798) [R](https://stat.ripe.net/AS60798)                                                                            |             0    |       0    |      0    |         1 |
| 646 | [Inovare-Prim SRL](w/as_number/AS60602) [H](https://bgp.he.net/AS60602) [R](https://stat.ripe.net/AS60602)                                                                          |             0    |       0    |      0    |         1 |
| 647 | [KomMITT-Ratingen GmbH](w/as_number/AS60522) [H](https://bgp.he.net/AS60522) [R](https://stat.ripe.net/AS60522)                                                                     |             0    |       0    |      0    |         1 |
| 648 | [Calypso IT Services GmbH](w/as_number/AS60251) [H](https://bgp.he.net/AS60251) [R](https://stat.ripe.net/AS60251)                                                                  |             0    |       0    |      0    |         1 |
| 649 | [Nowatel Sp. z o.o.](w/as_number/AS60191) [H](https://bgp.he.net/AS60191) [R](https://stat.ripe.net/AS60191)                                                                        |             0    |       0    |      0    |         1 |
| 650 | [High5 B.V.](w/as_number/AS60131) [H](https://bgp.he.net/AS60131) [R](https://stat.ripe.net/AS60131)                                                                                |             0    |       0    |      0    |         1 |
| 651 | [Fiberstream 87 AG](w/as_number/AS60016) [H](https://bgp.he.net/AS60016) [R](https://stat.ripe.net/AS60016)                                                                         |             0    |       0    |      0    |         1 |
| 652 | [BFB ONE FZ-LLC](w/as_number/AS59878) [H](https://bgp.he.net/AS59878) [R](https://stat.ripe.net/AS59878)                                                                            |             0    |       0    |      0    |         1 |
| 653 | [Marco Sandro Naef](w/as_number/AS59741) [H](https://bgp.he.net/AS59741) [R](https://stat.ripe.net/AS59741)                                                                         |             0    |       0    |      0    |         1 |
| 654 | [Livenet Sp. z o.o.](w/as_number/AS59491) [H](https://bgp.he.net/AS59491) [R](https://stat.ripe.net/AS59491)                                                                        |             0    |       0    |      0    |         1 |
| 655 | [Andrzej Szreter AMSNET](w/as_number/AS59444) [H](https://bgp.he.net/AS59444) [R](https://stat.ripe.net/AS59444)                                                                    |             0    |       0    |      0    |         1 |
| 656 | [uvensys GmbH](w/as_number/AS58010) [H](https://bgp.he.net/AS58010) [R](https://stat.ripe.net/AS58010)                                                                              |             0    |       0    |      0    |         1 |
| 657 | [Redge Technologies sp. z o.o.](w/as_number/AS57811) [H](https://bgp.he.net/AS57811) [R](https://stat.ripe.net/AS57811)                                                             |             0    |       0    |      0    |         1 |
| 658 | [REBA Communications BV](w/as_number/AS56611) [H](https://bgp.he.net/AS56611) [R](https://stat.ripe.net/AS56611)                                                                    |             0    |       0    |      0    |         1 |
| 659 | [TOV &quot;Global-NET&quot;](w/as_number/AS56610) [H](https://bgp.he.net/AS56610) [R](https://stat.ripe.net/AS56610)                                                                |             0    |       0    |      0    |         1 |
| 660 | [MYREPUBLIC LIMITED](w/as_number/AS56300) [H](https://bgp.he.net/AS56300) [R](https://stat.ripe.net/AS56300)                                                                        |             0    |       0    |      0    |         1 |
| 661 | [Voyager Internet Ltd.](w/as_number/AS56030) [H](https://bgp.he.net/AS56030) [R](https://stat.ripe.net/AS56030)                                                                     |             0    |       0    |      0    |         1 |
| 662 | [PT. Beon Intermedia](w/as_number/AS55688) [H](https://bgp.he.net/AS55688) [R](https://stat.ripe.net/AS55688)                                                                       |             0    |       0    |      0    |         1 |
| 663 | [Korea Data Telecommunication Co., Ltd.](w/as_number/AS55592) [H](https://bgp.he.net/AS55592) [R](https://stat.ripe.net/AS55592)                                                    |             0    |       0    |      0    |         1 |
| 664 | [Starhub Ltd.](w/as_number/AS55430) [H](https://bgp.he.net/AS55430) [R](https://stat.ripe.net/AS55430)                                                                              |             0    |       0    |      0    |         1 |
| 665 | [Polytechnic Institute of NYU](w/as_number/AS54965) [H](https://bgp.he.net/AS54965) [R](https://stat.ripe.net/AS54965)                                                              |             0    |       0    |      0    |         1 |
| 666 | [conova communications GmbH](w/as_number/AS5404) [H](https://bgp.he.net/AS5404) [R](https://stat.ripe.net/AS5404)                                                                   |             0    |       0    |      0    |         1 |
| 667 | [Alf servis, s.r.o.](w/as_number/AS52092) [H](https://bgp.he.net/AS52092) [R](https://stat.ripe.net/AS52092)                                                                        |             0    |       0    |      0    |         1 |
| 668 | [GlobalConnect AB](w/as_number/AS51815) [H](https://bgp.he.net/AS51815) [R](https://stat.ripe.net/AS51815)                                                                          |             0    |       0    |      0    |         1 |
| 669 | [&quot;X-City&quot; Ltd.](w/as_number/AS51784) [H](https://bgp.he.net/AS51784) [R](https://stat.ripe.net/AS51784)                                                                   |             0    |       0    |      0    |         1 |
| 670 | [Non-profit organization Jablonka.cz](w/as_number/AS51744) [H](https://bgp.he.net/AS51744) [R](https://stat.ripe.net/AS51744)                                                       |             0    |       0    |      0    |         1 |
| 671 | [AltusHost B.V.](w/as_number/AS51430) [H](https://bgp.he.net/AS51430) [R](https://stat.ripe.net/AS51430)                                                                            |             0    |       0    |      0    |         1 |
| 672 | [Multiplay Sp. z o.o. Sp. K.](w/as_number/AS51175) [H](https://bgp.he.net/AS51175) [R](https://stat.ripe.net/AS51175)                                                               |             0    |       0    |      0    |         1 |
| 673 | [Brightbox Systems Ltd](w/as_number/AS51059) [H](https://bgp.he.net/AS51059) [R](https://stat.ripe.net/AS51059)                                                                     |             0    |       0    |      0    |         1 |
| 674 | [CLOUDI NEXTGEN SL](w/as_number/AS49635) [H](https://bgp.he.net/AS49635) [R](https://stat.ripe.net/AS49635)                                                                         |             0    |       0    |      0    |         1 |
| 675 | [UNITEL-MEDIA Sp. z o.o.](w/as_number/AS49601) [H](https://bgp.he.net/AS49601) [R](https://stat.ripe.net/AS49601)                                                                   |             0    |       0    |      0    |         1 |
| 676 | [CLDIN B.V.](w/as_number/AS48635) [H](https://bgp.he.net/AS48635) [R](https://stat.ripe.net/AS48635)                                                                                |             0    |       0    |      0    |         1 |
| 677 | [SnapServ Ltd](w/as_number/AS48550) [H](https://bgp.he.net/AS48550) [R](https://stat.ripe.net/AS48550)                                                                              |             0    |       0    |      0    |         1 |
| 678 | [Trooli Ltd.](w/as_number/AS48101) [H](https://bgp.he.net/AS48101) [R](https://stat.ripe.net/AS48101)                                                                               |             0    |       0    |      0    |         1 |
| 679 | [Nessus GmbH](w/as_number/AS47692) [H](https://bgp.he.net/AS47692) [R](https://stat.ripe.net/AS47692)                                                                               |             0    |       0    |      0    |         1 |
| 680 | [iiNet Limited](w/as_number/AS4739) [H](https://bgp.he.net/AS4739) [R](https://stat.ripe.net/AS4739)                                                                                |             0    |       0    |      0    |         1 |
| 681 | [Crown Castle Fiber LLC](w/as_number/AS46887) [H](https://bgp.he.net/AS46887) [R](https://stat.ripe.net/AS46887)                                                                    |             0    |       0    |      0    |         1 |
| 682 | [Asahi Net, Inc.](w/as_number/AS4685) [H](https://bgp.he.net/AS4685) [R](https://stat.ripe.net/AS4685)                                                                              |             0    |       0    |      0    |         1 |
| 683 | [Southwest Arkansas Telephone Cooperative](w/as_number/AS46632) [H](https://bgp.he.net/AS46632) [R](https://stat.ripe.net/AS46632)                                                  |             0    |       0    |      0    |         1 |
| 684 | [Sonic Telecom LLC](w/as_number/AS46375) [H](https://bgp.he.net/AS46375) [R](https://stat.ripe.net/AS46375)                                                                         |             0    |       0    |      0    |         1 |
| 685 | [Exa Bytes Network Sdn.Bhd.](w/as_number/AS46015) [H](https://bgp.he.net/AS46015) [R](https://stat.ripe.net/AS46015)                                                                |             0    |       0    |      0    |         1 |
| 686 | [VNPT Corp](w/as_number/AS45899) [H](https://bgp.he.net/AS45899) [R](https://stat.ripe.net/AS45899)                                                                                 |             0    |       0    |      0    |         1 |
| 687 | [Triple T Broadband Public Company Limited](w/as_number/AS45758) [H](https://bgp.he.net/AS45758) [R](https://stat.ripe.net/AS45758)                                                 |             0    |       0    |      0    |         1 |
| 688 | [Net Onboard Sdn Bhd](w/as_number/AS45144) [H](https://bgp.he.net/AS45144) [R](https://stat.ripe.net/AS45144)                                                                       |             0    |       0    |      0    |         1 |
| 689 | [Propelin Consulting S.L.U.](w/as_number/AS45037) [H](https://bgp.he.net/AS45037) [R](https://stat.ripe.net/AS45037)                                                                |             0    |       0    |      0    |         1 |
| 690 | [Denis Pavlovich Semenyuk](w/as_number/AS44820) [H](https://bgp.he.net/AS44820) [R](https://stat.ripe.net/AS44820)                                                                  |             0    |       0    |      0    |         1 |
| 691 | [STARNET, s.r.o.](w/as_number/AS44489) [H](https://bgp.he.net/AS44489) [R](https://stat.ripe.net/AS44489)                                                                           |             0    |       0    |      0    |         1 |
| 692 | [The Mastermind Holding B.V.](w/as_number/AS44103) [H](https://bgp.he.net/AS44103) [R](https://stat.ripe.net/AS44103)                                                               |             0    |       0    |      0    |         1 |
| 693 | [Hi3G Access AB](w/as_number/AS44034) [H](https://bgp.he.net/AS44034) [R](https://stat.ripe.net/AS44034)                                                                            |             0    |       0    |      0    |         1 |
| 694 | [Netia SA](w/as_number/AS43939) [H](https://bgp.he.net/AS43939) [R](https://stat.ripe.net/AS43939)                                                                                  |             0    |       0    |      0    |         1 |
| 695 | [HOSTERION SRL](w/as_number/AS43927) [H](https://bgp.he.net/AS43927) [R](https://stat.ripe.net/AS43927)                                                                             |             0    |       0    |      0    |         1 |
| 696 | [MDlink online service center GmbH](w/as_number/AS43341) [H](https://bgp.he.net/AS43341) [R](https://stat.ripe.net/AS43341)                                                         |             0    |       0    |      0    |         1 |
| 697 | [Trunk Networks LTD](w/as_number/AS43180) [H](https://bgp.he.net/AS43180) [R](https://stat.ripe.net/AS43180)                                                                        |             0    |       0    |      0    |         1 |
| 698 | [inexio Informationstechnologie und Telekommunikation Gmbh](w/as_number/AS42652) [H](https://bgp.he.net/AS42652) [R](https://stat.ripe.net/AS42652)                                 |             0    |       0    |      0    |         1 |
| 699 | [Vialis SEM](w/as_number/AS42487) [H](https://bgp.he.net/AS42487) [R](https://stat.ripe.net/AS42487)                                                                                |             0    |       0    |      0    |         1 |
| 700 | [Sumofiber](w/as_number/AS4226) [H](https://bgp.he.net/AS4226) [R](https://stat.ripe.net/AS4226)                                                                                    |             0    |       0    |      0    |         1 |
| 701 | [NextGenWebs, S.L.](w/as_number/AS41608) [H](https://bgp.he.net/AS41608) [R](https://stat.ripe.net/AS41608)                                                                         |             0    |       0    |      0    |         1 |
| 702 | [Bart Vrancken trading as MLaB](w/as_number/AS41047) [H](https://bgp.he.net/AS41047) [R](https://stat.ripe.net/AS41047)                                                             |             0    |       0    |      0    |         1 |
| 703 | [Harley Security Solutions LLC](w/as_number/AS40924) [H](https://bgp.he.net/AS40924) [R](https://stat.ripe.net/AS40924)                                                             |             0    |       0    |      0    |         1 |
| 704 | [CLARKSVILLE DEPARTMENT OF ELECTRICITY](w/as_number/AS40749) [H](https://bgp.he.net/AS40749) [R](https://stat.ripe.net/AS40749)                                                     |             0    |       0    |      0    |         1 |
| 705 | [Clearwave Communications](w/as_number/AS40702) [H](https://bgp.he.net/AS40702) [R](https://stat.ripe.net/AS40702)                                                                  |             0    |       0    |      0    |         1 |
| 706 | [Mach Dilemma, LLC](w/as_number/AS40138) [H](https://bgp.he.net/AS40138) [R](https://stat.ripe.net/AS40138)                                                                         |             0    |       0    |      0    |         1 |
| 707 | [EKABI](w/as_number/AS401115) [H](https://bgp.he.net/AS401115) [R](https://stat.ripe.net/AS401115)                                                                                  |             0    |       0    |      0    |         1 |
| 708 | [DHI TECHNICAL SERVICES LLC](w/as_number/AS400848) [H](https://bgp.he.net/AS400848) [R](https://stat.ripe.net/AS400848)                                                             |             0    |       0    |      0    |         1 |
| 709 | [Weston Reed, Sole Proprietorship](w/as_number/AS400564) [H](https://bgp.he.net/AS400564) [R](https://stat.ripe.net/AS400564)                                                       |             0    |       0    |      0    |         1 |
| 710 | [Vulpine Networks](w/as_number/AS400442) [H](https://bgp.he.net/AS400442) [R](https://stat.ripe.net/AS400442)                                                                       |             0    |       0    |      0    |         1 |
| 711 | [Skysilk](w/as_number/AS399334) [H](https://bgp.he.net/AS399334) [R](https://stat.ripe.net/AS399334)                                                                                |             0    |       0    |      0    |         1 |
| 712 | [OXIO](w/as_number/AS398721) [H](https://bgp.he.net/AS398721) [R](https://stat.ripe.net/AS398721)                                                                                   |             0    |       0    |      0    |         1 |
| 713 | [Aalto University Student Union](w/as_number/AS39857) [H](https://bgp.he.net/AS39857) [R](https://stat.ripe.net/AS39857)                                                            |             0    |       0    |      0    |         1 |
| 714 | [Optima Telecom Ltd.](w/as_number/AS39819) [H](https://bgp.he.net/AS39819) [R](https://stat.ripe.net/AS39819)                                                                       |             0    |       0    |      0    |         1 |
| 715 | [Chaos Computer Club e.V.](w/as_number/AS39788) [H](https://bgp.he.net/AS39788) [R](https://stat.ripe.net/AS39788)                                                                  |             0    |       0    |      0    |         1 |
| 716 | [H4Y Technologies LLC](w/as_number/AS397373) [H](https://bgp.he.net/AS397373) [R](https://stat.ripe.net/AS397373)                                                                   |             0    |       0    |      0    |         1 |
| 717 | [Sumofiber](w/as_number/AS397162) [H](https://bgp.he.net/AS397162) [R](https://stat.ripe.net/AS397162)                                                                              |             0    |       0    |      0    |         1 |
| 718 | [SPARKED HOST LLC](w/as_number/AS397032) [H](https://bgp.he.net/AS397032) [R](https://stat.ripe.net/AS397032)                                                                       |             0    |       0    |      0    |         1 |
| 719 | [Aeacus B.V.](w/as_number/AS39587) [H](https://bgp.he.net/AS39587) [R](https://stat.ripe.net/AS39587)                                                                               |             0    |       0    |      0    |         1 |
| 720 | [NYC Mesh Inc.](w/as_number/AS395853) [H](https://bgp.he.net/AS395853) [R](https://stat.ripe.net/AS395853)                                                                          |             0    |       0    |      0    |         1 |
| 721 | [SHIFT HOSTING LLC](w/as_number/AS394177) [H](https://bgp.he.net/AS394177) [R](https://stat.ripe.net/AS394177)                                                                      |             0    |       0    |      0    |         1 |
| 722 | [BIF IV](w/as_number/AS394056) [H](https://bgp.he.net/AS394056) [R](https://stat.ripe.net/AS394056)                                                                                 |             0    |       0    |      0    |         1 |
| 723 | [Host Havoc](w/as_number/AS393905) [H](https://bgp.he.net/AS393905) [R](https://stat.ripe.net/AS393905)                                                                             |             0    |       0    |      0    |         1 |
| 724 | [Telekomunikacja Podlasie Sp. z o.o.](w/as_number/AS39375) [H](https://bgp.he.net/AS39375) [R](https://stat.ripe.net/AS39375)                                                       |             0    |       0    |      0    |         1 |
| 725 | [Amazing Creations and More LLC](w/as_number/AS393746) [H](https://bgp.he.net/AS393746) [R](https://stat.ripe.net/AS393746)                                                         |             0    |       0    |      0    |         1 |
| 726 | [Tritan Development](w/as_number/AS393577) [H](https://bgp.he.net/AS393577) [R](https://stat.ripe.net/AS393577)                                                                     |             0    |       0    |      0    |         1 |
| 727 | [Longmont Power &amp; Communications](w/as_number/AS393552) [H](https://bgp.he.net/AS393552) [R](https://stat.ripe.net/AS393552)                                                    |             0    |       0    |      0    |         1 |
| 728 | [University of Portland](w/as_number/AS393408) [H](https://bgp.he.net/AS393408) [R](https://stat.ripe.net/AS393408)                                                                 |             0    |       0    |      0    |         1 |
| 729 | [Catalyst Host LLC](w/as_number/AS393336) [H](https://bgp.he.net/AS393336) [R](https://stat.ripe.net/AS393336)                                                                      |             0    |       0    |      0    |         1 |
| 730 | [ImOn Communications, LLC](w/as_number/AS393238) [H](https://bgp.he.net/AS393238) [R](https://stat.ripe.net/AS393238)                                                               |             0    |       0    |      0    |         1 |
| 731 | [Comvive Servidores S.L.](w/as_number/AS39020) [H](https://bgp.he.net/AS39020) [R](https://stat.ripe.net/AS39020)                                                                   |             0    |       0    |      0    |         1 |
| 732 | [InMotion Hosting, Inc.](w/as_number/AS3842) [H](https://bgp.he.net/AS3842) [R](https://stat.ripe.net/AS3842)                                                                       |             0    |       0    |      0    |         1 |
| 733 | [Ayao Takata](w/as_number/AS38074) [H](https://bgp.he.net/AS38074) [R](https://stat.ripe.net/AS38074)                                                                               |             0    |       0    |      0    |         1 |
| 734 | [Afrihost Pty Ltd](w/as_number/AS37611) [H](https://bgp.he.net/AS37611) [R](https://stat.ripe.net/AS37611)                                                                          |             0    |       0    |      0    |         1 |
| 735 | [Hamilton County Communications, Inc](w/as_number/AS36813) [H](https://bgp.he.net/AS36813) [R](https://stat.ripe.net/AS36813)                                                       |             0    |       0    |      0    |         1 |
| 736 | [Rachamim Aviel Twito](w/as_number/AS35758) [H](https://bgp.he.net/AS35758) [R](https://stat.ripe.net/AS35758)                                                                      |             0    |       0    |      0    |         1 |
| 737 | [VIRTUA SYSTEMS SAS](w/as_number/AS35661) [H](https://bgp.he.net/AS35661) [R](https://stat.ripe.net/AS35661)                                                                        |             0    |       0    |      0    |         1 |
| 738 | [sasag Kabelkommunikation AG](w/as_number/AS35518) [H](https://bgp.he.net/AS35518) [R](https://stat.ripe.net/AS35518)                                                               |             0    |       0    |      0    |         1 |
| 739 | [PirxNet Grzegorz Bialas](w/as_number/AS35434) [H](https://bgp.he.net/AS35434) [R](https://stat.ripe.net/AS35434)                                                                   |             0    |       0    |      0    |         1 |
| 740 | [IOMART MANAGED SERVICES LIMITED](w/as_number/AS35425) [H](https://bgp.he.net/AS35425) [R](https://stat.ripe.net/AS35425)                                                           |             0    |       0    |      0    |         1 |
| 741 | [Tele Columbus AG](w/as_number/AS35244) [H](https://bgp.he.net/AS35244) [R](https://stat.ripe.net/AS35244)                                                                          |             0    |       0    |      0    |         1 |
| 742 | [Korbank S. A.](w/as_number/AS35179) [H](https://bgp.he.net/AS35179) [R](https://stat.ripe.net/AS35179)                                                                             |             0    |       0    |      0    |         1 |
| 743 | [GBN group Ltd](w/as_number/AS35112) [H](https://bgp.he.net/AS35112) [R](https://stat.ripe.net/AS35112)                                                                             |             0    |       0    |      0    |         1 |
| 744 | [ELDATA prazska s.r.o.](w/as_number/AS34911) [H](https://bgp.he.net/AS34911) [R](https://stat.ripe.net/AS34911)                                                                     |             0    |       0    |      0    |         1 |
| 745 | [T-2, d.o.o.](w/as_number/AS34779) [H](https://bgp.he.net/AS34779) [R](https://stat.ripe.net/AS34779)                                                                               |             0    |       0    |      0    |         1 |
| 746 | [MAXNET TELECOM, LTD](w/as_number/AS34700) [H](https://bgp.he.net/AS34700) [R](https://stat.ripe.net/AS34700)                                                                       |             0    |       0    |      0    |         1 |
| 747 | [Obenet AB](w/as_number/AS3399) [H](https://bgp.he.net/AS3399) [R](https://stat.ripe.net/AS3399)                                                                                    |             0    |       0    |      0    |         1 |
| 748 | [Telenor Sverige AB](w/as_number/AS33885) [H](https://bgp.he.net/AS33885) [R](https://stat.ripe.net/AS33885)                                                                        |             0    |       0    |      0    |         1 |
| 749 | [Charter Communications](w/as_number/AS33588) [H](https://bgp.he.net/AS33588) [R](https://stat.ripe.net/AS33588)                                                                    |             0    |       0    |      0    |         1 |
| 750 | [VODAFONE-PANAFON HELLENIC TELECOMMUNICATIONS COMPANY SA](w/as_number/AS3329) [H](https://bgp.he.net/AS3329) [R](https://stat.ripe.net/AS3329)                                      |             0    |       0    |      0    |         1 |
| 751 | [AxcelX Technologies LLC](w/as_number/AS33083) [H](https://bgp.he.net/AS33083) [R](https://stat.ripe.net/AS33083)                                                                   |             0    |       0    |      0    |         1 |
| 752 | [Stanford University](w/as_number/AS32) [H](https://bgp.he.net/AS32) [R](https://stat.ripe.net/AS32)                                                                                |             0    |       0    |      0    |         1 |
| 753 | [DataKeepers Pty Ltd](w/as_number/AS328170) [H](https://bgp.he.net/AS328170) [R](https://stat.ripe.net/AS328170)                                                                    |             0    |       0    |      0    |         1 |
| 754 | [xTom Japan Co., Ltd.](w/as_number/AS3258) [H](https://bgp.he.net/AS3258) [R](https://stat.ripe.net/AS3258)                                                                         |             0    |       0    |      0    |         1 |
| 755 | [Amanah Tech Inc.](w/as_number/AS32489) [H](https://bgp.he.net/AS32489) [R](https://stat.ripe.net/AS32489)                                                                          |             0    |       0    |      0    |         1 |
| 756 | [Liquid Web, L.L.C](w/as_number/AS32244) [H](https://bgp.he.net/AS32244) [R](https://stat.ripe.net/AS32244)                                                                         |             0    |       0    |      0    |         1 |
| 757 | [GigeNET](w/as_number/AS32181) [H](https://bgp.he.net/AS32181) [R](https://stat.ripe.net/AS32181)                                                                                   |             0    |       0    |      0    |         1 |
| 758 | [Ting Fiber Inc.](w/as_number/AS32133) [H](https://bgp.he.net/AS32133) [R](https://stat.ripe.net/AS32133)                                                                           |             0    |       0    |      0    |         1 |
| 759 | [Centrilogic, Inc.](w/as_number/AS31863) [H](https://bgp.he.net/AS31863) [R](https://stat.ripe.net/AS31863)                                                                         |             0    |       0    |      0    |         1 |
| 760 | [Wissenschaftsladen Dortmund e.V.](w/as_number/AS31371) [H](https://bgp.he.net/AS31371) [R](https://stat.ripe.net/AS31371)                                                          |             0    |       0    |      0    |         1 |
| 761 | [Freenet LTD](w/as_number/AS31148) [H](https://bgp.he.net/AS31148) [R](https://stat.ripe.net/AS31148)                                                                               |             0    |       0    |      0    |         1 |
| 762 | [GlobalConnect A/S](w/as_number/AS31027) [H](https://bgp.he.net/AS31027) [R](https://stat.ripe.net/AS31027)                                                                         |             0    |       0    |      0    |         1 |
| 763 | [CNRST Centre National pour la Recherche Scientifique et Technique](w/as_number/AS30983) [H](https://bgp.he.net/AS30983) [R](https://stat.ripe.net/AS30983)                         |             0    |       0    |      0    |         1 |
| 764 | [GGew net GmbH](w/as_number/AS30766) [H](https://bgp.he.net/AS30766) [R](https://stat.ripe.net/AS30766)                                                                             |             0    |       0    |      0    |         1 |
| 765 | [Vodafone Italia S.p.A.](w/as_number/AS30722) [H](https://bgp.he.net/AS30722) [R](https://stat.ripe.net/AS30722)                                                                    |             0    |       0    |      0    |         1 |
| 766 | [velia.net](w/as_number/AS30083) [H](https://bgp.he.net/AS30083) [R](https://stat.ripe.net/AS30083)                                                                                 |             0    |       0    |      0    |         1 |
| 767 | [VECTRA S.A.](w/as_number/AS29314) [H](https://bgp.he.net/AS29314) [R](https://stat.ripe.net/AS29314)                                                                               |             0    |       0    |      0    |         1 |
| 768 | [IABG Teleport GmbH](w/as_number/AS29259) [H](https://bgp.he.net/AS29259) [R](https://stat.ripe.net/AS29259)                                                                        |             0    |       0    |      0    |         1 |
| 769 | [NOS COMUNICACOES, S.A.](w/as_number/AS2860) [H](https://bgp.he.net/AS2860) [R](https://stat.ripe.net/AS2860)                                                                       |             0    |       0    |      0    |         1 |
| 770 | [PANGAEA](w/as_number/AS27631) [H](https://bgp.he.net/AS27631) [R](https://stat.ripe.net/AS27631)                                                                                   |             0    |       0    |      0    |         1 |
| 771 | [Zito Media, L.P.](w/as_number/AS26801) [H](https://bgp.he.net/AS26801) [R](https://stat.ripe.net/AS26801)                                                                          |             0    |       0    |      0    |         1 |
| 772 | [Interserver, Inc](w/as_number/AS26666) [H](https://bgp.he.net/AS26666) [R](https://stat.ripe.net/AS26666)                                                                          |             0    |       0    |      0    |         1 |
| 773 | [LightWave Networks](w/as_number/AS26527) [H](https://bgp.he.net/AS26527) [R](https://stat.ripe.net/AS26527)                                                                        |             0    |       0    |      0    |         1 |
| 774 | [OnShore, Inc.](w/as_number/AS26068) [H](https://bgp.he.net/AS26068) [R](https://stat.ripe.net/AS26068)                                                                             |             0    |       0    |      0    |         1 |
| 775 | [ARP NETWORKS, INC.](w/as_number/AS25795) [H](https://bgp.he.net/AS25795) [R](https://stat.ripe.net/AS25795)                                                                        |             0    |       0    |      0    |         1 |
| 776 | [Hydra Communications Ltd](w/as_number/AS25369) [H](https://bgp.he.net/AS25369) [R](https://stat.ripe.net/AS25369)                                                                  |             0    |       0    |      0    |         1 |
| 777 | [Sony Network Communications Inc.](w/as_number/AS2527) [H](https://bgp.he.net/AS2527) [R](https://stat.ripe.net/AS2527)                                                             |             0    |       0    |      0    |         1 |
| 778 | [Hutchison Drei Austria GmbH](w/as_number/AS25255) [H](https://bgp.he.net/AS25255) [R](https://stat.ripe.net/AS25255)                                                               |             0    |       0    |      0    |         1 |
| 779 | [BIGLOBE Inc.](w/as_number/AS2518) [H](https://bgp.he.net/AS2518) [R](https://stat.ripe.net/AS2518)                                                                                 |             0    |       0    |      0    |         1 |
| 780 | [NTT PC Communications, Inc.](w/as_number/AS2514) [H](https://bgp.he.net/AS2514) [R](https://stat.ripe.net/AS2514)                                                                  |             0    |       0    |      0    |         1 |
| 781 | [Internet Initiative Japan Inc.](w/as_number/AS2497) [H](https://bgp.he.net/AS2497) [R](https://stat.ripe.net/AS2497)                                                               |             0    |       0    |      0    |         1 |
| 782 | [KAGOYA Japan Inc.](w/as_number/AS24282) [H](https://bgp.he.net/AS24282) [R](https://stat.ripe.net/AS24282)                                                                         |             0    |       0    |      0    |         1 |
| 783 | [Mauritius Telecom Ltd](w/as_number/AS23889) [H](https://bgp.he.net/AS23889) [R](https://stat.ripe.net/AS23889)                                                                     |             0    |       0    |      0    |         1 |
| 784 | [Proen Corp Public Company Limited](w/as_number/AS23884) [H](https://bgp.he.net/AS23884) [R](https://stat.ripe.net/AS23884)                                                         |             0    |       0    |      0    |         1 |
| 785 | [HIGH SPEED UTAH LLC](w/as_number/AS23423) [H](https://bgp.he.net/AS23423) [R](https://stat.ripe.net/AS23423)                                                                       |             0    |       0    |      0    |         1 |
| 786 | [Wowrack.com](w/as_number/AS23033) [H](https://bgp.he.net/AS23033) [R](https://stat.ripe.net/AS23033)                                                                               |             0    |       0    |      0    |         1 |
| 787 | [BrightRidge](w/as_number/AS22987) [H](https://bgp.he.net/AS22987) [R](https://stat.ripe.net/AS22987)                                                                               |             0    |       0    |      0    |         1 |
| 788 | [Vorsk LLC](w/as_number/AS22296) [H](https://bgp.he.net/AS22296) [R](https://stat.ripe.net/AS22296)                                                                                 |             0    |       0    |      0    |         1 |
| 789 | [Promo Plus SRL](w/as_number/AS215362) [H](https://bgp.he.net/AS215362) [R](https://stat.ripe.net/AS215362)                                                                         |             0    |       0    |      0    |         1 |
| 790 | [Raoul Brouns](w/as_number/AS215296) [H](https://bgp.he.net/AS215296) [R](https://stat.ripe.net/AS215296)                                                                           |             0    |       0    |      0    |         1 |
| 791 | [Evolus IT Solutions GmbH](w/as_number/AS215120) [H](https://bgp.he.net/AS215120) [R](https://stat.ripe.net/AS215120)                                                               |             0    |       0    |      0    |         1 |
| 792 | [Din Server Group ApS](w/as_number/AS215052) [H](https://bgp.he.net/AS215052) [R](https://stat.ripe.net/AS215052)                                                                   |             0    |       0    |      0    |         1 |
| 793 | [PFALZKOM GmbH](w/as_number/AS21473) [H](https://bgp.he.net/AS21473) [R](https://stat.ripe.net/AS21473)                                                                             |             0    |       0    |      0    |         1 |
| 794 | [Hostup AB](w/as_number/AS214640) [H](https://bgp.he.net/AS214640) [R](https://stat.ripe.net/AS214640)                                                                              |             0    |       0    |      0    |         1 |
| 795 | [FOP Hornostay Mykhaylo Ivanovych](w/as_number/AS212913) [H](https://bgp.he.net/AS212913) [R](https://stat.ripe.net/AS212913)                                                       |             0    |       0    |      0    |         1 |
| 796 | [Cloud assets LLC](w/as_number/AS212441) [H](https://bgp.he.net/AS212441) [R](https://stat.ripe.net/AS212441)                                                                       |             0    |       0    |      0    |         1 |
| 797 | [FyfeWeb Ltd](w/as_number/AS212396) [H](https://bgp.he.net/AS212396) [R](https://stat.ripe.net/AS212396)                                                                            |             0    |       0    |      0    |         1 |
| 798 | [Hetzner Online GmbH](w/as_number/AS212317) [H](https://bgp.he.net/AS212317) [R](https://stat.ripe.net/AS212317)                                                                    |             0    |       0    |      0    |         1 |
| 799 | [Penkiu kontinentu komunikaciju centras, Ltd.](w/as_number/AS21211) [H](https://bgp.he.net/AS21211) [R](https://stat.ripe.net/AS21211)                                              |             0    |       0    |      0    |         1 |
| 800 | [AQUILENET](w/as_number/AS211882) [H](https://bgp.he.net/AS211882) [R](https://stat.ripe.net/AS211882)                                                                              |             0    |       0    |      0    |         1 |
| 801 | [NSHOST SRL](w/as_number/AS211857) [H](https://bgp.he.net/AS211857) [R](https://stat.ripe.net/AS211857)                                                                             |             0    |       0    |      0    |         1 |
| 802 | [Croatian Academic and Research Network](w/as_number/AS2108) [H](https://bgp.he.net/AS2108) [R](https://stat.ripe.net/AS2108)                                                       |             0    |       0    |      0    |         1 |
| 803 | [Katanytsia Lyubov Viktorivna](w/as_number/AS209825) [H](https://bgp.he.net/AS209825) [R](https://stat.ripe.net/AS209825)                                                           |             0    |       0    |      0    |         1 |
| 804 | [Generacion Tecnologica De Comunicaciones, Sociedad Limitada.](w/as_number/AS209281) [H](https://bgp.he.net/AS209281) [R](https://stat.ripe.net/AS209281)                           |             0    |       0    |      0    |         1 |
| 805 | [ITGLOBAL.COM NL B.V.](w/as_number/AS208951) [H](https://bgp.he.net/AS208951) [R](https://stat.ripe.net/AS208951)                                                                   |             0    |       0    |      0    |         1 |
| 806 | [eTOP sp. z o.o.](w/as_number/AS20853) [H](https://bgp.he.net/AS20853) [R](https://stat.ripe.net/AS20853)                                                                           |             0    |       0    |      0    |         1 |
| 807 | [CSpace Hostings OU](w/as_number/AS208367) [H](https://bgp.he.net/AS208367) [R](https://stat.ripe.net/AS208367)                                                                     |             0    |       0    |      0    |         1 |
| 808 | [DC Host INC](w/as_number/AS208287) [H](https://bgp.he.net/AS208287) [R](https://stat.ripe.net/AS208287)                                                                            |             0    |       0    |      0    |         1 |
| 809 | [Access2.IT Group B.V.](w/as_number/AS208258) [H](https://bgp.he.net/AS208258) [R](https://stat.ripe.net/AS208258)                                                                  |             0    |       0    |      0    |         1 |
| 810 | [Michael Kloos](w/as_number/AS208101) [H](https://bgp.he.net/AS208101) [R](https://stat.ripe.net/AS208101)                                                                          |             0    |       0    |      0    |         1 |
| 811 | [Velocity1 Limited](w/as_number/AS207916) [H](https://bgp.he.net/AS207916) [R](https://stat.ripe.net/AS207916)                                                                      |             0    |       0    |      0    |         1 |
| 812 | [Open Infra ISP Production International AB](w/as_number/AS207821) [H](https://bgp.he.net/AS207821) [R](https://stat.ripe.net/AS207821)                                             |             0    |       0    |      0    |         1 |
| 813 | [BOTANY SRL](w/as_number/AS207799) [H](https://bgp.he.net/AS207799) [R](https://stat.ripe.net/AS207799)                                                                             |             0    |       0    |      0    |         1 |
| 814 | [Zubritska Valeriia Nikolaevna](w/as_number/AS207560) [H](https://bgp.he.net/AS207560) [R](https://stat.ripe.net/AS207560)                                                          |             0    |       0    |      0    |         1 |
| 815 | [TEKNOSOS BILISIM HIZMETLERI VE TIC. LTD. STI.](w/as_number/AS207459) [H](https://bgp.he.net/AS207459) [R](https://stat.ripe.net/AS207459)                                          |             0    |       0    |      0    |         1 |
| 816 | [Andrews &amp; Arnold Ltd](w/as_number/AS20712) [H](https://bgp.he.net/AS20712) [R](https://stat.ripe.net/AS20712)                                                                  |             0    |       0    |      0    |         1 |
| 817 | [Media Land LLC](w/as_number/AS206728) [H](https://bgp.he.net/AS206728) [R](https://stat.ripe.net/AS206728)                                                                         |             0    |       0    |      0    |         1 |
| 818 | [Quasar Soluciones Tecnologicas, S.L.U.](w/as_number/AS206642) [H](https://bgp.he.net/AS206642) [R](https://stat.ripe.net/AS206642)                                                 |             0    |       0    |      0    |         1 |
| 819 | [Telemach Hrvatska d.o.o.](w/as_number/AS205714) [H](https://bgp.he.net/AS205714) [R](https://stat.ripe.net/AS205714)                                                               |             0    |       0    |      0    |         1 |
| 820 | [Hostigger INC.](w/as_number/AS205399) [H](https://bgp.he.net/AS205399) [R](https://stat.ripe.net/AS205399)                                                                         |             0    |       0    |      0    |         1 |
| 821 | [Marcel Andrew Zaiser trading as Metaliance ISP Systems e.k](w/as_number/AS205388) [H](https://bgp.he.net/AS205388) [R](https://stat.ripe.net/AS205388)                             |             0    |       0    |      0    |         1 |
| 822 | [BIG CORE LLC](w/as_number/AS205196) [H](https://bgp.he.net/AS205196) [R](https://stat.ripe.net/AS205196)                                                                           |             0    |       0    |      0    |         1 |
| 823 | [Asimia Damaskou](w/as_number/AS205053) [H](https://bgp.he.net/AS205053) [R](https://stat.ripe.net/AS205053)                                                                        |             0    |       0    |      0    |         1 |
| 824 | [Maxim Azarov trading as eServer](w/as_number/AS205007) [H](https://bgp.he.net/AS205007) [R](https://stat.ripe.net/AS205007)                                                        |             0    |       0    |      0    |         1 |
| 825 | [HOSTGW SRL](w/as_number/AS204641) [H](https://bgp.he.net/AS204641) [R](https://stat.ripe.net/AS204641)                                                                             |             0    |       0    |      0    |         1 |
| 826 | [SECURED SERVERS LLC](w/as_number/AS20454) [H](https://bgp.he.net/AS20454) [R](https://stat.ripe.net/AS20454)                                                                       |             0    |       0    |      0    |         1 |
| 827 | [Feistritzwerke-STEWEAG GmbH](w/as_number/AS204410) [H](https://bgp.he.net/AS204410) [R](https://stat.ripe.net/AS204410)                                                            |             0    |       0    |      0    |         1 |
| 828 | [Rainier Connect](w/as_number/AS20394) [H](https://bgp.he.net/AS20394) [R](https://stat.ripe.net/AS20394)                                                                           |             0    |       0    |      0    |         1 |
| 829 | [EUGAMEHOST LTD](w/as_number/AS203758) [H](https://bgp.he.net/AS203758) [R](https://stat.ripe.net/AS203758)                                                                         |             0    |       0    |      0    |         1 |
| 830 | [Association FAImaison](w/as_number/AS203432) [H](https://bgp.he.net/AS203432) [R](https://stat.ripe.net/AS203432)                                                                  |             0    |       0    |      0    |         1 |
| 831 | [Panix](w/as_number/AS2033) [H](https://bgp.he.net/AS2033) [R](https://stat.ripe.net/AS2033)                                                                                        |             0    |       0    |      0    |         1 |
| 832 | [DA International Group Ltd.](w/as_number/AS203380) [H](https://bgp.he.net/AS203380) [R](https://stat.ripe.net/AS203380)                                                            |             0    |       0    |      0    |         1 |
| 833 | [Kuroit Limited](w/as_number/AS203363) [H](https://bgp.he.net/AS203363) [R](https://stat.ripe.net/AS203363)                                                                         |             0    |       0    |      0    |         1 |
| 834 | [RJ Network OU](w/as_number/AS202759) [H](https://bgp.he.net/AS202759) [R](https://stat.ripe.net/AS202759)                                                                          |             0    |       0    |      0    |         1 |
| 835 | [Aruba S.p.A.](w/as_number/AS202613) [H](https://bgp.he.net/AS202613) [R](https://stat.ripe.net/AS202613)                                                                           |             0    |       0    |      0    |         1 |
| 836 | [Farmers Telephone Cooperative, Inc.](w/as_number/AS20257) [H](https://bgp.he.net/AS20257) [R](https://stat.ripe.net/AS20257)                                                       |             0    |       0    |      0    |         1 |
| 837 | [Webhosting24 GmbH](w/as_number/AS202401) [H](https://bgp.he.net/AS202401) [R](https://stat.ripe.net/AS202401)                                                                      |             0    |       0    |      0    |         1 |
| 838 | [NETH LLC](w/as_number/AS202302) [H](https://bgp.he.net/AS202302) [R](https://stat.ripe.net/AS202302)                                                                               |             0    |       0    |      0    |         1 |
| 839 | [lopnet AB](w/as_number/AS201146) [H](https://bgp.he.net/AS201146) [R](https://stat.ripe.net/AS201146)                                                                              |             0    |       0    |      0    |         1 |
| 840 | [Felix Annen](w/as_number/AS200490) [H](https://bgp.he.net/AS200490) [R](https://stat.ripe.net/AS200490)                                                                            |             0    |       0    |      0    |         1 |
| 841 | [Charter Communications Inc](w/as_number/AS20001) [H](https://bgp.he.net/AS20001) [R](https://stat.ripe.net/AS20001)                                                                |             0    |       0    |      0    |         1 |
| 842 | [Rackspace Hosting](w/as_number/AS19994) [H](https://bgp.he.net/AS19994) [R](https://stat.ripe.net/AS19994)                                                                         |             0    |       0    |      0    |         1 |
| 843 | [G-Core Labs S.A.](w/as_number/AS199524) [H](https://bgp.he.net/AS199524) [R](https://stat.ripe.net/AS199524)                                                                       |             0    |       0    |      0    |         1 |
| 844 | [Thueringer Netkom GmbH](w/as_number/AS199284) [H](https://bgp.he.net/AS199284) [R](https://stat.ripe.net/AS199284)                                                                 |             0    |       0    |      0    |         1 |
| 845 | [Heinlein-Support GmbH](w/as_number/AS199118) [H](https://bgp.he.net/AS199118) [R](https://stat.ripe.net/AS199118)                                                                  |             0    |       0    |      0    |         1 |
| 846 | [SERVA ONE LTD](w/as_number/AS199058) [H](https://bgp.he.net/AS199058) [R](https://stat.ripe.net/AS199058)                                                                          |             0    |       0    |      0    |         1 |
| 847 | [Brightspeed](w/as_number/AS19901) [H](https://bgp.he.net/AS19901) [R](https://stat.ripe.net/AS19901)                                                                               |             0    |       0    |      0    |         1 |
| 848 | [BITel Gesellschaft fuer Telekommunikation mbH](w/as_number/AS198967) [H](https://bgp.he.net/AS198967) [R](https://stat.ripe.net/AS198967)                                          |             0    |       0    |      0    |         1 |
| 849 | [Vereinigte Stadtwerke Media GmbH](w/as_number/AS198930) [H](https://bgp.he.net/AS198930) [R](https://stat.ripe.net/AS198930)                                                       |             0    |       0    |      0    |         1 |
| 850 | [Techstorage sp. z o.o.](w/as_number/AS198717) [H](https://bgp.he.net/AS198717) [R](https://stat.ripe.net/AS198717)                                                                 |             0    |       0    |      0    |         1 |
| 851 | [RouteLabel V.O.F.](w/as_number/AS198203) [H](https://bgp.he.net/AS198203) [R](https://stat.ripe.net/AS198203)                                                                      |             0    |       0    |      0    |         1 |
| 852 | [Sokolovska uhelna, pravni nastupce, a.s.](w/as_number/AS198161) [H](https://bgp.he.net/AS198161) [R](https://stat.ripe.net/AS198161)                                               |             0    |       0    |      0    |         1 |
| 853 | [Livady s.r.o.](w/as_number/AS197566) [H](https://bgp.he.net/AS197566) [R](https://stat.ripe.net/AS197566)                                                                          |             0    |       0    |      0    |         1 |
| 854 | [Leonet Group GmbH](w/as_number/AS197524) [H](https://bgp.he.net/AS197524) [R](https://stat.ripe.net/AS197524)                                                                      |             0    |       0    |      0    |         1 |
| 855 | [&quot;SPRINT&quot; S.A.](w/as_number/AS197226) [H](https://bgp.he.net/AS197226) [R](https://stat.ripe.net/AS197226)                                                                |             0    |       0    |      0    |         1 |
| 856 | [active 1 GmbH](w/as_number/AS197071) [H](https://bgp.he.net/AS197071) [R](https://stat.ripe.net/AS197071)                                                                          |             0    |       0    |      0    |         1 |
| 857 | [N.Henulin](w/as_number/AS196967) [H](https://bgp.he.net/AS196967) [R](https://stat.ripe.net/AS196967)                                                                              |             0    |       0    |      0    |         1 |
| 858 | [Nivos Energia Oy](w/as_number/AS196655) [H](https://bgp.he.net/AS196655) [R](https://stat.ripe.net/AS196655)                                                                       |             0    |       0    |      0    |         1 |
| 859 | [Google LLC](w/as_number/AS19527) [H](https://bgp.he.net/AS19527) [R](https://stat.ripe.net/AS19527)                                                                                |             0    |       0    |      0    |         1 |
| 860 | [WTC Communications, Inc.](w/as_number/AS19504) [H](https://bgp.he.net/AS19504) [R](https://stat.ripe.net/AS19504)                                                                  |             0    |       0    |      0    |         1 |
| 861 | [Optimum](w/as_number/AS19108) [H](https://bgp.he.net/AS19108) [R](https://stat.ripe.net/AS19108)                                                                                   |             0    |       0    |      0    |         1 |
| 862 | [Direct Communications Cedar Valley, LLC](w/as_number/AS19045) [H](https://bgp.he.net/AS19045) [R](https://stat.ripe.net/AS19045)                                                   |             0    |       0    |      0    |         1 |
| 863 | [Isomedia, Inc.](w/as_number/AS18530) [H](https://bgp.he.net/AS18530) [R](https://stat.ripe.net/AS18530)                                                                            |             0    |       0    |      0    |         1 |
| 864 | [DDPS Networks, LLC](w/as_number/AS18526) [H](https://bgp.he.net/AS18526) [R](https://stat.ripe.net/AS18526)                                                                        |             0    |       0    |      0    |         1 |
| 865 | [Netforest,Inc.](w/as_number/AS17931) [H](https://bgp.he.net/AS17931) [R](https://stat.ripe.net/AS17931)                                                                            |             0    |       0    |      0    |         1 |
| 866 | [SoftBank Corp.](w/as_number/AS17676) [H](https://bgp.he.net/AS17676) [R](https://stat.ripe.net/AS17676)                                                                            |             0    |       0    |      0    |         1 |
| 867 | [TRUE INTERNET CORPORATION CO. LTD.](w/as_number/AS17552) [H](https://bgp.he.net/AS17552) [R](https://stat.ripe.net/AS17552)                                                        |             0    |       0    |      0    |         1 |
| 868 | [Anycast Holdings Pty Ltd](w/as_number/AS17551) [H](https://bgp.he.net/AS17551) [R](https://stat.ripe.net/AS17551)                                                                  |             0    |       0    |      0    |         1 |
| 869 | [M1 NET LTD](w/as_number/AS17547) [H](https://bgp.he.net/AS17547) [R](https://stat.ripe.net/AS17547)                                                                                |             0    |       0    |      0    |         1 |
| 870 | [UCOM Corp.](w/as_number/AS17506) [H](https://bgp.he.net/AS17506) [R](https://stat.ripe.net/AS17506)                                                                                |             0    |       0    |      0    |         1 |
| 871 | [Vermont Telephone Company, Inc.](w/as_number/AS17356) [H](https://bgp.he.net/AS17356) [R](https://stat.ripe.net/AS17356)                                                           |             0    |       0    |      0    |         1 |
| 872 | [campuscolo.com](w/as_number/AS17017) [H](https://bgp.he.net/AS17017) [R](https://stat.ripe.net/AS17017)                                                                            |             0    |       0    |      0    |         1 |
| 873 | [Riseup Networks](w/as_number/AS16652) [H](https://bgp.he.net/AS16652) [R](https://stat.ripe.net/AS16652)                                                                           |             0    |       0    |      0    |         1 |
| 874 | [Suomi Communications Oy](w/as_number/AS16302) [H](https://bgp.he.net/AS16302) [R](https://stat.ripe.net/AS16302)                                                                   |             0    |       0    |      0    |         1 |
| 875 | [The University of Chicago](w/as_number/AS160) [H](https://bgp.he.net/AS160) [R](https://stat.ripe.net/AS160)                                                                       |             0    |       0    |      0    |         1 |
| 876 | [TAZ Verlags- und Vertriebsgesellschaft mit beschraenkter Haftung Berlin](w/as_number/AS16075) [H](https://bgp.he.net/AS16075) [R](https://stat.ripe.net/AS16075)                   |             0    |       0    |      0    |         1 |
| 877 | [Orange Slovensko a.s.](w/as_number/AS15962) [H](https://bgp.he.net/AS15962) [R](https://stat.ripe.net/AS15962)                                                                     |             0    |       0    |      0    |         1 |
| 878 | [&quot;Kyivstar&quot; PJSC](w/as_number/AS15895) [H](https://bgp.he.net/AS15895) [R](https://stat.ripe.net/AS15895)                                                                 |             0    |       0    |      0    |         1 |
| 879 | [XTRA TELECOM S.A.](w/as_number/AS15704) [H](https://bgp.he.net/AS15704) [R](https://stat.ripe.net/AS15704)                                                                         |             0    |       0    |      0    |         1 |
| 880 | [Dragon Internet a.s.](w/as_number/AS15614) [H](https://bgp.he.net/AS15614) [R](https://stat.ripe.net/AS15614)                                                                      |             0    |       0    |      0    |         1 |
| 881 | [netplus.ch SA](w/as_number/AS15547) [H](https://bgp.he.net/AS15547) [R](https://stat.ripe.net/AS15547)                                                                             |             0    |       0    |      0    |         1 |
| 882 | [Allo Communications LLC](w/as_number/AS15108) [H](https://bgp.he.net/AS15108) [R](https://stat.ripe.net/AS15108)                                                                   |             0    |       0    |      0    |         1 |
| 883 | [Omni Fiber](w/as_number/AS15081) [H](https://bgp.he.net/AS15081) [R](https://stat.ripe.net/AS15081)                                                                                |             0    |       0    |      0    |         1 |
| 884 | [RouterHosting LLC](w/as_number/AS14956) [H](https://bgp.he.net/AS14956) [R](https://stat.ripe.net/AS14956)                                                                         |             0    |       0    |      0    |         1 |
| 885 | [WHG Hosting Services Ltd](w/as_number/AS14670) [H](https://bgp.he.net/AS14670) [R](https://stat.ripe.net/AS14670)                                                                  |             0    |       0    |      0    |         1 |
| 886 | [Amazon.com, Inc.](w/as_number/AS14618) [H](https://bgp.he.net/AS14618) [R](https://stat.ripe.net/AS14618)                                                                          |             0    |       0    |      0    |         1 |
| 887 | [1GSERVERS, LLC](w/as_number/AS14315) [H](https://bgp.he.net/AS14315) [R](https://stat.ripe.net/AS14315)                                                                            |             0    |       0    |      0    |         1 |
| 888 | [LAM A ARCHITECTURE CONSTRUCTION COMPANY LIMITED](w/as_number/AS140787) [H](https://bgp.he.net/AS140787) [R](https://stat.ripe.net/AS140787)                                        |             0    |       0    |      0    |         1 |
| 889 | [EBOX](w/as_number/AS1403) [H](https://bgp.he.net/AS1403) [R](https://stat.ripe.net/AS1403)                                                                                         |             0    |       0    |      0    |         1 |
| 890 | [Skyway West](w/as_number/AS14007) [H](https://bgp.he.net/AS14007) [R](https://stat.ripe.net/AS14007)                                                                               |             0    |       0    |      0    |         1 |
| 891 | [Peak Internet](w/as_number/AS13868) [H](https://bgp.he.net/AS13868) [R](https://stat.ripe.net/AS13868)                                                                             |             0    |       0    |      0    |         1 |
| 892 | [GSL Networks Pty LTD](w/as_number/AS137409) [H](https://bgp.he.net/AS137409) [R](https://stat.ripe.net/AS137409)                                                                   |             0    |       0    |      0    |         1 |
| 893 | [Vexus Fiber](w/as_number/AS13693) [H](https://bgp.he.net/AS13693) [R](https://stat.ripe.net/AS13693)                                                                               |             0    |       0    |      0    |         1 |
| 894 | [Douglas FastNet](w/as_number/AS13692) [H](https://bgp.he.net/AS13692) [R](https://stat.ripe.net/AS13692)                                                                           |             0    |       0    |      0    |         1 |
| 895 | [Host Universal Pty Ltd](w/as_number/AS136557) [H](https://bgp.he.net/AS136557) [R](https://stat.ripe.net/AS136557)                                                                 |             0    |       0    |      0    |         1 |
| 896 | [All West Communications, Inc.](w/as_number/AS13614) [H](https://bgp.he.net/AS13614) [R](https://stat.ripe.net/AS13614)                                                             |             0    |       0    |      0    |         1 |
| 897 | [Onebim Vietnam Limited Company](w/as_number/AS135959) [H](https://bgp.he.net/AS135959) [R](https://stat.ripe.net/AS135959)                                                         |             0    |       0    |      0    |         1 |
| 898 | [Viet Storage Technology Joint Stock Company](w/as_number/AS135932) [H](https://bgp.he.net/AS135932) [R](https://stat.ripe.net/AS135932)                                            |             0    |       0    |      0    |         1 |
| 899 | [Starry Network Limited](w/as_number/AS134835) [H](https://bgp.he.net/AS134835) [R](https://stat.ripe.net/AS134835)                                                                 |             0    |       0    |      0    |         1 |
| 900 | [LAUNTEL PTY LTD](w/as_number/AS134697) [H](https://bgp.he.net/AS134697) [R](https://stat.ripe.net/AS134697)                                                                        |             0    |       0    |      0    |         1 |
| 901 | [Leaseweb Japan K.K.](w/as_number/AS134351) [H](https://bgp.he.net/AS134351) [R](https://stat.ripe.net/AS134351)                                                                    |             0    |       0    |      0    |         1 |
| 902 | [Surf Air Wireless, LLC](w/as_number/AS13428) [H](https://bgp.he.net/AS13428) [R](https://stat.ripe.net/AS13428)                                                                    |             0    |       0    |      0    |         1 |
| 903 | [DGTEK PTY LTD](w/as_number/AS133206) [H](https://bgp.he.net/AS133206) [R](https://stat.ripe.net/AS133206)                                                                          |             0    |       0    |      0    |         1 |
| 904 | [CONTENT DELIVERY NETWORK LTD](w/as_number/AS13188) [H](https://bgp.he.net/AS13188) [R](https://stat.ripe.net/AS13188)                                                              |             0    |       0    |      0    |         1 |
| 905 | [Odido Netherlands B.V.](w/as_number/AS13127) [H](https://bgp.he.net/AS13127) [R](https://stat.ripe.net/AS13127)                                                                    |             0    |       0    |      0    |         1 |
| 906 | [Hrvatski Telekom d.d.](w/as_number/AS13046) [H](https://bgp.he.net/AS13046) [R](https://stat.ripe.net/AS13046)                                                                     |             0    |       0    |      0    |         1 |
| 907 | [Ljosleidarinn ehf](w/as_number/AS12969) [H](https://bgp.he.net/AS12969) [R](https://stat.ripe.net/AS12969)                                                                         |             0    |       0    |      0    |         1 |
| 908 | [ENTEGA Medianet GmbH](w/as_number/AS12897) [H](https://bgp.he.net/AS12897) [R](https://stat.ripe.net/AS12897)                                                                      |             0    |       0    |      0    |         1 |
| 909 | [T-Mobile Czech Republic a.s.](w/as_number/AS12767) [H](https://bgp.he.net/AS12767) [R](https://stat.ripe.net/AS12767)                                                              |             0    |       0    |      0    |         1 |
| 910 | [LIWEST Kabelmedien GmbH](w/as_number/AS12605) [H](https://bgp.he.net/AS12605) [R](https://stat.ripe.net/AS12605)                                                                   |             0    |       0    |      0    |         1 |
| 911 | [EE Limited](w/as_number/AS12576) [H](https://bgp.he.net/AS12576) [R](https://stat.ripe.net/AS12576)                                                                                |             0    |       0    |      0    |         1 |
| 912 | [GlobalConnect AB](w/as_number/AS12552) [H](https://bgp.he.net/AS12552) [R](https://stat.ripe.net/AS12552)                                                                          |             0    |       0    |      0    |         1 |
| 913 | [Infinity Developments Limited](w/as_number/AS12496) [H](https://bgp.he.net/AS12496) [R](https://stat.ripe.net/AS12496)                                                             |             0    |       0    |      0    |         1 |
| 914 | [VODAFONE ESPANA S.A.U.](w/as_number/AS12430) [H](https://bgp.he.net/AS12430) [R](https://stat.ripe.net/AS12430)                                                                    |             0    |       0    |      0    |         1 |
| 915 | [Partner Communications Ltd.](w/as_number/AS12400) [H](https://bgp.he.net/AS12400) [R](https://stat.ripe.net/AS12400)                                                               |             0    |       0    |      0    |         1 |
| 916 | [VOO S.A.](w/as_number/AS12392) [H](https://bgp.he.net/AS12392) [R](https://stat.ripe.net/AS12392)                                                                                  |             0    |       0    |      0    |         1 |
| 917 | [University of Macedonia, Economic and Social Sciences](w/as_number/AS12364) [H](https://bgp.he.net/AS12364) [R](https://stat.ripe.net/AS12364)                                     |             0    |       0    |      0    |         1 |
| 918 | [Euskaltel S.A.](w/as_number/AS12338) [H](https://bgp.he.net/AS12338) [R](https://stat.ripe.net/AS12338)                                                                            |             0    |       0    |      0    |         1 |
| 919 | [noris network AG](w/as_number/AS12337) [H](https://bgp.he.net/AS12337) [R](https://stat.ripe.net/AS12337)                                                                          |             0    |       0    |      0    |         1 |
| 920 | [Charter Communications Inc](w/as_number/AS12271) [H](https://bgp.he.net/AS12271) [R](https://stat.ripe.net/AS12271)                                                                |             0    |       0    |      0    |         1 |
| 921 | [dao Consulting, LLC](w/as_number/AS12161) [H](https://bgp.he.net/AS12161) [R](https://stat.ripe.net/AS12161)                                                                       |             0    |       0    |      0    |         1 |
| 922 | [ITV-3](w/as_number/AS12119) [H](https://bgp.he.net/AS12119) [R](https://stat.ripe.net/AS12119)                                                                                     |             0    |       0    |      0    |         1 |
| 923 | [WideOpenWest Finance LLC](w/as_number/AS12083) [H](https://bgp.he.net/AS12083) [R](https://stat.ripe.net/AS12083)                                                                  |             0    |       0    |      0    |         1 |
| 924 | [GoNetSpeed](w/as_number/AS11847) [H](https://bgp.he.net/AS11847) [R](https://stat.ripe.net/AS11847)                                                                                |             0    |       0    |      0    |         1 |
| 925 | [Distributel Communications Limited](w/as_number/AS11814) [H](https://bgp.he.net/AS11814) [R](https://stat.ripe.net/AS11814)                                                        |             0    |       0    |      0    |         1 |
| 926 | [Airstream Communications, LLC](w/as_number/AS11796) [H](https://bgp.he.net/AS11796) [R](https://stat.ripe.net/AS11796)                                                             |             0    |       0    |      0    |         1 |
| 927 | [Pioneer Long Distance Inc.](w/as_number/AS11650) [H](https://bgp.he.net/AS11650) [R](https://stat.ripe.net/AS11650)                                                                |             0    |       0    |      0    |         1 |
| 928 | [Smithville Digital, LLC](w/as_number/AS11550) [H](https://bgp.he.net/AS11550) [R](https://stat.ripe.net/AS11550)                                                                   |             0    |       0    |      0    |         1 |
| 929 | [Wave Broadband](w/as_number/AS11404) [H](https://bgp.he.net/AS11404) [R](https://stat.ripe.net/AS11404)                                                                            |             0    |       0    |      0    |         1 |
| 930 | [Wintek Corporation](w/as_number/AS11114) [H](https://bgp.he.net/AS11114) [R](https://stat.ripe.net/AS11114)                                                                        |             0    |       0    |      0    |         1 |
| 931 | [Concorde inc.](w/as_number/AS10996) [H](https://bgp.he.net/AS10996) [R](https://stat.ripe.net/AS10996)                                                                             |             0    |       0    |      0    |         1 |
| 932 | [Boston GigaPoP](w/as_number/AS10961) [H](https://bgp.he.net/AS10961) [R](https://stat.ripe.net/AS10961)                                                                            |             0    |       0    |      0    |         1 |
| 933 | [eStruxture Data Centers Inc.](w/as_number/AS10929) [H](https://bgp.he.net/AS10929) [R](https://stat.ripe.net/AS10929)                                                              |             0    |       0    |      0    |         1 |
| 934 | [Armour Cloud, LLC](w/as_number/AS10489) [H](https://bgp.he.net/AS10489) [R](https://stat.ripe.net/AS10489)                                                                         |             0    |       0    |      0    |         1 |
| 935 | [US Internet Corp](w/as_number/AS10242) [H](https://bgp.he.net/AS10242) [R](https://stat.ripe.net/AS10242)                                                                          |             0    |       0    |      0    |         1 |

<div class="datatable-end"></div>

## Tor Version Distribution (Relays)

**Major Versions**

<div class="datatable-begin"></div>

| Tor Version   |   CW Fraction(%) |   Exit(%) |   Guard(%) |   #Relays |
|:--------------|-----------------:|----------:|-----------:|----------:|
| 0.4.8         |             96.8 |     92.89 |      98.85 |      7766 |
| 0.4.9         |              3.1 |      7.1  |       1.14 |       136 |

<div class="datatable-end"></div>

**Complete list of Tor versions**

<div class="datatable-begin"></div>

| Tor Version                                                                                               |   CW Fraction(%) |   Exit(%) |   Guard(%) |   #Relays |
|:----------------------------------------------------------------------------------------------------------|-----------------:|----------:|-----------:|----------:|
| [0.4.8.13](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.13)                   |             70.1 |     87.65 |      60.59 |      5450 |
| [0.4.8.12](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.12)                   |             16   |      3.42 |      23.42 |      1240 |
| [0.4.8.10](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.10)                   |              6.4 |      0.97 |       8.61 |       656 |
| [0.4.9.0-alpha-dev](https://metrics.torproject.org/rs.html#search/running:true version:0.4.9.0-alpha-dev) |              2.8 |      7.1  |       0.75 |       119 |
| [0.4.8.9](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.9)                     |              1.7 |      0    |       2.91 |        61 |
| [0.4.8.11](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.11)                   |              1.2 |      0.63 |       1.58 |       207 |
| [0.4.8.7](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.7)                     |              0.9 |      0.11 |       1.42 |        47 |
| [0.4.8.8](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.8)                     |              0.2 |      0.06 |       0.27 |        19 |
| [0.4.9.1-alpha-dev](https://metrics.torproject.org/rs.html#search/running:true version:0.4.9.1-alpha-dev) |              0.1 |      0    |       0.3  |        11 |
| [0.4.8.0-alpha-dev](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.0-alpha-dev) |              0   |      0    |       0    |        51 |
| [0.4.8.1-alpha-dev](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.1-alpha-dev) |              0   |      0    |       0    |         4 |
| [0.4.8.11-dev](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.11-dev)           |              0   |      0.01 |       0    |         2 |
| [0.4.8.4](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.4)                     |              0   |      0    |       0    |         4 |
| [0.4.8.5](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.5)                     |              0   |      0    |       0    |         5 |
| [0.4.8.6](https://metrics.torproject.org/rs.html#search/running:true version:0.4.8.6)                     |              0   |      0    |       0    |        20 |
| [0.4.9.1-alpha](https://metrics.torproject.org/rs.html#search/running:true version:0.4.9.1-alpha)         |              0   |      0    |       0.08 |         6 |

<div class="datatable-end"></div>

A version-distribution-over-time graph (by relay count) can be found on the [Torproject Metrics page](https://metrics.torproject.org/versions.html)

## End-of-Life Relays Share

The following table shows how many relays run a tor version that is [no longer supported](https://gitlab.torproject.org/tpo/core/team/-/wikis/NetworkTeam/CoreTorReleases#end-of-life)

| CW Fraction(%)   | Guard(%)   | Exit(%)   |   #Relays |
|:-----------------|:-----------|:----------|----------:|
| None             | None       | None      |         0 |

The following table shows which operators (with a non-empty ContactInfo) run EOL releases.

<div class="datatable-begin"></div>

| Contact   | Tor Versions   | Nicknames   | #Relays   | Consensus Weight   |
|-----------|----------------|-------------|-----------|--------------------|

<div class="datatable-end"></div>

## OS Distribution (Relays)

<div class="datatable-begin"></div>

| OS      |   CW Fraction(%) |   Exit(%) |   Guard(%) |   #Relays |
|:--------|-----------------:|----------:|-----------:|----------:|
| Linux   |             89.8 |      79.8 |       94.9 |      7307 |
| BSD     |              9.9 |      20.1 |        4.9 |       549 |
| SunOS   |              0   |       0   |        0.1 |         5 |
| other   |              0   |       0   |        0   |         2 |
| Windows |              0   |       0   |        0   |        32 |
| Darwin  |              0   |       0   |        0   |         3 |

<div class="datatable-end"></div>

A OS-distribution-over-time graph (by relay count) can be found on the [Torproject Metrics page](https://metrics.torproject.org/platforms.html)

## IPv6 Relay Stats

**What cw fraction / guard/middle/exit probability has an IPv6 ORPort?**

|   CW Fraction(%) |   Guard(%) |   Middle(%) |   Exit(%) |   #Relays |
|-----------------:|-----------:|------------:|----------:|----------:|
|            65.79 |      55.77 |       52.91 |      88.7 |      4085 |

**What exit probability allows IPv6 exiting?**

|   Exit(%) |   #Exit Relays |
|----------:|---------------:|
|     85.62 |           1707 |

## Bridge Operators (grouped by contactinfo)

The following table includes only operators with at least 50 Mbit/s advertised bandwidth.
The displayed contact can be arbitrarily spoofed by malicious operators.

<div class="datatable-begin"></div>

|     | Contact                                                               |   Advertised Bandwidth (Mbit/s) |   #Bridges |
|----:|:----------------------------------------------------------------------|--------------------------------:|-----------:|
|   0 | hello from onionland                                                  |                            3644 |         48 |
|   1 | gus@riseup.net                                                        |                            3323 |         58 |
|   2 | Artikel10 url:artikel10.org email:info artikel10.org abuse:           |                            3048 |         32 |
|   3 | abuse@tuxli.org                                                       |                            2346 |         72 |
|   4 | abuse-tor@lists.kau.se                                                |                            1019 |          3 |
|   5 | Tor dot ElephantsHaveLongTrunks at hotmail dot com tor-rela           |                             730 |         10 |
|   6 | did not write the code to populate yet                                |                             653 |          5 |
|   7 | &lt;address@email.com&gt;                                             |                             582 |         26 |
|   8 | email:tor axstet.de url:https://axstet.de proof:uri-rsa abu           |                             561 |          6 |
|   9 | &lt;tor@netdev.cloud&gt;                                              |                             555 |         12 |
|  10 | email:abuse artikel5ev.de url:https://artikel5ev.de proof:u           |                             527 |          7 |
|  11 | Brandon Kuschel &lt;tor AT NOSPAM brandonkuschel dot com&gt;          |                             526 |          8 |
|  12 | Anonymous                                                             |                             522 |          4 |
|  13 | bridges@relayon.org                                                   |                             512 |         39 |
|  14 | tech@emeraldonion.org                                                 |                             504 |         10 |
|  15 | scobo@gmx.li                                                          |                             423 |          6 |
|  16 | v.nivlac@posteo.de                                                    |                             402 |          5 |
|  17 | ultramar@acuare.la                                                    |                             369 |          2 |
|  18 | address@email.com                                                     |                             364 |         10 |
|  19 | 0x37C6224D225BCD7D Jon Proulx &lt;jon AT jonproulx dot com&gt;        |                             323 |          7 |
|  20 | Dave Null &lt;dave@null.net&gt;                                       |                             302 |          8 |
|  21 | torbridge1667@proton.me                                               |                             295 |          2 |
|  22 | &lt;Jean Paul Remy&gt; jean.paul.remy at protonmail.com               |                             274 |          6 |
|  23 | brookrameev@pm.me                                                     |                             261 |          3 |
|  24 | holla556torbridge@umn.edu                                             |                             260 |          1 |
|  25 | &lt;ZombieComputers@Outlook.Com&gt;                                   |                             258 |          3 |
|  26 | tor@kurokitsune.de                                                    |                             254 |          1 |
|  27 | cp tor@mailfence.com                                                  |                             248 |         11 |
|  28 | kuangbiao.musmo.com                                                   |                             247 |          5 |
|  29 | 0320c8867fccd45d6a6f7a577ed09773f8929a6e CSGuard &lt;admin AT c       |                             243 |          2 |
|  30 | m@bianchi.dev                                                         |                             241 |          6 |
|  31 | linustor@nordu.net                                                    |                             230 |          3 |
|  32 | Heisenberg@example.com                                                |                             229 |          5 |
|  33 | technonerd@riseup.net                                                 |                             227 |          1 |
|  34 | torrelaysaregreat@gmail.com xmr:84czj1u2Q4dJ7bzf41TyDFS1i1GP          |                             223 |          5 |
|  35 | cvjoint73@protonmail.com                                              |                             223 |          2 |
|  36 | engel.niklas@pm.me                                                    |                             223 |          2 |
|  37 | 161ta@riseup.net                                                      |                             220 |          1 |
|  38 | vi astra@pm.me                                                        |                             212 |          2 |
|  39 | StopWarinUkraineNow@protonmail.com                                    |                             206 |          3 |
|  40 | &lt;lleon@cock.li&gt;                                                 |                             199 |          1 |
|  41 | g.eckardt@protonmail.com                                              |                             193 |          1 |
|  42 | &lt;albaldah atsymbol gmail.com&gt;                                   |                             191 |          1 |
|  43 | scans@mailbox.org                                                     |                             187 |          1 |
|  44 | you@example.com                                                       |                             178 |          5 |
|  45 | &lt;mrm@email.com&gt;                                                 |                             177 |          1 |
|  46 | katze@kunfoo.org                                                      |                             175 |          1 |
|  47 | lockesmith@coldforge.xyz                                              |                             166 |          2 |
|  48 | &lt;toradmin@niekel.net&gt;                                           |                             166 |          1 |
|  49 | Gains73-Lung4 Pork75@xobnur.uk                                        |                             164 |          9 |
|  50 | Wil&x27;yam Sheq&x27;spir &lt;gewandung-delfin-02@icloud.com&gt;      |                             161 |          1 |
|  51 | w3da5mxwr@relay.firefox.com                                           |                             161 |          3 |
|  52 | obfs4-bridge@axelv.net                                                |                             159 |          2 |
|  53 | torproject@verry.org                                                  |                             155 |          1 |
|  54 | Tor Admin &lt;tor@nr18.space&gt;                                      |                             155 |          1 |
|  55 | runtime-error@riseup.net                                              |                             155 |          1 |
|  56 | privacy2925@proton.me                                                 |                             155 |          1 |
|  57 | tor@nomagic.de                                                        |                             155 |          1 |
|  58 | torops@cccfr.de                                                       |                             155 |          2 |
|  59 | Lejo 1@web.de                                                         |                             152 |          2 |
|  60 | tor dot relay dot edc /at/ danwin1210 dot de                          |                             151 |          3 |
|  61 | jaysen@fr4me.io                                                       |                             151 |          2 |
|  62 | torproject at telekobold dot de                                       |                             149 |          2 |
|  63 | &lt;hodor2022@gmail.com&gt;                                           |                             145 |          1 |
|  64 | truetrup@gmail.com                                                    |                             143 |          1 |
|  65 | bartleby tor@protonmail.com                                           |                             143 |          3 |
|  66 | &lt;jomo@masters-of-cloud.de&gt;                                      |                             142 |          1 |
|  67 | Pontazzicadenti@lovecat.com                                           |                             139 |          1 |
|  68 | avaet1iriejai9duv6aj at gmail dot com tor-relay.co                    |                             139 |          2 |
|  69 | 0xa1&lt;:at:&gt;mailbox&lt;:dot:&gt;org                               |                             135 |          2 |
|  70 | ZombieComputers@Outlook.Com                                           |                             132 |          2 |
|  71 | arnab@moonward.net                                                    |                             131 |          1 |
|  72 | &lt;address@blackw.id.com&gt;                                         |                             130 |          1 |
|  73 | vermonixa@ rem proton.me                                              |                             130 |          2 |
|  74 | WebTunnel email: a78i2efsewr0neeknk@proton.me ciissversion:2          |                             129 |          2 |
|  75 | Federation High Court &lt;gewandung-delfin-02@icloud.com&gt;          |                             126 |          1 |
|  76 | Tor-Admins &lt;toooor AT all DOT de&gt;                               |                             126 |          5 |
|  77 | xBTWutUkIk4T0up8Lawe@dispostable.com                                  |                             124 |          1 |
|  78 | service-tor@sd.ai                                                     |                             124 |          1 |
|  79 | &lt;tomlig@yandex.ru&gt;                                              |                             123 |          2 |
|  80 | oskar AT oskar MINUS roesler DOT de                                   |                             122 |          1 |
|  81 | padre@proton.me                                                       |                             120 |          1 |
|  82 | &lt;poerava atsymbol freemail.com&gt;                                 |                             120 |          1 |
|  83 | &lt;hello@dbatley.com&gt;                                             |                             116 |          1 |
|  84 | tor@opentree.cz                                                       |                             116 |          2 |
|  85 | tellmemore@inbox.lv                                                   |                             116 |          1 |
|  86 | &lt;ph.ilippelatuli.petb@protonmail.com&gt;                           |                             115 |          2 |
|  87 | beehiiv.47ph3@passmail.net                                            |                             114 |          1 |
|  88 | &lt;kaveh atsymbol outlook.com&gt;                                    |                             113 |          1 |
|  89 | admin@tor-relay.utilizer.de                                           |                             113 |          6 |
|  90 | anonymous15@tutamail.com                                              |                             112 |          1 |
|  91 | admin@prsv.ch                                                         |                             111 |          1 |
|  92 | torbridge avas AT manchester DOT gr                                   |                             111 |          1 |
|  93 | &lt;irate dot wronged456 at 4wrd.cc&gt;                               |                             111 |          1 |
|  94 | tor@theyosh.nl                                                        |                             109 |          1 |
|  95 | tornodescontact1.envelope270 AT passinbox dot com                     |                             107 |          1 |
|  96 | rhlhrgle76@gmail.com                                                  |                             106 |          1 |
|  97 | D562F2BF4E3702A723DEDB3D3D103B6BDF0274B6                              |                             106 |          1 |
|  98 | &lt;mj gill 89@hotmail.com&gt;                                        |                             106 |          1 |
|  99 | nobody@example.com                                                    |                             106 |          2 |
| 100 | anime.girl@ahegao.party                                               |                             106 |          1 |
| 101 | &lt;SQPajCUF7tNE@i2pmail.org&gt;                                      |                             105 |          1 |
| 102 | arole@protonmail.com                                                  |                             105 |          1 |
| 103 | d7nsitzadtxcvybh@sinenomine.email                                     |                             104 |          1 |
| 104 | &lt;friends know how to contact me&gt;                                |                             104 |          2 |
| 105 | Marc &lt;marcfleck AT free dot fr&gt;                                 |                             104 |          1 |
| 106 | &lt;info@ebenefuenf.de&gt;                                            |                             104 |          1 |
| 107 | tor-relay@zug.si                                                      |                             104 |          1 |
| 108 | sleuthy@gmail.com                                                     |                             103 |          2 |
| 109 | &lt;plhk@sdf.org&gt;                                                  |                             103 |          1 |
| 110 | contact@nearlydone.press                                              |                             103 |          1 |
| 111 | reply@mynetblog.com                                                   |                             102 |          1 |
| 112 | tor bridge.passable513@slmail.me                                      |                             102 |          1 |
| 113 | always@befreeon.net                                                   |                             102 |          2 |
| 114 | example@exmple.com                                                    |                             101 |          2 |
| 115 | robin@haberecht.org                                                   |                             101 |          2 |
| 116 | thomthom33@free.fr                                                    |                             100 |          1 |
| 117 | Random Person &lt;pv1exxrw@anonaddy.me&gt;                            |                              98 |          1 |
| 118 | wyke &lt;at&gt; lighthouse &lt;dot&gt; my dot id                      |                              98 |          4 |
| 119 | swift.koala4926@fastmail.com                                          |                              98 |          1 |
| 120 | tor@aaronb.cc                                                         |                              96 |          2 |
| 121 | &lt;matthew findley@hotmail.com&gt;                                   |                              96 |          1 |
| 122 | jens@anonymitaet-im-inter.net                                         |                              96 |          1 |
| 123 | systemli &lt;t o r - e x i t .AT. s y s t e m l i DOT o r g&gt;       |                              96 |          1 |
| 124 | tech@altertek.org                                                     |                              96 |          1 |
| 125 | kalpalwolf@protonmail.com                                             |                              94 |          1 |
| 126 | nqq0xztx@duck.com                                                     |                              94 |          1 |
| 127 | sorry@no.com                                                          |                              94 |          1 |
| 128 | My Privacy DNS &lt;mypdnstor AT danwin1210 d0t de&gt;                 |                              93 |          1 |
| 129 | tor-contact &lt;at&gt; behringer &lt;dot&gt; me                       |                              93 |          1 |
| 130 | docker1@email.en                                                      |                              93 |          1 |
| 131 | no@email.com                                                          |                              92 |          2 |
| 132 | beat@it                                                               |                              91 |          1 |
| 133 | &lt;sventor@stormbind.net&gt;                                         |                              91 |          1 |
| 134 | freiraum TK AT protonmail DOT ch                                      |                              90 |          1 |
| 135 | m5fdcv8phk1imfo@seznam.cz                                             |                              90 |          1 |
| 136 | noemail                                                               |                              90 |          1 |
| 137 | Random Person &lt;nobody AT example dot com&gt;                       |                              90 |          4 |
| 138 | 0x91E6C85892ADF482 jmjl &lt;tor AT tilde DOT green&gt;                |                              89 |          1 |
| 139 | 0xEFF5B2E180F294CE - &lt;caioau underscore tor at riseup dot ne       |                              89 |          3 |
| 140 | &lt;torbridge-fout.re@proton.me&gt;                                   |                              89 |          1 |
| 141 | quail 09feeders@icloud.com                                            |                              89 |          1 |
| 142 | doubtTrouble@onionmail.org                                            |                              88 |          1 |
| 143 | &lt;karen at p.izza.party&gt;                                         |                              88 |          3 |
| 144 | 0x010BBAC502ECA3159A4BD6161CD3142065E93086 Siddhartha &lt;siddh       |                              88 |          2 |
| 145 | Tor Bridge &lt;tor-bridge AT skeps DOT ch&gt;                         |                              88 |          2 |
| 146 | admin@wsquarepa.com                                                   |                              88 |          1 |
| 147 | toroperator1776@protonmail.com                                        |                              88 |          1 |
| 148 | temmyhurstREMOVETHIS@outlook.com                                      |                              88 |          2 |
| 149 | matthew.labuda@proton.me                                              |                              87 |          2 |
| 150 | lckz4zku1@mozmail.com                                                 |                              87 |          1 |
| 151 | gerontius@tuta.io                                                     |                              87 |          1 |
| 152 | ziggie1984@protonmail.com                                             |                              87 |          1 |
| 153 | kahjs2007@gmail.com                                                   |                              87 |          1 |
| 154 | tor.q55nr@simplelogin.com                                             |                              86 |          1 |
| 155 | elpajaroeslaclave@gmail.com                                           |                              86 |          1 |
| 156 | email:tor dzwdz.net url:not.dzwdz.net proof:uri-rsa ciissve           |                              86 |          3 |
| 157 | &lt;7ooooo2 at tuta dot io&gt;                                        |                              85 |          1 |
| 158 | elias@evzg.se                                                         |                              85 |          5 |
| 159 | tor at skatnet.de                                                     |                              85 |          1 |
| 160 | tor at 0x2142 dot net - bitcoin:BC1QS45FKEUNQWZUK9WTPZYVETE2          |                              85 |          6 |
| 161 | support @ duscha . dev                                                |                              85 |          1 |
| 162 | xtgts24j@duck.com                                                     |                              84 |          1 |
| 163 | newyorkstarling@nym.hush.com                                          |                              84 |          1 |
| 164 | I S &lt;tor AT t01 DOT s-ix DOT net&gt;                               |                              83 |          1 |
| 165 | torbraeu@riseup.net                                                   |                              83 |          1 |
| 166 | democratiam &lt;democratiam.vw5fh@8shield.net&gt;                     |                              83 |          2 |
| 167 | vovakozlovskiy@yandex.ru                                              |                              83 |          1 |
| 168 | 2b7d8fb991@sinenomine.email                                           |                              83 |          1 |
| 169 | &lt;srick@senckenberg.de&gt;                                          |                              82 |          1 |
| 170 | &lt;tor-relay@fbslo.net&gt;                                           |                              82 |          1 |
| 171 | mail@mail.net                                                         |                              82 |          1 |
| 172 | martijn.baaytorproject@gmail.com                                      |                              82 |          1 |
| 173 | simonstrutt@strutt.org.uk                                             |                              82 |          1 |
| 174 | Ian Kumlien &lt;ian.kumlien@gmail.com&gt;                             |                              81 |          1 |
| 175 | g30g43br4 at protonmail.com                                           |                              81 |          1 |
| 176 | Tor Guard &lt;torguard@thetube.ch&gt;                                 |                              81 |          1 |
| 177 | 0x4471de61 Senf &lt;tor AT senf dot space&gt;                         |                              81 |          1 |
| 178 | post@trbr.anonaddy.com                                                |                              81 |          2 |
| 179 | codingdodo@protonmail.com                                             |                              81 |          1 |
| 180 | email:tor-bridge mzgszm.com pgp:ACB8A4426995D37EC2B9A9CA7CF           |                              80 |          1 |
| 181 | ktchvsbr2@gmail.com                                                   |                              79 |          1 |
| 182 | isodiapher /at/ movim / eu xmpp ad9c85ac 5aded378 8fee04              |                              79 |          1 |
| 183 | tor.ageless854@passinbox.com                                          |                              78 |          1 |
| 184 | 0x3632046A Dmitry &lt;dbaryshkov@gmail.com&gt;                        |                              78 |          1 |
| 185 | &lt;blackynet@web.de&gt;                                              |                              77 |          1 |
| 186 | s8472@outlook.com                                                     |                              77 |          1 |
| 187 | email:torix@protonmail.com url:https://torix-relays.org proo          |                              77 |          3 |
| 188 | tor-relaysailingSea@herocc.com                                        |                              77 |          1 |
| 189 | artemisort23 at proton dot me                                         |                              76 |          1 |
| 190 | &lt;fl4co@fl4co.net&gt;                                               |                              76 |          1 |
| 191 | schweinehund@onionmail.info                                           |                              76 |          1 |
| 192 | henry.woodler@protonmail.com                                          |                              76 |          1 |
| 193 | better.day@seznam.cz                                                  |                              75 |          1 |
| 194 | Petzi &lt;cmVsYXktb3BlcmF0b3JAYXNjaWlhbmRodXRjaC5iZQ==&gt;            |                              75 |          1 |
| 195 | &lt;tor@ludost.net&gt;                                                |                              75 |          1 |
| 196 | microfab899@protonmail.com                                            |                              74 |          1 |
| 197 | tor@gnuproject.org                                                    |                              74 |          2 |
| 198 | email:tor-man BogoLinux.net url:https://bogolinux.net proof           |                              73 |          1 |
| 199 | maIDor &lt;alt dot gi-5oif2qye AT yopmail dot com&gt;                 |                              73 |          1 |
| 200 | armel@broquet.ovh                                                     |                              72 |          1 |
| 201 | admin-tor@netc.eu                                                     |                              72 |          1 |
| 202 | arnim@posteo.de                                                       |                              72 |          1 |
| 203 | indot pointedness@aleeas.com                                          |                              71 |          2 |
| 204 | tor bridge@subset.ch                                                  |                              71 |          1 |
| 205 | tor@linuxawy.org                                                      |                              71 |          1 |
| 206 | info &lt;at&gt; notarealdomain &lt;dot&gt; net                        |                              70 |          1 |
| 207 | tor@b717.dev                                                          |                              70 |          2 |
| 208 | tor@eerie-indiana.uk                                                  |                              70 |          1 |
| 209 | robotor                                                               |                              70 |          1 |
| 210 | 0xF307F7EC780B8D59003108A911F8AC24015F093D Horst &lt;horst@agor       |                              70 |          1 |
| 211 | josh thecybers.net                                                    |                              70 |          2 |
| 212 | torroot@essignetz.de                                                  |                              69 |          1 |
| 213 | blobster@tuta.io                                                      |                              69 |          1 |
| 214 | info@quantentoast.de                                                  |                              69 |          1 |
| 215 | mr.james.doe@gmail.com                                                |                              69 |          1 |
| 216 | lnxredir@tuta.io                                                      |                              69 |          1 |
| 217 | do-contact AT riseup DOT net                                          |                              69 |          1 |
| 218 | contact@ronaak.eu                                                     |                              68 |          1 |
| 219 | mohammad &lt;m0han AT pm dot me&gt;                                   |                              67 |          1 |
| 220 | ash@ashmcbri.de                                                       |                              67 |          1 |
| 221 | hi@cloudybyte.net                                                     |                              67 |          1 |
| 222 | test@test.com                                                         |                              66 |          1 |
| 223 | dummy ema1l for secur1ty purposes 1@outlook.com                       |                              66 |          1 |
| 224 | tor at zyron dot de                                                   |                              66 |          1 |
| 225 | dino-tor@syring.name                                                  |                              66 |          1 |
| 226 | &lt;ryanong@gmail.com&gt;                                             |                              65 |          1 |
| 227 | anonymousfyf@gmail.com                                                |                              65 |          1 |
| 228 | armando@esiliati.org                                                  |                              65 |          1 |
| 229 | Rhys RE -- me at rhysre dot net                                       |                              65 |          1 |
| 230 | badgerfighter at proton dot me                                        |                              65 |          2 |
| 231 | kl4rx &lt;kl4rx@onionmail.org&gt;                                     |                              64 |          2 |
| 232 | rmp1                                                                  |                              64 |          1 |
| 233 | &lt;newyorkswoodpecker@nym.hush.com&gt;                               |                              64 |          1 |
| 234 | sam.hadow@inbox.lv                                                    |                              64 |          1 |
| 235 | tor-operator@dcsl.dk                                                  |                              64 |          1 |
| 236 | david@fife.cc                                                         |                              63 |          1 |
| 237 | tor@lahfa.xyz                                                         |                              63 |          1 |
| 238 | &lt;tor@shalmirane.com&gt;                                            |                              63 |          2 |
| 239 | miratytor@antopie.org                                                 |                              62 |          1 |
| 240 | info@zettlr.com                                                       |                              62 |          1 |
| 241 | &lt;numlock-lqhtor@pm.me&gt;                                          |                              62 |          1 |
| 242 | potlatch proton me                                                    |                              62 |          3 |
| 243 | Webmaster &lt;webmaster@linuxpourtous.com&gt;                         |                              61 |          1 |
| 244 | &lt; address @email.com&gt;                                           |                              61 |          1 |
| 245 | theisgroenbech@pm.me                                                  |                              61 |          1 |
| 246 | E-Mail: mthiru protonmail com                                         |                              61 |          1 |
| 247 | &lt;smtor@khjk.org&gt;                                                |                              61 |          1 |
| 248 | torbridge nafplio AT manchester DOT gr                                |                              61 |          1 |
| 249 | c.scholz@c-s-media.net                                                |                              61 |          1 |
| 250 | Johan Debourg &lt;uneadresseemail -arobaz- riseup net&gt;             |                              61 |          1 |
| 251 | prokopparuzek@protonmail.com                                          |                              61 |          1 |
| 252 | noone@nowhere.com                                                     |                              61 |          1 |
| 253 | fuzzduzter2008@yahoo.com                                              |                              60 |          2 |
| 254 | Brandon Kuschel &lt;kusch023 AT NOSPAM umn dot edu&gt;                |                              60 |          1 |
| 255 | splurge3810@proton.me                                                 |                              60 |          1 |
| 256 | striderghost@mail.ru                                                  |                              60 |          1 |
| 257 | user@localhost                                                        |                              60 |          1 |
| 258 | Andreas Kempe &lt;tor@kempe.user.lysator.liu.se&gt;                   |                              60 |          1 |
| 259 | Random Person stephane.dewitte@protonmail.com                         |                              59 |          1 |
| 260 | tor@snehankekre.com                                                   |                              59 |          1 |
| 261 | Olafur &lt;olafuringvason@posteo.is&gt;                               |                              59 |          1 |
| 262 | &lt;athena202202 AT gmail dot com&gt;                                 |                              59 |          1 |
| 263 | Atlas Admin &lt;root AT atlas dot uniri dot hr&gt;                    |                              59 |          1 |
| 264 | b6 DOT redacted AT protonmail DOT ch                                  |                              59 |          1 |
| 265 | &lt;torrelay@incense.org&gt;                                          |                              59 |          1 |
| 266 | contact@webplayground.fr                                              |                              58 |          1 |
| 267 | &lt;anonymous@server&gt;                                              |                              58 |          1 |
| 268 | admintor@pinkbyte.ru                                                  |                              58 |          1 |
| 269 | iordanov@ognjan.de                                                    |                              58 |          1 |
| 270 | email:tormaster nerdreich.de btc:1Ma9whLg6U5HDBUPDmH82W5rbp           |                              58 |          1 |
| 271 | jjones102794@gmail.com                                                |                              58 |          1 |
| 272 | 0xFF6A449EE1FA1DE687D88DC508D96F76CA4E11C7 Philipp Richter &lt;       |                              58 |          1 |
| 273 | &lt;quick DOT hope9185 AT aenomie DOT com&gt;                         |                              58 |          1 |
| 274 | Alexander Faeroey &lt;ahf@0x90.dk&gt;                                 |                              57 |          4 |
| 275 | circl.lu &lt;info AT circl dot lu&gt;                                 |                              57 |          1 |
| 276 | tor@rondie.nl                                                         |                              56 |          8 |
| 277 | &lt;robertwinkler@posteo.net&gt;                                      |                              56 |          1 |
| 278 | snoopeh AT gmail DOT com                                              |                              56 |          1 |
| 279 | worldgate-relays AT protonmail DOT com                                |                              56 |          1 |
| 280 | bigDICK28sm                                                           |                              56 |          1 |
| 281 | email:jens kubieziel.de url:https://kubieziel.de/ proof:uri           |                              56 |          1 |
| 282 | &lt;mineniko@gmail.com&gt;                                            |                              56 |          1 |
| 283 | tor@fletch.blue                                                       |                              56 |          1 |
| 284 | bytebobatsidereadotnl                                                 |                              56 |          1 |
| 285 | jjskoli@gmail.com                                                     |                              56 |          1 |
| 286 | tor-node operator &lt;tor-node AT collective DASH b DOT org DOT       |                              56 |          2 |
| 287 | nonvalid@email.com                                                    |                              56 |          1 |
| 288 | &lt;shitpisscum@cock.li&gt;                                           |                              55 |          1 |
| 289 | obfs4@matb.se                                                         |                              55 |          1 |
| 290 | tor@dazeilad.eu                                                       |                              55 |          1 |
| 291 | torbridge4@ki9.gf4.pw                                                 |                              55 |          1 |
| 292 | &lt;deneb atsymbol outlook.com&gt;                                    |                              55 |          1 |
| 293 | your@email.org                                                        |                              55 |          2 |
| 294 | tor-rueeblitorte &lt;you know what belongs here&gt; mmap &lt;and here |                              54 |          1 |
| 295 | mendeleev AT riseup.net                                               |                              54 |          3 |
| 296 | tor@wonk.org                                                          |                              54 |          1 |
| 297 | Damn these things are expensive &lt;3 tordel-network@protonmai        |                              54 |          1 |
| 298 | devnull@void.com                                                      |                              54 |          1 |
| 299 | noone@noone.no                                                        |                              54 |          1 |
| 300 | torproject.heroics014@passmail.net                                    |                              53 |          1 |
| 301 | theporcelainkaiser@lortemail.dk                                       |                              53 |          1 |
| 302 | wurli@tutanota.com                                                    |                              53 |          1 |
| 303 | nlyh72g5@duck.com                                                     |                              53 |          1 |
| 304 | alberto@casetta.co.uk                                                 |                              53 |          1 |
| 305 | ContactInfo voqelfrei &lt;tor voqel AT pm me&gt; pgp:8018FA5B9E760    |                              52 |          1 |
| 306 | 0x18FFB9259E11C3BC69ABC8857E65272B32D3C971 f19.4jbg3@gmail.c          |                              52 |          2 |
| 307 | admin@mnlab.xyz                                                       |                              52 |          1 |
| 308 | email:o6267097 gmail.com uplinkbw:200 ciissversion:2                  |                              52 |          2 |
| 309 | torbridge@07f.de                                                      |                              52 |          1 |
| 310 | nezu@nezu.cc                                                          |                              52 |          2 |
| 311 | poiasdpoiasd@live.com                                                 |                              52 |          1 |
| 312 | &lt;fgiyhw4ur@outlook.com&gt;                                         |                              52 |          1 |
| 313 | goofy at d1sn3y dot com                                               |                              52 |          1 |
| 314 | someone at somehost dot com                                           |                              51 |          1 |
| 315 | papworth solio@aleeas.com                                             |                              51 |          1 |
| 316 | breakersinc@secmail.pro                                               |                              51 |          1 |
| 317 | torhelper@proton.me                                                   |                              51 |          1 |
| 318 | email@example.ltd                                                     |                              51 |          1 |
| 319 | &lt;radek.mazar@gmail.com&gt;                                         |                              51 |          1 |
| 320 | hism00m@disroot.org                                                   |                              51 |          1 |
| 321 | tor@schmidtie.net                                                     |                              50 |          1 |
| 322 | fred@dead.com                                                         |                              50 |          1 |
| 323 | SorentoAR@protonmail.com                                              |                              50 |          1 |
| 324 | &lt;toad@schloop.win&gt;                                              |                              50 |          1 |
| 325 | tor@engelseruiter.nl                                                  |                              50 |          1 |
| 326 | &lt;hans@hjbaader.de&gt;                                              |                              50 |          1 |
| 327 | tor@pusit.ph                                                          |                              50 |          1 |
| 328 | domitor@secnd.me                                                      |                              50 |          1 |

<div class="datatable-end"></div>

**Bridge Transports Distribution**

<div class="datatable-begin"></div>

| Supported Transports    |   Bridges |
|:------------------------|----------:|
| obfs4                   |      1406 |
| None                    |       291 |
| webtunnel               |       195 |
| obfs3, obfs4            |        23 |
| obfs4, webtunnel        |         4 |
| meek                    |         2 |
| obfs3                   |         2 |
| obfs4, obfs4            |         2 |
| obfs2, obfs3, obfs4     |         1 |
| obfs3, obfs4, webtunnel |         1 |
| snowflake               |         1 |

<div class="datatable-end"></div>



## Tor Relay Operators in End-to-End Correlation Position

The following table lists relay operators that are in a position to see a tor client's entry and exit connections.
In the **worst-case a tor client would use these groups as entry (guard) and exit relay at the same time.**

Operators are only listed if they actually have a chance to do end-to-end correlation attacks, that is:
* their guard **and** exit probability is > 0%
* they did **not** properly configure MyFamily
* they run in **more** than a single /16 network block

This list might contain false-positives as ContactInfo is not authenticated.

The ContactInfo is truncated. Middle-only relays are not included in per-group relaycounts.

The table is sorted by guard probability.

<div class="datatable-begin"></div>

| Contact                                                                                                                     | Guard (%)   | Exit (%)   | #Relays   | /16 Netblocks   | Newest Relay   | Eff. Family Members (min)   |
|:----------------------------------------------------------------------------------------------------------------------------|:------------|:-----------|:----------|:----------------|:---------------|:----------------------------|
| [email:Quetzalcoatl relays proton.me url:https://q](endtoend-correlation-groups#emailquetzalcoatlrelaysprotonme-urlhttpsq)  | 0.91        | 8.79       | 406       | 20              | 2024-12-18     | 8                           |
| [your@e-mail](endtoend-correlation-groups#youre-mail)                                                                       | 0.06        | 0.22       | 6         | 6               | 2024-11-04     | 1                           |
| [5h098y32 at duck . com](endtoend-correlation-groups#5h098y32-at-duckcom)                                                   | 0.05        | 0.01       | 3         | 3               | 2024-08-28     | 1                           |
| [email:denny.obreham a-n-o-n-y-m-e.net url:https:/](endtoend-correlation-groups#emaildennyobrehama-n-o-n-y-m-enet-urlhttps) | 0.05        | 0.39       | 18        | 18              | 2024-10-26     | 1                           |
| **Total**                                                                                                                   | **1.07**    | **9.41**   | **433**   |                 |                |                             |

<div class="datatable-end"></div>

For a detailed list of (known) relays in end-to-end correlation position see **[this page](endtoend-correlation-groups)**.

**NOTE:** There are many more relays with
MyFamily configuration issues but most operate exit or guard relays
exclusively or within a single /16 network block. Such operators can not become the first **and** last hop of your tor circuits,
but they might be able to reveal your guard relay (when they act as the middle and exit relay in a single circuit).

## Likely Misconfigured Families

This table shows likely misconfigured families. This is detected by looking for relays where the amount of relays
with a given contactInfo is higher than the amount of members in a relay's effective family.

The "Famstats" column shows two counters: a/b.

* a: The lowest effective family member count within a relay group using this ContactInfo
* b: The total amount of relays using this ContactInfo

<div class="datatable-begin"></div>

| Contact                                                                                                                       | Famstats   |   Guard(%) |   Exit(%) | First Seen   |
|:------------------------------------------------------------------------------------------------------------------------------|:-----------|-----------:|----------:|:-------------|
| [abuse@srstubes.com](w/contact/3f14a7576fef65dae4233754c29611cb)                                                              | 1/5        |        0.1 |       0   | 2025-01-06   |
| [darmstadt@fridaysforfuture.de](w/contact/e4b03185c5e1cd08de49d2b4b1e05fa6)                                                   | 1/5        |        0.2 |       0   | 2024-11-07   |
| [mikael datanerd.se](w/contact/2064ffecb466709f86293059dc545c85)                                                              | 5/22       |        0.1 |       1   | 2024-10-19   |
| [dev.null@kryptonit.org](w/contact/43ab202b92e0e1c77ce787984b9247e2)                                                          | 1/5        |        0.1 |       0   | 2024-09-29   |
| [Sponsored by https://tor.foundation](w/contact/b64d62e0383a7b3e3e68b1d917bf501f)                                             | 1/28       |        0.7 |       0   | 2024-07-19   |
| [0x88888888 Ole Tange &lt;ole@tange.dk&gt;](w/contact/6003d55e7b0ac55021e4fa2e2bb3e270)                                       | 1/2        |        0.1 |       0   | 2024-06-16   |
| [&lt;private&gt;](w/contact/c148595277f0538d6e7c5e4cf01d66a0)                                                                 | 1/2        |        0.1 |       0   | 2024-03-11   |
| [email:xonumi protonmail.ch url:xonumi.com proof:dns-rsa abuse:xonumi protonmai](w/contact/c1cb08961e1d6817477cb9c73ddabf8e)  | 2/5        |        0.1 |       0   | 2024-01-15   |
| [5h098y32 at duck.com](w/contact/8320f36aaf71acc6986cdd740493dc35)                                                            | 1/3        |        0.2 |       0   | 2023-06-21   |
| [email:denny.obreham a-n-o-n-y-m-e.net url:https://a-n-o-n-y-m-e.net proof:uri-r](w/contact/dae95e54b345f1cc4a1362bfcae626f3) | 1/18       |        0   |       0.3 | 2023-03-25   |
| [mentor@palokaj.co](w/contact/8499e56a3459b8820315ff2121e397ae)                                                               | 1/8        |        0   |       0.5 | 2023-03-22   |
| [Random Person nobody@tor.org](w/contact/11b235d30ab012cf3c2b968cb5dfbcb1)                                                    | 1/19       |        0.1 |       0   | 2023-01-28   |
| [email:support torservers.net url:https://torservers.net/ proof:uri-rsa abuse:ab](w/contact/97c5db8b15e501780112554fd572e99e) | 1/2        |        0   |       0.1 | 2023-01-08   |
| [tor-operator@theu.li](w/contact/43a509f2ee80dad6052d755f8897e632)                                                            | 1/11       |        0.3 |       0   | 2022-12-31   |
| [tornode2022@protonmail.com](w/contact/5f860de0ce8adc1dacddea82bb214b4a)                                                      | 1/7        |        0   |       0.1 | 2022-10-10   |
| [gus@riseup.net](w/contact/2d05e90e10f0f55fc284db0447d0c175)                                                                  | 1/28       |        0.6 |       0   | 2022-08-31   |
| [Mi Gibtsdonet &lt;nobody AT example dot com&gt;](w/contact/1ddbd1df64b5a10bf160d2bfb14462aa)                                 | 1/5        |        0.1 |       0   | 2022-05-23   |
| [your@e-mail](w/contact/c2987c438d3cf03610c35c305e206e48)                                                                     | 1/17       |        0   |       0.2 | 2022-04-23   |
| [email:torrelay limoneneis.de url:limoneneis.de proof:uri-rsa pgp:7BF6A4C298CC27](w/contact/7f469543917f6349ad80acddadfe8e5f) | 11/14      |        0.5 |       0   | 2022-01-26   |
| [email:Quetzalcoatl relays proton.me url:https://quetzalcoatl-relays.org proof:u](w/contact/b32573fcfbc780a4b9ef03425f676400) | 8/406      |        0.9 |       8.7 | 2020-11-08   |
| [url:relayon.org proof:uri-rsa abuse:abuse relayon.org ciissversion:2](w/contact/4c56757b4d4929a48b7f325b69510b01)            | 1/113      |        1.5 |       1.4 | 2020-10-19   |
| [email:usura sabotage.org url:https://sabotage.net proof:uri-rsa abuse:abuse sa](w/contact/1c0e39b98752aae9b440530adb45eab9)  | 1/6        |        0   |       0.4 | 2019-02-18   |
| [Vasil Kolev &lt;tor@ludost.net&gt;](w/contact/fe1f0d3cb9f17cdc717a90531352380a)                                              | 1/2        |        0.1 |       0   | 2019-02-18   |
| [2048R/B640BF1A Tor Relay &lt;tor AT sec dot nl&gt;](w/contact/d25552a4aa28463a77ceacfa9163aa17)                              | 1/2        |        0.2 |       0   | 2019-02-18   |

<div class="datatable-end"></div>



## Data Source

OrNetStats uses public data provided by The Tor Project:
* [Onionoo](https://metrics.torproject.org/onionoo.html)
* [CollecTor](https://metrics.torproject.org/collector.html)

